(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   1118009,      22219]
NotebookOptionsPosition[   1114767,      22114]
NotebookOutlinePosition[   1115178,      22130]
CellTagsIndexPosition[   1115135,      22127]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["Evading Derrick\[CloseCurlyQuote]s Theorem in curved space: Static \
metastable spherical domain wall",
  FontSize->36,
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox["\n",
  FontSize->36],
 StyleBox["(Figures File)",
  FontSize->18]
}], "Title",
 CellChangeTimes->{{3.7569086626900234`*^9, 3.756908739523151*^9}, {
  3.7569087901976547`*^9, 3.7569088727050858`*^9}, {3.756920485385234*^9, 
  3.756920498452719*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Grid Plot Module ",
 FontSize->18]], "Section",
 CellChangeTimes->{{3.7569088902980876`*^9, 3.756908905181097*^9}, {
  3.756908939206375*^9, 3.7569089614477816`*^9}},
 Background->RGBColor[0., 1., 0.]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "It", " ", "is", " ", "used", " ", "to", " ", "join", " ", "multiple", " ",
     "plots", " ", "together", " ", "with", " ", "a", " ", "common", " ", 
    "axis", " ", "\"\<ALWAYS RUN FIRST!!\>\""}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Options", "[", "plotGrid", "]"}], "=", 
     RowBox[{"{", 
      RowBox[{"ImagePadding", "\[Rule]", "40"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"plotGrid", "[", 
     RowBox[{"l_List", ",", "w_", ",", "h_", ",", 
      RowBox[{"opts", ":", 
       RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"nx", ",", "ny", ",", 
        RowBox[{"sidePadding", "=", 
         RowBox[{"OptionValue", "[", 
          RowBox[{"plotGrid", ",", "ImagePadding"}], "]"}]}], ",", 
        RowBox[{"topPadding", "=", "0"}], ",", "widths", ",", "heights", ",", 
        "dimensions", ",", "positions", ",", 
        RowBox[{"frameOptions", "=", 
         RowBox[{"FilterRules", "[", 
          RowBox[{
           RowBox[{"{", "opts", "}"}], ",", 
           RowBox[{"FilterRules", "[", 
            RowBox[{
             RowBox[{"Options", "[", "Graphics", "]"}], ",", 
             RowBox[{"Except", "[", 
              RowBox[{"{", 
               RowBox[{"ImagePadding", ",", "Frame", ",", "FrameTicks"}], 
               "}"}], "]"}]}], "]"}]}], "]"}]}]}], "}"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"ny", ",", "nx"}], "}"}], "=", 
        RowBox[{"Dimensions", "[", "l", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"widths", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"w", "-", 
            RowBox[{"2", " ", "sidePadding"}]}], ")"}], "/", "nx"}], " ", 
         RowBox[{"Table", "[", 
          RowBox[{"1", ",", 
           RowBox[{"{", "nx", "}"}]}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"widths", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "=", 
        RowBox[{
         RowBox[{"widths", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "+", "sidePadding"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"widths", "[", 
         RowBox[{"[", 
          RowBox[{"-", "1"}], "]"}], "]"}], "=", 
        RowBox[{
         RowBox[{"widths", "[", 
          RowBox[{"[", 
           RowBox[{"-", "1"}], "]"}], "]"}], "+", "sidePadding"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"heights", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"h", "-", 
            RowBox[{"2", " ", "sidePadding"}]}], ")"}], "/", "ny"}], " ", 
         RowBox[{"Table", "[", 
          RowBox[{"1", ",", 
           RowBox[{"{", "ny", "}"}]}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"heights", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "=", 
        RowBox[{
         RowBox[{"heights", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "+", "sidePadding"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"heights", "[", 
         RowBox[{"[", 
          RowBox[{"-", "1"}], "]"}], "]"}], "=", 
        RowBox[{
         RowBox[{"heights", "[", 
          RowBox[{"[", 
           RowBox[{"-", "1"}], "]"}], "]"}], "+", "sidePadding"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"positions", "=", 
        RowBox[{"Transpose", "@", 
         RowBox[{"Partition", "[", 
          RowBox[{
           RowBox[{"Tuples", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Prepend", "[", 
               RowBox[{
                RowBox[{"Accumulate", "[", 
                 RowBox[{"Most", "[", "#", "]"}], "]"}], ",", "0"}], "]"}], 
              "&"}], "/@", 
             RowBox[{"{", 
              RowBox[{"widths", ",", "heights"}], "}"}]}], "]"}], ",", "ny"}],
           "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Graphics", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Show", "[", 
              RowBox[{
               RowBox[{"l", "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{"ny", "-", "j", "+", "1"}], ",", "i"}], "]"}], 
                "]"}], ",", 
               RowBox[{"ImagePadding", "\[Rule]", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"i", "\[Equal]", "1"}], ",", "sidePadding", ",", 
                    "0"}], "]"}], ",", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"i", "\[Equal]", "nx"}], ",", "sidePadding", ",", 
                    "0"}], "]"}]}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"j", "\[Equal]", "1"}], ",", "sidePadding", ",", 
                    "0"}], "]"}], ",", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"j", "\[Equal]", "ny"}], ",", "sidePadding", ",", 
                    "topPadding"}], "]"}]}], "}"}]}], "}"}]}], ",", 
               RowBox[{"AspectRatio", "\[Rule]", "Full"}]}], "]"}], ",", 
             RowBox[{"positions", "[", 
              RowBox[{"[", 
               RowBox[{"j", ",", "i"}], "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"Left", ",", "Bottom"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"widths", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", 
               RowBox[{"heights", "[", 
                RowBox[{"[", "j", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "nx"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", "ny"}], "}"}]}], "]"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "w"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "h"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"ImageSize", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"w", ",", "h"}], "}"}]}], ",", 
         RowBox[{"Evaluate", "@", 
          RowBox[{"Apply", "[", 
           RowBox[{"Sequence", ",", "frameOptions"}], "]"}]}]}], "]"}]}]}], 
     "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SetDirectory", "[", 
     RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.756908911498969*^9, 3.7569089240012417`*^9}, {
  3.7569101859629974`*^9, 3.7569102004013505`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Figure 1",
 FontSize->18,
 FontWeight->"Bold"]], "Section",
 CellChangeTimes->{{3.7563803471240826`*^9, 3.75638039116936*^9}, {
   3.7568978368786745`*^9, 3.756897859463026*^9}, 3.7569033692434664`*^9, {
   3.756909062227412*^9, 3.756909084466393*^9}},
 Background->RGBColor[0., 1., 1.]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Plot", " ", "of", " ", "three", " ", "different", " ", "behaviours", " ", 
    "of", " ", "the", " ", "metric", " ", "and", " ", "their", " ", "field", 
    " ", "configurations"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"b", ",", "ll"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"b", "=", 
     RowBox[{"-", "0.24"}]}], ";", " ", 
    RowBox[{"ll", "=", 
     RowBox[{"-", "0.2"}]}], ";", 
    RowBox[{"m", "=", "0.23"}], ";", 
    RowBox[{"(*", 
     RowBox[{
     "parameters", " ", "leading", " ", "to", " ", "a", " ", "stable", " ", 
      "solution"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"gr", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "m", " ", "r"}], "+", 
      RowBox[{"r", "^", "2"}], "+", 
      RowBox[{"2", " ", "b", " ", 
       RowBox[{"r", "^", "3"}]}], " ", "-", " ", 
      RowBox[{"ll", " ", 
       RowBox[{
        RowBox[{"r", "^", "4"}], " ", "/", "3"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"plgr1", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{"gr", ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "0", ",", "4.2"}], "}"}], ",", " ", 
       RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "Dashed"}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", " ", 
        RowBox[{"{", 
         RowBox[{
         "\"\<r\>\"", ",", 
          "\"\<\!\(\*SuperscriptBox[\(r\), \(2\)]\)f(r)\>\""}], "}"}]}], ",", 
       RowBox[{"BaseStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Medium", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Italic"}],
          "}"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Black", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Medium"}],
          "]"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"roots", "=", 
     RowBox[{"NSolve", " ", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"r", "^", "2"}], "-", 
         RowBox[{"2", " ", "m", " ", "r"}], "+", 
         RowBox[{"2", " ", "b", " ", 
          RowBox[{"r", "^", "3"}]}], " ", "-", " ", 
         RowBox[{"ll", " ", 
          RowBox[{
           RowBox[{"r", "^", "4"}], " ", "/", "3"}]}]}], "==", "0"}], ",", 
       "r"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r1", "=", 
     RowBox[{"roots", "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "1", ",", "2"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rmin", "=", "r1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rmax", "=", "16"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"imax", "=", "200"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dx", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"rmax", "-", "rmin"}], ")"}], "/", "imax"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"r", "[", "i_", "]"}], ":=", 
     RowBox[{
      RowBox[{"i", " ", "dx"}], "+", "rmin"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"fp", "[", "i_", "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"f", "[", "i", "]"}], "-", 
        RowBox[{"f", "[", 
         RowBox[{"i", "-", "1"}], "]"}]}], ")"}], "/", "dx"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"e", "[", "i_", "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"r", "[", "i", "]"}], "^", "2"}], " ", "-", 
         RowBox[{"2", "m", " ", 
          RowBox[{"r", "[", "i", "]"}]}], "+", 
         RowBox[{"2", " ", "b", " ", 
          RowBox[{
           RowBox[{"r", "[", "i", "]"}], "^", "3"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"ll", "/", "3"}], ")"}], " ", 
          RowBox[{
           RowBox[{"r", "[", "i", "]"}], "^", "4"}]}]}], ")"}], 
       RowBox[{
        RowBox[{"fp", "[", "i", "]"}], "^", "2"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"r", "[", "i", "]"}], "^", "2"}], 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"f", "[", "i", "]"}], "^", "2"}], "-", "1"}], ")"}], "^", 
         "2"}], " ", "/", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "0", "]"}], "=", 
     RowBox[{"-", "1"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "imax", "]"}], "=", "1"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"etot", "=", 
     RowBox[{"dx", "  ", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{"e", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "imax"}], "}"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r0", "=", "10"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ft", "[", "x_", "]"}], ":=", 
     RowBox[{"Tanh", "[", 
      RowBox[{"5", 
       RowBox[{"(", 
        RowBox[{"x", "-", "r0"}], ")"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ftab", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"f", "[", "i", "]"}], ",", 
         RowBox[{"ft", "[", 
          RowBox[{"r", "[", "i", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"imax", "-", "1"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sol1", "=", 
     RowBox[{"FindMinimum", "[", 
      RowBox[{"etot", ",", "ftab", ",", 
       RowBox[{"MaxIterations", "\[Rule]", "1000000"}], ",", 
       RowBox[{"AccuracyGoal", "\[Rule]", "6"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"etot", " ", "/.", " ", 
     RowBox[{"sol1", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tfsol", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"i", " ", "dx"}], "+", "rmin"}], ",", 
         RowBox[{
          RowBox[{"f", "[", "i", "]"}], "/.", " ", 
          RowBox[{"sol1", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "imax"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"plf2", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"tfsol", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"r1", ",", "6"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", " ", 
       RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "Dashed", ",", ",", 
          RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}]}], ",", 
       RowBox[{"BaseStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Medium", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Italic"}],
          "}"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Black", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Large"}], 
         "]"}]}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<r\>\"", ",", "\"\<\[CapitalPhi](r)\>\""}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"b", ",", "ll"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"b", "=", 
     RowBox[{"-", "0.232"}]}], ";", " ", 
    RowBox[{"ll", "=", 
     RowBox[{"-", "0.2"}]}], ";", 
    RowBox[{"m", "=", "0.23"}], ";", 
    RowBox[{"(*", 
     RowBox[{"parameters", " ", "leading", " ", "to", " ", "collapse"}], 
     "*)"}], "\[IndentingNewLine]", 
    RowBox[{"gr", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "m", " ", "r"}], "+", 
      RowBox[{"r", "^", "2"}], "+", 
      RowBox[{"2", " ", "b", " ", 
       RowBox[{"r", "^", "3"}]}], " ", "-", " ", 
      RowBox[{"ll", " ", 
       RowBox[{
        RowBox[{"r", "^", "4"}], " ", "/", "3"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"plgr2", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{"gr", ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "0", ",", "4.2"}], "}"}], ",", " ", 
       RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Blue", "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", " ", 
        RowBox[{"{", 
         RowBox[{
         "\"\<r\>\"", ",", 
          "\"\<\!\(\*SuperscriptBox[\(r\), \(2\)]\)f(r)\>\""}], "}"}]}], ",", 
       RowBox[{"BaseStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Medium", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Italic"}],
          "}"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Black", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Medium"}],
          "]"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"roots", "=", 
     RowBox[{"NSolve", " ", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"r", "^", "2"}], "-", 
         RowBox[{"2", " ", "m", " ", "r"}], "+", 
         RowBox[{"2", " ", "b", " ", 
          RowBox[{"r", "^", "3"}]}], " ", "-", " ", 
         RowBox[{"ll", " ", 
          RowBox[{
           RowBox[{"r", "^", "4"}], " ", "/", "3"}]}]}], "==", "0"}], ",", 
       "r"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r1", "=", 
     RowBox[{"roots", "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "1", ",", "2"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rmin", "=", "r1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rmax", "=", "16"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"imax", "=", "200"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dx", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"rmax", "-", "rmin"}], ")"}], "/", "imax"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"r", "[", "i_", "]"}], ":=", 
     RowBox[{
      RowBox[{"i", " ", "dx"}], "+", "rmin"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"fp", "[", "i_", "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"f", "[", "i", "]"}], "-", 
        RowBox[{"f", "[", 
         RowBox[{"i", "-", "1"}], "]"}]}], ")"}], "/", "dx"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"e", "[", "i_", "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"r", "[", "i", "]"}], "^", "2"}], " ", "-", 
         RowBox[{"2", "m", " ", 
          RowBox[{"r", "[", "i", "]"}]}], "+", 
         RowBox[{"2", " ", "b", " ", 
          RowBox[{
           RowBox[{"r", "[", "i", "]"}], "^", "3"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"ll", "/", "3"}], ")"}], " ", 
          RowBox[{
           RowBox[{"r", "[", "i", "]"}], "^", "4"}]}]}], ")"}], 
       RowBox[{
        RowBox[{"fp", "[", "i", "]"}], "^", "2"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"r", "[", "i", "]"}], "^", "2"}], 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"f", "[", "i", "]"}], "^", "2"}], "-", "1"}], ")"}], "^", 
         "2"}], " ", "/", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "0", "]"}], "=", 
     RowBox[{"-", "1"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "imax", "]"}], "=", "1"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"etot", "=", 
     RowBox[{"dx", "  ", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{"e", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "imax"}], "}"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r0", "=", "10"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ft", "[", "x_", "]"}], ":=", 
     RowBox[{"Tanh", "[", 
      RowBox[{"5", 
       RowBox[{"(", 
        RowBox[{"x", "-", "r0"}], ")"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ftab", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"f", "[", "i", "]"}], ",", 
         RowBox[{"ft", "[", 
          RowBox[{"r", "[", "i", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"imax", "-", "1"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sol1", "=", 
     RowBox[{"FindMinimum", "[", 
      RowBox[{"etot", ",", "ftab", ",", 
       RowBox[{"MaxIterations", "\[Rule]", "1000000"}], ",", 
       RowBox[{"AccuracyGoal", "\[Rule]", "6"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"etot", " ", "/.", " ", 
     RowBox[{"sol1", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tfsol", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"i", " ", "dx"}], "+", "rmin"}], ",", 
         RowBox[{
          RowBox[{"f", "[", "i", "]"}], "/.", " ", 
          RowBox[{"sol1", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "imax"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"plf1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"tfsol", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"r1", ",", "6"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", " ", 
       RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"Thickness", "[", "0.001", "]"}]}], "}"}]}], ",", 
       RowBox[{"BaseStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Medium", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Italic"}],
          "}"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Black", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Large"}], 
         "]"}]}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<r\>\"", ",", "\"\<\[CapitalPhi](r)\>\""}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"b", ",", "ll"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"b", "=", 
     RowBox[{"-", "0.243"}]}], ";", " ", 
    RowBox[{"ll", "=", 
     RowBox[{"-", "0.2"}]}], ";", 
    RowBox[{"m", "=", "0.23"}], ";", 
    RowBox[{"(*", 
     RowBox[{
     "parameters", " ", "leading", " ", "to", " ", "ghost", " ", 
      "instabilities"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"gr", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "m", " ", "r"}], "+", 
      RowBox[{"r", "^", "2"}], "+", 
      RowBox[{"2", " ", "b", " ", 
       RowBox[{"r", "^", "3"}]}], " ", "-", " ", 
      RowBox[{"ll", " ", 
       RowBox[{
        RowBox[{"r", "^", "4"}], " ", "/", "3"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"plgr3", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{"gr", ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "0", ",", "4.2"}], "}"}], ",", " ", 
       RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Purple", "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", " ", 
        RowBox[{"{", 
         RowBox[{
         "\"\<r\>\"", ",", 
          "\"\<\!\(\*SuperscriptBox[\(r\), \(2\)]\)f(r)\>\""}], "}"}]}], ",", 
       RowBox[{"BaseStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Medium", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Italic"}],
          "}"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Black", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Medium"}],
          "]"}]}]}], "]"}]}], ";", 
    RowBox[{"roots", "=", 
     RowBox[{"NSolve", " ", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"r", "^", "2"}], "-", 
         RowBox[{"2", " ", "m", " ", "r"}], "+", 
         RowBox[{"2", " ", "b", " ", 
          RowBox[{"r", "^", "3"}]}], " ", "-", " ", 
         RowBox[{"ll", " ", 
          RowBox[{
           RowBox[{"r", "^", "4"}], " ", "/", "3"}]}]}], "==", "0"}], ",", 
       "r"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r1", "=", 
     RowBox[{"roots", "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "1", ",", "2"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rmin", "=", "r1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rmax", "=", "16"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"imax", "=", "200"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dx", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"rmax", "-", "rmin"}], ")"}], "/", "imax"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"r", "[", "i_", "]"}], ":=", 
     RowBox[{
      RowBox[{"i", " ", "dx"}], "+", "rmin"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"fp", "[", "i_", "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"f", "[", "i", "]"}], "-", 
        RowBox[{"f", "[", 
         RowBox[{"i", "-", "1"}], "]"}]}], ")"}], "/", "dx"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"e", "[", "i_", "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"r", "[", "i", "]"}], "^", "2"}], " ", "-", 
         RowBox[{"2", "m", " ", 
          RowBox[{"r", "[", "i", "]"}]}], "+", 
         RowBox[{"2", " ", "b", " ", 
          RowBox[{
           RowBox[{"r", "[", "i", "]"}], "^", "3"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"ll", "/", "3"}], ")"}], " ", 
          RowBox[{
           RowBox[{"r", "[", "i", "]"}], "^", "4"}]}]}], ")"}], 
       RowBox[{
        RowBox[{"fp", "[", "i", "]"}], "^", "2"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"r", "[", "i", "]"}], "^", "2"}], 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"f", "[", "i", "]"}], "^", "2"}], "-", "1"}], ")"}], "^", 
         "2"}], " ", "/", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "0", "]"}], "=", 
     RowBox[{"-", "1"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "imax", "]"}], "=", "1"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"etot", "=", 
     RowBox[{"dx", "  ", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{"e", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "imax"}], "}"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r0", "=", "10"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ft", "[", "x_", "]"}], ":=", 
     RowBox[{"Tanh", "[", 
      RowBox[{"5", 
       RowBox[{"(", 
        RowBox[{"x", "-", "r0"}], ")"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ftab", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"f", "[", "i", "]"}], ",", 
         RowBox[{"ft", "[", 
          RowBox[{"r", "[", "i", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"imax", "-", "1"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sol1", "=", 
     RowBox[{"FindMinimum", "[", 
      RowBox[{"etot", ",", "ftab", ",", 
       RowBox[{"MaxIterations", "\[Rule]", "1000000"}], ",", 
       RowBox[{"AccuracyGoal", "\[Rule]", "6"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"etot", " ", "/.", " ", 
     RowBox[{"sol1", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tfsol", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"i", " ", "dx"}], "+", "rmin"}], ",", 
         RowBox[{
          RowBox[{"f", "[", "i", "]"}], "/.", " ", 
          RowBox[{"sol1", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "imax"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"plf3", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"tfsol", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"r1", ",", "6"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", " ", 
       RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Purple", ",", 
          RowBox[{"Thickness", "[", "0.001", "]"}]}], "}"}]}], ",", 
       RowBox[{"BaseStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Medium", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Italic"}],
          "}"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Black", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Large"}], 
         "]"}]}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<r\>\"", ",", "\"\<\[CapitalPhi](r)\>\""}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"panel3", "=", 
     RowBox[{"Show", "[", 
      RowBox[{"plgr1", ",", "plgr2", ",", "plgr3", ",", 
       RowBox[{"Graphics", "[", 
        RowBox[{"Inset", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(b\), \(1\)]\)=-0.232\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"2", ",", "0.5"}], "}"}]}], "]"}], "]"}], ",", 
       RowBox[{"Graphics", "[", 
        RowBox[{"Inset", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(b\), \(2\)]\)=-0.24\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"3", ",", "0.25"}], "}"}]}], "]"}], "]"}], ",", 
       RowBox[{"Graphics", "[", 
        RowBox[{"Inset", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(b\), \(3\)]\)=-0.243\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"1.7", ",", "0.13"}], "}"}]}], "]"}], "]"}], ",", 
       RowBox[{"Graphics", "[", 
        RowBox[{"Inset", "[", 
         RowBox[{"\"\<\[CapitalLambda]=-0.2\\n m=0.23\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"0.5", ",", "0.8"}], "}"}]}], "]"}], "]"}], ",", 
       RowBox[{"BaseStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Medium", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Italic"}],
          "}"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Black", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Medium"}],
          "]"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.15"}], ",", "1"}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"panel4", "=", 
     RowBox[{"Show", "[", 
      RowBox[{"plf3", ",", "plf1", ",", "plf2", ",", " ", 
       RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Purple", "}"}]}], ",", 
       RowBox[{"BaseStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Medium", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Italic"}],
          "}"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Black", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Medium"}],
          "]"}]}]}], "]"}]}], ";"}], "\n", 
   RowBox[{"fig2", "=", 
    RowBox[{"Panel", "[", 
     RowBox[{
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"panel3", ",", "panel4"}], "}"}], "}"}], ",", 
        RowBox[{"Spacings", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "Full"}]}], "]"}], ",", 
      RowBox[{"Background", "\[Rule]", "White"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{"\"\<fig1.pdf\>\"", ",", "fig2", ",", 
     RowBox[{"ImageResolution", "\[Rule]", "1000"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Full"}]}], "]"}], "\n"}]}]], "Input",
 CellChangeTimes->{{3.755615461139578*^9, 3.755615626516698*^9}, 
   3.7556156868861475`*^9, {3.7556157267879353`*^9, 3.7556159457977786`*^9}, {
   3.755615991001136*^9, 3.75561605065349*^9}, {3.7556160850697517`*^9, 
   3.755616117383354*^9}, {3.755617280476466*^9, 3.7556172955429516`*^9}, {
   3.755617408571048*^9, 3.755617520946898*^9}, {3.7556179608712454`*^9, 
   3.755617961442007*^9}, {3.755618344639683*^9, 3.755618469191171*^9}, {
   3.7556185048382936`*^9, 3.7556185800090575`*^9}, {3.7556188452898045`*^9, 
   3.7556188726795564`*^9}, {3.755618940649274*^9, 3.755618966300002*^9}, 
   3.755619043984234*^9, {3.7556249706061068`*^9, 3.7556249743158183`*^9}, {
   3.7556250522579565`*^9, 3.755625086715466*^9}, {3.7563785776689954`*^9, 
   3.7563787468277073`*^9}, {3.7563788793014555`*^9, 3.756378899339871*^9}, {
   3.7563789688619733`*^9, 3.756378972541133*^9}, {3.756379126654976*^9, 
   3.756379139416896*^9}, {3.756379221048607*^9, 3.756379233581051*^9}, {
   3.7563794856579847`*^9, 3.756379498694124*^9}, {3.75637953902432*^9, 
   3.7563795618173685`*^9}, {3.756379596596368*^9, 3.7563796158469048`*^9}, {
   3.756380247393813*^9, 3.75638025217598*^9}, {3.756380300726153*^9, 
   3.756380329828371*^9}, {3.756745889759271*^9, 3.7567459080171204`*^9}, {
   3.7567459454234695`*^9, 3.7567459535119476`*^9}, {3.7568979498172693`*^9, 
   3.7568980612037654`*^9}, {3.756902429821529*^9, 3.7569024737717876`*^9}, 
   3.7569089199587393`*^9, {3.756909112049999*^9, 3.7569091381275826`*^9}, {
   3.7569097272261767`*^9, 3.756909728546132*^9}, 3.756912588979149*^9, {
   3.756922212263691*^9, 3.7569222905412073`*^9}}],

Cell[BoxData[
 PanelBox[
  GraphicsBox[{{}, {InsetBox[
      GraphicsBox[{{{{}, {}, 
          TagBox[
           {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
            Dashing[{Small, Small}], CapForm["Butt"], LineBox[CompressedData["
1:eJwV13c81d8bAPBLZVVWyGgQyRdRRqnw3AYp2SOiqJAVkq2iNJBKVqpr73Xt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             "]]},
           
           Annotation[#, 
            "Charting`Private`Tag$5619#1"]& ]}, {}, {}}, {{{}, {}, 
          TagBox[
           {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], CapForm[
            "Butt"], LineBox[CompressedData["
1:eJwVl3k4lG8Xx2fGNiSRJSERociS8iPLuSuV7GupKLJFm8gWoUSKiqyV7Psy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             "]]},
           
           Annotation[#, 
            "Charting`Private`Tag$6161#1"]& ]}, {}, {}}, {{{}, {}, 
          TagBox[
           {RGBColor[0.5, 0, 0.5], AbsoluteThickness[1.6], Opacity[1.], 
            CapForm["Butt"], LineBox[CompressedData["
1:eJwVl3k8lN8Xx0ckRCSV7RtlSciWpMR5KpV9T6S0IUuSLYWiohTKrtWe3VhD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             "]]},
           Annotation[#, "Charting`Private`Tag$6844#1"]& ]}, {}, {}}, 
        TagBox[InsetBox[
          RowBox[{
           SubscriptBox["b", "1"], "=", 
           RowBox[{"-", "0.232"}]}], {2, 0.5}],
         "InsetString"], 
        TagBox[InsetBox[
          RowBox[{
           SubscriptBox["b", "2"], "=", 
           RowBox[{"-", "0.24"}]}], {3, 0.25}],
         "InsetString"], 
        TagBox[InsetBox[
          RowBox[{
           SubscriptBox["b", "3"], "=", 
           RowBox[{"-", "0.243"}]}], {1.7, 0.13}],
         "InsetString"], 
        TagBox[InsetBox[
          RowBox[{
           RowBox[{"\[CapitalLambda]", "=", 
            RowBox[{"-", "0.2"}]}], "\n", " ", 
           RowBox[{"m", "=", "0.23"}]}], {0.5, 0.8}],
         "InsetString"]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{False, False},
       AxesLabel->{None, None},
       AxesOrigin->{0, 0},
       BaseStyle->{Medium, FontFamily -> "Times", Italic},
       DisplayFunction->Identity,
       Frame->{{True, True}, {True, True}},
       FrameLabel->{{
          FormBox[
          "\"\\!\\(\\*SuperscriptBox[\\(r\\), \\(2\\)]\\)f(r)\"", 
           TraditionalForm], None}, {
          FormBox["\"r\"", TraditionalForm], None}},
       FrameStyle->Automatic,
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{{0}, {0}},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->All,
       LabelStyle->Directive[
         GrayLevel[0], FontFamily -> "Times", Medium],
       Method->{
        "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None, 
         "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
             (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
              Part[#, 1]], 
             (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
              Part[#, 1]], 
             (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
              Part[#, 2]]}& )}},
       PlotRange->{-0.15, 1},
       PlotRangeClipping->True,
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.02], 
          Scaled[0.02]}},
       Ticks->{Automatic, Automatic}], {180, -111.24611797498106}, 
      ImageScaled[{0.5, 0.5}], {360, 222.49223594996212}], InsetBox[
      GraphicsBox[{{{}, {{}, {}, 
          {RGBColor[0.5, 0, 0.5], PointSize[0.01388888888888889], Thickness[
           0.001], CapForm["Butt"], 
           StyleBox[LineBox[CompressedData["
1:eJw913s01OkbAHCGcZuhYRiM68y4zH0kJcL3oahV5LKySuuXS9lIii4qrPbo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             "]],
            FontFamily->"Times"]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
          {RGBColor[0, 0, 1], PointSize[0.01388888888888889], Thickness[
           0.001], CapForm["Butt"], 
           StyleBox[LineBox[CompressedData["
1:eJwt1ws4lNkbAPAZBrnEmBh3ZhhjhnEZu2xufa/CrrSh0pJtk1uprNtGbBeW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             "]],
            FontFamily->"Times"]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
          {RGBColor[1, 0, 0], PointSize[0.01388888888888889], Thickness[0.01],
            Dashing[{Small, Small}], CapForm["Butt"], 
           StyleBox[LineBox[CompressedData["
1:eJxF1gs0lOkfB3C3RCX3+20YxhgzhpaKsu9v7RK5JCK1ueQSsptsynV1WVYl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             "]],
            FontFamily->"Times"]}}, {}, {}, {{}, {}}}},
       PlotTheme -> "Scientific",
       PlotStyle -> {
         RGBColor[0.5, 0, 0.5]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{False, False},
       AxesLabel->{None, None},
       AxesOrigin->{0.6702482910830401, 0},
       BaseStyle->{Medium, FontFamily -> "Times", Italic},
       DisplayFunction->Identity,
       Frame->{{True, True}, {True, True}},
       FrameLabel->{{
          FormBox["\"\[CapitalPhi](r)\"", TraditionalForm], None}, {
          FormBox["\"r\"", TraditionalForm], None}},
       FrameStyle->Automatic,
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{{0}, {0}},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->All,
       LabelStyle->Directive[
         GrayLevel[0], FontFamily -> "Times", Medium],
       Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
             (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
              Part[#, 1]], 
             (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
              Part[#, 1]], 
             (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
              Part[#, 2]]}& )}},
       PlotRange->{{0.6434656191789347, 6}, {-4, 4}},
       PlotRangeClipping->True,
       PlotRangePadding->{{0, 0}, {0, 0}},
       Ticks->{Automatic, Automatic}], {540, -111.24611797498106}, 
      ImageScaled[{0.5, 0.5}], {360, 222.49223594996212}]}, {}},
   ContentSelectable->True,
   ImageSize->Full,
   PlotRangePadding->{6, 5}],
  Background->GrayLevel[1]]], "Output",
 CellChangeTimes->{{3.7569223038245296`*^9, 3.756922327830855*^9}}],

Cell[BoxData["\<\"fig1.pdf\"\>"], "Output",
 CellChangeTimes->{{3.7569223038245296`*^9, 3.7569223281800327`*^9}}]
}, Open  ]],

Cell[BoxData["\"\<fig1.pdf\>\""], "Input",
 CellChangeTimes->{{3.755615461139578*^9, 3.755615626516698*^9}, 
   3.7556156868861475`*^9, {3.7556157267879353`*^9, 3.7556159457977786`*^9}, {
   3.755615991001136*^9, 3.75561605065349*^9}, {3.7556160850697517`*^9, 
   3.755616117383354*^9}, {3.755617280476466*^9, 3.7556172955429516`*^9}, {
   3.755617408571048*^9, 3.755617520946898*^9}, {3.7556179608712454`*^9, 
   3.755617961442007*^9}, {3.755618344639683*^9, 3.755618469191171*^9}, {
   3.7556185048382936`*^9, 3.7556185800090575`*^9}, {3.7556188452898045`*^9, 
   3.7556188726795564`*^9}, {3.755618940649274*^9, 3.755618966300002*^9}, 
   3.755619043984234*^9, {3.7556249706061068`*^9, 3.7556249743158183`*^9}, {
   3.7556250522579565`*^9, 3.755625086715466*^9}, {3.7563785776689954`*^9, 
   3.7563787468277073`*^9}, {3.7563788793014555`*^9, 3.756378899339871*^9}, {
   3.7563789688619733`*^9, 3.756378972541133*^9}, {3.756379126654976*^9, 
   3.756379139416896*^9}, {3.756379221048607*^9, 3.756379233581051*^9}, {
   3.7563794856579847`*^9, 3.756379498694124*^9}, {3.75637953902432*^9, 
   3.7563795618173685`*^9}, {3.756379596596368*^9, 3.7563796158469048`*^9}, {
   3.756380247393813*^9, 3.75638025217598*^9}, {3.756380300726153*^9, 
   3.756380329828371*^9}, {3.756745889759271*^9, 3.7567459080171204`*^9}, {
   3.7567459454234695`*^9, 3.7567459535119476`*^9}, {3.7568979498172693`*^9, 
   3.7568980612037654`*^9}, {3.756902429821529*^9, 3.7569024737717876`*^9}, 
   3.7569089199587393`*^9, {3.756909112049999*^9, 3.7569091381275826`*^9}, {
   3.7569097272261767`*^9, 3.756909728546132*^9}, 3.756912588979149*^9, {
   3.756922212263691*^9, 3.7569222669652476`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Figure 2",
 FontSize->18]], "Section",
 CellChangeTimes->{{3.7569092161576033`*^9, 3.756909249477521*^9}},
 Background->RGBColor[0., 1., 1.]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "PLot", " ", "of", " ", "a", " ", "field", " ", "configuration", " ", 
    "and", " ", "its", " ", "corresponding", " ", "analytic", " ", "fit"}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"b", "=", 
     RowBox[{"-", "0.212"}]}], ";", " ", 
    RowBox[{"ll", "=", 
     RowBox[{"-", "0.14"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "ft", ",", "ftab"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"imax", "=", "400"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rmin", "=", "0.0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rmax", "=", "8"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dx", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"rmax", "-", "rmin"}], ")"}], "/", "imax"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"r", "[", "i_", "]"}], ":=", 
     RowBox[{
      RowBox[{"i", " ", "dx"}], "+", "rmin"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"fp", "[", "i_", "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"f", "[", "i", "]"}], "-", 
        RowBox[{"f", "[", 
         RowBox[{"i", "-", "1"}], "]"}]}], ")"}], "/", "dx"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"e", "[", "i_", "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"r", "[", "i", "]"}], "^", "2"}], " ", "+", " ", 
         RowBox[{"2", " ", "b", " ", 
          RowBox[{
           RowBox[{"r", "[", "i", "]"}], "^", "3"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"ll", "/", "3"}], ")"}], " ", 
          RowBox[{
           RowBox[{"r", "[", "i", "]"}], "^", "4"}]}]}], ")"}], 
       RowBox[{
        RowBox[{
         RowBox[{"fp", "[", "i", "]"}], "^", "2"}], "/", "2"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"r", "[", "i", "]"}], "^", "2"}], 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"f", "[", "i", "]"}], "^", "2"}], "-", "1"}], ")"}], "^", 
         "2"}], " ", "/", "4"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "0", "]"}], "=", 
     RowBox[{"-", "1"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "imax", "]"}], "=", "1"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"etot", "=", 
     RowBox[{"dx", "  ", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{"e", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "imax"}], "}"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r0", "=", "10"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ft", "[", "x_", "]"}], ":=", 
     RowBox[{"Tanh", "[", 
      RowBox[{"5", 
       RowBox[{"(", 
        RowBox[{"x", "-", "r0"}], ")"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ftab", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"f", "[", "i", "]"}], ",", 
         RowBox[{"ft", "[", 
          RowBox[{"r", "[", "i", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"imax", "-", "1"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sol1", "=", 
     RowBox[{"FindMinimum", "[", 
      RowBox[{"etot", ",", "ftab", ",", 
       RowBox[{"MaxIterations", "\[Rule]", "1000000"}], ",", 
       RowBox[{"AccuracyGoal", "\[Rule]", "6"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"etot", " ", "/.", " ", 
     RowBox[{"sol1", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tfsol", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"i", " ", "dx"}], "+", "rmin"}], ",", 
         RowBox[{
          RowBox[{"f", "[", "i", "]"}], "/.", " ", 
          RowBox[{"sol1", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "imax"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"plsol1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"tfsol", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"r", ",", "\[CapitalPhi]"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"a", ",", "r0"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"nlm", "=", 
    RowBox[{"NonlinearModelFit", "[", 
     RowBox[{"tfsol", ",", 
      RowBox[{"Tanh", "[", 
       RowBox[{"a", " ", 
        RowBox[{"(", 
         RowBox[{"r", "-", "r0"}], ")"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"a", ",", "r0"}], "}"}], ",", "r"}], "]"}]}], 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"Fitted", " ", "Solution", " ", "using", " ", "\[CapitalPhi]", 
      RowBox[{"(", "r", ")"}]}], "=", 
     RowBox[{"Tanh", "[", 
      RowBox[{"q", 
       RowBox[{"(", 
        RowBox[{"r", "-", 
         SubscriptBox["r", "0"]}], ")"}]}], "]"}]}], "*)"}], "\n", 
   RowBox[{"fapprox", "=", 
    RowBox[{"Show", "[", 
     RowBox[{
      RowBox[{"ListPlot", "[", 
       RowBox[{"tfsol", ",", 
        RowBox[{"Joined", "->", "True"}]}], "]"}], ",", 
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{"nlm", "[", "x", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "rmin", ",", "rmax"}], "}"}], ",", 
        RowBox[{"PlotTheme", "->", "\"\<Scientific\>\""}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Red", ",", "Dashed", ",", 
           RowBox[{"Thickness", "[", "0.003", "]"}]}], "}"}]}]}], "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Inset", "[", 
         RowBox[{"\"\<\!\(\*
StyleBox[\"Numerical\",
FontSize->14]\)\!\(\*
StyleBox[\" \",
FontSize->14]\)\!\(\*
StyleBox[\"Solution\",
FontSize->14]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"2.3", ",", ".8"}], "}"}]}], "]"}], "}"}], "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"3.16", ",", "0.81"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"4.3", ",", "0.93"}], "}"}]}], "}"}], "]"}], "}"}], "]"}],
       ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Inset", "[", 
         RowBox[{"\"\<\!\(\*
StyleBox[\"Fitted\",
FontSize->14]\)\!\(\*
StyleBox[\" \",
FontSize->14]\)\!\(\*
StyleBox[\"Solution\",
FontSize->14]\)\!\(\*
StyleBox[\" \",
FontSize->14]\)\!\(\*
StyleBox[\"(\",
FontSize->14]\)\!\(\*
StyleBox[\"dashed\",
FontSize->14]\)\!\(\*
StyleBox[\")\",
FontSize->14]\)\\n\!\(\*
StyleBox[\"\[CapitalPhi]\",
FontSize->14]\)\!\(\*
StyleBox[\"(\",
FontSize->14]\)\!\(\*
StyleBox[\"r\",
FontSize->14]\)\!\(\*
StyleBox[\")\",
FontSize->14]\)\!\(\*
StyleBox[\"=\",
FontSize->14]\)\!\(\*
StyleBox[\"Tanh\",
FontSize->14]\)\!\(\*
StyleBox[\"[\",
FontSize->14]\)\!\(\*
StyleBox[\"2.89\",
FontSize->14]\)\!\(\*
StyleBox[\"(\",
FontSize->14]\)\!\(\*
StyleBox[\"r\",
FontSize->14]\)\!\(\*
StyleBox[\"-\",
FontSize->14]\)\!\(\*
StyleBox[\"3.84\",
FontSize->14]\)\!\(\*
StyleBox[\")\",
FontSize->14]\)\!\(\*
StyleBox[\"]\",
FontSize->14]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"6", ",", 
            RowBox[{"-", ".8"}]}], "}"}]}], "]"}], "}"}], "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"4.86", ",", 
             RowBox[{"-", "0.8"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"3.36", ",", 
             RowBox[{"-", "0.94"}]}], "}"}]}], "}"}], "]"}], "}"}], "]"}], 
      ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "8"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{"-", "1"}]}], "}"}]}], "}"}]}], ",", 
      RowBox[{"PlotTheme", "->", "\"\<Scientific\>\""}], ",", 
      RowBox[{"PlotLabel", "\[Rule]", " ", "None"}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Medium", ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Italic"}], 
        "}"}]}], ",", 
      RowBox[{"LabelStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Black", ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Large"}], 
        "]"}]}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", " ", 
       RowBox[{"{", 
        RowBox[{"\"\<r\>\"", ",", "\"\<\[CapitalPhi](r)\>\""}], "}"}]}]}], 
     "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{"\"\<fig2.pdf\>\"", ",", "fapprox", ",", 
     RowBox[{"ImageResolution", "\[Rule]", "1000"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.756402401761854*^9, 3.756402402056238*^9}, {
   3.756402787338176*^9, 3.756402809011959*^9}, {3.7564029336084027`*^9, 
   3.7564029943269143`*^9}, {3.756403943802362*^9, 3.7564039557867064`*^9}, {
   3.756730847060576*^9, 3.75673087395189*^9}, {3.7567325213311815`*^9, 
   3.7567325486168237`*^9}, {3.756732581525938*^9, 3.7567326381904373`*^9}, {
   3.75673266863466*^9, 3.7567326693518476`*^9}, 3.756732897787825*^9, {
   3.756733003315981*^9, 3.756733192237257*^9}, {3.756733234305318*^9, 
   3.756733296332073*^9}, {3.7567335163790784`*^9, 3.756733517343285*^9}, {
   3.756898346143795*^9, 3.756898411551366*^9}, {3.7569019668818984`*^9, 
   3.756902049129563*^9}, {3.756909699112853*^9, 3.7569096994985943`*^9}, 
   3.7569125984811687`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"FittedModel", "[", 
   TagBox[
    PanelBox[
     TagBox[
      RowBox[{"Tanh", "[", 
       RowBox[{"2.8948829506744476`", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3.8476649434964494`"}], "+", "r"}], ")"}]}], "]"}],
      Short[#, 2]& ],
     FrameMargins->5],
    Editable -> False], "]"}],
  InterpretTemplate[
  FittedModel[{
    "Nonlinear", {$CellContext`a -> 2.8948829506744476`, $CellContext`r0 -> 
      3.8476649434964494`}, {{$CellContext`r}, 
      Tanh[$CellContext`a ($CellContext`r - $CellContext`r0)]}}, {
    1}, {{0., -1}, {0.02, -0.9997251939437223}, {0.04, -0.9996676207392973}, {
     0.06, -0.9996426529902439}, {0.08, -0.9996296052692452}, {
     0.1, -0.9996219011696788}, {0.12, -0.9996170869483851}, {
     0.14, -0.999613692967178}, {0.16, -0.9996108782674765}, {
     0.18, -0.9996076867327031}, {0.2, -0.9996045581790088}, {
     0.22, -0.9996017022966843}, {0.24, -0.9995990734160758}, {
     0.26, -0.9995964569809611}, {0.28, -0.99959385853845}, {
     0.3, -0.9995915568092151}, {0.32, -0.9995894862864068}, {
     0.34, -0.999587204373099}, {0.36, -0.9995851220847556}, {
     0.38, -0.9995829495829711}, {0.4, -0.9995805281387733}, {
     0.42, -0.9995778652704994}, {0.44, -0.9995752029134147}, {
     0.46, -0.9995721481624464}, {0.48, -0.9995689021049228}, {
     0.5, -0.9995654938358522}, {0.52, -0.9995619376459863}, {
     0.54, -0.999558300335742}, {0.56, -0.9995544017864438}, {
     0.58, -0.9995502977653254}, {0.6, -0.9995460277633307}, {
     0.62, -0.9995415921456879}, {0.64, -0.999536967082532}, {
     0.66, -0.999532171476181}, {0.68, -0.9995270535471268}, {
     0.7000000000000001, -0.9995216594413302}, {0.72, -0.9995160109458733}, {
     0.74, -0.9995100649499907}, {0.76, -0.9995038280526162}, {
     0.78, -0.9994973136447293}, {0.8, -0.9994904972760057}, {
     0.8200000000000001, -0.9994833739736694}, {0.84, -0.9994759850233761}, {
     0.86, -0.9994682411208785}, {0.88, -0.999460182890848}, {
     0.9, -0.9994517393394443}, {0.92, -0.999442948522863}, {
     0.9400000000000001, -0.9994337936524177}, {0.96, -0.9994242487250011}, {
     0.98, -0.9994142916559259}, {1., -0.9994039246548965}, {
     1.02, -0.9993931309839291}, {1.04, -0.9993818851108122}, {
     1.06, -0.9993701576654211}, {1.08, -0.9993579269421505}, {
     1.1, -0.9993451704018397}, {1.12, -0.9993318803273076}, {
     1.1400000000000001`, -0.9993180352746864}, {1.16, -0.9993035872150499}, {
     1.18, -0.9992885062507793}, {1.2, -0.9992727762058885}, {
     1.22, -0.9992563353139599}, {1.24, -0.9992391760364123}, {
     1.26, -0.9992213016044749}, {1.28, -0.9992026476178019}, {
     1.3, -0.9991831646959449}, {1.32, -0.9991628256203272}, {
     1.34, -0.9991416031428589}, {1.36, -0.9991194676038017}, {
     1.3800000000000001`, -0.9990963653916944}, {
     1.4000000000000001`, -0.9990722389809665}, {1.42, -0.9990470456941065}, {
     1.44, -0.9990207395448854}, {1.46, -0.9989932451917615}, {
     1.48, -0.9989645206490729}, {1.5, -0.998934532539826}, {
     1.52, -0.9989031988193782}, {1.54, -0.9988704284419919}, {
     1.56, -0.998836147859347}, {1.58, -0.998800293149053}, {
     1.6, -0.9987627794869852}, {1.62, -0.9987235122336401}, {
     1.6400000000000001`, -0.9986824046531595}, {
     1.6600000000000001`, -0.9986393623164562}, {1.68, -0.998594271409736}, {
     1.7, -0.9985470332025824}, {1.72, -0.9984975392109883}, {
     1.74, -0.9984456438136345}, {1.76, -0.9983911882068461}, {
     1.78, -0.9983340290801171}, {1.8, -0.9982740332495476}, {
     1.82, -0.9982110585868105}, {1.84, -0.9981449373999096}, {
     1.86, -0.9980754779893604}, {1.8800000000000001`, -0.9980024763573727}, {
     1.9000000000000001`, -0.9979257195517499}, {1.92, -0.9978449894050324}, {
     1.94, -0.9977600583500373}, {1.96, -0.9976706752544044}, {
     1.98, -0.9975765562917422}, {2., -0.9974774107111384}, {
     2.02, -0.9973729407038218}, {2.04, -0.9972628225979526}, {
     2.06, -0.9971466963028389}, {2.08, -0.9970241745106665}, {
     2.1, -0.9968948476352449}, {2.12, -0.9967582807874331}, {
     2.14, -0.9966140083602044}, {2.16, -0.9964615313631789}, {
     2.18, -0.9963003156858329}, {2.2, -0.9961297827684606}, {
     2.22, -0.9959493094814404}, {2.24, -0.9957582267526734}, {
     2.2600000000000002`, -0.9955558198624257}, {
     2.2800000000000002`, -0.9953413228224138}, {
     2.3000000000000003`, -0.9951138971330009}, {2.32, -0.9948726315309049}, {
     2.34, -0.9946165512725292}, {2.36, -0.9943446158802249}, {
     2.38, -0.9940557083218052}, {2.4, -0.9937486133669173}, {
     2.42, -0.993422004180738}, {2.44, -0.993074444838928}, {
     2.46, -0.9927043915300364}, {2.48, -0.9923101748429615}, {
     2.5, -0.991889981252665}, {2.52, -0.9914418530590281}, {
     2.54, -0.9909636776939198}, {2.56, -0.9904531576937189}, {
     2.58, -0.989907780698296}, {2.6, -0.9893248094090298}, {
     2.62, -0.9887012871724333}, {2.64, -0.9880340186376414}, {
     2.66, -0.987319522942873}, {2.68, -0.9865539882496088}, {
     2.7, -0.985733252595935}, {2.72, -0.9848527971106226}, {
     2.74, -0.9839077063324403}, {2.7600000000000002`, -0.9828926087867756}, {
     2.7800000000000002`, -0.9818016277008813}, {
     2.8000000000000003`, -0.9806283440221621}, {2.82, -0.9793657461518533}, {
     2.84, -0.9780061654611644}, {2.86, -0.9765412254602092}, {
     2.88, -0.9749617640542076}, {2.9, -0.9732577353607712}, {
     2.92, -0.9714181273302097}, {2.94, -0.9694308812154911}, {
     2.96, -0.9672827950596978}, {2.98, -0.9649593934312118}, {
     3., -0.9624447859420666}, {3.02, -0.9597215317158472}, {
     3.04, -0.9567705165321312}, {3.06, -0.9535707847893027}, {
     3.08, -0.9500993314227587}, {3.1, -0.9463308981450992}, {
     3.12, -0.9422377930602643}, {3.14, -0.9377896574267265}, {
     3.16, -0.9329532002600275}, {3.18, -0.9276919482863492}, {
     3.2, -0.9219659779470097}, {3.22, -0.9157316099244973}, {
     3.24, -0.9089410931610338}, {3.2600000000000002`, -0.9015423087219112}, {
     3.2800000000000002`, -0.8934784731969795}, {
     3.3000000000000003`, -0.8846878300636896}, {
     3.3200000000000003`, -0.8751033297001106}, {3.34, -0.8646523672909487}, {
     3.36, -0.8532565907191632}, {3.38, -0.8408317226098145}, {
     3.4, -0.8272874585649177}, {3.42, -0.8125275326795809}, {
     3.44, -0.7964499139135764}, {3.46, -0.7789471807406577}, {
     3.48, -0.759907133809008}, {3.5, -0.7392137089557425}, {
     3.52, -0.7167482310002175}, {3.54, -0.6923910539690665}, {
     3.56, -0.6660236586922575}, {3.58, -0.6375312820327906}, {
     3.6, -0.6068060699217417}, {3.62, -0.5737507985950555}, {
     3.64, -0.5382831263093876}, {3.66, -0.5003403232334974}, {
     3.68, -0.4598844094387372}, {3.7, -0.4169075300259481}, {
     3.72, -0.37143731904084815`}, {3.74, -0.3235419087527327}, {
     3.7600000000000002`, -0.27333432400405194`}, {
     3.7800000000000002`, -0.22097578286432779`}, {
     3.8000000000000003`, -0.16667756101870423`}, {
     3.8200000000000003`, -0.11070092492513783`}, {
     3.84, -0.05335489422833358}, {3.86, 0.0050083627685092846`}, {3.88, 
     0.0640004926962881}, {3.9, 0.12320623183493075`}, {3.92, 
     0.1821944830448253}, {3.94, 0.2405306762785531}, {3.96, 
     0.29778970941678296`}, {3.98, 0.3535685348176129}, {4., 
     0.407497737466846}, {4.0200000000000005`, 0.45925142728769197`}, {4.04, 
     0.508554750110057}, {4.0600000000000005`, 0.5551888217985653}, {4.08, 
     0.5989929335603331}, {4.1, 0.6398642023668573}, {4.12, 
     0.6777548420198141}, {4.14, 0.7126674691327642}, {4.16, 
     0.7446493335899901}, {4.18, 0.7737855764577096}, {4.2, 
     0.8001920306460162}, {4.22, 0.824008143455711}, {4.24, 
     0.8453902683730824}, {4.26, 0.8645056394862388}, {4.28, 
     0.8815269472838573}, {4.3, 0.896627789933972}, {4.32, 
     0.9099791195711512}, {4.34, 0.9217463097193532}, {4.36, 
     0.9320869865407184}, {4.38, 0.9411495445168269}, {4.4, 
     0.9490721401432687}, {4.42, 0.955982268108594}, {4.44, 
     0.9619966537807739}, {4.46, 0.9672212675597046}, {4.48, 
     0.9717518744306548}, {4.5, 0.9756743225462451}, {4.5200000000000005`, 
     0.9790653008768134}, {4.54, 0.9819929735505656}, {4.5600000000000005`, 
     0.9845176493776153}, {4.58, 0.9866924802087932}, {4.6000000000000005`, 
     0.9885642788627048}, {4.62, 0.9901739837066899}, {4.64, 
     0.9915573347774169}, {4.66, 0.9927454481547323}, {4.68, 
     0.9937654023095897}, {4.7, 0.9946407250368154}, {4.72, 
     0.9953916891246416}, {4.74, 0.9960359019308733}, {4.76, 
     0.9965884521937844}, {4.78, 0.9970624222114352}, {4.8, 
     0.9974689905674898}, {4.82, 0.9978178149197181}, {4.84, 
     0.9981172224755243}, {4.86, 0.9983742792043375}, {4.88, 
     0.9985950636271766}, {4.9, 0.9987847829434182}, {4.92, 
     0.998947924722862}, {4.94, 0.9990882785064639}, {4.96, 
     0.9992091174529468}, {4.98, 0.9993132114145971}, {5., 
     0.999402943345606}, {5.0200000000000005`, 0.999480373676367}, {5.04, 
     0.9995472543716076}, {5.0600000000000005`, 0.9996050691533304}, {5.08, 
     0.9996551196795214}, {5.1000000000000005`, 0.9996984593673778}, {5.12, 
     0.9997360302975864}, {5.14, 0.9997686502918985}, {5.16, 
     0.9997969794740801}, {5.18, 0.9998216262212152}, {5.2, 
     0.99984310269559}, {5.22, 0.9998618041038156}, {5.24, 
     0.9998781289168178}, {5.26, 0.9998923876772944}, {5.28, 
     0.9999048772704546}, {5.3, 0.9999158047713387}, {5.32, 
     0.9999253740695094}, {5.34, 0.9999337879692941}, {5.36, 
     0.9999411764064884}, {5.38, 0.999947666693297}, {5.4, 
     0.9999533875375385}, {5.42, 0.9999584295398041}, {5.44, 
     0.9999628838517253}, {5.46, 0.9999668264400532}, {5.48, 
     0.9999703112634678}, {5.5, 0.999973392018005}, {5.5200000000000005`, 
     0.9999761327080607}, {5.54, 0.9999785646277916}, {5.5600000000000005`, 
     0.9999807249363948}, {5.58, 0.9999826532742134}, {5.6000000000000005`, 
     0.9999843535728115}, {5.62, 0.999985867042599}, {5.64, 
     0.9999872322856829}, {5.66, 0.999988461714253}, {5.68, 
     0.9999895510196325}, {5.7, 0.9999905146671796}, {5.72, 
     0.9999913947438823}, {5.74, 0.9999921932243602}, {5.76, 
     0.9999928969439504}, {5.78, 0.9999935366942155}, {5.8, 
     0.9999941258047379}, {5.82, 0.9999946476517108}, {5.84, 
     0.9999951072200549}, {5.86, 0.9999955316837296}, {5.88, 
     0.9999959239735963}, {5.9, 0.9999962723450618}, {5.92, 
     0.9999965860472122}, {5.94, 0.9999968790901216}, {5.96, 
     0.9999971515196914}, {5.98, 0.9999973910199896}, {6., 
     0.9999976088665858}, {6.0200000000000005`, 0.999997806339979}, {6.04, 
     0.9999979739146891}, {6.0600000000000005`, 0.9999981387667725}, {6.08, 
     0.9999982829089019}, {6.1000000000000005`, 0.9999984272203181}, {6.12, 
     0.9999985524557268}, {6.140000000000001, 0.9999986695083924}, {6.16, 
     0.9999987730544633}, {6.18, 0.9999988639062428}, {6.2, 
     0.9999989527053712}, {6.22, 0.9999990364282051}, {6.24, 
     0.9999991115416762}, {6.26, 0.999999176886371}, {6.28, 
     0.9999992325774808}, {6.3, 0.9999992832520783}, {6.32, 
     0.9999993324504598}, {6.34, 0.9999993799177235}, {6.36, 
     0.9999994250709522}, {6.38, 0.9999994656072531}, {6.4, 
     0.9999994981128831}, {6.42, 0.999999525661569}, {6.44, 
     0.9999995553381449}, {6.46, 0.9999995863048805}, {6.48, 
     0.9999996124944663}, {6.5, 0.9999996349120904}, {6.5200000000000005`, 
     0.9999996581997292}, {6.54, 0.9999996800713252}, {6.5600000000000005`, 
     0.9999996963174959}, {6.58, 0.9999997103418196}, {6.6000000000000005`, 
     0.9999997278564604}, {6.62, 0.9999997478860817}, {6.640000000000001, 
     0.9999997664041707}, {6.66, 0.9999997835563655}, {6.68, 
     0.9999998015037297}, {6.7, 0.999999819423272}, {6.72, 
     0.9999998353053474}, {6.74, 0.9999998496662551}, {6.76, 
     0.9999998638953378}, {6.78, 0.9999998771250063}, {6.8, 
     0.999999887775464}, {6.82, 0.9999998968448955}, {6.84, 
     0.9999999070055892}, {6.86, 0.9999999188898419}, {6.88, 
     0.99999993035191}, {6.9, 0.9999999395243246}, {6.92, 
     0.9999999470241058}, {6.94, 0.9999999546102609}, {6.96, 
     0.9999999627748714}, {6.98, 0.9999999705185406}, {7., 
     0.9999999769899908}, {7.0200000000000005`, 0.9999999824570517}, {7.04, 
     0.9999999876419975}, {7.0600000000000005`, 0.9999999927641992}, {7.08, 
     0.9999999975821238}, {7.1000000000000005`, 1.0000000020547641`}, {7.12, 
     1.0000000065199417`}, {7.140000000000001, 1.0000000111982792`}, {7.16, 
     1.0000000158177447`}, {7.18, 1.000000019910837}, {7.2, 
     1.0000000233789166`}, {7.22, 1.000000026569039}, {7.24, 
     1.0000000297420195`}, {7.26, 1.0000000325701068`}, {7.28, 
     1.0000000342833906`}, {7.3, 1.0000000343715014`}, {7.32, 
     1.000000033140714}, {7.34, 1.000000031597242}, {7.36, 
     1.0000000307062313`}, {7.38, 1.0000000307769363`}, {7.4, 
     1.0000000312243271`}, {7.42, 1.0000000313022157`}, {7.44, 
     1.0000000302276995`}, {7.46, 1.0000000283581145`}, {7.48, 
     1.000000025529739}, {7.5, 1.0000000230742168`}, {7.5200000000000005`, 
     1.0000000199766423`}, {7.54, 1.0000000178271262`}, {7.5600000000000005`, 
     1.0000000147947026`}, {7.58, 1.0000000127958395`}, {7.6000000000000005`, 
     1.000000010775833}, {7.62, 1.0000000093744106`}, {7.640000000000001, 
     1.000000009514014}, {7.66, 1.0000000086323724`}, {7.68, 
     1.0000000096481874`}, {7.7, 1.0000000085044434`}, {7.72, 
     1.0000000081641949`}, {7.74, 1.0000000067097496`}, {7.76, 
     1.0000000052310707`}, {7.78, 1.0000000039796804`}, {7.8, 
     1.0000000029121312`}, {7.82, 1.0000000023946798`}, {7.84, 
     1.0000000016532415`}, {7.86, 1.0000000016966542`}, {7.88, 
     1.0000000012095727`}, {7.9, 1.0000000004317102`}, {7.92, 
     1.0000000008751817`}, {7.94, 0.9999999997150102}, {7.96, 
     1.0000000000370963`}, {7.98, 0.9999999999613496}, {8., 1}}, 
    Function[Null, 
     Internal`LocalizedBlock[{$CellContext`a, $CellContext`r, \
$CellContext`r0}, #], {HoldAll}]]& ],
  Editable->False,
  SelectWithContents->True,
  Selectable->True]], "Output",
 CellChangeTimes->{
  3.7564024085704803`*^9, {3.7564027908330355`*^9, 3.7564028111490192`*^9}, {
   3.756402940270625*^9, 3.7564029969017057`*^9}, {3.756403946409819*^9, 
   3.7564039575889907`*^9}, {3.756730840588401*^9, 3.7567308757173395`*^9}, {
   3.756732593154055*^9, 3.7567326717642508`*^9}, {3.756733019687006*^9, 
   3.7567330493296523`*^9}, {3.75673311556913*^9, 3.7567331556678214`*^9}, {
   3.756733195637099*^9, 3.756733218850814*^9}, 3.75673329834809*^9, 
   3.7567333387139225`*^9, {3.7567333950548415`*^9, 3.756733411753706*^9}, 
   3.756733450661966*^9, {3.7567335195061646`*^9, 3.756733527969396*^9}, 
   3.756748267043603*^9, 3.7569223420508604`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.028, 0.5376, 0.5936], PointSize[0.011111111111111112`], 
      AbsoluteThickness[1.6], 
      StyleBox[LineBox[CompressedData["
1:eJxV2HdYU+fbB/AQ9oYQkkCWC38OWi2idVSf21GGVhS1ihVRUMGJUrSuuhDE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        "]],
       FontFamily->"Helvetica"]}}, {}, {}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {RGBColor[1, 0, 0], Thickness[0.003], Opacity[1.], 
       Dashing[{Small, Small}], CapForm["Butt"], LineBox[CompressedData["
1:eJwd23c4lV8cAHB7Z9zl3isKKYmmkobzFWVmRTSojIYUIaXsUUSloiGiRCWz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        "]]},
      Annotation[#, "Charting`Private`Tag$8216#1"]& ]}, {}, {}}, 
   TagBox[InsetBox[
     StyleBox[
      RowBox[{"Numerical", " ", "Solution"}],
      FontSize->14], {2.3, 0.8}],
    "InsetString"], ArrowBox[{{3.16, 0.81}, {4.3, 0.93}}], 
   TagBox[InsetBox[
     RowBox[{
      StyleBox[
       RowBox[{"Fitted", " ", "Solution", " ", 
        RowBox[{"(", "dashed", ")"}]}],
       FontSize->14], "\n", 
      StyleBox[
       RowBox[{
        RowBox[{"\[CapitalPhi]", 
         RowBox[{"(", "r", ")"}]}], "=", 
        RowBox[{"Tanh", "[", 
         RowBox[{"2.89", 
          RowBox[{"(", 
           RowBox[{"r", "-", "3.84"}], ")"}]}], "]"}]}],
       FontSize->14]}], {6, -0.8}],
    "InsetString"], ArrowBox[{{4.86, -0.8}, {3.36, -0.94}}]},
  PlotTheme -> "Scientific",
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{Medium, FontFamily -> "Times", Italic},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox["\"r\"", TraditionalForm], 
    FormBox["\"\[CapitalPhi](r)\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    GrayLevel[0], FontFamily -> "Times", Large],
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->None,
  PlotRange->{{0, 8}, {1, -1}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.7564024085704803`*^9, {3.7564027908330355`*^9, 3.7564028111490192`*^9}, {
   3.756402940270625*^9, 3.7564029969017057`*^9}, {3.756403946409819*^9, 
   3.7564039575889907`*^9}, {3.756730840588401*^9, 3.7567308757173395`*^9}, {
   3.756732593154055*^9, 3.7567326717642508`*^9}, {3.756733019687006*^9, 
   3.7567330493296523`*^9}, {3.75673311556913*^9, 3.7567331556678214`*^9}, {
   3.756733195637099*^9, 3.756733218850814*^9}, 3.75673329834809*^9, 
   3.7567333387139225`*^9, {3.7567333950548415`*^9, 3.756733411753706*^9}, 
   3.756733450661966*^9, {3.7567335195061646`*^9, 3.756733527969396*^9}, 
   3.756748267043603*^9, 3.7569223421709657`*^9}],

Cell[BoxData["\<\"fig2.pdf\"\>"], "Output",
 CellChangeTimes->{
  3.7564024085704803`*^9, {3.7564027908330355`*^9, 3.7564028111490192`*^9}, {
   3.756402940270625*^9, 3.7564029969017057`*^9}, {3.756403946409819*^9, 
   3.7564039575889907`*^9}, {3.756730840588401*^9, 3.7567308757173395`*^9}, {
   3.756732593154055*^9, 3.7567326717642508`*^9}, {3.756733019687006*^9, 
   3.7567330493296523`*^9}, {3.75673311556913*^9, 3.7567331556678214`*^9}, {
   3.756733195637099*^9, 3.756733218850814*^9}, 3.75673329834809*^9, 
   3.7567333387139225`*^9, {3.7567333950548415`*^9, 3.756733411753706*^9}, 
   3.756733450661966*^9, {3.7567335195061646`*^9, 3.756733527969396*^9}, 
   3.756748267043603*^9, 3.756922342591037*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Figure 3",
 FontSize->18]], "Section",
 CellChangeTimes->{{3.756909287217084*^9, 3.75690929049059*^9}},
 Background->RGBColor[0., 1., 1.]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Plots", " ", "of", " ", "a", " ", "3", "d", " ", "metastable", " ", 
    "field", " ", "configuration", " ", "and", " ", "its", " ", "density"}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"b", ",", "ll"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"b", "=", 
     RowBox[{"-", "0.255"}]}], ";", " ", 
    RowBox[{"ll", "=", 
     RowBox[{"-", "0.202"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"v", ",", "f", ",", "h", ",", "h1"}], "]"}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{
    "this", " ", "is", " ", "a", " ", "good", " ", "choice", " ", "of", " ", 
     "parameters", " ", "starting", " ", "exactly", "  ", "on", " ", "the", 
     " ", "static", " ", "solution", " ", "and", " ", "staying", " ", 
     "there"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Vphi", "[", 
      RowBox[{"t_", ",", "x_"}], "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"f", "[", 
           RowBox[{"t", ",", "x"}], "]"}], "^", "2"}], "-", "1"}], ")"}], "^",
        "2"}], "/", "4"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"V", "[", 
      RowBox[{"t_", ",", "x_"}], "]"}], "=", 
     RowBox[{"Vphi", "[", 
      RowBox[{"t", ",", "x"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"dV", "[", 
      RowBox[{"t_", ",", "x_"}], "]"}], "=", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"Vphi", "[", 
        RowBox[{"t", ",", "x"}], "]"}], ",", 
       RowBox[{"f", "[", 
        RowBox[{"t", ",", "x"}], "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dd", "=", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", "b", " ", "r"}], " ", "-", 
      RowBox[{"ll", " ", 
       RowBox[{
        RowBox[{"r", "^", "2"}], "/", "3"}]}]}]}], " ", ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pde", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"f", "[", 
           RowBox[{"t", ",", "r"}], "]"}], ",", "t"}], "]"}], " ", "==", 
        RowBox[{"g", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"r", "^", "2"}], " ", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"g", "[", 
             RowBox[{"t", ",", "r"}], "]"}], ",", "t"}], "]"}], "/", "dd"}]}],
         "\[Equal]", " ", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"r", "^", "2"}], " ", "dd", " ", 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"f", "[", 
               RowBox[{"t", ",", "r"}], "]"}], ",", "r"}], "]"}]}], ",", 
           "r"}], "]"}], "-", 
         RowBox[{
          RowBox[{"dV", "[", 
           RowBox[{"t", ",", "r"}], "]"}], " ", 
          RowBox[{"r", "^", "2"}]}]}]}]}], "}"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"rmin", "=", "0.1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rmax", "=", "15"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r0", "=", "3.3"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tmax", "=", "800"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], "=", 
     RowBox[{"Tanh", "[", 
      RowBox[{"3", 
       RowBox[{"(", 
        RowBox[{"r", "-", "r0"}], ")"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"h1", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], "=", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"h", "[", 
        RowBox[{"t", ",", "r"}], "]"}], ",", "t"}], "]"}]}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"time", " ", "derivative", " ", "of", " ", 
     RowBox[{"h", "[", 
      RowBox[{"t", ",", "x"}], "]"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"bc", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"0", ",", "r"}], "]"}], "\[Equal]", 
        RowBox[{"h", "[", 
         RowBox[{"0", ",", "r"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"g", "[", 
         RowBox[{"0", ",", "r"}], "]"}], "\[Equal]", 
        RowBox[{"h1", "[", 
         RowBox[{"0", ",", "r"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"t", ",", "rmin"}], "]"}], "\[Equal]", 
        RowBox[{"-", "1"}]}], ",", 
       RowBox[{
        RowBox[{"g", "[", 
         RowBox[{"t", ",", "rmin"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"t", ",", "rmax"}], "]"}], "\[Equal]", "1"}], ",", 
       RowBox[{
        RowBox[{"g", "[", 
         RowBox[{"t", ",", "rmax"}], "]"}], "\[Equal]", "0"}]}], "}"}]}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{"solution", "=", 
     RowBox[{"NDSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"pde", ",", "bc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"f", ",", "g"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "rmin", ",", "rmax"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
       RowBox[{"StartingStepSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", 
          RowBox[{"rmax", "/", "30"}]}], "}"}]}], ",", 
       RowBox[{"PrecisionGoal", "\[Rule]", "2"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"fsol0", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{"t", ",", "r"}], "]"}], " ", "/.", " ", "solution"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"field", "=", 
     RowBox[{"RevolutionPlot3D", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"fsol0", "[", 
         RowBox[{"100", ",", "rr"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"rr", ",", "0.1", ",", "6"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "x", ",", "y", ",", "z", ",", "t", ",", "\[Theta]", ",", "r"}], 
           "}"}], ",", 
          RowBox[{
           RowBox[{"ColorData", "[", "\"\<Rainbow\>\"", "]"}], "[", "r", 
           "]"}]}], "]"}]}], ",", 
       RowBox[{"PlotTheme", "->", "\"\<Scientific\>\""}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<\!\(\*
StyleBox[\"x\",
FontSize->14]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"y\",
FontSize->14]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"\[CapitalPhi]\",
FontSize->14]\)\!\(\*
StyleBox[\"(\",
FontSize->14]\)\!\(\*
StyleBox[\"r\",
FontSize->14]\)\!\(\*
StyleBox[\")\",
FontSize->14]\)\>\""}], "}"}]}]}], "]"}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"Plot", " ", "of", " ", "the", " ", "field"}], "*)"}], "\n", 
   RowBox[{"Clear", "[", 
    RowBox[{"rho1", ",", "tt"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"fmet", "[", "r_", "]"}], ":=", 
     RowBox[{"(", 
      RowBox[{"1", " ", "+", " ", 
       RowBox[{"2", " ", "b", " ", "r"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"ll", "/", "3"}], ")"}], " ", 
        RowBox[{"r", "^", "2"}]}]}], ")"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"rho1", "[", 
      RowBox[{"tt_", ",", "rr_"}], "]"}], ":=", 
     RowBox[{"Part", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"0.5", " ", 
          RowBox[{"fmet", "[", "r", "]"}], " ", 
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"fsol0", "[", 
              RowBox[{"t", ",", "r"}], "]"}], ",", "r"}], "]"}], "^", "2"}]}],
          "+", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"fsol0", "[", 
               RowBox[{"t", ",", "r"}], "]"}], "^", "2"}], "-", "1"}], ")"}], 
           "^", "2"}], " ", "/", "4"}]}], "  ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"t", "\[Rule]", "tt"}], ",", 
          RowBox[{"r", "\[Rule]", "rr"}]}], "}"}]}], ",", "1"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rho1", "[", 
     RowBox[{"0.1", ",", "rmin"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"density", "=", 
     RowBox[{"RevolutionPlot3D", "[", 
      RowBox[{
       RowBox[{"rho1", "[", 
        RowBox[{"100", ",", "rr"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"rr", ",", "0.1", ",", "6"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "x", ",", "y", ",", "z", ",", "t", ",", "\[Theta]", ",", "r"}], 
           "}"}], ",", 
          RowBox[{
           RowBox[{"ColorData", "[", "\"\<Rainbow\>\"", "]"}], "[", "r", 
           "]"}]}], "]"}]}], ",", 
       RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<\!\(\*
StyleBox[\"x\",
FontSize->14]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"y\",
FontSize->14]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"\[Rho]\",
FontSize->14]\)\!\(\*
StyleBox[\"(\",
FontSize->14]\)\!\(\*
StyleBox[\"r\",
FontSize->14]\)\!\(\*
StyleBox[\")\",
FontSize->14]\)\>\""}], 
         StyleBox["}",
          FontSize->12]}]}]}], "]"}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"Density", " ", "plot"}], "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.7563888941775365`*^9, 3.7563888953333235`*^9}, {
   3.7563890092787285`*^9, 3.756389019175475*^9}, 3.7567336991214895`*^9, {
   3.7567338302196355`*^9, 3.75673383230855*^9}, {3.756733917098283*^9, 
   3.756733991336949*^9}, {3.756734061097028*^9, 3.7567340634142294`*^9}, {
   3.756734118348467*^9, 3.7567341363474264`*^9}, {3.7567341694464183`*^9, 
   3.7567341910233154`*^9}, {3.7568984665404787`*^9, 
   3.7568984976182942`*^9}, {3.756898548445243*^9, 3.7568986595640674`*^9}, 
   3.7569126081456795`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"grid3d", "=", 
  RowBox[{"Panel", "[", 
   RowBox[{
    RowBox[{"GraphicsGrid", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"field", ",", "density"}], "}"}], "}"}], ",", 
      RowBox[{"Spacings", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "Full"}]}], "]"}], ",", 
    RowBox[{"Background", "\[Rule]", "White"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 PanelBox[
  GraphicsBox[{{}, {InsetBox[
      Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx0fXlcTd/3fvMgjSpTCHlnJolSOgeVIUMyjyGiJEJknofMQpIMGUIyl4rc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        "], {{
          {RGBColor[0.91, 0.424, 0.1486], EdgeForm[None], 
           StyleBox[GraphicsGroup3DBox[
             TagBox[
              TagBox[{Polygon3DBox[CompressedData["
1:eJxFnHkcFtP3x59nZu7MgxKyR7QohUohW7ZoQVREdpLsJftO9iXKvi9l3yr7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                 "]], Polygon3DBox[CompressedData["
1:eJwtm3cc19MXxj/zfr6UQrIiTW2joqWlqUFFGYlKKjIKUSHSInuURMqWPbIJ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                 "]], Polygon3DBox[CompressedData["
1:eJwt1necFtUVxvGBd2WjC2hEQBYwNJENIggqRToonQCKSFlQjLqIgCgLhN4V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                 "]]},
               Annotation[#, "Charting`Private`Tag$8583#1"]& ],
              Annotation[#, "Charting`Private`Tag$8602#1"]& ]],
            Lighting->"Neutral"]}, {}, {}, {}, {}}, {
          {GrayLevel[0.2], Line3DBox[CompressedData["
1:eJwl0ktLVGEYwPFnHNPUTFtEiZC0jvoE9glqlRBUO3cWmUShLoJKUTcFkRS1
qY1C1EZRupi31EUXL3hpvNsgSEUgfoHo9yZ4+P+e95x3zjnjnKy/caExExGv
HG0FEcmh23LnQESl3rfYyTXcxY/4DC8VRTw0n+Ucd/N5XuHnfIU3+CVf5V6d
treV33COu7if8/yU33Gv/rRvhAf5N0/yJE/xNX7vGRfMd/VLmrMRi+YPuqRD
+l0/ak6HdVmXCyPSC69wo3vO2N9kHtJVazd5xLVrPGvtlvm660Z53dpt86jz
GzymmzquW/pJf6R3do9m143Zk0/fn34zH/fs8+bPXMoTPMF/ff5Aekbu0R3n
3vIT3ua+9P1znl9zC/foV/sa+AUP82V+xn18jh+nz+NaXrT3gfk0z3Enn+AG
3kv/V89Yoaf0nnPV3uWwuUrL9Zge0qNappe8466WOrL2XDT/4Q4u0TrzLz3o
yFjb0XY9Yn8xt7pHBbt9lKvHjDK1LUrUXxRn//8UY9NiS2b/9/kPJTRfDw==

            "],
            VertexColors->None]}, {}, {}, 
          {GrayLevel[0.2], 
           Line3DBox[{775, 964, 1956, 776, 974, 798, 2009, 984, 811, 2011, 
            994, 824, 2014, 1004, 837, 2020, 1014, 850, 2027, 1024, 863, 1034,
             1983, 876, 1044, 889, 2037, 1054, 902, 2038, 1064, 915, 2040, 
            1074, 928, 2045, 1084, 941, 2052, 1094, 954},
            VertexColors->None], 
           Line3DBox[{777, 965, 1957, 778, 975, 1964, 799, 2010, 985, 812, 
            2012, 995, 825, 2015, 1005, 838, 2021, 1015, 851, 2028, 1025, 864,
             1035, 1984, 877, 1045, 1991, 890, 1055, 903, 2039, 1065, 916, 
            2041, 1075, 929, 2046, 1085, 942, 2053, 1095, 955},
            VertexColors->None], 
           Line3DBox[{779, 966, 1958, 780, 976, 1965, 800, 986, 1971, 813, 
            2013, 996, 826, 2016, 1006, 839, 2022, 1016, 852, 2029, 1026, 865,
             1036, 1985, 878, 1046, 1992, 891, 1056, 1997, 904, 1066, 917, 
            2042, 1076, 930, 2047, 1086, 943, 2054, 1096, 956},
            VertexColors->None], 
           Line3DBox[{781, 967, 1959, 782, 977, 1966, 801, 987, 1972, 814, 
            997, 1976, 827, 2017, 1007, 840, 2023, 1017, 853, 2030, 1027, 866,
             1037, 1986, 879, 1047, 1993, 892, 1057, 1998, 905, 1067, 2002, 
            918, 1077, 931, 2048, 1087, 944, 2055, 1097, 957},
            VertexColors->None], 
           Line3DBox[{783, 1104, 1105, 1960, 784, 1117, 1118, 1967, 802, 1127,
             2069, 1128, 815, 1137, 2073, 1138, 828, 1147, 2078, 1148, 841, 
            1157, 1158, 854, 2031, 1167, 1168, 867, 1177, 1178, 1987, 880, 
            1187, 1188, 893, 1197, 2093, 1198, 906, 1207, 2096, 1208, 919, 
            1217, 2100, 1218, 932, 1227, 1228, 945, 2056, 1237, 1238, 1240},
            VertexColors->None], Line3DBox[CompressedData["
1:eJwV0DssQwEYR/FPkNjUM6EGZVAGj0EZ6pEUoWVQBo+hdPBYajCbzWaz2Ww2
m40kIo2IiIiIhMTvDifn/L/c3OTeTPWkXGuIiAraGiN+myL+8ICO5oh2LLVE
PNqdugsV3csp9x5+stPch2O97J7R/Xi2B3gQ3e6ndlYPoa6HeQRneoxH8aLH
ecXzE3xu53gSr3rGfUpP4yLZnMebnuU5XOoFLqDo+Xd7MfkWXOkSZ92L/GGv
8hqudZnX8ak3eBM3epu38KV3eBe3ei/5J/jW+1zy3irf2Yd8gB89736U/CPc
2yluRQ3/Flgp/w==
            "],
            VertexColors->None], 
           Line3DBox[{8, 645, 379, 720, 1864, 23, 649, 245, 1644, 705, 38, 
            653, 255, 1654, 706, 53, 657, 1839, 265, 707, 68, 661, 1844, 275, 
            708, 83, 665, 285, 709, 98, 1476, 669, 295, 710, 113, 673, 305, 
            711, 1863, 128, 677, 315, 712, 143, 681, 325, 1709, 713, 158, 685,
             335, 714, 173, 689, 1855, 345, 715, 188, 693, 355, 716, 203, 
            1553, 698, 367, 717, 218},
            VertexColors->None], 
           Line3DBox[{789, 970, 1961, 790, 980, 1968, 806, 990, 1973, 819, 
            1000, 1977, 832, 2019, 1010, 845, 2025, 1020, 858, 2034, 1030, 
            871, 1040, 1988, 884, 1050, 1994, 897, 1060, 1999, 910, 1070, 
            2003, 923, 2044, 1080, 936, 2050, 1090, 949, 2058, 1100, 960},
            VertexColors->None], 
           Line3DBox[{791, 971, 1962, 792, 981, 1969, 807, 991, 1974, 820, 
            1001, 1978, 833, 1011, 1980, 846, 2026, 1021, 859, 2035, 1031, 
            872, 1041, 1989, 885, 1051, 1995, 898, 1061, 2000, 911, 1071, 
            2004, 924, 1081, 2006, 937, 2051, 1091, 950, 2059, 1101, 961},
            VertexColors->None], 
           Line3DBox[{793, 972, 1963, 794, 982, 1970, 808, 992, 1975, 821, 
            1002, 1979, 834, 1012, 1981, 847, 1022, 1982, 860, 2036, 1032, 
            873, 1042, 1990, 886, 1052, 1996, 899, 1062, 2001, 912, 1072, 
            2005, 925, 1082, 2007, 938, 1092, 2008, 951, 2060, 1102, 962},
            VertexColors->None], 
           Line3DBox[{795, 1114, 2062, 1115, 796, 1124, 2067, 1125, 809, 1134,
             2071, 1135, 822, 1144, 2076, 1145, 835, 1154, 2080, 1155, 848, 
            1164, 2083, 1165, 861, 1174, 2084, 1175, 874, 1184, 2086, 1185, 
            887, 1194, 2091, 1195, 900, 1204, 2094, 1205, 913, 1214, 2098, 
            1215, 926, 1224, 2102, 1225, 939, 1234, 2105, 1235, 952, 1243, 
            2106, 1244, 1245},
            VertexColors->None], 
           Line3DBox[{953, 1093, 1236, 940, 1083, 2103, 1226, 927, 1073, 2099,
             1216, 914, 1063, 2095, 1206, 901, 1053, 2092, 1196, 888, 1043, 
            2087, 1186, 875, 1033, 1176, 862, 1023, 1166, 849, 1013, 2081, 
            1156, 836, 1003, 2077, 1146, 823, 993, 2072, 1136, 810, 983, 2068,
             1126, 797, 973, 2063, 1116, 774, 1955, 963, 1103, 1246},
            VertexColors->None], 
           Line3DBox[{958, 1098, 1241, 1231, 946, 1088, 1230, 2104, 1221, 933,
             1078, 1220, 2101, 1211, 920, 1068, 1210, 1201, 907, 1058, 2089, 
            1200, 1191, 894, 1048, 2085, 1190, 1181, 881, 2110, 1038, 1180, 
            1171, 868, 1028, 1170, 1161, 2032, 855, 1018, 1160, 2082, 1151, 
            842, 1008, 1150, 2079, 1141, 829, 998, 1140, 2074, 1131, 816, 988,
             2065, 1130, 1121, 803, 978, 2061, 1120, 1109, 786, 2107, 968, 
            1249, 1106, 1107},
            VertexColors->None], 
           Line3DBox[{959, 1099, 1242, 2057, 948, 1089, 1232, 2049, 935, 1079,
             1222, 2043, 922, 1069, 2097, 1212, 909, 2129, 1059, 1202, 896, 
            2128, 1049, 1192, 883, 2127, 1039, 1182, 870, 1029, 1172, 2033, 
            857, 1019, 1162, 2024, 844, 1009, 1152, 2018, 831, 999, 2075, 
            1142, 818, 2126, 989, 1132, 805, 2125, 979, 1122, 788, 2124, 969, 
            1111, 1113},
            VertexColors->None], Line3DBox[CompressedData["
1:eJwV0Lkrx2EcB/DHfSsUFqQwOAbH4sgtpJBcAwY/Fvd9DjKzGkw2ZTabzf4F
SZIkSaLw+g6v3p/n9/48355+pbOrIytxIYRDxhND+CU7KYRReU++eZUCWlJD
yEsI4c/vhc6T8oEic69uTRZTZifIEmL6R3L1Zc7rlFNrJ05WsKzv0D/JKucN
qmm1Ey9r2NV12nmWdc6b1DNgJ0E2cKx7odG8RVP0Rn2Xe4nmZk70r7Sbt+lg
3k6S7ORM90aveYc+2tzfsJNs7udC/85g9C6GONKnyGGudB9UujfmvMc4p3ZS
5QTX+k+mzPtMc65PkzPc6Lrd/5Ix5wPmuLSTHr2ZW903C+ZDFqPv6nvcyzAv
caf/IdOcQ1b0f/MPScgz7A==
            "],
            VertexColors->None]}, 
          {GrayLevel[0.2], 
           Line3DBox[{1405, 1636, 1955, 1561, 1404, 1956, 1562, 1406, 1957, 
            1563, 1407, 1958, 1564, 1408, 1959, 1565, 1409, 1931, 1960, 1566, 
            1737, 1945, 2118, 1808, 1738, 1805, 1567, 1864, 1806, 1807, 1740, 
            2107, 1568, 1739, 1809, 1810, 1741, 1946, 2108, 1569, 1867, 1865, 
            1866, 1837, 2124, 1570, 1410, 1961, 1571, 1411, 1962, 1572, 1412, 
            1963, 1573, 1413, 2062, 1640, 1574, 1641},
            VertexColors->None], 
           Line3DBox[{1415, 1642, 1880, 2063, 1414, 974, 1416, 1964, 1575, 
            1417, 1965, 1576, 1418, 1966, 1577, 1419, 1932, 1967, 1578, 1643, 
            2064, 1811, 1637, 1868, 1793, 1794, 1644, 1795, 1638, 1742, 1881, 
            2061, 1646, 1814, 1639, 1870, 2119, 1812, 1813, 1743, 1869, 1648, 
            1838, 2125, 1579, 1420, 1968, 1580, 1421, 1969, 1581, 1422, 1970, 
            1582, 1423, 2067, 1650, 1583, 1744},
            VertexColors->None], 
           Line3DBox[{1425, 1651, 1882, 2068, 1424, 1883, 2009, 1426, 1884, 
            2010, 1427, 1971, 1584, 1428, 1972, 1585, 1429, 2069, 1652, 1586, 
            1653, 1947, 2120, 1645, 1871, 1796, 1797, 1654, 1798, 1647, 1745, 
            1885, 2065, 1657, 1817, 1649, 1873, 1949, 2066, 1816, 1747, 1872, 
            1660, 1840, 2126, 1587, 1430, 1973, 1588, 1431, 1974, 1589, 1432, 
            1975, 1590, 1433, 2071, 1663, 1591, 1748},
            VertexColors->None], 
           Line3DBox[{1445, 1677, 1676, 2076, 1444, 1595, 1979, 1443, 1594, 
            1978, 1442, 1593, 1977, 1441, 2075, 1673, 1841, 1672, 1842, 1843, 
            1776, 2113, 1662, 1819, 1661, 1818, 1440, 2074, 1659, 1746, 1658, 
            1775, 1839, 1774, 1656, 1815, 1655, 2070, 1948, 1439, 1667, 1666, 
            2073, 1438, 1592, 1976, 1437, 2013, 1888, 1436, 2012, 1887, 1435, 
            2011, 1886, 1434, 2072, 1665, 1664, 1749},
            VertexColors->None], 
           Line3DBox[{1457, 1685, 1684, 2080, 1456, 1597, 1981, 1455, 1596, 
            1980, 1454, 2019, 1893, 1453, 1933, 2018, 1845, 1683, 1846, 1847, 
            1779, 2114, 1675, 1822, 1674, 1821, 1452, 2079, 1671, 1750, 1670, 
            1778, 1844, 1777, 1669, 1820, 1668, 1322, 1451, 1681, 1680, 2078, 
            1450, 2017, 1892, 1449, 2016, 1891, 1448, 2015, 1890, 1447, 2014, 
            1889, 1446, 2077, 1679, 1678, 1751},
            VertexColors->None], 
           Line3DBox[{1469, 1690, 1689, 2083, 1468, 1598, 1982, 1467, 2026, 
            1899, 1466, 2025, 1898, 1465, 1935, 2024, 1848, 667, 668, 483, 
            1332, 583, 582, 1464, 2082, 1682, 1752, 482, 665, 481, 579, 578, 
            2121, 1463, 1688, 1157, 1462, 2023, 1897, 1461, 2022, 1896, 1460, 
            2021, 1895, 1459, 2020, 1894, 1458, 2081, 1687, 1686, 1753},
            VertexColors->None], 
           Line3DBox[{106, 862, 107, 863, 108, 864, 109, 865, 110, 866, 111, 
            867, 112, 1261, 417, 113, 418, 868, 114, 420, 869, 115, 674, 870, 
            116, 871, 117, 872, 118, 873, 119, 874, 120},
            VertexColors->None], 
           Line3DBox[{1483, 1694, 1693, 2084, 1482, 2036, 1906, 1481, 2035, 
            1905, 1480, 2034, 1904, 1479, 1937, 2033, 1849, 1851, 1850, 1478, 
            1784, 2115, 1943, 1756, 1825, 1824, 1477, 1934, 2032, 1755, 1783, 
            1782, 1476, 1780, 1781, 1754, 1823, 2109, 1950, 1475, 1692, 2031, 
            1936, 1474, 2030, 1903, 1473, 2029, 1902, 1472, 2028, 1901, 1471, 
            2027, 1900, 1470, 1166, 1691, 1757},
            VertexColors->None], 
           Line3DBox[{1485, 1695, 1033, 1484, 1983, 1599, 1486, 1984, 1600, 
            1487, 1985, 1601, 1488, 1986, 1602, 1489, 1938, 1987, 1603, 1696, 
            1951, 2122, 1826, 1758, 1799, 1604, 1863, 1800, 1801, 1759, 2110, 
            1605, 1697, 1827, 1828, 1760, 1952, 2111, 1606, 1876, 1874, 1875, 
            1852, 2127, 1607, 1490, 1988, 1608, 1491, 1989, 1609, 1492, 1990, 
            1610, 1493, 2086, 1698, 1611, 1761},
            VertexColors->None], 
           Line3DBox[{1495, 1699, 1907, 2087, 1494, 1044, 1496, 1991, 1612, 
            1497, 1992, 1613, 1498, 1993, 1614, 1499, 1188, 1615, 1700, 2088, 
            605, 753, 531, 712, 532, 1762, 1908, 2085, 1702, 609, 756, 1399, 
            608, 755, 754, 1853, 2128, 1616, 1500, 1994, 1617, 1501, 1995, 
            1618, 1502, 1996, 1619, 1503, 2091, 1705, 1620, 1763},
            VertexColors->None], 
           Line3DBox[{1505, 1706, 1909, 2092, 1504, 1910, 2037, 1506, 1055, 
            1507, 1997, 1621, 1508, 1998, 1622, 1509, 2093, 1707, 1623, 1708, 
            1362, 1701, 1877, 1802, 1803, 1709, 1804, 1703, 1764, 1911, 2089, 
            1710, 1830, 1704, 1879, 1953, 2090, 1829, 1765, 1878, 1711, 1854, 
            2129, 1624, 1510, 1999, 1625, 1511, 2000, 1626, 1512, 2001, 1627, 
            1513, 2094, 1712, 1628, 1766},
            VertexColors->None], 
           Line3DBox[{440, 332, 2095, 1514, 1912, 2038, 1515, 1913, 2039, 
            1516, 1066, 1517, 2002, 1629, 1518, 2096, 333, 334, 1209, 326, 
            335, 328, 1210, 337, 330, 1270, 443, 339, 2097, 1519, 2003, 1630, 
            1520, 2004, 1631, 1521, 2005, 1632, 1522, 2098, 341, 445},
            VertexColors->None], 
           Line3DBox[{1534, 1726, 1725, 2102, 1533, 1634, 2007, 1532, 1633, 
            2006, 1531, 2044, 1917, 1530, 1939, 2043, 1856, 1724, 1857, 1858, 
            1787, 2116, 1718, 1833, 1717, 1832, 1529, 2101, 1716, 1767, 1715, 
            1786, 1855, 1785, 1714, 1831, 1713, 1371, 1528, 1722, 1721, 2100, 
            1527, 1077, 1526, 2042, 1916, 1525, 2041, 1915, 1524, 2040, 1914, 
            1523, 2099, 1720, 1719, 1768},
            VertexColors->None], 
           Line3DBox[{1546, 1731, 1730, 2105, 1545, 1635, 2008, 1544, 2051, 
            1923, 1543, 2050, 1922, 1542, 1940, 2049, 1859, 695, 696, 504, 
            1381, 632, 631, 1541, 2104, 1723, 1769, 503, 693, 502, 628, 627, 
            2123, 1540, 1729, 1227, 1539, 2048, 1921, 1538, 2047, 1920, 1537, 
            2046, 1919, 1536, 2045, 1918, 1535, 2103, 1728, 1727, 1770},
            VertexColors->None], 
           Line3DBox[{1560, 1736, 1735, 2106, 1559, 2060, 1930, 1558, 2059, 
            1929, 1557, 2058, 1928, 1556, 1942, 2057, 1860, 1862, 1861, 1555, 
            1792, 2117, 1944, 1773, 1836, 1835, 1554, 1231, 1772, 1791, 1790, 
            1553, 1788, 1789, 1771, 1834, 2112, 1954, 1552, 1734, 2056, 1941, 
            1551, 2055, 1927, 1550, 2054, 1926, 1549, 2053, 1925, 1548, 2052, 
            1924, 1547, 1236, 1732, 1733},
            VertexColors->None]}}},
        VertexColors->{
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.34489114285714295`, 0.6357064285714287, 0.6725417142857142], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.5134169999999999, 0.72992, 0.44068200000000013`], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857143, 0.6205167142857141, 0.22512285714285712`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.31617314285714304`, 0.16498571428571435`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428576`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571427, 0.3161731428571422, 0.16498571428571418`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571393`, 0.19902199999999992`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[
          0.41993314285714295`, 0.6952647142857143, 0.5553739999999999], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571393`, 0.19902199999999992`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[
          0.24882857142857143`, 0.26420199999999994`, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.5134169999999999, 0.72992, 0.44068200000000013`], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285712, 0.6995635714285716, 0.25042971428571437`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714289, 0.743557, 0.35009928571428556`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571393`, 0.19902199999999992`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.5134169999999999, 0.72992, 0.44068200000000013`], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285712, 0.6995635714285716, 0.25042971428571437`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428576`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714289, 0.743557, 0.35009928571428556`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571393`, 0.19902199999999992`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.4907817142857146, 0.19902200000000006`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.34489114285714295`, 0.6357064285714287, 0.6725417142857142], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.5134169999999999, 0.72992, 0.44068200000000013`], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[
          0.37978228571428574`, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.6772131428571428, 0.742913, 0.31614442857142866`], 
          RGBColor[
          0.7817617142857145, 0.7242198571428571, 0.26630585714285704`], 
          RGBColor[0.869215, 0.22373571428571426`, 0.1483297142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[
          0.37978228571428574`, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[0.869215, 0.22373571428571426`, 0.1483297142857143], 
          RGBColor[
          0.37978228571428574`, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.5134169999999999, 0.72992, 0.44068200000000013`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[0.869215, 0.22373571428571426`, 0.1483297142857143], 
          RGBColor[
          0.37978228571428574`, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7817617142857145, 0.7242198571428571, 0.26630585714285704`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[0.869215, 0.22373571428571398`, 0.14832971428571423`], 
          RGBColor[
          0.37978228571428574`, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[0.38029771428571435`, 0.6689275714285714, 0.615586], 
          RGBColor[
          0.41993314285714295`, 0.6952647142857143, 0.5553739999999999], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[0.869215, 0.22373571428571426`, 0.1483297142857143], 
          RGBColor[
          0.37978228571428574`, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.5134169999999999, 0.72992, 0.44068200000000013`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[0.869215, 0.22373571428571426`, 0.1483297142857143], 
          RGBColor[
          0.3797822857142857, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7817617142857145, 0.7242198571428571, 0.26630585714285704`], 
          RGBColor[0.6772131428571428, 0.742913, 0.31614442857142866`], 
          RGBColor[0.869215, 0.22373571428571426`, 0.1483297142857143], 
          RGBColor[
          0.3797822857142857, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[
          0.38029771428571424`, 0.6689275714285714, 0.6155860000000002], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.8692150000000001, 0.22373571428571482`, 0.1483297142857144], 
          RGBColor[
          0.3797822857142857, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.6215634285714289, 0.743557, 0.35009928571428556`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[0.869215, 0.22373571428571398`, 0.14832971428571423`], 
          RGBColor[
          0.37978228571428574`, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.6215634285714289, 0.743557, 0.35009928571428556`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[0.869215, 0.22373571428571398`, 0.14832971428571423`], 
          RGBColor[
          0.37978228571428574`, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7817617142857145, 0.7242198571428571, 0.26630585714285704`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[0.869215, 0.22373571428571398`, 0.14832971428571423`], 
          RGBColor[
          0.37978228571428574`, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.5134170000000002, 0.72992, 0.44068199999999985`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.6215634285714289, 0.743557, 0.35009928571428556`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7817617142857145, 0.7242198571428571, 0.26630585714285704`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[0.869215, 0.22373571428571398`, 0.14832971428571423`], 
          RGBColor[
          0.37978228571428574`, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[0.869215, 0.22373571428571398`, 0.14832971428571423`], 
          RGBColor[
          0.37978228571428574`, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.7817617142857145, 0.7242198571428571, 0.26630585714285704`], 
          RGBColor[0.869215, 0.22373571428571426`, 0.1483297142857143], 
          RGBColor[0.869215, 0.22373571428571398`, 0.14832971428571423`], 
          RGBColor[
          0.37978228571428574`, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[0.869215, 0.22373571428571398`, 0.14832971428571423`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.6772131428571428, 0.742913, 0.31614442857142866`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.4656598571428573, 0.7138794285714286, 0.49761857142857124`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.6772131428571428, 0.742913, 0.31614442857142866`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.6772131428571432, 0.742913, 0.31614442857142844`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[
          0.37978228571428574`, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[
          0.42559714285714284`, 0.11128428571428572`, 0.5662882857142858], 
          RGBColor[
          0.4417812857142858, 0.7058591428571428, 0.5260868571428571], 
          RGBColor[
          0.48953842857142876`, 0.7218997142857143, 0.4691502857142855], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[0.649388285714286, 0.743235, 0.333121857142857], 
          RGBColor[
          0.7050380000000004, 0.7425909999999999, 0.2991669999999999], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.8632869999999999, 0.1774208571428567, 0.14022885714285707`], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[
          0.48953842857142865`, 0.7218997142857143, 0.46915028571428563`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[0.540341, 0.7338622857142857, 0.41722657142857156`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[
          0.48953842857142876`, 0.7218997142857143, 0.4691502857142855], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[
          0.48953842857142865`, 0.7218997142857143, 0.46915028571428563`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[
          0.48953842857142865`, 0.7218997142857143, 0.46915028571428563`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[
          0.48953842857142865`, 0.7218997142857143, 0.46915028571428563`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[
          0.7050380000000004, 0.7425909999999999, 0.2991669999999999], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[
          0.48953842857142865`, 0.7218997142857143, 0.46915028571428563`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[
          0.48953842857142865`, 0.7218997142857143, 0.46915028571428563`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[
          0.48953842857142865`, 0.7218997142857143, 0.46915028571428563`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[
          0.7050380000000004, 0.7425909999999999, 0.2991669999999999], 
          RGBColor[
          0.42559714285714284`, 0.11128428571428571`, 0.5662882857142857], 
          RGBColor[
          0.48953842857142865`, 0.7218997142857143, 0.46915028571428563`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.8632869999999999, 0.177420857142857, 0.1402288571428571], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[
          0.4656598571428573, 0.7138794285714286, 0.49761857142857124`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[
          0.48953842857142865`, 0.7218997142857143, 0.46915028571428563`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[0.540341, 0.7338622857142857, 0.41722657142857156`], 
          RGBColor[
          0.48953842857142865`, 0.7218997142857143, 0.46915028571428563`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[
          0.48953842857142876`, 0.7218997142857143, 0.4691502857142855], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[0.540341, 0.7338622857142857, 0.41722657142857156`], 
          RGBColor[
          0.48953842857142876`, 0.7218997142857143, 0.4691502857142855], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[
          0.48953842857142865`, 0.7218997142857143, 0.46915028571428563`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[0.540341, 0.7338622857142857, 0.41722657142857156`], 
          RGBColor[
          0.48953842857142876`, 0.7218997142857143, 0.4691502857142855], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[
          0.48953842857142865`, 0.7218997142857143, 0.46915028571428563`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[
          0.4417812857142856, 0.7058591428571428, 0.5260868571428573], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[0.540341, 0.7338622857142857, 0.41722657142857156`], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.6772131428571428, 0.742913, 0.31614442857142866`], 
          RGBColor[
          0.8632869999999999, 0.1774208571428567, 0.14022885714285707`], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.649388285714286, 0.743235, 0.333121857142857], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.4417812857142856, 0.7058591428571428, 0.5260868571428573], 
          RGBColor[
          0.4417812857142856, 0.7058591428571428, 0.5260868571428573], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.4417812857142858, 0.7058591428571428, 0.5260868571428571], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.4417812857142856, 0.7058591428571428, 0.5260868571428573], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.6772131428571428, 0.742913, 0.31614442857142866`], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.4417812857142858, 0.7058591428571428, 0.5260868571428571], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.4417812857142856, 0.7058591428571428, 0.5260868571428573], 
          RGBColor[
          0.4417812857142856, 0.7058591428571428, 0.5260868571428573], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.4417812857142858, 0.7058591428571428, 0.5260868571428571], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.7050380000000004, 0.7425909999999999, 0.2991669999999999], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.7050380000000004, 0.7425909999999999, 0.2991669999999999], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.42559714285714284`, 0.11128428571428571`, 0.5662882857142857], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[
          0.42559714285714284`, 0.11128428571428571`, 0.5662882857142857], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[0.5134170000000002, 0.72992, 0.44068199999999985`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.857359, 0.131106, 0.132128], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.5134170000000002, 0.72992, 0.44068199999999985`], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.5134170000000002, 0.72992, 0.44068199999999985`], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.7817617142857145, 0.7242198571428571, 0.26630585714285704`], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.5134170000000002, 0.72992, 0.44068199999999985`], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.5134169999999999, 0.72992, 0.44068200000000013`], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.5134170000000002, 0.72992, 0.44068199999999985`], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.7306125714285717, 0.7364672857142857, 0.2882132857142856], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.7817617142857145, 0.7242198571428571, 0.26630585714285704`], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[
          0.8632869999999999, 0.1774208571428567, 0.14022885714285707`], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.5134169999999999, 0.72992, 0.44068200000000013`], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.5134169999999999, 0.72992, 0.44068200000000013`], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.5134170000000002, 0.72992, 0.44068199999999985`], 
          RGBColor[0.5134169999999999, 0.72992, 0.44068200000000013`], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.5134169999999999, 0.72992, 0.44068200000000013`], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.5134169999999999, 0.72992, 0.44068200000000013`], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.5134170000000002, 0.72992, 0.44068199999999985`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.6772131428571428, 0.742913, 0.31614442857142866`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.6772131428571428, 0.742913, 0.31614442857142866`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.4656598571428573, 0.7138794285714286, 0.49761857142857124`], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.6076510000000003, 0.743718, 0.3585879999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000004, 0.19201400000000007`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.878107, 0.29320799999999975`, 0.16048099999999996`], 
          RGBColor[0.878107, 0.29320799999999975`, 0.16048099999999996`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.4866639999999999, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.6076510000000003, 0.743718, 0.3585879999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[
          0.30591899999999994`, 0.5855749999999998, 0.7396660000000002], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.486664, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.794549, 0.721158, 0.260829], 
          RGBColor[
          0.8635120000000001, 0.6707709999999999, 0.23656399999999997`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635120000000001, 0.6707709999999999, 0.23656399999999997`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[
          0.25072800000000006`, 0.22538599999999992`, 0.7691519999999998], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.4866639999999999, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999997, 0.6707710000000002, 0.23656400000000008`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.486664, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.794549, 0.721158, 0.260829], 
          RGBColor[
          0.8635120000000001, 0.6707709999999999, 0.23656399999999997`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[
          0.30591899999999994`, 0.5855749999999998, 0.7396660000000002], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000003, 0.2165420000000001], 
          RGBColor[0.902853, 0.4539639999999997, 0.19201399999999993`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.486664, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000004, 0.19201400000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.3612419999999999, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539639999999997, 0.19201399999999993`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539639999999997, 0.19201399999999993`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.4866639999999999, 0.802529], 
          RGBColor[
          0.30591899999999994`, 0.5855749999999998, 0.7396660000000002], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.794549, 0.721158, 0.260829], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124200000000006`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.486664, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.794549, 0.721158, 0.260829], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[
          0.25072800000000006`, 0.22538599999999992`, 0.7691519999999998], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.486664, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[
          0.30591899999999994`, 0.5855749999999998, 0.7396660000000002], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635120000000001, 0.6707709999999999, 0.23656399999999997`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124200000000006`, 0.816084], 
          RGBColor[0.266122, 0.486664, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[
          0.25072800000000006`, 0.22538599999999992`, 0.7691519999999998], 
          RGBColor[0.24408, 0.36124200000000006`, 0.816084], 
          RGBColor[0.266122, 0.4866639999999999, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.486664, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[
          0.25072800000000006`, 0.22538599999999992`, 0.7691519999999998], 
          RGBColor[0.24408, 0.3612419999999999, 0.816084], 
          RGBColor[0.266122, 0.486664, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000004, 0.19201400000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124200000000006`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999997, 0.6707710000000002, 0.23656400000000008`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.36047999999999997`, 0.655759, 0.6456920000000002], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.6076510000000003, 0.743718, 0.3585879999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.878107, 0.29320799999999975`, 0.16048099999999996`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.878107, 0.29320799999999975`, 0.16048099999999996`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.42984200000000017`, 0.701849, 0.5403209999999998], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.878107, 0.29320799999999975`, 0.16048099999999996`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.794549, 0.721158, 0.260829], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.878107, 0.29320799999999975`, 0.16048099999999996`], 
          RGBColor[0.878107, 0.29320799999999975`, 0.16048099999999996`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.42984199999999995`, 0.701849, 0.5403210000000002], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.878107, 0.29320799999999975`, 0.16048099999999996`], 
          RGBColor[0.878107, 0.29320799999999975`, 0.16048099999999996`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000017`, 0.701849, 0.5403209999999998], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984199999999995`, 0.701849, 0.5403210000000002], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984199999999995`, 0.701849, 0.5403210000000002], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984199999999995`, 0.701849, 0.5403210000000002], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.42984199999999995`, 0.701849, 0.5403210000000002], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984199999999995`, 0.701849, 0.5403210000000002], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.24882857142857143`, 0.26420199999999994`, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.4907817142857146, 0.19902200000000006`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[
          0.3024411428571429, 0.1329808571428571, 0.6794237142857142], 
          RGBColor[
          0.24882857142857143`, 0.26420199999999994`, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571428, 0.6357064285714285, 0.6725417142857145], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571393`, 0.19902199999999992`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428576`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857143, 0.6205167142857141, 0.22512285714285712`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571427, 0.3161731428571422, 0.16498571428571418`], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285718`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428576`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.6215634285714289, 0.743557, 0.35009928571428556`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571427, 0.3161731428571422, 0.16498571428571418`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[
          0.24977828571428573`, 0.24479399999999998`, 0.7758565714285713], 
          RGBColor[
          0.25037771428571426`, 0.3970768571428571, 0.8122111428571429], 
          RGBColor[
          0.28317785714285715`, 0.5290544285714285, 0.7755877142857144], 
          RGBColor[
          0.3370967142857143, 0.6256801428571428, 0.6859665714285715], 
          RGBColor[0.41002428571428573`, 0.6886804285714285, 0.570427], 
          RGBColor[
          0.5014777142857145, 0.7259098571428572, 0.45491614285714266`], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[
          0.717825285714286, 0.7395291428571428, 0.29369014285714273`], 
          RGBColor[
          0.8142527142857141, 0.7067617142857143, 0.25389614285714285`], 
          RGBColor[
          0.8795842857142857, 0.6330802857142857, 0.22798314285714286`], 
          RGBColor[
          0.9020648571428571, 0.5091905714285709, 0.20252599999999993`], 
          RGBColor[
          0.8851772857142857, 0.33913828571428556`, 0.16949042857142854`], 
          RGBColor[
          0.8603230000000001, 0.15426342857142877`, 0.13617842857142862`], 
          RGBColor[
          0.2472288571428571, 0.3791594285714284, 0.8141475714285715], 
          RGBColor[
          0.2774925714285714, 0.5149242857142856, 0.7845681428571429], 
          RGBColor[
          0.32930228571428566`, 0.615653857142857, 0.6993914285714287], 
          RGBColor[
          0.40011542857142857`, 0.6820961428571428, 0.5854800000000001], 
          RGBColor[
          0.804400857142857, 0.7139598571428571, 0.25736257142857144`], 
          RGBColor[
          0.8742268571428571, 0.6456438571428572, 0.2308434285714286], 
          RGBColor[0.9018021428571429, 0.5275994285714285, 0.20603], 
          RGBColor[
          0.8887124285714285, 0.36210342857142863`, 0.17399514285714288`], 
          RGBColor[0.863287, 0.17742085714285755`, 0.1402288571428572], 
          RGBColor[
          0.2718072857142857, 0.5007941428571427, 0.7935485714285716], 
          RGBColor[
          0.32150785714285707`, 0.6056275714285713, 0.7128162857142859], 
          RGBColor[
          0.3902065714285714, 0.6755118571428571, 0.6005330000000001], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8688694285714285, 0.6582074285714287, 0.2337037142857143], 
          RGBColor[
          0.9015394285714285, 0.5460082857142861, 0.20953400000000008`], 
          RGBColor[
          0.8922475714285715, 0.385068571428572, 0.17849985714285724`], 
          RGBColor[0.866251, 0.20057828571428576`, 0.14427928571428572`], 
          RGBColor[
          0.3137134285714284, 0.5956012857142855, 0.7262411428571431], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9012767142857143, 0.5644171428571428, 0.21303800000000003`], 
          RGBColor[
          0.8957827142857143, 0.40803371428571444`, 0.18300457142857146`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[
          0.8993178571428572, 0.4309988571428569, 0.18750928571428566`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[
          0.24977828571428573`, 0.24479399999999998`, 0.7758565714285713], 
          RGBColor[
          0.25037771428571426`, 0.3970768571428571, 0.8122111428571429], 
          RGBColor[
          0.28317785714285715`, 0.5290544285714286, 0.7755877142857143], 
          RGBColor[
          0.3370967142857143, 0.6256801428571428, 0.6859665714285715], 
          RGBColor[
          0.4100242857142858, 0.6886804285714285, 0.5704269999999999], 
          RGBColor[
          0.5014777142857145, 0.7259098571428572, 0.45491614285714266`], 
          RGBColor[0.6076510000000003, 0.743718, 0.3585879999999999], 
          RGBColor[
          0.717825285714286, 0.7395291428571428, 0.29369014285714273`], 
          RGBColor[
          0.8142527142857141, 0.7067617142857143, 0.25389614285714285`], 
          RGBColor[
          0.8795842857142857, 0.6330802857142857, 0.22798314285714286`], 
          RGBColor[0.9020648571428571, 0.5091905714285714, 0.202526], 
          RGBColor[
          0.8851772857142857, 0.33913828571428556`, 0.16949042857142854`], 
          RGBColor[
          0.8603230000000001, 0.15426342857142877`, 0.13617842857142862`], 
          RGBColor[
          0.2472288571428571, 0.3791594285714284, 0.8141475714285715], 
          RGBColor[
          0.2774925714285714, 0.5149242857142856, 0.7845681428571429], 
          RGBColor[
          0.3293022857142857, 0.6156538571428571, 0.6993914285714286], 
          RGBColor[0.4001154285714286, 0.6820961428571428, 0.58548], 
          RGBColor[
          0.8044008571428573, 0.7139598571428569, 0.25736257142857133`], 
          RGBColor[
          0.8742268571428571, 0.6456438571428572, 0.2308434285714286], 
          RGBColor[0.9018021428571429, 0.5275994285714285, 0.20603], 
          RGBColor[
          0.8887124285714285, 0.36210342857142863`, 0.17399514285714288`], 
          RGBColor[0.8632869999999999, 0.177420857142857, 0.1402288571428571], 
          RGBColor[
          0.2718072857142857, 0.5007941428571427, 0.7935485714285715], 
          RGBColor[
          0.32150785714285707`, 0.6056275714285713, 0.7128162857142859], 
          RGBColor[0.39020657142857146`, 0.6755118571428571, 0.600533], 
          RGBColor[0.794549, 0.721158, 0.260829], 
          RGBColor[
          0.8688694285714286, 0.6582074285714284, 0.23370371428571426`], 
          RGBColor[
          0.9015394285714285, 0.5460082857142854, 0.20953399999999994`], 
          RGBColor[
          0.8922475714285715, 0.38506857142857137`, 0.17849985714285713`], 
          RGBColor[0.866251, 0.20057828571428576`, 0.14427928571428572`], 
          RGBColor[0.3137134285714285, 0.5956012857142856, 0.726241142857143], 
          RGBColor[
          0.8635120000000001, 0.6707709999999999, 0.23656399999999997`], 
          RGBColor[
          0.9012767142857143, 0.5644171428571426, 0.21303799999999998`], 
          RGBColor[
          0.8957827142857142, 0.4080337142857139, 0.18300457142857135`], 
          RGBColor[0.901014, 0.5828259999999997, 0.21654199999999996`], 
          RGBColor[
          0.8993178571428572, 0.4309988571428569, 0.18750928571428566`], 
          RGBColor[0.902853, 0.4539639999999997, 0.19201399999999993`], 
          RGBColor[
          0.4485045714285714, 0.11002514285714286`, 0.5466521428571429], 
          RGBColor[
          0.4417812857142856, 0.7058591428571428, 0.5260868571428573], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[
          0.8781069999999999, 0.29320799999999947`, 0.1604809999999999], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[
          0.4255971428571428, 0.11128428571428572`, 0.5662882857142858], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.4537205714285716, 0.7098692857142858, 0.5118527142857142], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[0.5538030000000003, 0.7358334285714286, 0.405498857142857], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[0.6633007142857145, 0.743074, 0.3246331428571428], 
          RGBColor[
          0.8751429999999999, 0.27005057142857125`, 0.1564305714285714], 
          RGBColor[
          0.4026897142857142, 0.11254342857142859`, 0.5859244285714287], 
          RGBColor[0.37038885714285724`, 0.6623432857142858, 0.630639], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.5134169999999999, 0.72992, 0.44068200000000013`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7689744285714286, 0.7272817142857142, 0.2717827142857142], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.8721789999999999, 0.24689314285714248`, 0.1523801428571428], 
          RGBColor[
          0.3797822857142858, 0.11380257142857142`, 0.6055605714285713], 
          RGBColor[
          0.37978228571428563`, 0.11380257142857143`, 0.6055605714285716], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[
          0.45372057142857136`, 0.7098692857142856, 0.5118527142857144], 
          RGBColor[
          0.4775991428571429, 0.7178895714285715, 0.48338442857142855`], 
          RGBColor[
          0.5538029999999999, 0.7358334285714285, 0.40549885714285727`], 
          RGBColor[0.580727, 0.7397757142857143, 0.38204342857142864`], 
          RGBColor[
          0.7817617142857145, 0.7242198571428571, 0.26630585714285704`], 
          RGBColor[
          0.7817617142857145, 0.7242198571428571, 0.26630585714285704`], 
          RGBColor[0.6633007142857144, 0.743074, 0.3246331428571429], 
          RGBColor[0.6911255714285717, 0.742752, 0.30765571428571414`], 
          RGBColor[0.869215, 0.22373571428571398`, 0.14832971428571423`], 
          RGBColor[0.869215, 0.22373571428571398`, 0.14832971428571423`], 
          RGBColor[
          0.40268971428571443`, 0.11254342857142857`, 0.5859244285714285], 
          RGBColor[0.356874857142857, 0.1150617142857143, 0.6251967142857144], 
          RGBColor[
          0.37038885714285713`, 0.6623432857142857, 0.6306390000000001], 
          RGBColor[
          0.3902065714285714, 0.6755118571428571, 0.6005330000000001], 
          RGBColor[
          0.5941890000000001, 0.7417468571428572, 0.37031571428571425`], 
          RGBColor[
          0.7689744285714286, 0.7272817142857142, 0.2717827142857142], 
          RGBColor[0.872179, 0.24689314285714303`, 0.15238014285714288`], 
          RGBColor[0.866251, 0.20057828571428576`, 0.14427928571428572`], 
          RGBColor[
          0.42559714285714284`, 0.11128428571428571`, 0.5662882857142857], 
          RGBColor[
          0.3339674285714286, 0.11632085714285714`, 0.6448328571428571], 
          RGBColor[0.4001154285714286, 0.6820961428571428, 0.58548], 
          RGBColor[
          0.8751429999999999, 0.2700505714285707, 0.1564305714285713], 
          RGBColor[0.8632869999999999, 0.177420857142857, 0.1402288571428571], 
          RGBColor[
          0.4485045714285715, 0.11002514285714286`, 0.5466521428571428], 
          RGBColor[0.41002428571428573`, 0.6886804285714285, 0.570427], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[
          0.8603230000000001, 0.15426342857142877`, 0.13617842857142862`], 
          RGBColor[
          0.4485045714285715, 0.11002514285714286`, 0.5466521428571429], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[
          0.42559714285714284`, 0.11128428571428572`, 0.5662882857142858], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[
          0.4537205714285714, 0.7098692857142856, 0.5118527142857143], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[0.553803, 0.7358334285714285, 0.40549885714285716`], 
          RGBColor[0.6633007142857145, 0.743074, 0.3246331428571428], 
          RGBColor[
          0.8751429999999999, 0.27005057142857125`, 0.1564305714285714], 
          RGBColor[
          0.4026897142857143, 0.11254342857142857`, 0.5859244285714286], 
          RGBColor[0.37038885714285724`, 0.6623432857142858, 0.630639], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7689744285714286, 0.7272817142857142, 0.2717827142857142], 
          RGBColor[0.872179, 0.24689314285714303`, 0.15238014285714288`], 
          RGBColor[
          0.4537205714285714, 0.7098692857142856, 0.5118527142857143], 
          RGBColor[
          0.47759914285714306`, 0.7178895714285715, 0.4833844285714284], 
          RGBColor[0.5538030000000003, 0.7358334285714286, 0.405498857142857], 
          RGBColor[
          0.5807270000000001, 0.7397757142857143, 0.3820434285714285], 
          RGBColor[0.6633007142857145, 0.743074, 0.3246331428571428], 
          RGBColor[0.6911255714285717, 0.742752, 0.30765571428571414`], 
          RGBColor[
          0.4026897142857143, 0.11254342857142857`, 0.5859244285714286], 
          RGBColor[
          0.35687485714285716`, 0.1150617142857143, 0.6251967142857143], 
          RGBColor[0.37038885714285724`, 0.6623432857142858, 0.630639], 
          RGBColor[0.3902065714285715, 0.6755118571428571, 0.600533], 
          RGBColor[
          0.5941890000000001, 0.7417468571428572, 0.37031571428571425`], 
          RGBColor[
          0.7689744285714286, 0.7272817142857142, 0.2717827142857142], 
          RGBColor[
          0.8721789999999999, 0.24689314285714248`, 0.1523801428571428], 
          RGBColor[0.866251, 0.20057828571428576`, 0.14427928571428572`], 
          RGBColor[
          0.42559714285714284`, 0.11128428571428571`, 0.5662882857142857], 
          RGBColor[
          0.3339674285714286, 0.11632085714285714`, 0.6448328571428571], 
          RGBColor[0.4001154285714286, 0.6820961428571428, 0.58548], 
          RGBColor[
          0.8751429999999999, 0.27005057142857125`, 0.1564305714285714], 
          RGBColor[0.8632869999999999, 0.177420857142857, 0.1402288571428571], 
          RGBColor[
          0.44850457142857153`, 0.11002514285714285`, 0.5466521428571428], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.41002428571428573`, 0.6886804285714285, 0.570427], 
          RGBColor[0.878107, 0.29320799999999975`, 0.16048099999999996`], 
          RGBColor[
          0.8603230000000001, 0.15426342857142908`, 0.13617842857142864`], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8573590000000001, 0.13110600000000058`, 0.1321280000000001], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[0.857359, 0.131106, 0.132128], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.5014777142857143, 0.7259098571428572, 0.4549161428571428], 
          RGBColor[
          0.5268790000000001, 0.7318911428571429, 0.4289542857142856], 
          RGBColor[
          0.7178252857142858, 0.7395291428571428, 0.29369014285714284`], 
          RGBColor[
          0.5014777142857144, 0.7259098571428572, 0.45491614285714277`], 
          RGBColor[
          0.47759914285714306`, 0.7178895714285715, 0.4833844285714284], 
          RGBColor[0.526879, 0.7318911428571429, 0.4289542857142858], 
          RGBColor[0.553803, 0.7358334285714285, 0.40549885714285716`], 
          RGBColor[
          0.717825285714286, 0.7395291428571428, 0.29369014285714273`], 
          RGBColor[
          0.5014777142857145, 0.7259098571428572, 0.45491614285714266`], 
          RGBColor[0.526879, 0.7318911428571429, 0.4289542857142858], 
          RGBColor[
          0.717825285714286, 0.7395291428571428, 0.29369014285714273`], 
          RGBColor[
          0.5014777142857144, 0.7259098571428572, 0.45491614285714277`], 
          RGBColor[
          0.47759914285714283`, 0.7178895714285713, 0.4833844285714286], 
          RGBColor[0.526879, 0.7318911428571429, 0.4289542857142858], 
          RGBColor[0.5538030000000003, 0.7358334285714286, 0.405498857142857], 
          RGBColor[
          0.717825285714286, 0.7395291428571428, 0.29369014285714273`], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[
          0.47759914285714283`, 0.7178895714285713, 0.4833844285714286], 
          RGBColor[
          0.5014777142857144, 0.7259098571428572, 0.45491614285714277`], 
          RGBColor[0.526879, 0.7318911428571429, 0.4289542857142858], 
          RGBColor[
          0.47759914285714306`, 0.7178895714285715, 0.4833844285714284], 
          RGBColor[0.526879, 0.7318911428571429, 0.4289542857142858], 
          RGBColor[
          0.5538029999999999, 0.7358334285714285, 0.40549885714285727`], 
          RGBColor[
          0.4775991428571429, 0.7178895714285715, 0.48338442857142855`], 
          RGBColor[
          0.5014777142857144, 0.7259098571428572, 0.45491614285714277`], 
          RGBColor[0.526879, 0.7318911428571429, 0.4289542857142858], 
          RGBColor[
          0.4775991428571429, 0.7178895714285715, 0.48338442857142855`], 
          RGBColor[
          0.5268790000000001, 0.7318911428571429, 0.4289542857142856], 
          RGBColor[0.553803, 0.7358334285714285, 0.40549885714285716`], 
          RGBColor[
          0.4537205714285714, 0.7098692857142856, 0.5118527142857143], 
          RGBColor[0.6354758571428573, 0.743396, 0.34161057142857143`], 
          RGBColor[0.6633007142857145, 0.743074, 0.3246331428571428], 
          RGBColor[
          0.4417812857142856, 0.7058591428571428, 0.5260868571428573], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.7178252857142858, 0.7395291428571428, 0.29369014285714284`], 
          RGBColor[0.6354758571428573, 0.743396, 0.34161057142857143`], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.6354758571428573, 0.743396, 0.34161057142857143`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.4537205714285716, 0.7098692857142858, 0.5118527142857142], 
          RGBColor[0.6354758571428573, 0.743396, 0.34161057142857143`], 
          RGBColor[0.6633007142857145, 0.743074, 0.3246331428571428], 
          RGBColor[
          0.4537205714285714, 0.7098692857142856, 0.5118527142857143], 
          RGBColor[0.6354758571428573, 0.743396, 0.34161057142857143`], 
          RGBColor[0.6633007142857145, 0.743074, 0.3246331428571428], 
          RGBColor[
          0.717825285714286, 0.7395291428571428, 0.29369014285714273`], 
          RGBColor[0.6354758571428573, 0.743396, 0.34161057142857143`], 
          RGBColor[
          0.4656598571428573, 0.7138794285714286, 0.49761857142857124`], 
          RGBColor[0.6354758571428573, 0.743396, 0.34161057142857143`], 
          RGBColor[0.6772131428571432, 0.742913, 0.31614442857142844`], 
          RGBColor[
          0.4537205714285716, 0.7098692857142858, 0.5118527142857142], 
          RGBColor[0.6354758571428573, 0.743396, 0.34161057142857143`], 
          RGBColor[0.6633007142857145, 0.743074, 0.3246331428571428], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[
          0.7817617142857145, 0.7242198571428571, 0.26630585714285704`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[
          0.7433998571428573, 0.7334054285714285, 0.2827364285714285], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[
          0.7433998571428573, 0.7334054285714285, 0.2827364285714285], 
          RGBColor[
          0.7689744285714286, 0.7272817142857142, 0.2717827142857142], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.5134170000000002, 0.72992, 0.44068199999999985`], 
          RGBColor[
          0.7817617142857145, 0.7242198571428571, 0.26630585714285704`], 
          RGBColor[
          0.7433998571428572, 0.7334054285714285, 0.28273642857142856`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[
          0.7433998571428572, 0.7334054285714285, 0.28273642857142856`], 
          RGBColor[
          0.7689744285714286, 0.7272817142857142, 0.2717827142857142], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.7433998571428572, 0.7334054285714285, 0.28273642857142856`], 
          RGBColor[
          0.7689744285714286, 0.7272817142857142, 0.2717827142857142], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[0.6772131428571428, 0.742913, 0.31614442857142866`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.7433998571428572, 0.7334054285714285, 0.28273642857142856`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.7433998571428572, 0.7334054285714285, 0.28273642857142856`], 
          RGBColor[
          0.7689744285714286, 0.7272817142857142, 0.2717827142857142], 
          RGBColor[
          0.7306125714285717, 0.7364672857142857, 0.2882132857142856], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.7433998571428572, 0.7334054285714285, 0.28273642857142856`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.3339674285714287, 0.11632085714285714`, 0.644832857142857], 
          RGBColor[
          0.5941890000000001, 0.7417468571428572, 0.37031571428571425`], 
          RGBColor[
          0.35687485714285727`, 0.11506171428571428`, 0.6251967142857141], 
          RGBColor[
          0.2593468571428572, 0.20998514285714276`, 0.7541972857142856], 
          RGBColor[0.24408, 0.36124199999999973`, 0.8160839999999999], 
          RGBColor[0.580727, 0.7397757142857143, 0.38204342857142864`], 
          RGBColor[
          0.26796571428571436`, 0.19458428571428565`, 0.7392425714285713], 
          RGBColor[
          0.2450297142857143, 0.34183399999999986`, 0.8093794285714285], 
          RGBColor[0.26612199999999997`, 0.4866639999999998, 0.802529], 
          RGBColor[
          0.2765845714285715, 0.17918342857142844`, 0.724287857142857], 
          RGBColor[
          0.24597942857142857`, 0.3224259999999998, 0.8026748571428571], 
          RGBColor[
          0.26297314285714285`, 0.46874657142857123`, 0.8044654285714287], 
          RGBColor[
          0.30591899999999994`, 0.5855749999999997, 0.7396660000000002], 
          RGBColor[
          0.8536601428571429, 0.6779691428571428, 0.24003042857142856`], 
          RGBColor[
          0.2852034285714286, 0.16378257142857136`, 0.7093331428571428], 
          RGBColor[
          0.24692914285714285`, 0.3030179999999999, 0.7959702857142856], 
          RGBColor[
          0.2598242857142857, 0.45082914285714265`, 0.8064018571428572], 
          RGBColor[
          0.3002337142857142, 0.5714448571428569, 0.7486464285714287], 
          RGBColor[
          0.8438082857142857, 0.6851672857142856, 0.2434968571428571], 
          RGBColor[
          0.8956565714285715, 0.5953895714285713, 0.21940228571428572`], 
          RGBColor[
          0.29382228571428576`, 0.14838171428571426`, 0.6943784285714285], 
          RGBColor[
          0.24787885714285715`, 0.2836099999999999, 0.7892657142857142], 
          RGBColor[
          0.25667542857142855`, 0.4329117142857142, 0.8083382857142858], 
          RGBColor[
          0.29454842857142854`, 0.5573147142857142, 0.7576268571428573], 
          RGBColor[
          0.8339564285714285, 0.6923654285714286, 0.24696328571428572`], 
          RGBColor[0.890299142857143, 0.6079531428571425, 0.2222625714285714], 
          RGBColor[
          0.9025902857142857, 0.47237285714285704`, 0.19551799999999997`], 
          RGBColor[
          0.3339674285714286, 0.11632085714285714`, 0.6448328571428571], 
          RGBColor[
          0.5941890000000001, 0.7417468571428572, 0.37031571428571425`], 
          RGBColor[
          0.35687485714285716`, 0.1150617142857143, 0.6251967142857143], 
          RGBColor[
          0.25934685714285716`, 0.20998514285714284`, 0.7541972857142857], 
          RGBColor[
          0.5807270000000001, 0.7397757142857143, 0.3820434285714285], 
          RGBColor[
          0.2679657142857143, 0.19458428571428565`, 0.7392425714285713], 
          RGBColor[0.24502971428571427`, 0.341834, 0.8093794285714286], 
          RGBColor[
          0.27658457142857146`, 0.17918342857142858`, 0.7242878571428571], 
          RGBColor[0.24597942857142857`, 0.322426, 0.8026748571428571], 
          RGBColor[
          0.26297314285714285`, 0.46874657142857135`, 0.8044654285714287], 
          RGBColor[
          0.8536601428571429, 0.6779691428571428, 0.24003042857142856`], 
          RGBColor[
          0.2852034285714286, 0.1637825714285714, 0.7093331428571428], 
          RGBColor[0.24692914285714285`, 0.303018, 0.7959702857142857], 
          RGBColor[
          0.25982428571428573`, 0.4508291428571428, 0.8064018571428572], 
          RGBColor[
          0.30023371428571427`, 0.5714448571428571, 0.7486464285714286], 
          RGBColor[
          0.8438082857142857, 0.6851672857142856, 0.2434968571428571], 
          RGBColor[
          0.8956565714285715, 0.5953895714285713, 0.21940228571428572`], 
          RGBColor[
          0.29382228571428576`, 0.1483817142857142, 0.6943784285714285], 
          RGBColor[
          0.24787885714285715`, 0.28360999999999986`, 0.7892657142857142], 
          RGBColor[
          0.25667542857142855`, 0.4329117142857142, 0.8083382857142858], 
          RGBColor[0.2945484285714285, 0.557314714285714, 0.7576268571428574], 
          RGBColor[
          0.8339564285714285, 0.6923654285714286, 0.24696328571428572`], 
          RGBColor[
          0.8902991428571428, 0.6079531428571427, 0.22226257142857142`], 
          RGBColor[
          0.9025902857142857, 0.47237285714285726`, 0.19551800000000003`], 
          RGBColor[
          0.3526855714285715, 0.6457327142857143, 0.6591168571428572], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.794549, 0.721158, 0.260829], 
          RGBColor[0.6076510000000003, 0.743718, 0.3585879999999999], 
          RGBColor[0.8044008571428571, 0.713959857142857, 0.2573625714285714], 
          RGBColor[
          0.3526855714285715, 0.6457327142857143, 0.6591168571428572], 
          RGBColor[
          0.8142527142857141, 0.7067617142857143, 0.25389614285714285`], 
          RGBColor[
          0.35268557142857154`, 0.6457327142857143, 0.6591168571428571], 
          RGBColor[0.794549, 0.721158, 0.260829], 
          RGBColor[
          0.8044008571428573, 0.7139598571428569, 0.25736257142857133`], 
          RGBColor[
          0.3526855714285714, 0.6457327142857142, 0.6591168571428573], 
          RGBColor[
          0.8142527142857143, 0.7067617142857142, 0.25389614285714285`], 
          RGBColor[0.6911255714285717, 0.742752, 0.30765571428571414`], 
          RGBColor[0.6911255714285717, 0.742752, 0.30765571428571414`], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.6911255714285717, 0.742752, 0.30765571428571414`], 
          RGBColor[0.42984199999999995`, 0.701849, 0.5403210000000002], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.6911255714285716, 0.742752, 0.30765571428571425`], 
          RGBColor[0.42984199999999995`, 0.701849, 0.5403210000000002], 
          RGBColor[0.42984199999999995`, 0.701849, 0.5403210000000002], 
          RGBColor[0.6911255714285717, 0.742752, 0.30765571428571414`], 
          RGBColor[0.6911255714285717, 0.742752, 0.30765571428571414`], 
          RGBColor[
          0.4298419999999999, 0.7018489999999998, 0.5403210000000003], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.4866639999999999, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000004, 0.19201400000000007`], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000004, 0.19201400000000007`], 
          RGBColor[
          0.30591899999999994`, 0.5855749999999998, 0.7396660000000002], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000004, 0.19201400000000007`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124200000000006`, 0.816084], 
          RGBColor[0.266122, 0.486664, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.266122, 0.486664, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[
          0.30591899999999994`, 0.5855749999999998, 0.7396660000000002], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.4866639999999999, 0.802529], 
          RGBColor[
          0.25072800000000006`, 0.22538599999999992`, 0.7691519999999998], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.4866639999999999, 0.802529], 
          RGBColor[
          0.30591899999999994`, 0.5855749999999998, 0.7396660000000002], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999997, 0.6707710000000002, 0.23656400000000008`], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.4866639999999999, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.486664, 0.802529], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.3612419999999999, 0.816084], 
          RGBColor[0.266122, 0.4866639999999999, 0.802529], 
          RGBColor[
          0.30591899999999994`, 0.5855749999999998, 0.7396660000000002], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.878107, 0.29320799999999975`, 0.16048099999999996`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.878107, 0.29320799999999975`, 0.16048099999999996`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[
          0.36048000000000013`, 0.6557590000000001, 0.6456919999999998], 
          RGBColor[0.6076510000000003, 0.743718, 0.3585879999999999], 
          RGBColor[0.878107, 0.29320799999999975`, 0.16048099999999996`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.6076510000000003, 0.743718, 0.3585879999999999], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`]},
        VertexNormals->CompressedData["
1:eJxMXHk4VV8XpoylolSIRFKJokwpd0sokimJTClDmTIklfCjRIbKEGWIkqGS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         "],
        VertexTextureCoordinates->CompressedData["
1:eJx1nF9vo8d1xlW3F+136I3jdeJvQaBAGztNA9QfoUB70WTtpL0tUMA3bS8K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         "]],
       Axes->True,
       AxesEdge->{{-1, -1}, {1, -1}, {-1, -1}},
       AxesLabel->{
         FormBox[
         "\"\\!\\(\\*\\nStyleBox[\\\"x\\\",\\nFontSize->14]\\)\"", 
          TraditionalForm], 
         FormBox[
         "\"\\!\\(\\*\\nStyleBox[\\\"y\\\",\\nFontSize->14]\\)\"", 
          TraditionalForm], 
         FormBox[
         "\"\\!\\(\\*\\nStyleBox[\\\"\[CapitalPhi]\\\",\\nFontSize->14]\\)\\!\
\\(\\*\\nStyleBox[\\\"(\\\",\\nFontSize->14]\\)\\!\\(\\*\\nStyleBox[\\\"r\\\",\
\\nFontSize->14]\\)\\!\\(\\*\\nStyleBox[\\\")\\\",\\nFontSize->14]\\)\"", 
          TraditionalForm]},
       BaseStyle->Specularity[
         GrayLevel[0.5], 30],
       BoxRatios->NCache[{2, 2, GoldenRatio^(-1)}, {2, 2, 0.6180339887498948}],
       Boxed->{Left, Bottom, Back},
       DisplayFunction->Identity,
       FaceGridsStyle->Directive[
         GrayLevel[0.3, 1], 
         AbsoluteDashing[{1, 2}]],
       LabelStyle->{FontFamily -> "Times"},
       Lighting->"Neutral",
       Method->{},
       PlotRange->{All, All, All},
       PlotRangePadding->{Automatic, Automatic, Automatic},
       Ticks->{Automatic, Automatic, Automatic}], {180, -180}, 
      ImageScaled[{0.5, 0.5}], {360, 360},
      ContentSelectable->True], InsetBox[
      Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx0XXk8F933t2SPLKFFSukR7aESPjMV2ksqpU2rIu0p7ftGq0oblRaVtChC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        "], {{
          {RGBColor[0.91, 0.424, 0.1486], EdgeForm[None], 
           StyleBox[GraphicsGroup3DBox[
             TagBox[
              TagBox[{Polygon3DBox[CompressedData["
1:eJxNnHf8l9P7x9/3OPcdMsseyabMhKxUZI+MkBEZWRUZmRUaRJIKGYWQUEbI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                 "]], Polygon3DBox[CompressedData["
1:eJwtmwn8F1MXxme9I3uiqGjRQvbIkpJKi+ypiFCWJPta4qVVKlmiEkKFqCiy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                 "]], Polygon3DBox[CompressedData["
1:eJwt13m8T3Uex/Ff93fdW7plSRJdUmS7rjX7mi3XpKIUKWOpmQo3FaYZS6VC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                 "]]},
               Annotation[#, "Charting`Private`Tag$8626#1"]& ],
              Annotation[#, "Charting`Private`Tag$8640#1"]& ]],
            Lighting->"Neutral"]}, {}, {}, {}, {}}, {
          {GrayLevel[0.2], Line3DBox[CompressedData["
1:eJwl0r1LlWEYwOFbzTLTanNTWqShGkKabAsiLFGXQtFB7cNjqEviyb4MRBvK
wCg0URedVCIswiGiGpr9KrW0CCQk+gskuh4aDr/rfs55zvu87zlHmjvrOnIi
YtYrmxuRXKE/9Wh+xGG9ZPEkl3ETV/IJvrM3otV8mu9yhs/zPe7iBu7jbs7w
Le21N8v3uZ8HeZCH+Bk/4mkdsu8Jv+LHPMof+Tqf4afOuGTu1klzc17EsrlF
V7RVV/WyftYr+iXdy56Isz6/xuWuOWP/OfOIrqfnoFXmUb1qz4a1Ob5grdDn
n/NXa9Xma97/xm26qRnd0nb9ro2uVeNzY/b8MPfolPmT71k0T/ACf+ARnuV5
Huap9Czc68N0r/yAB3iA+7mPe7hXs/a18Q1u53ru5CauSufjWq7k2/a2mI+n
83Ajl3IJ/0nvO+OhdHa9mJ65HjS/12J9p0X6Vg/oX/f6WwvT/VjbNe+k35r3
a7HrjvMvPqYFekq39aYueO3jOtd6w44Rr9W2mFePMF6qr40Xmpv+gxZrc/7/
X/8BGtpWyg==
            "],
            VertexColors->None]}, {}, {}, 
          {GrayLevel[0.2], 
           Line3DBox[{688, 877, 1865, 689, 887, 711, 1924, 897, 724, 1926, 
            907, 737, 1929, 917, 750, 1935, 927, 763, 1943, 937, 776, 947, 
            1895, 789, 957, 802, 1952, 967, 815, 1953, 977, 828, 1955, 987, 
            841, 1960, 997, 854, 1968, 1007, 867},
            VertexColors->None], 
           Line3DBox[{690, 878, 1866, 691, 888, 1874, 712, 1925, 898, 725, 
            1927, 908, 738, 1930, 918, 751, 1936, 928, 764, 1944, 938, 777, 
            948, 1896, 790, 958, 1904, 803, 968, 816, 1954, 978, 829, 1956, 
            988, 842, 1961, 998, 855, 1969, 1008, 868},
            VertexColors->None], 
           Line3DBox[{692, 879, 1867, 693, 889, 1875, 713, 899, 1882, 726, 
            1928, 909, 739, 1931, 919, 752, 1937, 929, 765, 1945, 939, 778, 
            949, 1897, 791, 959, 1905, 804, 969, 1911, 817, 979, 830, 1957, 
            989, 843, 1962, 999, 856, 1970, 1009, 869},
            VertexColors->None], 
           Line3DBox[{694, 880, 1868, 695, 890, 1876, 714, 900, 1883, 727, 
            910, 1888, 740, 1932, 920, 753, 1938, 930, 766, 1946, 940, 779, 
            950, 1898, 792, 960, 1906, 805, 970, 1912, 818, 980, 1917, 831, 
            990, 844, 1963, 1000, 857, 1971, 1010, 870},
            VertexColors->None], 
           Line3DBox[{696, 1017, 1018, 1869, 697, 1026, 1027, 1877, 715, 1033,
             1981, 1034, 728, 1040, 1986, 1041, 741, 1047, 1991, 1048, 754, 
            1054, 1055, 767, 1947, 1061, 1062, 780, 1068, 1069, 1899, 793, 
            1075, 1076, 806, 1082, 2000, 1083, 819, 1089, 2004, 1090, 832, 
            1096, 2008, 1097, 845, 1103, 1104, 858, 1972, 1110, 1111, 1112},
            VertexColors->None], Line3DBox[CompressedData["
1:eJwVzldKQ2EQBtBJTIygxF5jixoX5AYCFwRBiAiCIAiC4KJ8dRH6oIi9xZZi
7HrycPhmvvm53GKytlRJRUSZ/XTEYSbiiDI92YhumrmIY/sZ5yT06k/0eXlh
v+SKZd70/fo+ru033HKgX5GD+gHuzPc8sMqwboiq+ZFX759khVH9CM/mmv6l
fWedcf0YNXOdBhsUdBO0vG+2/4sWm0zpT/WT8t3+wSdbzOim+TJ/88M2Rd0s
v+Y/wrwj5+UcKdLUfbdD7rqV5AIZGvqs7GTPrUvmWOQfQU82Vw==
            "],
            VertexColors->None], 
           Line3DBox[{8, 635, 340, 604, 1768, 23, 639, 346, 1653, 607, 38, 
            641, 352, 1658, 609, 53, 643, 1778, 358, 611, 68, 645, 1780, 364, 
            613, 83, 647, 370, 615, 98, 1394, 649, 376, 617, 113, 651, 382, 
            619, 1774, 128, 653, 388, 621, 143, 655, 394, 1675, 623, 158, 657,
             400, 625, 173, 659, 1784, 406, 627, 188, 661, 412, 629, 203, 
            1473, 664, 418, 631, 218},
            VertexColors->None], 
           Line3DBox[{702, 883, 1871, 703, 893, 1879, 719, 903, 1885, 732, 
            913, 1889, 745, 1934, 923, 758, 1941, 933, 771, 1949, 943, 784, 
            953, 1901, 797, 963, 1908, 810, 973, 1914, 823, 983, 1918, 836, 
            1959, 993, 849, 1966, 1003, 862, 1974, 1013, 873},
            VertexColors->None], 
           Line3DBox[{704, 884, 1872, 705, 894, 1880, 720, 904, 1886, 733, 
            914, 1890, 746, 924, 1892, 759, 1942, 934, 772, 1950, 944, 785, 
            954, 1902, 798, 964, 1909, 811, 974, 1915, 824, 984, 1919, 837, 
            994, 1921, 850, 1967, 1004, 863, 1975, 1014, 874},
            VertexColors->None], 
           Line3DBox[{706, 885, 1873, 707, 895, 1881, 721, 905, 1887, 734, 
            915, 1891, 747, 925, 1893, 760, 935, 1894, 773, 1951, 945, 786, 
            955, 1903, 799, 965, 1910, 812, 975, 1916, 825, 985, 1920, 838, 
            995, 1922, 851, 1005, 1923, 864, 1976, 1015, 875},
            VertexColors->None], 
           Line3DBox[{708, 1023, 1977, 1024, 709, 1030, 1979, 1031, 722, 1037,
             1984, 1038, 735, 1044, 1989, 1045, 748, 1051, 1992, 1052, 761, 
            1058, 1994, 1059, 774, 1065, 1995, 1066, 787, 1072, 1996, 1073, 
            800, 1079, 1998, 1080, 813, 1086, 2002, 1087, 826, 1093, 2006, 
            1094, 839, 1100, 2009, 1101, 852, 1107, 2011, 1108, 865, 1115, 
            2012, 1116, 1117},
            VertexColors->None], 
           Line3DBox[{866, 1006, 1109, 853, 996, 2010, 1102, 840, 986, 2007, 
            1095, 827, 976, 2003, 1088, 814, 966, 1999, 1081, 801, 956, 1997, 
            1074, 788, 946, 1067, 775, 936, 1060, 762, 926, 1993, 1053, 749, 
            916, 1990, 1046, 736, 906, 1985, 1039, 723, 896, 1980, 1032, 710, 
            886, 1978, 1025, 687, 1864, 876, 1016, 1118},
            VertexColors->None], Line3DBox[CompressedData["
1:eJwVz80qhHEUB+DjKys3YGflBtyAG7CwtRhRpGSilJpSyiSlppQipUQppYjI
91dEIyKzmIWvhKaUxdyA5794Ouf8ztv7nrelJ9s5VBMRGfrrIqqU6yOmKPHM
X2NEl7zChnmSJ97lj2qH/I11/QQP3NMuK7GmH+eOIm2yIqv6HLfc0Co758d7
l81jXHNFs/xTvqcumUe55IKmdBeL+hHOOOXX8yFfYd6c5ZhX+ZFarY1YsJvT
D3LAPt/ygnxWP0AlfVfdpWyXtyvoT+R96g7b6f/scnZf8hlzL1tscmj3IR+2
nzZ3pzt4Sfc3RPwD+yFAtw==
            "],
            VertexColors->None], 
           Line3DBox[{872, 1012, 1114, 1973, 861, 1002, 1106, 1965, 848, 992, 
            1099, 1958, 835, 982, 2005, 1092, 822, 1913, 972, 1085, 809, 1907,
             962, 1078, 796, 1900, 952, 1071, 783, 942, 1064, 1948, 770, 932, 
            1057, 1940, 757, 922, 1050, 1933, 744, 912, 1988, 1043, 731, 1884,
             902, 1036, 718, 1878, 892, 1029, 701, 1870, 882, 1021, 1022},
            VertexColors->None], Line3DBox[CompressedData["
1:eJwV0D8oRXEYBuDvciWUwSYLE5PNZmKziE1Z6JZS/pRSSimlRERERERERCml
iJRSSpEyMJCEiAw2Bs8Znt6v9/0Np1PW2tXYmYqIDH/ZEQ/piEd+3S1yhFGe
ciOOsiL23GkyjPGiH5eXtn1ZQBsn+gk5yZ3tQBbxrm+XU0zzajuUxXzYOuQM
s/zYjpO3+lLZzRzzpHzfp/7UXU4PCyxSaDuTlfSyxDLP3pfYzt1V9LHCm35V
VtguZDX9XOvX5Hry3nYpaxlgg01q9Feyji/vB+UW29TbbpJb3yCH2GGXZtu3
/tbdxHDyn8jLibiX+fIfytY8fw==
            "],
            VertexColors->None]}, 
          {GrayLevel[0.2], 
           Line3DBox[{1320, 1556, 1864, 1481, 1319, 1865, 1482, 1321, 1866, 
            1483, 1322, 1867, 1484, 1323, 1868, 1485, 1324, 1837, 1869, 1486, 
            1649, 1861, 2037, 1787, 1752, 1767, 1487, 1768, 1717, 1718, 1681, 
            1707, 2017, 1488, 1650, 1719, 1720, 1682, 1848, 2018, 1489, 1651, 
            1557, 1870, 1490, 1325, 1871, 1491, 1326, 1872, 1492, 1327, 1873, 
            1493, 1328, 1977, 1558, 1494, 1559},
            VertexColors->None], 
           Line3DBox[{1330, 1560, 1790, 1978, 1329, 887, 1331, 1874, 1495, 
            1332, 1875, 1496, 1333, 1876, 1497, 1334, 1838, 1877, 1498, 1652, 
            2013, 1788, 1561, 1753, 1769, 1770, 1653, 1721, 1562, 1683, 1708, 
            1709, 2021, 1654, 1722, 1563, 1684, 2022, 1710, 1711, 1655, 1564, 
            1878, 1499, 1335, 1879, 1500, 1336, 1880, 1501, 1337, 1881, 1502, 
            1338, 1979, 1565, 1503, 1656},
            VertexColors->None], 
           Line3DBox[{1340, 1566, 1791, 1980, 1339, 1792, 1924, 1341, 1793, 
            1925, 1342, 1882, 1504, 1343, 1883, 1505, 1344, 1981, 1567, 1506, 
            1657, 1862, 2038, 1568, 1754, 1771, 1772, 1658, 1723, 1569, 1685, 
            1712, 1982, 1849, 1659, 1724, 1570, 1687, 1850, 1983, 1713, 1660, 
            1571, 1884, 1507, 1345, 1885, 1508, 1346, 1886, 1509, 1347, 1887, 
            1510, 1348, 1984, 1572, 1511, 1661},
            VertexColors->None], 
           Line3DBox[{1361, 1586, 1585, 1989, 1360, 1515, 1891, 1359, 1514, 
            1890, 1358, 1513, 1889, 1357, 1988, 1584, 1583, 1356, 1727, 2026, 
            1582, 1688, 1581, 1726, 1355, 1853, 2025, 1580, 1686, 1579, 1725, 
            1778, 1777, 1578, 1755, 1577, 1987, 1858, 1354, 1576, 1575, 1986, 
            1353, 1512, 1888, 1352, 1928, 1796, 1351, 1927, 1795, 1350, 1926, 
            1794, 1349, 1985, 1574, 1573, 1662},
            VertexColors->None], 
           Line3DBox[{1374, 1599, 1598, 1992, 1373, 1517, 1893, 1372, 1516, 
            1892, 1371, 1934, 1801, 1370, 1839, 1933, 1597, 1369, 1730, 2027, 
            1596, 1690, 1595, 1729, 1368, 1210, 1594, 1689, 1593, 1728, 1780, 
            1779, 1592, 1756, 1591, 1259, 1367, 1590, 1589, 1991, 1366, 1932, 
            1800, 1365, 1931, 1799, 1364, 1930, 1798, 1363, 1929, 1797, 1362, 
            1990, 1588, 1587, 1663},
            VertexColors->None], 
           Line3DBox[{1387, 1605, 1604, 1994, 1386, 1518, 1894, 1385, 1942, 
            1807, 1384, 1941, 1806, 1383, 1840, 1940, 1603, 1382, 504, 1939, 
            1692, 503, 1381, 2014, 501, 1691, 500, 647, 646, 1757, 580, 2033, 
            1380, 1602, 1054, 1379, 1938, 1805, 1378, 1937, 1804, 1377, 1936, 
            1803, 1376, 1935, 1802, 1375, 1993, 1601, 1600, 1664},
            VertexColors->None], 
           Line3DBox[{106, 775, 107, 776, 108, 777, 109, 778, 110, 779, 111, 
            780, 112, 1266, 583, 113, 434, 781, 114, 435, 782, 115, 783, 116, 
            784, 117, 785, 118, 786, 119, 787, 120},
            VertexColors->None], 
           Line3DBox[{1401, 1610, 1609, 1995, 1400, 1951, 1814, 1399, 1950, 
            1813, 1398, 1949, 1812, 1397, 1842, 1948, 1608, 1396, 1736, 2029, 
            1855, 1694, 1735, 1734, 1395, 1854, 2028, 1733, 1693, 1732, 1731, 
            1394, 1781, 1782, 1758, 1759, 2034, 1859, 1393, 1607, 1947, 1841, 
            1392, 1946, 1811, 1391, 1945, 1810, 1390, 1944, 1809, 1389, 1943, 
            1808, 1388, 1060, 1606, 1665},
            VertexColors->None], 
           Line3DBox[{1403, 1611, 946, 1402, 1895, 1519, 1404, 1896, 1520, 
            1405, 1897, 1521, 1406, 1898, 1522, 1407, 1843, 1899, 1523, 1666, 
            1863, 2039, 1789, 1760, 1773, 1524, 1774, 1737, 1738, 1695, 1714, 
            2019, 1525, 1667, 1739, 1740, 1696, 1851, 2020, 1526, 1668, 1612, 
            1900, 1527, 1408, 1901, 1528, 1409, 1902, 1529, 1410, 1903, 1530, 
            1411, 1996, 1613, 1531, 1669},
            VertexColors->None], 
           Line3DBox[{1413, 1614, 1815, 1997, 1412, 957, 1414, 1904, 1532, 
            1415, 1905, 1533, 1416, 1906, 1534, 1417, 1076, 1535, 1670, 2015, 
            679, 1761, 620, 621, 520, 1697, 464, 2023, 1671, 523, 1698, 2024, 
            465, 1672, 1615, 1907, 1536, 1418, 1908, 1537, 1419, 1909, 1538, 
            1420, 1910, 1539, 1421, 1998, 1616, 1540, 1673},
            VertexColors->None], 
           Line3DBox[{1423, 1617, 1816, 1999, 1422, 1817, 1952, 1424, 968, 
            1425, 1911, 1541, 1426, 1912, 1542, 1427, 2000, 1618, 1543, 1674, 
            1311, 1619, 1762, 1775, 1776, 1675, 1741, 1620, 1699, 1715, 1188, 
            1676, 1742, 1621, 1700, 1852, 2001, 1716, 1677, 1622, 1913, 1544, 
            1428, 1914, 1545, 1429, 1915, 1546, 1430, 1916, 1547, 1431, 2002, 
            1623, 1548, 1678},
            VertexColors->None], 
           Line3DBox[{398, 302, 2003, 1432, 1818, 1953, 1433, 1819, 1954, 
            1434, 979, 1435, 1917, 1549, 1436, 2004, 303, 399, 1149, 304, 400,
             305, 1150, 401, 306, 1151, 402, 307, 2005, 1437, 1918, 1550, 
            1438, 1919, 1551, 1439, 1920, 1552, 1440, 2006, 308, 403},
            VertexColors->None], 
           Line3DBox[{1453, 1636, 1635, 2009, 1452, 1554, 1922, 1451, 1553, 
            1921, 1450, 1959, 1823, 1449, 1844, 1958, 1634, 1448, 1745, 2030, 
            1633, 1702, 1632, 1744, 1447, 1231, 1631, 1701, 1630, 1743, 1784, 
            1783, 1629, 1763, 1628, 1280, 1446, 1627, 1626, 2008, 1445, 990, 
            1444, 1957, 1822, 1443, 1956, 1821, 1442, 1955, 1820, 1441, 2007, 
            1625, 1624, 1679},
            VertexColors->None], 
           Line3DBox[{1466, 1642, 1641, 2011, 1465, 1555, 1923, 1464, 1967, 
            1829, 1463, 1966, 1828, 1462, 1845, 1965, 1640, 1461, 546, 1964, 
            1704, 545, 1460, 2016, 543, 1703, 542, 661, 660, 1764, 594, 2035, 
            1459, 1639, 1103, 1458, 1963, 1827, 1457, 1962, 1826, 1456, 1961, 
            1825, 1455, 1960, 1824, 1454, 2010, 1638, 1637, 1680},
            VertexColors->None], 
           Line3DBox[{1480, 1648, 1647, 2012, 1479, 1976, 1836, 1478, 1975, 
            1835, 1477, 1974, 1834, 1476, 1847, 1973, 1646, 1475, 1751, 2032, 
            1857, 1706, 1750, 1749, 1474, 1856, 2031, 1748, 1705, 1747, 1746, 
            1473, 1785, 1786, 1765, 1766, 2036, 1860, 1472, 1645, 1972, 1846, 
            1471, 1971, 1833, 1470, 1970, 1832, 1469, 1969, 1831, 1468, 1968, 
            1830, 1467, 1109, 1643, 1644},
            VertexColors->None]}}},
        VertexColors->{
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.34489114285714295`, 0.6357064285714287, 0.6725417142857142], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.5134169999999999, 0.72992, 0.44068200000000013`], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857143, 0.6205167142857141, 0.22512285714285712`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.31617314285714304`, 0.16498571428571435`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428576`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571427, 0.3161731428571422, 0.16498571428571418`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571393`, 0.19902199999999992`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[
          0.41993314285714295`, 0.6952647142857143, 0.5553739999999999], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571393`, 0.19902199999999992`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[
          0.24882857142857143`, 0.26420199999999994`, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.5134169999999999, 0.72992, 0.44068200000000013`], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285712, 0.6995635714285716, 0.25042971428571437`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714289, 0.743557, 0.35009928571428556`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571393`, 0.19902199999999992`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.5134169999999999, 0.72992, 0.44068200000000013`], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285712, 0.6995635714285716, 0.25042971428571437`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428576`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714289, 0.743557, 0.35009928571428556`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571393`, 0.19902199999999992`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.4907817142857146, 0.19902200000000006`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.34489114285714295`, 0.6357064285714287, 0.6725417142857142], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.5134169999999999, 0.72992, 0.44068200000000013`], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[
          0.37978228571428574`, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[
          0.7817617142857145, 0.7242198571428571, 0.26630585714285704`], 
          RGBColor[0.869215, 0.22373571428571426`, 0.1483297142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[
          0.37978228571428574`, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571428, 0.742913, 0.31614442857142866`], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.869215, 0.22373571428571426`, 0.1483297142857143], 
          RGBColor[
          0.37978228571428574`, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.869215, 0.22373571428571426`, 0.1483297142857143], 
          RGBColor[
          0.37978228571428574`, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.7817617142857145, 0.7242198571428571, 0.26630585714285704`], 
          RGBColor[0.869215, 0.22373571428571398`, 0.14832971428571423`], 
          RGBColor[
          0.37978228571428574`, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[0.38029771428571435`, 0.6689275714285714, 0.615586], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.869215, 0.22373571428571426`, 0.1483297142857143], 
          RGBColor[
          0.37978228571428574`, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.869215, 0.22373571428571426`, 0.1483297142857143], 
          RGBColor[
          0.3797822857142857, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.7817617142857145, 0.7242198571428571, 0.26630585714285704`], 
          RGBColor[0.869215, 0.22373571428571426`, 0.1483297142857143], 
          RGBColor[
          0.3797822857142857, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[
          0.38029771428571424`, 0.6689275714285714, 0.6155860000000002], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571428, 0.742913, 0.31614442857142866`], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[
          0.8692150000000001, 0.22373571428571482`, 0.1483297142857144], 
          RGBColor[
          0.3797822857142857, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.869215, 0.22373571428571398`, 0.14832971428571423`], 
          RGBColor[
          0.37978228571428574`, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.869215, 0.22373571428571398`, 0.14832971428571423`], 
          RGBColor[
          0.37978228571428574`, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.7817617142857145, 0.7242198571428571, 0.26630585714285704`], 
          RGBColor[0.869215, 0.22373571428571398`, 0.14832971428571423`], 
          RGBColor[
          0.37978228571428574`, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.7817617142857145, 0.7242198571428571, 0.26630585714285704`], 
          RGBColor[0.869215, 0.22373571428571398`, 0.14832971428571423`], 
          RGBColor[
          0.37978228571428574`, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.869215, 0.22373571428571398`, 0.14832971428571423`], 
          RGBColor[
          0.37978228571428574`, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7817617142857143, 0.7242198571428571, 0.2663058571428571], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.7817617142857145, 0.7242198571428571, 0.26630585714285704`], 
          RGBColor[0.869215, 0.22373571428571426`, 0.1483297142857143], 
          RGBColor[0.869215, 0.22373571428571398`, 0.14832971428571423`], 
          RGBColor[
          0.37978228571428574`, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.869215, 0.22373571428571398`, 0.14832971428571423`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.5134169999999999, 0.72992, 0.44068200000000013`], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.41993314285714295`, 0.6952647142857143, 0.5553739999999999], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.5134169999999999, 0.72992, 0.44068200000000013`], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714289, 0.743557, 0.35009928571428556`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714289, 0.743557, 0.35009928571428556`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.5134170000000002, 0.72992, 0.44068199999999985`], 
          RGBColor[0.6215634285714289, 0.743557, 0.35009928571428556`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[
          0.37978228571428574`, 0.11380257142857143`, 0.6055605714285714], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571428, 0.742913, 0.31614442857142866`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571428, 0.742913, 0.31614442857142866`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571432, 0.742913, 0.31614442857142844`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.5941890000000003, 0.7417468571428572, 0.3703157142857141], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[
          0.5941890000000001, 0.7417468571428572, 0.37031571428571425`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[
          0.5941890000000001, 0.7417468571428572, 0.37031571428571425`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[
          0.5941890000000003, 0.7417468571428572, 0.3703157142857141], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[
          0.5941890000000003, 0.7417468571428572, 0.3703157142857141], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[
          0.5941890000000001, 0.7417468571428572, 0.37031571428571425`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[
          0.5941890000000001, 0.7417468571428572, 0.37031571428571425`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[
          0.5941890000000003, 0.7417468571428572, 0.3703157142857141], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[
          0.5941890000000003, 0.7417468571428572, 0.3703157142857141], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[
          0.5941890000000003, 0.7417468571428572, 0.3703157142857141], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[
          0.5941890000000001, 0.7417468571428572, 0.37031571428571425`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[
          0.5941890000000003, 0.7417468571428572, 0.3703157142857141], 
          RGBColor[
          0.7050380000000004, 0.7425909999999999, 0.2991669999999999], 
          RGBColor[
          0.5941890000000003, 0.7417468571428572, 0.3703157142857141], 
          RGBColor[
          0.7050380000000004, 0.7425909999999999, 0.2991669999999999], 
          RGBColor[0.540341, 0.7338622857142857, 0.41722657142857156`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[
          0.5941890000000003, 0.7417468571428572, 0.3703157142857141], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[
          0.5941890000000003, 0.7417468571428572, 0.3703157142857141], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[0.649388285714286, 0.743235, 0.333121857142857], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.540341, 0.7338622857142857, 0.41722657142857156`], 
          RGBColor[
          0.5941890000000003, 0.7417468571428572, 0.3703157142857141], 
          RGBColor[0.540341, 0.7338622857142857, 0.41722657142857156`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[
          0.5941890000000003, 0.7417468571428572, 0.3703157142857141], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[
          0.5941890000000003, 0.7417468571428572, 0.3703157142857141], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[
          0.5941890000000001, 0.7417468571428572, 0.37031571428571425`], 
          RGBColor[0.540341, 0.7338622857142857, 0.41722657142857156`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[
          0.5941890000000003, 0.7417468571428572, 0.3703157142857141], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[
          0.7050380000000004, 0.7425909999999999, 0.2991669999999999], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[
          0.5941890000000003, 0.7417468571428572, 0.3703157142857141], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[
          0.5941890000000001, 0.7417468571428572, 0.37031571428571425`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[
          0.5941890000000003, 0.7417468571428572, 0.3703157142857141], 
          RGBColor[0.540341, 0.7338622857142857, 0.41722657142857156`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[
          0.5941890000000003, 0.7417468571428572, 0.3703157142857141], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[
          0.5941890000000003, 0.7417468571428572, 0.3703157142857141], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[
          0.7050380000000004, 0.7425909999999999, 0.2991669999999999], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[
          0.5941890000000003, 0.7417468571428572, 0.3703157142857141], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[
          0.42559714285714284`, 0.11128428571428572`, 0.5662882857142858], 
          RGBColor[
          0.4417812857142858, 0.7058591428571428, 0.5260868571428571], 
          RGBColor[
          0.48953842857142876`, 0.7218997142857143, 0.4691502857142855], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[0.649388285714286, 0.743235, 0.333121857142857], 
          RGBColor[
          0.8632869999999999, 0.1774208571428567, 0.14022885714285707`], 
          RGBColor[
          0.42559714285714284`, 0.11128428571428571`, 0.5662882857142857], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[
          0.5941890000000003, 0.7417468571428572, 0.3703157142857141], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.8632869999999999, 0.177420857142857, 0.1402288571428571], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[
          0.4656598571428573, 0.7138794285714286, 0.49761857142857124`], 
          RGBColor[
          0.5941890000000003, 0.7417468571428572, 0.3703157142857141], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.7050380000000004, 0.7425909999999999, 0.2991669999999999], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.4417812857142856, 0.7058591428571428, 0.5260868571428573], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.4417812857142858, 0.7058591428571428, 0.5260868571428571], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.4417812857142858, 0.7058591428571428, 0.5260868571428571], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.4417812857142856, 0.7058591428571428, 0.5260868571428573], 
          RGBColor[
          0.4656598571428573, 0.7138794285714286, 0.49761857142857124`], 
          RGBColor[
          0.4417812857142858, 0.7058591428571428, 0.5260868571428571], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.4417812857142856, 0.7058591428571428, 0.5260868571428573], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[0.5134170000000002, 0.72992, 0.44068199999999985`], 
          RGBColor[
          0.8632869999999999, 0.1774208571428567, 0.14022885714285707`], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.48953842857142865`, 0.7218997142857143, 0.46915028571428563`], 
          RGBColor[0.5134169999999999, 0.72992, 0.44068200000000013`], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.48953842857142865`, 0.7218997142857143, 0.46915028571428563`], 
          RGBColor[0.5134169999999999, 0.72992, 0.44068200000000013`], 
          RGBColor[
          0.48953842857142876`, 0.7218997142857143, 0.4691502857142855], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.48953842857142876`, 0.7218997142857143, 0.4691502857142855], 
          RGBColor[0.5134170000000002, 0.72992, 0.44068199999999985`], 
          RGBColor[
          0.48953842857142865`, 0.7218997142857143, 0.46915028571428563`], 
          RGBColor[0.5134169999999999, 0.72992, 0.44068200000000013`], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[0.5134169999999999, 0.72992, 0.44068200000000013`], 
          RGBColor[
          0.48953842857142876`, 0.7218997142857143, 0.4691502857142855], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.48953842857142865`, 0.7218997142857143, 0.46915028571428563`], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.42559714285714284`, 0.11128428571428571`, 0.5662882857142857], 
          RGBColor[0.5134169999999999, 0.72992, 0.44068200000000013`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[
          0.42559714285714284`, 0.11128428571428571`, 0.5662882857142857], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[0.5134170000000002, 0.72992, 0.44068199999999985`], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.857359, 0.131106, 0.132128], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.48953842857142865`, 0.7218997142857143, 0.46915028571428563`], 
          RGBColor[0.5134170000000002, 0.72992, 0.44068199999999985`], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.48953842857142876`, 0.7218997142857143, 0.4691502857142855], 
          RGBColor[0.5134170000000002, 0.72992, 0.44068199999999985`], 
          RGBColor[
          0.48953842857142865`, 0.7218997142857143, 0.46915028571428563`], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.48953842857142865`, 0.7218997142857143, 0.46915028571428563`], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.48953842857142865`, 0.7218997142857143, 0.46915028571428563`], 
          RGBColor[0.5134170000000002, 0.72992, 0.44068199999999985`], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[0.5134169999999999, 0.72992, 0.44068200000000013`], 
          RGBColor[
          0.48953842857142865`, 0.7218997142857143, 0.46915028571428563`], 
          RGBColor[0.5134170000000002, 0.72992, 0.44068199999999985`], 
          RGBColor[
          0.48953842857142865`, 0.7218997142857143, 0.46915028571428563`], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.48953842857142865`, 0.7218997142857143, 0.46915028571428563`], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.48953842857142865`, 0.7218997142857143, 0.46915028571428563`], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[
          0.5941890000000003, 0.7417468571428572, 0.3703157142857141], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[
          0.8632869999999999, 0.1774208571428567, 0.14022885714285707`], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.5941890000000003, 0.7417468571428572, 0.3703157142857141], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.4417812857142856, 0.7058591428571428, 0.5260868571428573], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.4417812857142856, 0.7058591428571428, 0.5260868571428573], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.4417812857142856, 0.7058591428571428, 0.5260868571428573], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.44178128571428565`, 0.7058591428571428, 0.5260868571428572], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.6076510000000003, 0.743718, 0.3585879999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000004, 0.19201400000000007`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.878107, 0.29320799999999975`, 0.16048099999999996`], 
          RGBColor[0.878107, 0.29320799999999975`, 0.16048099999999996`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.4866639999999999, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.6076510000000003, 0.743718, 0.3585879999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[
          0.30591899999999994`, 0.5855749999999998, 0.7396660000000002], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.486664, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.794549, 0.721158, 0.260829], 
          RGBColor[
          0.8635120000000001, 0.6707709999999999, 0.23656399999999997`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635120000000001, 0.6707709999999999, 0.23656399999999997`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[
          0.25072800000000006`, 0.22538599999999992`, 0.7691519999999998], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.4866639999999999, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999997, 0.6707710000000002, 0.23656400000000008`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.486664, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.794549, 0.721158, 0.260829], 
          RGBColor[
          0.8635120000000001, 0.6707709999999999, 0.23656399999999997`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[
          0.30591899999999994`, 0.5855749999999998, 0.7396660000000002], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000003, 0.2165420000000001], 
          RGBColor[0.902853, 0.4539639999999997, 0.19201399999999993`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.486664, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000004, 0.19201400000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.3612419999999999, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539639999999997, 0.19201399999999993`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539639999999997, 0.19201399999999993`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.4866639999999999, 0.802529], 
          RGBColor[
          0.30591899999999994`, 0.5855749999999998, 0.7396660000000002], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.794549, 0.721158, 0.260829], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124200000000006`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.486664, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.794549, 0.721158, 0.260829], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[
          0.25072800000000006`, 0.22538599999999992`, 0.7691519999999998], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.486664, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[
          0.30591899999999994`, 0.5855749999999998, 0.7396660000000002], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635120000000001, 0.6707709999999999, 0.23656399999999997`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124200000000006`, 0.816084], 
          RGBColor[0.266122, 0.486664, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[
          0.25072800000000006`, 0.22538599999999992`, 0.7691519999999998], 
          RGBColor[0.24408, 0.36124200000000006`, 0.816084], 
          RGBColor[0.266122, 0.4866639999999999, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.486664, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[
          0.25072800000000006`, 0.22538599999999992`, 0.7691519999999998], 
          RGBColor[0.24408, 0.3612419999999999, 0.816084], 
          RGBColor[0.266122, 0.486664, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000004, 0.19201400000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124200000000006`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999997, 0.6707710000000002, 0.23656400000000008`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.36047999999999997`, 0.655759, 0.6456920000000002], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.878107, 0.29320799999999975`, 0.16048099999999996`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.878107, 0.29320799999999975`, 0.16048099999999996`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.878107, 0.29320799999999975`, 0.16048099999999996`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.794549, 0.721158, 0.260829], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.878107, 0.29320799999999975`, 0.16048099999999996`], 
          RGBColor[0.878107, 0.29320799999999975`, 0.16048099999999996`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.878107, 0.29320799999999975`, 0.16048099999999996`], 
          RGBColor[0.878107, 0.29320799999999975`, 0.16048099999999996`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000017`, 0.701849, 0.5403209999999998], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.42984199999999995`, 0.701849, 0.5403210000000002], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.6076510000000003, 0.743718, 0.3585879999999999], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.6076510000000003, 0.743718, 0.3585879999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984199999999995`, 0.701849, 0.5403210000000002], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000017`, 0.701849, 0.5403209999999998], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984199999999995`, 0.701849, 0.5403210000000002], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984199999999995`, 0.701849, 0.5403210000000002], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984199999999995`, 0.701849, 0.5403210000000002], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984199999999995`, 0.701849, 0.5403210000000002], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.24882857142857143`, 0.26420199999999994`, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.4907817142857146, 0.19902200000000006`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[
          0.3024411428571429, 0.1329808571428571, 0.6794237142857142], 
          RGBColor[
          0.24882857142857143`, 0.26420199999999994`, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571428, 0.6357064285714285, 0.6725417142857145], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571393`, 0.19902199999999992`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428576`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857143, 0.6205167142857141, 0.22512285714285712`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571427, 0.3161731428571422, 0.16498571428571418`], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285718`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428576`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.6215634285714289, 0.743557, 0.35009928571428556`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571427, 0.3161731428571422, 0.16498571428571418`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[
          0.30244114285714285`, 0.13298085714285715`, 0.6794237142857142], 
          RGBColor[0.24882857142857143`, 0.264202, 0.7825611428571428], 
          RGBColor[
          0.25352657142857143`, 0.41499428571428565`, 0.8102747142857143], 
          RGBColor[
          0.2888631428571429, 0.5431845714285714, 0.7666072857142858], 
          RGBColor[
          0.3448911428571429, 0.6357064285714286, 0.6725417142857143], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8241045714285714, 0.6995635714285714, 0.25042971428571426`], 
          RGBColor[
          0.8849417142857142, 0.6205167142857143, 0.22512285714285715`], 
          RGBColor[
          0.9023275714285715, 0.49078171428571415`, 0.19902199999999998`], 
          RGBColor[
          0.8816421428571428, 0.3161731428571428, 0.1649857142857143], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[
          0.24977828571428573`, 0.24479399999999998`, 0.7758565714285713], 
          RGBColor[
          0.25037771428571426`, 0.3970768571428571, 0.8122111428571429], 
          RGBColor[
          0.28317785714285715`, 0.5290544285714285, 0.7755877142857144], 
          RGBColor[
          0.3370967142857143, 0.6256801428571428, 0.6859665714285715], 
          RGBColor[0.41002428571428573`, 0.6886804285714285, 0.570427], 
          RGBColor[
          0.5014777142857145, 0.7259098571428572, 0.45491614285714266`], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[
          0.717825285714286, 0.7395291428571428, 0.29369014285714273`], 
          RGBColor[
          0.8142527142857141, 0.7067617142857143, 0.25389614285714285`], 
          RGBColor[
          0.8795842857142857, 0.6330802857142857, 0.22798314285714286`], 
          RGBColor[
          0.9020648571428571, 0.5091905714285709, 0.20252599999999993`], 
          RGBColor[
          0.8851772857142857, 0.33913828571428556`, 0.16949042857142854`], 
          RGBColor[
          0.8603230000000001, 0.15426342857142877`, 0.13617842857142862`], 
          RGBColor[
          0.2472288571428571, 0.3791594285714284, 0.8141475714285715], 
          RGBColor[
          0.2774925714285714, 0.5149242857142856, 0.7845681428571429], 
          RGBColor[
          0.32930228571428566`, 0.615653857142857, 0.6993914285714287], 
          RGBColor[
          0.40011542857142857`, 0.6820961428571428, 0.5854800000000001], 
          RGBColor[
          0.804400857142857, 0.7139598571428571, 0.25736257142857144`], 
          RGBColor[
          0.8742268571428571, 0.6456438571428572, 0.2308434285714286], 
          RGBColor[0.9018021428571429, 0.5275994285714285, 0.20603], 
          RGBColor[
          0.8887124285714285, 0.36210342857142863`, 0.17399514285714288`], 
          RGBColor[0.863287, 0.17742085714285755`, 0.1402288571428572], 
          RGBColor[
          0.2718072857142857, 0.5007941428571427, 0.7935485714285716], 
          RGBColor[
          0.32150785714285707`, 0.6056275714285713, 0.7128162857142859], 
          RGBColor[
          0.3902065714285714, 0.6755118571428571, 0.6005330000000001], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8688694285714285, 0.6582074285714287, 0.2337037142857143], 
          RGBColor[
          0.9015394285714285, 0.5460082857142861, 0.20953400000000008`], 
          RGBColor[
          0.8922475714285715, 0.385068571428572, 0.17849985714285724`], 
          RGBColor[0.866251, 0.20057828571428576`, 0.14427928571428572`], 
          RGBColor[
          0.3137134285714284, 0.5956012857142855, 0.7262411428571431], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9012767142857143, 0.5644171428571428, 0.21303800000000003`], 
          RGBColor[
          0.8957827142857143, 0.40803371428571444`, 0.18300457142857146`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[
          0.8993178571428572, 0.4309988571428569, 0.18750928571428566`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[
          0.24977828571428573`, 0.24479399999999998`, 0.7758565714285713], 
          RGBColor[
          0.25037771428571426`, 0.3970768571428571, 0.8122111428571429], 
          RGBColor[
          0.28317785714285715`, 0.5290544285714286, 0.7755877142857143], 
          RGBColor[
          0.3370967142857143, 0.6256801428571428, 0.6859665714285715], 
          RGBColor[
          0.4100242857142858, 0.6886804285714285, 0.5704269999999999], 
          RGBColor[
          0.5014777142857145, 0.7259098571428572, 0.45491614285714266`], 
          RGBColor[0.6076510000000003, 0.743718, 0.3585879999999999], 
          RGBColor[
          0.717825285714286, 0.7395291428571428, 0.29369014285714273`], 
          RGBColor[
          0.8142527142857141, 0.7067617142857143, 0.25389614285714285`], 
          RGBColor[
          0.8795842857142857, 0.6330802857142857, 0.22798314285714286`], 
          RGBColor[0.9020648571428571, 0.5091905714285714, 0.202526], 
          RGBColor[
          0.8851772857142857, 0.33913828571428556`, 0.16949042857142854`], 
          RGBColor[
          0.8603230000000001, 0.15426342857142877`, 0.13617842857142862`], 
          RGBColor[
          0.2472288571428571, 0.3791594285714284, 0.8141475714285715], 
          RGBColor[
          0.2774925714285714, 0.5149242857142856, 0.7845681428571429], 
          RGBColor[
          0.3293022857142857, 0.6156538571428571, 0.6993914285714286], 
          RGBColor[0.4001154285714286, 0.6820961428571428, 0.58548], 
          RGBColor[
          0.8044008571428573, 0.7139598571428569, 0.25736257142857133`], 
          RGBColor[
          0.8742268571428571, 0.6456438571428572, 0.2308434285714286], 
          RGBColor[0.9018021428571429, 0.5275994285714285, 0.20603], 
          RGBColor[
          0.8887124285714285, 0.36210342857142863`, 0.17399514285714288`], 
          RGBColor[0.8632869999999999, 0.177420857142857, 0.1402288571428571], 
          RGBColor[
          0.2718072857142857, 0.5007941428571427, 0.7935485714285715], 
          RGBColor[
          0.32150785714285707`, 0.6056275714285713, 0.7128162857142859], 
          RGBColor[0.39020657142857146`, 0.6755118571428571, 0.600533], 
          RGBColor[0.794549, 0.721158, 0.260829], 
          RGBColor[
          0.8688694285714286, 0.6582074285714284, 0.23370371428571426`], 
          RGBColor[
          0.9015394285714285, 0.5460082857142854, 0.20953399999999994`], 
          RGBColor[
          0.8922475714285715, 0.38506857142857137`, 0.17849985714285713`], 
          RGBColor[0.866251, 0.20057828571428576`, 0.14427928571428572`], 
          RGBColor[0.3137134285714285, 0.5956012857142856, 0.726241142857143], 
          RGBColor[
          0.8635120000000001, 0.6707709999999999, 0.23656399999999997`], 
          RGBColor[
          0.9012767142857143, 0.5644171428571426, 0.21303799999999998`], 
          RGBColor[
          0.8957827142857142, 0.4080337142857139, 0.18300457142857135`], 
          RGBColor[0.901014, 0.5828259999999997, 0.21654199999999996`], 
          RGBColor[
          0.8993178571428572, 0.4309988571428569, 0.18750928571428566`], 
          RGBColor[0.902853, 0.4539639999999997, 0.19201399999999993`], 
          RGBColor[
          0.4485045714285714, 0.11002514285714286`, 0.5466521428571429], 
          RGBColor[
          0.7433998571428573, 0.7334054285714285, 0.2827364285714285], 
          RGBColor[
          0.8781069999999999, 0.29320799999999947`, 0.1604809999999999], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[
          0.4255971428571428, 0.11128428571428572`, 0.5662882857142858], 
          RGBColor[
          0.4417812857142856, 0.7058591428571428, 0.5260868571428573], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.8751429999999999, 0.27005057142857125`, 0.1564305714285714], 
          RGBColor[
          0.4026897142857142, 0.11254342857142859`, 0.5859244285714287], 
          RGBColor[0.37038885714285724`, 0.6623432857142858, 0.630639], 
          RGBColor[
          0.4537205714285716, 0.7098692857142858, 0.5118527142857142], 
          RGBColor[0.5538030000000003, 0.7358334285714286, 0.405498857142857], 
          RGBColor[0.6633007142857145, 0.743074, 0.3246331428571428], 
          RGBColor[
          0.7689744285714286, 0.7272817142857142, 0.2717827142857142], 
          RGBColor[
          0.8721789999999999, 0.24689314285714248`, 0.1523801428571428], 
          RGBColor[
          0.3797822857142858, 0.11380257142857142`, 0.6055605714285713], 
          RGBColor[
          0.37978228571428563`, 0.11380257142857143`, 0.6055605714285716], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[
          0.3802977142857143, 0.6689275714285714, 0.6155860000000001], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.7817617142857145, 0.7242198571428571, 0.26630585714285704`], 
          RGBColor[
          0.7817617142857145, 0.7242198571428571, 0.26630585714285704`], 
          RGBColor[0.869215, 0.22373571428571398`, 0.14832971428571423`], 
          RGBColor[0.869215, 0.22373571428571398`, 0.14832971428571423`], 
          RGBColor[
          0.40268971428571443`, 0.11254342857142857`, 0.5859244285714285], 
          RGBColor[0.356874857142857, 0.1150617142857143, 0.6251967142857144], 
          RGBColor[
          0.37038885714285713`, 0.6623432857142857, 0.6306390000000001], 
          RGBColor[
          0.3902065714285714, 0.6755118571428571, 0.6005330000000001], 
          RGBColor[
          0.45372057142857136`, 0.7098692857142856, 0.5118527142857144], 
          RGBColor[
          0.4775991428571429, 0.7178895714285715, 0.48338442857142855`], 
          RGBColor[
          0.5538029999999999, 0.7358334285714285, 0.40549885714285727`], 
          RGBColor[
          0.5807270000000001, 0.7397757142857143, 0.3820434285714285], 
          RGBColor[0.6633007142857144, 0.743074, 0.3246331428571429], 
          RGBColor[0.6911255714285717, 0.742752, 0.30765571428571414`], 
          RGBColor[
          0.7689744285714286, 0.7272817142857142, 0.2717827142857142], 
          RGBColor[0.872179, 0.24689314285714303`, 0.15238014285714288`], 
          RGBColor[0.866251, 0.20057828571428576`, 0.14427928571428572`], 
          RGBColor[
          0.42559714285714284`, 0.11128428571428571`, 0.5662882857142857], 
          RGBColor[
          0.3339674285714286, 0.11632085714285714`, 0.6448328571428571], 
          RGBColor[0.4001154285714286, 0.6820961428571428, 0.58548], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.8751429999999999, 0.2700505714285707, 0.1564305714285713], 
          RGBColor[0.8632869999999999, 0.177420857142857, 0.1402288571428571], 
          RGBColor[
          0.4485045714285715, 0.11002514285714286`, 0.5466521428571428], 
          RGBColor[0.41002428571428573`, 0.6886804285714285, 0.570427], 
          RGBColor[
          0.7433998571428573, 0.7334054285714285, 0.2827364285714285], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[
          0.8603230000000001, 0.15426342857142877`, 0.13617842857142862`], 
          RGBColor[
          0.4485045714285715, 0.11002514285714286`, 0.5466521428571429], 
          RGBColor[
          0.7433998571428575, 0.7334054285714284, 0.28273642857142844`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[
          0.42559714285714284`, 0.11128428571428572`, 0.5662882857142858], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.8751429999999999, 0.27005057142857125`, 0.1564305714285714], 
          RGBColor[
          0.4026897142857143, 0.11254342857142857`, 0.5859244285714286], 
          RGBColor[0.37038885714285724`, 0.6623432857142858, 0.630639], 
          RGBColor[
          0.4537205714285714, 0.7098692857142856, 0.5118527142857143], 
          RGBColor[0.553803, 0.7358334285714285, 0.40549885714285716`], 
          RGBColor[0.6633007142857145, 0.743074, 0.3246331428571428], 
          RGBColor[
          0.7689744285714286, 0.7272817142857142, 0.2717827142857142], 
          RGBColor[0.872179, 0.24689314285714303`, 0.15238014285714288`], 
          RGBColor[
          0.4026897142857143, 0.11254342857142857`, 0.5859244285714286], 
          RGBColor[
          0.35687485714285716`, 0.1150617142857143, 0.6251967142857143], 
          RGBColor[0.37038885714285724`, 0.6623432857142858, 0.630639], 
          RGBColor[0.3902065714285715, 0.6755118571428571, 0.600533], 
          RGBColor[
          0.4537205714285714, 0.7098692857142856, 0.5118527142857143], 
          RGBColor[
          0.47759914285714306`, 0.7178895714285715, 0.4833844285714284], 
          RGBColor[0.5538030000000003, 0.7358334285714286, 0.405498857142857], 
          RGBColor[
          0.5807270000000001, 0.7397757142857143, 0.3820434285714285], 
          RGBColor[0.6633007142857145, 0.743074, 0.3246331428571428], 
          RGBColor[0.6911255714285717, 0.742752, 0.30765571428571414`], 
          RGBColor[
          0.7689744285714286, 0.7272817142857142, 0.2717827142857142], 
          RGBColor[
          0.8721789999999999, 0.24689314285714248`, 0.1523801428571428], 
          RGBColor[0.866251, 0.20057828571428576`, 0.14427928571428572`], 
          RGBColor[
          0.42559714285714284`, 0.11128428571428571`, 0.5662882857142857], 
          RGBColor[
          0.3339674285714286, 0.11632085714285714`, 0.6448328571428571], 
          RGBColor[0.4001154285714286, 0.6820961428571428, 0.58548], 
          RGBColor[0.756187142857143, 0.7303435714285714, 0.2772595714285714], 
          RGBColor[
          0.8751429999999999, 0.27005057142857125`, 0.1564305714285714], 
          RGBColor[0.8632869999999999, 0.177420857142857, 0.1402288571428571], 
          RGBColor[
          0.44850457142857153`, 0.11002514285714285`, 0.5466521428571428], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.41002428571428573`, 0.6886804285714285, 0.570427], 
          RGBColor[
          0.7433998571428572, 0.7334054285714285, 0.28273642857142856`], 
          RGBColor[0.878107, 0.29320799999999975`, 0.16048099999999996`], 
          RGBColor[
          0.8603230000000001, 0.15426342857142908`, 0.13617842857142864`], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.8573590000000001, 0.13110600000000058`, 0.1321280000000001], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.5134169999999999, 0.72992, 0.44068200000000013`], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285717, 0.7364672857142857, 0.2882132857142856], 
          RGBColor[0.857359, 0.131106, 0.132128], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[0.857359, 0.13110600000000028`, 0.13212800000000005`], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[0.471412, 0.108766, 0.527016], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571428, 0.742913, 0.31614442857142866`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571428, 0.742913, 0.31614442857142866`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571432, 0.742913, 0.31614442857142844`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.5672650000000001, 0.7378045714285715, 0.39377114285714276`], 
          RGBColor[0.6772131428571431, 0.742913, 0.31614442857142855`], 
          RGBColor[
          0.5807270000000001, 0.7397757142857143, 0.3820434285714285], 
          RGBColor[
          0.5941890000000001, 0.7417468571428572, 0.37031571428571425`], 
          RGBColor[
          0.5941890000000001, 0.7417468571428572, 0.37031571428571425`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.580727, 0.7397757142857143, 0.38204342857142864`], 
          RGBColor[
          0.7178252857142858, 0.7395291428571428, 0.29369014285714284`], 
          RGBColor[
          0.5807270000000001, 0.7397757142857143, 0.3820434285714285], 
          RGBColor[
          0.5807270000000001, 0.7397757142857143, 0.3820434285714285], 
          RGBColor[
          0.717825285714286, 0.7395291428571428, 0.29369014285714273`], 
          RGBColor[
          0.5268790000000001, 0.7318911428571429, 0.4289542857142856], 
          RGBColor[0.553803, 0.7358334285714285, 0.40549885714285716`], 
          RGBColor[0.6354758571428573, 0.743396, 0.34161057142857143`], 
          RGBColor[0.6633007142857145, 0.743074, 0.3246331428571428], 
          RGBColor[
          0.5403410000000001, 0.7338622857142857, 0.4172265714285714], 
          RGBColor[0.6493882857142858, 0.743235, 0.33312185714285714`], 
          RGBColor[0.526879, 0.7318911428571429, 0.4289542857142858], 
          RGBColor[0.6354758571428573, 0.743396, 0.34161057142857143`], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[
          0.7306125714285715, 0.7364672857142857, 0.28821328571428567`], 
          RGBColor[
          0.5268790000000001, 0.7318911428571429, 0.4289542857142856], 
          RGBColor[0.6354758571428573, 0.743396, 0.34161057142857143`], 
          RGBColor[
          0.7178252857142858, 0.7395291428571428, 0.29369014285714284`], 
          RGBColor[0.526879, 0.7318911428571429, 0.4289542857142858], 
          RGBColor[0.553803, 0.7358334285714285, 0.40549885714285716`], 
          RGBColor[
          0.5807270000000001, 0.7397757142857143, 0.3820434285714285], 
          RGBColor[0.6354758571428573, 0.743396, 0.34161057142857143`], 
          RGBColor[0.6633007142857145, 0.743074, 0.3246331428571428], 
          RGBColor[
          0.717825285714286, 0.7395291428571428, 0.29369014285714273`], 
          RGBColor[0.526879, 0.7318911428571429, 0.4289542857142858], 
          RGBColor[
          0.5538029999999999, 0.7358334285714285, 0.40549885714285727`], 
          RGBColor[0.6354758571428573, 0.743396, 0.34161057142857143`], 
          RGBColor[0.6633007142857145, 0.743074, 0.3246331428571428], 
          RGBColor[0.526879, 0.7318911428571429, 0.4289542857142858], 
          RGBColor[0.6354758571428573, 0.743396, 0.34161057142857143`], 
          RGBColor[0.526879, 0.7318911428571429, 0.4289542857142858], 
          RGBColor[0.6354758571428573, 0.743396, 0.34161057142857143`], 
          RGBColor[
          0.717825285714286, 0.7395291428571428, 0.29369014285714273`], 
          RGBColor[0.526879, 0.7318911428571429, 0.4289542857142858], 
          RGBColor[0.5538030000000003, 0.7358334285714286, 0.405498857142857], 
          RGBColor[0.580727, 0.7397757142857143, 0.38204342857142864`], 
          RGBColor[0.6354758571428573, 0.743396, 0.34161057142857143`], 
          RGBColor[0.6633007142857145, 0.743074, 0.3246331428571428], 
          RGBColor[
          0.717825285714286, 0.7395291428571428, 0.29369014285714273`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.4537205714285716, 0.7098692857142858, 0.5118527142857142], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.4656598571428573, 0.7138794285714286, 0.49761857142857124`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.4656598571428573, 0.7138794285714286, 0.49761857142857124`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.4656598571428572, 0.7138794285714285, 0.49761857142857147`], 
          RGBColor[
          0.4537205714285716, 0.7098692857142858, 0.5118527142857142], 
          RGBColor[
          0.4775991428571429, 0.7178895714285715, 0.48338442857142855`], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[
          0.4895384285714286, 0.7218997142857143, 0.46915028571428574`], 
          RGBColor[
          0.47759914285714283`, 0.7178895714285713, 0.4833844285714286], 
          RGBColor[
          0.5014777142857144, 0.7259098571428572, 0.45491614285714277`], 
          RGBColor[
          0.47759914285714306`, 0.7178895714285715, 0.4833844285714284], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.4775991428571429, 0.7178895714285715, 0.48338442857142855`], 
          RGBColor[
          0.5014777142857144, 0.7259098571428572, 0.45491614285714277`], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.5014777142857143, 0.7259098571428572, 0.4549161428571428], 
          RGBColor[0.513417, 0.72992, 0.440682], 
          RGBColor[
          0.5014777142857144, 0.7259098571428572, 0.45491614285714277`], 
          RGBColor[
          0.47759914285714306`, 0.7178895714285715, 0.4833844285714284], 
          RGBColor[
          0.5014777142857145, 0.7259098571428572, 0.45491614285714266`], 
          RGBColor[0.5134170000000002, 0.72992, 0.44068199999999985`], 
          RGBColor[
          0.5014777142857144, 0.7259098571428572, 0.45491614285714277`], 
          RGBColor[
          0.47759914285714283`, 0.7178895714285713, 0.4833844285714286], 
          RGBColor[
          0.4537205714285714, 0.7098692857142856, 0.5118527142857143], 
          RGBColor[
          0.4417812857142856, 0.7058591428571428, 0.5260868571428573], 
          RGBColor[
          0.4537205714285714, 0.7098692857142856, 0.5118527142857143], 
          RGBColor[
          0.3339674285714287, 0.11632085714285714`, 0.644832857142857], 
          RGBColor[
          0.35687485714285727`, 0.11506171428571428`, 0.6251967142857141], 
          RGBColor[
          0.2593468571428572, 0.20998514285714276`, 0.7541972857142856], 
          RGBColor[0.24408, 0.36124199999999973`, 0.8160839999999999], 
          RGBColor[
          0.26796571428571436`, 0.19458428571428565`, 0.7392425714285713], 
          RGBColor[
          0.2450297142857143, 0.34183399999999986`, 0.8093794285714285], 
          RGBColor[0.26612199999999997`, 0.4866639999999998, 0.802529], 
          RGBColor[
          0.2765845714285715, 0.17918342857142844`, 0.724287857142857], 
          RGBColor[
          0.24597942857142857`, 0.3224259999999998, 0.8026748571428571], 
          RGBColor[
          0.26297314285714285`, 0.46874657142857123`, 0.8044654285714287], 
          RGBColor[
          0.30591899999999994`, 0.5855749999999997, 0.7396660000000002], 
          RGBColor[
          0.8536601428571429, 0.6779691428571428, 0.24003042857142856`], 
          RGBColor[
          0.2852034285714286, 0.16378257142857136`, 0.7093331428571428], 
          RGBColor[
          0.24692914285714285`, 0.3030179999999999, 0.7959702857142856], 
          RGBColor[
          0.2598242857142857, 0.45082914285714265`, 0.8064018571428572], 
          RGBColor[
          0.3002337142857142, 0.5714448571428569, 0.7486464285714287], 
          RGBColor[
          0.8438082857142857, 0.6851672857142856, 0.2434968571428571], 
          RGBColor[
          0.8956565714285715, 0.5953895714285713, 0.21940228571428572`], 
          RGBColor[
          0.29382228571428576`, 0.14838171428571426`, 0.6943784285714285], 
          RGBColor[
          0.24787885714285715`, 0.2836099999999999, 0.7892657142857142], 
          RGBColor[
          0.25667542857142855`, 0.4329117142857142, 0.8083382857142858], 
          RGBColor[
          0.29454842857142854`, 0.5573147142857142, 0.7576268571428573], 
          RGBColor[
          0.8339564285714285, 0.6923654285714286, 0.24696328571428572`], 
          RGBColor[0.890299142857143, 0.6079531428571425, 0.2222625714285714], 
          RGBColor[
          0.9025902857142857, 0.47237285714285704`, 0.19551799999999997`], 
          RGBColor[
          0.3339674285714286, 0.11632085714285714`, 0.6448328571428571], 
          RGBColor[
          0.35687485714285716`, 0.1150617142857143, 0.6251967142857143], 
          RGBColor[
          0.25934685714285716`, 0.20998514285714284`, 0.7541972857142857], 
          RGBColor[
          0.2679657142857143, 0.19458428571428565`, 0.7392425714285713], 
          RGBColor[0.24502971428571427`, 0.341834, 0.8093794285714286], 
          RGBColor[
          0.27658457142857146`, 0.17918342857142858`, 0.7242878571428571], 
          RGBColor[0.24597942857142857`, 0.322426, 0.8026748571428571], 
          RGBColor[
          0.26297314285714285`, 0.46874657142857135`, 0.8044654285714287], 
          RGBColor[
          0.8536601428571429, 0.6779691428571428, 0.24003042857142856`], 
          RGBColor[
          0.2852034285714286, 0.1637825714285714, 0.7093331428571428], 
          RGBColor[0.24692914285714285`, 0.303018, 0.7959702857142857], 
          RGBColor[
          0.25982428571428573`, 0.4508291428571428, 0.8064018571428572], 
          RGBColor[
          0.30023371428571427`, 0.5714448571428571, 0.7486464285714286], 
          RGBColor[
          0.8438082857142857, 0.6851672857142856, 0.2434968571428571], 
          RGBColor[
          0.8956565714285715, 0.5953895714285713, 0.21940228571428572`], 
          RGBColor[
          0.29382228571428576`, 0.1483817142857142, 0.6943784285714285], 
          RGBColor[
          0.24787885714285715`, 0.28360999999999986`, 0.7892657142857142], 
          RGBColor[
          0.25667542857142855`, 0.4329117142857142, 0.8083382857142858], 
          RGBColor[0.2945484285714285, 0.557314714285714, 0.7576268571428574], 
          RGBColor[
          0.8339564285714285, 0.6923654285714286, 0.24696328571428572`], 
          RGBColor[
          0.8902991428571428, 0.6079531428571427, 0.22226257142857142`], 
          RGBColor[
          0.9025902857142857, 0.47237285714285726`, 0.19551800000000003`], 
          RGBColor[
          0.3526855714285715, 0.6457327142857143, 0.6591168571428572], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.794549, 0.721158, 0.260829], 
          RGBColor[0.8044008571428571, 0.713959857142857, 0.2573625714285714], 
          RGBColor[
          0.3526855714285715, 0.6457327142857143, 0.6591168571428572], 
          RGBColor[
          0.8142527142857141, 0.7067617142857143, 0.25389614285714285`], 
          RGBColor[
          0.35268557142857154`, 0.6457327142857143, 0.6591168571428571], 
          RGBColor[0.794549, 0.721158, 0.260829], 
          RGBColor[
          0.8044008571428573, 0.7139598571428569, 0.25736257142857133`], 
          RGBColor[
          0.3526855714285714, 0.6457327142857142, 0.6591168571428573], 
          RGBColor[
          0.8142527142857143, 0.7067617142857142, 0.25389614285714285`], 
          RGBColor[0.6911255714285717, 0.742752, 0.30765571428571414`], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.6911255714285716, 0.742752, 0.30765571428571425`], 
          RGBColor[0.6911255714285717, 0.742752, 0.30765571428571414`], 
          RGBColor[0.6911255714285717, 0.742752, 0.30765571428571414`], 
          RGBColor[0.6215634285714288, 0.743557, 0.35009928571428567`], 
          RGBColor[0.6076510000000003, 0.743718, 0.3585879999999999], 
          RGBColor[0.6911255714285717, 0.742752, 0.30765571428571414`], 
          RGBColor[0.6076510000000004, 0.743718, 0.3585879999999998], 
          RGBColor[0.6911255714285717, 0.742752, 0.30765571428571414`], 
          RGBColor[0.4199331428571429, 0.6952647142857142, 0.555374], 
          RGBColor[0.42984199999999995`, 0.701849, 0.5403210000000002], 
          RGBColor[
          0.4298419999999999, 0.7018489999999998, 0.5403210000000003], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984199999999995`, 0.701849, 0.5403210000000002], 
          RGBColor[0.42984199999999995`, 0.701849, 0.5403210000000002], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.4866639999999999, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000004, 0.19201400000000007`], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000004, 0.19201400000000007`], 
          RGBColor[
          0.30591899999999994`, 0.5855749999999998, 0.7396660000000002], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000004, 0.19201400000000007`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124200000000006`, 0.816084], 
          RGBColor[0.266122, 0.486664, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.266122, 0.486664, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[
          0.30591899999999994`, 0.5855749999999998, 0.7396660000000002], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.4866639999999999, 0.802529], 
          RGBColor[
          0.25072800000000006`, 0.22538599999999992`, 0.7691519999999998], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.4866639999999999, 0.802529], 
          RGBColor[
          0.30591899999999994`, 0.5855749999999998, 0.7396660000000002], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999997, 0.6707710000000002, 0.23656400000000008`], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.4866639999999999, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.486664, 0.802529], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.36124199999999995`, 0.816084], 
          RGBColor[0.266122, 0.48666399999999993`, 0.802529], 
          RGBColor[0.305919, 0.585575, 0.739666], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.25072800000000006`, 0.22538599999999998`, 0.769152], 
          RGBColor[0.24408, 0.3612419999999999, 0.816084], 
          RGBColor[0.266122, 0.4866639999999999, 0.802529], 
          RGBColor[
          0.30591899999999994`, 0.5855749999999998, 0.7396660000000002], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[
          0.8635119999999998, 0.6707710000000001, 0.23656400000000005`], 
          RGBColor[
          0.9010139999999999, 0.5828260000000001, 0.21654200000000004`], 
          RGBColor[0.902853, 0.4539640000000002, 0.19201400000000005`], 
          RGBColor[0.878107, 0.29320799999999975`, 0.16048099999999996`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.878107, 0.29320799999999975`, 0.16048099999999996`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.3604800000000001, 0.655759, 0.6456919999999999], 
          RGBColor[0.7945489999999998, 0.721158, 0.26082900000000003`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[
          0.36048000000000013`, 0.6557590000000001, 0.6456919999999998], 
          RGBColor[0.878107, 0.29320799999999975`, 0.16048099999999996`], 
          RGBColor[0.31106, 0.11758, 0.664469], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.878107, 0.2932080000000003, 0.16048100000000007`], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.6076510000000003, 0.743718, 0.3585879999999999], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.7050380000000002, 0.742591, 0.29916699999999996`], 
          RGBColor[0.607651, 0.743718, 0.358588], 
          RGBColor[0.705038, 0.742591, 0.299167], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999], 
          RGBColor[0.42984200000000006`, 0.701849, 0.5403209999999999]},
        VertexNormals->CompressedData["
1:eJxcXHk8VV3blrmIytAslKGnzEOoc3bKrEypDCklc8lMkswiCYkSpaIMKUNk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         "],
        VertexTextureCoordinates->CompressedData["
1:eJyFnE2PHMd5xzdygCDfIRdFb/4WAwRILDKOD/oIAZJDYlJScg0QwJckhwD2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         "]],
       Axes->True,
       AxesEdge->{{-1, -1}, {1, -1}, {-1, -1}},
       AxesLabel->{
         FormBox[
         "\"\\!\\(\\*\\nStyleBox[\\\"x\\\",\\nFontSize->14]\\)\"", 
          TraditionalForm], 
         FormBox[
         "\"\\!\\(\\*\\nStyleBox[\\\"y\\\",\\nFontSize->14]\\)\"", 
          TraditionalForm], 
         FormBox[
         "\"\\!\\(\\*\\nStyleBox[\\\"\[Rho]\\\",\\nFontSize->14]\\)\\!\\(\\*\\\
nStyleBox[\\\"(\\\",\\nFontSize->14]\\)\\!\\(\\*\\nStyleBox[\\\"r\\\",\\\
nFontSize->14]\\)\\!\\(\\*\\nStyleBox[\\\")\\\",\\nFontSize->14]\\)\"", 
          TraditionalForm]},
       BaseStyle->Specularity[
         GrayLevel[0.5], 30],
       BoxRatios->NCache[{2, 2, GoldenRatio^(-1)}, {2, 2, 0.6180339887498948}],
       Boxed->{Left, Bottom, Back},
       DisplayFunction->Identity,
       FaceGridsStyle->Directive[
         GrayLevel[0.3, 1], 
         AbsoluteDashing[{1, 2}]],
       LabelStyle->{FontFamily -> "Times"},
       Lighting->"Neutral",
       Method->{},
       PlotRange->{All, All, All},
       PlotRangePadding->{Automatic, Automatic, Automatic},
       Ticks->{Automatic, Automatic, Automatic}], {540, -180}, 
      ImageScaled[{0.5, 0.5}], {360, 360},
      ContentSelectable->True]}, {}},
   ContentSelectable->True,
   ImageSize->Full,
   PlotRangePadding->{6, 5}],
  Background->GrayLevel[1]]], "Output",
 CellChangeTimes->{3.7563890611261234`*^9, 3.756734235212099*^9, 
  3.7567342841205425`*^9, 3.7567482969044933`*^9, 3.7569223761042395`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Export", "[", 
   RowBox[{"\"\<fig3.pdf\>\"", ",", "grid3d", ",", 
    RowBox[{"ImageResolution", "\[Rule]", "1000"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "Full"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7563912023582497`*^9, 3.756391204884892*^9}, {
   3.756403894691716*^9, 3.7564038954938273`*^9}, 3.7569096848269925`*^9}],

Cell[BoxData["\<\"fig3.pdf\"\>"], "Output",
 CellChangeTimes->{3.7567342904076834`*^9, 3.756748305890074*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Figure 4",
 FontSize->18]], "Section",
 CellChangeTimes->{{3.756909376818782*^9, 3.75690938851333*^9}},
 Background->RGBColor[0., 1., 1.]],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"Stability", " ", "range", " ", "with", " ", "m"}], "=", "0"}], 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7563892390380387`*^9, 3.756389261930705*^9}}],

Cell[BoxData[{
 RowBox[{
  StyleBox[
   RowBox[{
    RowBox[{"alistrangemin", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.02"}], ",", 
         RowBox[{"-", "0.07698"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03"}], ",", 
         RowBox[{"-", "0.0942809"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.04"}], ",", 
         RowBox[{"-", "0.108866"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.05"}], ",", 
         RowBox[{"-", "0.121716"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.06"}], ",", 
         RowBox[{"-", "0.133333"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.07"}], ",", 
         RowBox[{"-", "0.144016"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.08"}], ",", 
         RowBox[{"-", "0.15396"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.09"}], ",", 
         RowBox[{"-", "0.163299"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.1"}], ",", 
         RowBox[{"-", "0.172133"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.11"}], ",", 
         RowBox[{"-", "0.180534"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.12"}], ",", 
         RowBox[{"-", "0.188562"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.13"}], ",", 
         RowBox[{"-", "0.196261"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.14"}], ",", 
         RowBox[{"-", "0.20367"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15"}], ",", 
         RowBox[{"-", "0.210819"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.16"}], ",", 
         RowBox[{"-", "0.217732"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.17"}], ",", 
         RowBox[{"-", "0.224433"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.18"}], ",", 
         RowBox[{"-", "0.23094"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.19"}], ",", 
         RowBox[{"-", "0.237268"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2"}], ",", 
         RowBox[{"-", "0.243432"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.21"}], ",", 
         RowBox[{"-", "0.249444"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.22"}], ",", 
         RowBox[{"-", "0.255314"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.23"}], ",", 
         RowBox[{"-", "0.261052"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.24"}], ",", 
         RowBox[{"-", "0.266667"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.25"}], ",", 
         RowBox[{"-", "0.272166"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.26"}], ",", 
         RowBox[{"-", "0.277555"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.27"}], ",", 
         RowBox[{"-", "0.282843"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.28"}], ",", 
         RowBox[{"-", "0.288033"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.29"}], ",", 
         RowBox[{"-", "0.293131"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.3"}], ",", 
         RowBox[{"-", "0.298142"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.31"}], ",", 
         RowBox[{"-", "0.303071"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.32"}], ",", 
         RowBox[{"-", "0.30792"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.33"}], ",", 
         RowBox[{"-", "0.312694"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.34"}], ",", 
         RowBox[{"-", "0.317397"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.35"}], ",", 
         RowBox[{"-", "0.322031"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.36"}], ",", 
         RowBox[{"-", "0.326599"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.37"}], ",", 
         RowBox[{"-", "0.331104"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.38"}], ",", 
         RowBox[{"-", "0.335548"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.39"}], ",", 
         RowBox[{"-", "0.339935"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.4"}], ",", 
         RowBox[{"-", "0.344265"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.41"}], ",", 
         RowBox[{"-", "0.348542"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.42"}], ",", 
         RowBox[{"-", "0.352767"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.43"}], ",", 
         RowBox[{"-", "0.356942"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.44"}], ",", 
         RowBox[{"-", "0.361068"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.45"}], ",", 
         RowBox[{"-", "0.365148"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.46"}], ",", 
         RowBox[{"-", "0.369183"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.47"}], ",", 
         RowBox[{"-", "0.373175"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.48"}], ",", 
         RowBox[{"-", "0.377124"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.49"}], ",", 
         RowBox[{"-", "0.381032"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.5"}], ",", 
         RowBox[{"-", "0.3849"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.51"}], ",", 
         RowBox[{"-", "0.38873"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.52"}], ",", 
         RowBox[{"-", "0.392523"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.53"}], ",", 
         RowBox[{"-", "0.396279"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.54"}], ",", 
         RowBox[{"-", "0.4"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.55"}], ",", 
         RowBox[{"-", "0.403687"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.56"}], ",", 
         RowBox[{"-", "0.40734"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.57"}], ",", 
         RowBox[{"-", "0.410961"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.58"}], ",", 
         RowBox[{"-", "0.41455"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.59"}], ",", 
         RowBox[{"-", "0.418109"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.6"}], ",", 
         RowBox[{"-", "0.421637"}]}], "}"}]}], "}"}]}], ";"}],
   FontSize->9], 
  StyleBox[
   RowBox[{"(*", 
    RowBox[{
    "List", " ", "of", " ", "parameters", " ", "corresponding", " ", "to", 
     " ", "the", " ", "upper", " ", "theoretical", " ", "limit"}], "*)"}],
   FontSize->12]}], "\[IndentingNewLine]", 
 RowBox[{
  StyleBox[
   RowBox[{
    RowBox[{"listbrangemax", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.02"}], ",", 
         RowBox[{"-", "0.0816497"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03"}], ",", 
         RowBox[{"-", "0.1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.04"}], ",", 
         RowBox[{"-", "0.11547"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.05"}], ",", 
         RowBox[{"-", "0.129099"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.06"}], ",", 
         RowBox[{"-", "0.141421"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.07"}], ",", 
         RowBox[{"-", "0.152753"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.08"}], ",", 
         RowBox[{"-", "0.163299"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.09"}], ",", 
         RowBox[{"-", "0.173205"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.1"}], ",", 
         RowBox[{"-", "0.182574"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.11"}], ",", 
         RowBox[{"-", "0.191485"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.12"}], ",", 
         RowBox[{"-", "0.2"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.13"}], ",", 
         RowBox[{"-", "0.208167"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.14"}], ",", 
         RowBox[{"-", "0.216025"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15"}], ",", 
         RowBox[{"-", "0.223607"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.16"}], ",", 
         RowBox[{"-", "0.23094"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.17"}], ",", 
         RowBox[{"-", "0.238048"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.18"}], ",", 
         RowBox[{"-", "0.244949"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.19"}], ",", 
         RowBox[{"-", "0.251661"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2"}], ",", 
         RowBox[{"-", "0.258199"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.21"}], ",", 
         RowBox[{"-", "0.264575"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.22"}], ",", 
         RowBox[{"-", "0.270801"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.23"}], ",", 
         RowBox[{"-", "0.276887"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.24"}], ",", 
         RowBox[{"-", "0.282843"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.25"}], ",", 
         RowBox[{"-", "0.288675"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.26"}], ",", 
         RowBox[{"-", "0.294392"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.27"}], ",", 
         RowBox[{"-", "0.3"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.28"}], ",", 
         RowBox[{"-", "0.305505"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.29"}], ",", 
         RowBox[{"-", "0.310913"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.3"}], ",", 
         RowBox[{"-", "0.316228"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.31"}], ",", 
         RowBox[{"-", "0.321455"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.32"}], ",", 
         RowBox[{"-", "0.326599"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.33"}], ",", 
         RowBox[{"-", "0.331662"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.34"}], ",", 
         RowBox[{"-", "0.33665"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.35"}], ",", 
         RowBox[{"-", "0.341565"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.36"}], ",", 
         RowBox[{"-", "0.34641"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.37"}], ",", 
         RowBox[{"-", "0.351188"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.38"}], ",", 
         RowBox[{"-", "0.355903"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.39"}], ",", 
         RowBox[{"-", "0.360555"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.4"}], ",", 
         RowBox[{"-", "0.365148"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.41"}], ",", 
         RowBox[{"-", "0.369685"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.42"}], ",", 
         RowBox[{"-", "0.374166"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.43"}], ",", 
         RowBox[{"-", "0.378594"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.44"}], ",", 
         RowBox[{"-", "0.382971"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.45"}], ",", 
         RowBox[{"-", "0.387298"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.46"}], ",", 
         RowBox[{"-", "0.391578"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.47"}], ",", 
         RowBox[{"-", "0.395811"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.48"}], ",", 
         RowBox[{"-", "0.4"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.49"}], ",", 
         RowBox[{"-", "0.404145"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.5"}], ",", 
         RowBox[{"-", "0.408248"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.51"}], ",", 
         RowBox[{"-", "0.412311"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.52"}], ",", 
         RowBox[{"-", "0.416333"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.53"}], ",", 
         RowBox[{"-", "0.420317"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.54"}], ",", 
         RowBox[{"-", "0.424264"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.55"}], ",", 
         RowBox[{"-", "0.428174"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.56"}], ",", 
         RowBox[{"-", "0.432049"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.57"}], ",", 
         RowBox[{"-", "0.43589"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.58"}], ",", 
         RowBox[{"-", "0.439697"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.59"}], ",", 
         RowBox[{"-", "0.443471"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.6"}], ",", 
         RowBox[{"-", "0.447214"}]}], "}"}]}], "}"}]}], ";"}],
   FontSize->9], 
  StyleBox[
   RowBox[{"(*", 
    RowBox[{
    "List", " ", "of", " ", "parameters", " ", "corresponding", " ", "to", 
     " ", "the", " ", "lower", " ", "limit", " ", "of", " ", "metastable", 
     " ", "solutions"}], "*)"}],
   FontSize->12]}], "\n", 
 RowBox[{
  StyleBox[
   RowBox[{
    RowBox[{"lista05", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.02"}], ",", 
         RowBox[{"-", "0.07998"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03"}], ",", 
         RowBox[{"-", "0.0979809"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.04"}], ",", 
         RowBox[{"-", "0.113166"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.05"}], ",", 
         RowBox[{"-", "0.126516"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.06"}], ",", 
         RowBox[{"-", "0.138533"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.07"}], ",", 
         RowBox[{"-", "0.149616"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.08"}], ",", 
         RowBox[{"-", "0.15996"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.09"}], ",", 
         RowBox[{"-", "0.169699"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.1"}], ",", 
         RowBox[{"-", "0.178833"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.11"}], ",", 
         RowBox[{"-", "0.187534"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.12"}], ",", 
         RowBox[{"-", "0.195962"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.13"}], ",", 
         RowBox[{"-", "0.203961"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.14"}], ",", 
         RowBox[{"-", "0.21167"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15"}], ",", 
         RowBox[{"-", "0.219119"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.16"}], ",", 
         RowBox[{"-", "0.226232"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.17"}], ",", 
         RowBox[{"-", "0.233233"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.18"}], ",", 
         RowBox[{"-", "0.24004"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.19"}], ",", 
         RowBox[{"-", "0.246568"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2"}], ",", 
         RowBox[{"-", "0.253032"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.21"}], ",", 
         RowBox[{"-", "0.259244"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.22"}], ",", 
         RowBox[{"-", "0.265414"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.23"}], ",", 
         RowBox[{"-", "0.271352"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.24"}], ",", 
         RowBox[{"-", "0.277167"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.25"}], ",", 
         RowBox[{"-", "0.282966"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.26"}], ",", 
         RowBox[{"-", "0.288555"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.27"}], ",", 
         RowBox[{"-", "0.294043"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.28"}], ",", 
         RowBox[{"-", "0.299433"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.29"}], ",", 
         RowBox[{"-", "0.304831"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.3"}], ",", 
         RowBox[{"-", "0.310042"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.31"}], ",", 
         RowBox[{"-", "0.315171"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.32"}], ",", 
         RowBox[{"-", "0.32022"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.33"}], ",", 
         RowBox[{"-", "0.325194"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.34"}], ",", 
         RowBox[{"-", "0.330097"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.35"}], ",", 
         RowBox[{"-", "0.334931"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.36"}], ",", 
         RowBox[{"-", "0.339699"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.37"}], ",", 
         RowBox[{"-", "0.344404"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.38"}], ",", 
         RowBox[{"-", "0.349048"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.39"}], ",", 
         RowBox[{"-", "0.353635"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.4"}], ",", 
         RowBox[{"-", "0.358165"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.41"}], ",", 
         RowBox[{"-", "0.362642"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.42"}], ",", 
         RowBox[{"-", "0.367067"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.43"}], ",", 
         RowBox[{"-", "0.371442"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.44"}], ",", 
         RowBox[{"-", "0.375768"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.45"}], ",", 
         RowBox[{"-", "0.379948"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.46"}], ",", 
         RowBox[{"-", "0.384183"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.47"}], ",", 
         RowBox[{"-", "0.388375"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.48"}], ",", 
         RowBox[{"-", "0.392524"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.49"}], ",", 
         RowBox[{"-", "0.396632"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.5"}], ",", 
         RowBox[{"-", "0.4006"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.51"}], ",", 
         RowBox[{"-", "0.40463"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.52"}], ",", 
         RowBox[{"-", "0.408623"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.53"}], ",", 
         RowBox[{"-", "0.412579"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.54"}], ",", 
         RowBox[{"-", "0.4165"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.55"}], ",", 
         RowBox[{"-", "0.420287"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.56"}], ",", 
         RowBox[{"-", "0.42414"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.57"}], ",", 
         RowBox[{"-", "0.427961"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.58"}], ",", 
         RowBox[{"-", "0.43165"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.59"}], ",", 
         RowBox[{"-", "0.435409"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.6"}], ",", 
         RowBox[{"-", "0.439137"}]}], "}"}]}], "}"}]}], ";"}],
   FontSize->10], 
  StyleBox[
   RowBox[{"(*", 
    RowBox[{
    "List", " ", "of", " ", "parameters", " ", "corresponding", " ", "to", 
     " ", "the", " ", "upper", " ", "limit", " ", "of", " ", "metastalble", 
     " ", "solutions", " ", "for", " ", "Backreaction", " ", "parameter", " ",
      "equal", " ", "to", " ", "0.5"}], "*)"}],
   FontSize->12]}], "\[IndentingNewLine]", 
 RowBox[{
  StyleBox[
   RowBox[{
    RowBox[{"lista1", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.02"}], ",", 
         RowBox[{"-", "0.07998"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03"}], ",", 
         RowBox[{"-", "0.0978809"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.04"}], ",", 
         RowBox[{"-", "0.112966"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.05"}], ",", 
         RowBox[{"-", "0.126416"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.06"}], ",", 
         RowBox[{"-", "0.138333"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.07"}], ",", 
         RowBox[{"-", "0.149416"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.08"}], ",", 
         RowBox[{"-", "0.15976"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.09"}], ",", 
         RowBox[{"-", "0.169399"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.1"}], ",", 
         RowBox[{"-", "0.178533"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.11"}], ",", 
         RowBox[{"-", "0.187234"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.12"}], ",", 
         RowBox[{"-", "0.195562"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.13"}], ",", 
         RowBox[{"-", "0.203561"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.14"}], ",", 
         RowBox[{"-", "0.21127"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15"}], ",", 
         RowBox[{"-", "0.218619"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.16"}], ",", 
         RowBox[{"-", "0.225832"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.17"}], ",", 
         RowBox[{"-", "0.232733"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.18"}], ",", 
         RowBox[{"-", "0.23954"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.19"}], ",", 
         RowBox[{"-", "0.246068"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2"}], ",", 
         RowBox[{"-", "0.252432"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.21"}], ",", 
         RowBox[{"-", "0.258644"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.22"}], ",", 
         RowBox[{"-", "0.264714"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.23"}], ",", 
         RowBox[{"-", "0.270752"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.24"}], ",", 
         RowBox[{"-", "0.276567"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.25"}], ",", 
         RowBox[{"-", "0.282266"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.26"}], ",", 
         RowBox[{"-", "0.287855"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.27"}], ",", 
         RowBox[{"-", "0.293243"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.28"}], ",", 
         RowBox[{"-", "0.298633"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.29"}], ",", 
         RowBox[{"-", "0.303931"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.3"}], ",", 
         RowBox[{"-", "0.309142"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.31"}], ",", 
         RowBox[{"-", "0.314271"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.32"}], ",", 
         RowBox[{"-", "0.31932"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.33"}], ",", 
         RowBox[{"-", "0.324294"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.34"}], ",", 
         RowBox[{"-", "0.329097"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.35"}], ",", 
         RowBox[{"-", "0.333931"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.36"}], ",", 
         RowBox[{"-", "0.338699"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.37"}], ",", 
         RowBox[{"-", "0.343304"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.38"}], ",", 
         RowBox[{"-", "0.347948"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.39"}], ",", 
         RowBox[{"-", "0.352535"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.4"}], ",", 
         RowBox[{"-", "0.356965"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.41"}], ",", 
         RowBox[{"-", "0.361442"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.42"}], ",", 
         RowBox[{"-", "0.365867"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.43"}], ",", 
         RowBox[{"-", "0.370142"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.44"}], ",", 
         RowBox[{"-", "0.374468"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.45"}], ",", 
         RowBox[{"-", "0.378648"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.46"}], ",", 
         RowBox[{"-", "0.382883"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.47"}], ",", 
         RowBox[{"-", "0.386975"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.48"}], ",", 
         RowBox[{"-", "0.391124"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.49"}], ",", 
         RowBox[{"-", "0.395132"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.5"}], ",", 
         RowBox[{"-", "0.3992"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.51"}], ",", 
         RowBox[{"-", "0.40313"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.52"}], ",", 
         RowBox[{"-", "0.407123"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.53"}], ",", 
         RowBox[{"-", "0.410979"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.54"}], ",", 
         RowBox[{"-", "0.4149"}]}], "}"}]}], "}"}]}], ";"}],
   FontSize->10], 
  StyleBox[
   RowBox[{"(*", 
    RowBox[{
    "List", " ", "of", " ", "parameters", " ", "corresponding", " ", "to", 
     " ", "the", " ", "upper", " ", "limit", " ", "of", " ", "metastalble", 
     " ", "solutions", " ", "for", " ", "Backreaction", " ", "parameter", " ",
      "equal", " ", "to", " ", "1"}], "*)"}],
   FontSize->12]}], "\[IndentingNewLine]", 
 RowBox[{
  StyleBox[
   RowBox[{
    RowBox[{"lista0", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.02"}], ",", 
         RowBox[{"-", "0.08008"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03"}], ",", 
         RowBox[{"-", "0.0980809"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.04"}], ",", 
         RowBox[{"-", "0.113266"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.05"}], ",", 
         RowBox[{"-", "0.126616"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.06"}], ",", 
         RowBox[{"-", "0.138733"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.07"}], ",", 
         RowBox[{"-", "0.149816"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.08"}], ",", 
         RowBox[{"-", "0.16016"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.09"}], ",", 
         RowBox[{"-", "0.169899"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.1"}], ",", 
         RowBox[{"-", "0.179133"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.11"}], ",", 
         RowBox[{"-", "0.187934"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.12"}], ",", 
         RowBox[{"-", "0.196262"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.13"}], ",", 
         RowBox[{"-", "0.204261"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.14"}], ",", 
         RowBox[{"-", "0.21207"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15"}], ",", 
         RowBox[{"-", "0.219519"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.16"}], ",", 
         RowBox[{"-", "0.226732"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.17"}], ",", 
         RowBox[{"-", "0.233733"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.18"}], ",", 
         RowBox[{"-", "0.24054"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.19"}], ",", 
         RowBox[{"-", "0.247168"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2"}], ",", 
         RowBox[{"-", "0.253532"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.21"}], ",", 
         RowBox[{"-", "0.259844"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.22"}], ",", 
         RowBox[{"-", "0.266014"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.23"}], ",", 
         RowBox[{"-", "0.272052"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.24"}], ",", 
         RowBox[{"-", "0.277867"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.25"}], ",", 
         RowBox[{"-", "0.283666"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.26"}], ",", 
         RowBox[{"-", "0.289255"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.27"}], ",", 
         RowBox[{"-", "0.294843"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.28"}], ",", 
         RowBox[{"-", "0.300233"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.29"}], ",", 
         RowBox[{"-", "0.305631"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.3"}], ",", 
         RowBox[{"-", "0.310842"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.31"}], ",", 
         RowBox[{"-", "0.316071"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.32"}], ",", 
         RowBox[{"-", "0.32112"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.33"}], ",", 
         RowBox[{"-", "0.326094"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.34"}], ",", 
         RowBox[{"-", "0.331097"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.35"}], ",", 
         RowBox[{"-", "0.335931"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.36"}], ",", 
         RowBox[{"-", "0.340699"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.37"}], ",", 
         RowBox[{"-", "0.345504"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.38"}], ",", 
         RowBox[{"-", "0.350148"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.39"}], ",", 
         RowBox[{"-", "0.354735"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.4"}], ",", 
         RowBox[{"-", "0.359265"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.41"}], ",", 
         RowBox[{"-", "0.363842"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.42"}], ",", 
         RowBox[{"-", "0.368267"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.43"}], ",", 
         RowBox[{"-", "0.372642"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.44"}], ",", 
         RowBox[{"-", "0.376968"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.45"}], ",", 
         RowBox[{"-", "0.381248"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.46"}], ",", 
         RowBox[{"-", "0.385483"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.47"}], ",", 
         RowBox[{"-", "0.389675"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.48"}], ",", 
         RowBox[{"-", "0.393924"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.49"}], ",", 
         RowBox[{"-", "0.398032"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.5"}], ",", 
         RowBox[{"-", "0.4021"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.51"}], ",", 
         RowBox[{"-", "0.40613"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.52"}], ",", 
         RowBox[{"-", "0.410123"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.53"}], ",", 
         RowBox[{"-", "0.414079"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.54"}], ",", 
         RowBox[{"-", "0.418"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.55"}], ",", 
         RowBox[{"-", "0.421887"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.56"}], ",", 
         RowBox[{"-", "0.42574"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.57"}], ",", 
         RowBox[{"-", "0.429561"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.58"}], ",", 
         RowBox[{"-", "0.43335"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.59"}], ",", 
         RowBox[{"-", "0.437109"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.6"}], ",", 
         RowBox[{"-", "0.440837"}]}], "}"}]}], "}"}]}], ";"}],
   FontSize->9], 
  StyleBox[
   RowBox[{"(*", 
    RowBox[{
    "List", " ", "of", " ", "parameters", " ", "corresponding", " ", "to", 
     " ", "the", " ", "upper", " ", "limit", " ", "of", " ", "metastalble", 
     " ", "solutions", " ", "for", " ", "zero", " ", "Backreaction"}], "*)"}],
   FontSize->12]}]}], "Input",
 CellChangeTimes->{{3.75208589959956*^9, 3.7520859019036565`*^9}, {
   3.752086481182496*^9, 3.7520865062466326`*^9}, {3.752086592042345*^9, 
   3.752086593676483*^9}, {3.7520866925654087`*^9, 3.7520866945678473`*^9}, 
   3.7520867595176725`*^9, {3.7520869741941547`*^9, 3.7520869856870017`*^9}, {
   3.7520881313022013`*^9, 3.752088185918377*^9}, {3.7520882361085668`*^9, 
   3.7520882443590465`*^9}, {3.752091380807761*^9, 3.7520916008097315`*^9}, 
   3.7520991133093843`*^9, 3.752099198624321*^9, {3.752099256203718*^9, 
   3.752099409637435*^9}, {3.752099444006674*^9, 3.752099500461929*^9}, {
   3.7520995315169106`*^9, 3.7520995458992834`*^9}, {3.75209959967735*^9, 
   3.7520996082773714`*^9}, {3.752099640215619*^9, 3.7520996558878794`*^9}, {
   3.7520996899679203`*^9, 3.752099690030707*^9}, {3.752099869939332*^9, 
   3.7520999718913946`*^9}, {3.7521000218643026`*^9, 3.7521000284647*^9}, {
   3.7521000893534365`*^9, 3.7521000999345703`*^9}, {3.752100160639863*^9, 
   3.7521002088108826`*^9}, {3.752100274786871*^9, 3.7521002817401466`*^9}, {
   3.7521003142488623`*^9, 3.7521003233251753`*^9}, {3.752100366542133*^9, 
   3.7521003690340877`*^9}, {3.752100604771637*^9, 3.752100619688848*^9}, {
   3.752100666298362*^9, 3.752100705144148*^9}, {3.7521007588949633`*^9, 
   3.75210094429085*^9}, {3.7521010751815567`*^9, 3.7521010965851607`*^9}, {
   3.752101473467805*^9, 3.7521015170786996`*^9}, {3.7521015903255177`*^9, 
   3.752101708765486*^9}, {3.7521017621445894`*^9, 3.7521018098262415`*^9}, {
   3.752101923945779*^9, 3.752102010174405*^9}, {3.7521020478504133`*^9, 
   3.7521021125865307`*^9}, {3.752102194133829*^9, 3.752102196319542*^9}, {
   3.752102230044306*^9, 3.752102300076659*^9}, {3.752102414454301*^9, 
   3.7521024552990775`*^9}, {3.752102583203092*^9, 3.7521026511584496`*^9}, {
   3.752102780867454*^9, 3.752102838081809*^9}, {3.752102879472971*^9, 
   3.7521028876025596`*^9}, {3.7521029248789344`*^9, 3.752102926680682*^9}, 
   3.752102961349124*^9, {3.75210302690586*^9, 3.7521030275912566`*^9}, {
   3.752103163960002*^9, 3.7521032191318684`*^9}, {3.7521032535096564`*^9, 
   3.7521033090845237`*^9}, {3.7521033544603796`*^9, 3.752103429129639*^9}, {
   3.7521037464622235`*^9, 3.7521037835594263`*^9}, {3.752103835047926*^9, 
   3.7521038706422777`*^9}, {3.7523454387986903`*^9, 
   3.7523455060339136`*^9}, {3.7523460314562654`*^9, 3.752346051472335*^9}, {
   3.7523528520863457`*^9, 3.75235288129289*^9}, 3.752352915494753*^9, {
   3.7523529555833645`*^9, 3.7523530252977448`*^9}, {3.7523532354346533`*^9, 
   3.7523532668172874`*^9}, {3.7523533417687273`*^9, 
   3.7523534550488267`*^9}, {3.7523535863504143`*^9, 
   3.7523536256371965`*^9}, {3.7523537420493584`*^9, 
   3.7523537736644673`*^9}, {3.7523538817776413`*^9, 3.752353917765624*^9}, {
   3.7523539612643733`*^9, 3.752354009189381*^9}, {3.752354039816905*^9, 
   3.7523540606400757`*^9}, {3.75235412661557*^9, 3.752354145030898*^9}, {
   3.7523542123238583`*^9, 3.7523542221965284`*^9}, {3.752354517333931*^9, 
   3.7523545192554398`*^9}, {3.752354733799906*^9, 3.7523547354557676`*^9}, {
   3.7523547671179304`*^9, 3.7523547787244697`*^9}, {3.752354881081523*^9, 
   3.75235493224817*^9}, {3.752355036651207*^9, 3.7523551036347966`*^9}, {
   3.752355204396655*^9, 3.7523552143008633`*^9}, {3.7523553162799845`*^9, 
   3.7523554024203453`*^9}, {3.7523556404983354`*^9, 3.75235565879823*^9}, {
   3.7523557429320793`*^9, 3.752355774290135*^9}, {3.7523558101275935`*^9, 
   3.7523558904235764`*^9}, {3.752355940830698*^9, 3.7523559712978573`*^9}, {
   3.752356055593285*^9, 3.7523560715020633`*^9}, {3.7523561331814966`*^9, 
   3.75235617937757*^9}, {3.75235632651105*^9, 3.7523563935070767`*^9}, {
   3.7523564240067625`*^9, 3.7523564607312937`*^9}, {3.7523566970623603`*^9, 
   3.752356777941436*^9}, {3.7523568983785057`*^9, 3.752356962480715*^9}, {
   3.7523570098195453`*^9, 3.7523570385429897`*^9}, {3.7523575193887067`*^9, 
   3.752357807536792*^9}, {3.7523579683305044`*^9, 3.7523580057261677`*^9}, {
   3.752358045834137*^9, 3.7523580562515755`*^9}, {3.7523581238953886`*^9, 
   3.7523581257459984`*^9}, {3.7523585823532305`*^9, 3.752358634296155*^9}, {
   3.752359191161358*^9, 3.752359268631358*^9}, {3.7523593300136905`*^9, 
   3.75235943149063*^9}, 3.752359518487529*^9, {3.7523602331620007`*^9, 
   3.752360252454573*^9}, {3.752360287793211*^9, 3.7523603313328257`*^9}, {
   3.752360373779833*^9, 3.7523603740544496`*^9}, {3.7523604749419193`*^9, 
   3.7523605208840218`*^9}, {3.752361019897502*^9, 3.7523610596853795`*^9}, {
   3.75236110984317*^9, 3.752361165970044*^9}, {3.7523612376838923`*^9, 
   3.7523612447575808`*^9}, {3.752361338375884*^9, 3.7523613726807795`*^9}, {
   3.7523618214910593`*^9, 3.7523618249479265`*^9}, {3.7523618629621086`*^9, 
   3.752361863655758*^9}, {3.7523619319887705`*^9, 3.7523620660350356`*^9}, {
   3.7523621158915668`*^9, 3.7523621536245203`*^9}, {3.7523623583830805`*^9, 
   3.7523624211567054`*^9}, {3.752362463734298*^9, 3.7523624961174912`*^9}, {
   3.7523628546298327`*^9, 3.7523629916716557`*^9}, {3.752363053991394*^9, 
   3.752363056234857*^9}, {3.752363131956924*^9, 3.7523631404053235`*^9}, {
   3.752363270566121*^9, 3.752363282011137*^9}, {3.7523633188928013`*^9, 
   3.752363358139471*^9}, 3.7523635060036592`*^9, {3.752364634803946*^9, 
   3.7523646604915032`*^9}, {3.752364692958366*^9, 3.7523647343492875`*^9}, 
   3.752364774187847*^9, {3.752364809587865*^9, 3.752364869423341*^9}, {
   3.752365252234191*^9, 3.752365263492938*^9}, {3.7523653518878803`*^9, 
   3.7523653593268185`*^9}, {3.7524145914404345`*^9, 
   3.7524145964084387`*^9}, {3.7524290647116327`*^9, 
   3.7524291230342574`*^9}, {3.752429212642844*^9, 3.75242921500246*^9}, {
   3.752429255110145*^9, 3.7524292845188093`*^9}, {3.7524293176699963`*^9, 
   3.752429367480211*^9}, {3.752429404155453*^9, 3.752429453482559*^9}, {
   3.7524295234765453`*^9, 3.7524295475527754`*^9}, {3.7524295942037835`*^9, 
   3.752429642908874*^9}, 3.75242968479486*^9, {3.7524298279533277`*^9, 
   3.7524298286768208`*^9}, {3.7524298714837604`*^9, 3.752429872499134*^9}, {
   3.7524299249953427`*^9, 3.7524299378897457`*^9}, 3.752430499922566*^9, {
   3.75269846547786*^9, 3.7526984672815266`*^9}, 3.7529582206185446`*^9, 
   3.753365968445602*^9, {3.753653200151884*^9, 3.7536532008078413`*^9}, 
   3.754163008179987*^9, {3.754163201687709*^9, 3.754163213497727*^9}, 
   3.754164582454904*^9, {3.7543401779473143`*^9, 3.7543401912650113`*^9}, 
   3.754766526832803*^9, {3.7547666869508567`*^9, 3.754766702838605*^9}, {
   3.7563863302218513`*^9, 3.7563863425758867`*^9}, {3.756389224848353*^9, 
   3.756389234867218*^9}, 3.756898753750597*^9, 3.7568988548138227`*^9, {
   3.756898930312624*^9, 3.7568989316574736`*^9}, {3.7568989799222403`*^9, 
   3.7568989918758945`*^9}, {3.7568991545043097`*^9, 3.756899202175948*^9}, {
   3.7568992490018787`*^9, 3.756899428047962*^9}, {3.7568994654225655`*^9, 
   3.756899476486122*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"p", "[", "1", "]"}], "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"ListLinePlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sort", "[", "alistrangemin", "]"}], ",", 
         RowBox[{"Sort", "[", "lista0", "]"}], ",", 
         RowBox[{"Sort", "[", "listbrangemax", "]"}]}], "}"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Dashed", ",", "Black", ",", 
            RowBox[{"Thickness", "[", "0.005", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Green", ",", 
            RowBox[{"Thickness", "[", "0.005", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Dashed", ",", "Red", ",", 
            RowBox[{"Thickness", "[", "0.005", "]"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", ".45"}], ",", 
            RowBox[{"-", ".44"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", ".39"}], ",", 
            RowBox[{"-", ".36"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
       RowBox[{"Filling", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", "3", "}"}], ",", "Yellow"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"Axis", ",", "LightRed"}], "}"}]}], ",", 
            RowBox[{"3", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"Bottom", ",", "LightBlue"}], "}"}]}]}], "}"}]}], 
         "}"}]}]}], "]"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Inset", "[", 
        RowBox[{
        "\"\<m=0\\n\!\(\*OverscriptBox[\(\[Kappa]\), \(_\)]\)= 0\>\"", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", ".441"}], ",", 
           RowBox[{"-", ".3650"}]}], "}"}]}], "]"}], "}"}], "]"}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Large", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Italic"}], 
       "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "14"}]}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"p", "[", "2", "]"}], "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"ListLinePlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sort", "[", "alistrangemin", "]"}], ",", 
         RowBox[{"Sort", "[", "lista05", "]"}], ",", 
         RowBox[{"Sort", "[", "listbrangemin", "]"}], ",", 
         RowBox[{"Sort", "[", "listbrangemax", "]"}]}], "}"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Dashed", ",", "Black", ",", 
            RowBox[{"Thickness", "[", "0.005", "]"}]}], "}"}], ",", 
          RowBox[{"Thickness", "[", "0.005", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Green", ",", 
            RowBox[{"Thickness", "[", "0.005", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Dashed", ",", "Red", ",", 
            RowBox[{"Thickness", "[", "0.005", "]"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", ".45"}], ",", 
            RowBox[{"-", ".44"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", ".39"}], ",", 
            RowBox[{"-", ".36"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
       RowBox[{"Filling", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", "3", "}"}], ",", "Yellow"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"Axis", ",", "LightRed"}], "}"}]}], ",", 
            RowBox[{"3", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"Bottom", ",", "LightBlue"}], "}"}]}]}], "}"}]}], 
         "}"}]}]}], "]"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Inset", "[", 
        RowBox[{
        "\"\<m=0\\n\!\(\*OverscriptBox[\(\[Kappa]\), \(_\)]\)= 0.5\>\"", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", ".441"}], ",", 
           RowBox[{"-", ".3650"}]}], "}"}]}], "]"}], "}"}], "]"}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Large", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Italic"}], 
       "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "14"}]}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"p", "[", "3", "]"}], "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"ListLinePlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sort", "[", "alistrangemin", "]"}], ",", 
         RowBox[{"Sort", "[", "lista1", "]"}], ",", 
         RowBox[{"Sort", "[", "listbrangemin", "]"}], ",", 
         RowBox[{"Sort", "[", "listbrangemax", "]"}]}], "}"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Dashed", ",", "Black", ",", 
            RowBox[{"Thickness", "[", "0.005", "]"}]}], "}"}], ",", 
          RowBox[{"Thickness", "[", "0.005", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Green", ",", 
            RowBox[{"Thickness", "[", "0.005", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Dashed", ",", "Red", ",", 
            RowBox[{"Thickness", "[", "0.005", "]"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", ".45"}], ",", 
            RowBox[{"-", ".44"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", ".39"}], ",", 
            RowBox[{"-", ".36"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
       RowBox[{"Filling", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", "3", "}"}], ",", "Yellow"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"Axis", ",", "LightRed"}], "}"}]}], ",", 
            RowBox[{"3", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"Bottom", ",", "LightBlue"}], "}"}]}]}], "}"}]}], 
         "}"}]}]}], "]"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Inset", "[", 
        RowBox[{
        "\"\<m=0\\n\!\(\*OverscriptBox[\(\[Kappa]\), \(_\)]\)= 1\>\"", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", ".441"}], ",", 
           RowBox[{"-", ".3650"}]}], "}"}]}], "]"}], "}"}], "]"}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Large", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Italic"}], 
       "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "14"}]}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"grid", "=", 
   RowBox[{"Panel", "[", 
    RowBox[{
     RowBox[{"GraphicsGrid", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], ",", 
          RowBox[{"p", "[", "2", "]"}], ",", 
          RowBox[{"p", "[", "3", "]"}]}], "}"}], "}"}], ",", 
       RowBox[{"Spacings", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "Full"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<\[CapitalLambda]\>\"", ",", 
       RowBox[{"Rotate", "[", 
        RowBox[{"\"\<b\>\"", ",", 
         RowBox[{"Pi", "/", "2"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Bottom", ",", "Left"}], "}"}], ",", 
     RowBox[{"Background", "\[Rule]", "White"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"grid1", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"p", "[", "i", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "3"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{"k1", "=", 
  RowBox[{"Panel", "[", 
   RowBox[{
    RowBox[{"plotGrid", "[", 
     RowBox[{"grid1", ",", "1363", ",", "363"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<\!\(\*
StyleBox[\"\[CapitalLambda]\",
FontFamily->\"Times New Roman\",
FontSize->24,
FontWeight->\"Plain\"]\)\>\"", ",", 
      RowBox[{"Rotate", "[", 
       RowBox[{"\"\<\!\(\*
StyleBox[\"b\",
FontFamily->\"Times New Roman\",
FontSize->24,
FontWeight->\"Plain\"]\)\>\"", ",", 
        RowBox[{"Pi", "/", "2"}]}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"Bottom", ",", "Left"}], "}"}], ",", 
    RowBox[{"Background", "\[Rule]", "White"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{"\"\<fig4.pdf\>\"", ",", "k1", ",", 
   RowBox[{"ImageResolution", "\[Rule]", "1000"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"Scaled", "[", "4", "]"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7536538176490245`*^9, 3.7536538506257844`*^9}, {
   3.7536539081435213`*^9, 3.753653974831171*^9}, {3.7536540907515993`*^9, 
   3.753654106294742*^9}, {3.75365419025947*^9, 3.753654191821603*^9}, {
   3.753654255728459*^9, 3.7536542620551076`*^9}, {3.753654402193952*^9, 
   3.7536544100046043`*^9}, {3.753654474344164*^9, 3.753654508001071*^9}, 
   3.7536545508248386`*^9, {3.7536545970241575`*^9, 3.7536546883233604`*^9}, {
   3.7536548087302732`*^9, 3.753654809833188*^9}, {3.7536548559630013`*^9, 
   3.7536548836843576`*^9}, {3.7536549787254143`*^9, 
   3.7536549983615184`*^9}, {3.7540073788311815`*^9, 3.754007441352668*^9}, {
   3.7540074881128826`*^9, 3.754007532137848*^9}, {3.7541785480503473`*^9, 
   3.7541785611188297`*^9}, {3.754178654144493*^9, 3.7541787862470617`*^9}, {
   3.754762693280895*^9, 3.754762709646721*^9}, {3.754762814645157*^9, 
   3.754762821429123*^9}, {3.7547647046855445`*^9, 3.754764712412219*^9}, 
   3.7547647775007973`*^9, 3.754764819680087*^9, {3.754764861882491*^9, 
   3.7547649054651427`*^9}, {3.754765024590821*^9, 3.754765065353256*^9}, {
   3.7547651327140613`*^9, 3.754765232995646*^9}, {3.754765274018084*^9, 
   3.7547653158800397`*^9}, {3.7547653820440054`*^9, 3.75476543981363*^9}, {
   3.754765611492484*^9, 3.7547656516111236`*^9}, {3.754765682682743*^9, 
   3.754765704533641*^9}, {3.754765737253068*^9, 3.7547657762753572`*^9}, {
   3.7547658398640933`*^9, 3.754765908892927*^9}, {3.754765950392736*^9, 
   3.7547659904814043`*^9}, {3.75476603300047*^9, 3.7547660577574005`*^9}, {
   3.754766089718772*^9, 3.754766101736182*^9}, {3.754766145545825*^9, 
   3.7547661690649147`*^9}, {3.754766260045656*^9, 3.75476627668668*^9}, {
   3.7547669274746017`*^9, 3.7547669405218887`*^9}, {3.754766978002569*^9, 
   3.754766980220413*^9}, {3.7547670318185987`*^9, 3.7547670340741143`*^9}, {
   3.7547685392374506`*^9, 3.754768551274889*^9}, {3.754953117428275*^9, 
   3.7549531272285576`*^9}, 3.755030140489441*^9, {3.7551196080029078`*^9, 
   3.7551196154170933`*^9}, {3.7551196596274834`*^9, 3.755119660106476*^9}, {
   3.755119693380048*^9, 3.7551197106885324`*^9}, {3.755119785413538*^9, 
   3.75511984145114*^9}, {3.7551199269820786`*^9, 3.7551199762826796`*^9}, {
   3.755120083558215*^9, 3.755120094158459*^9}, {3.755120255037077*^9, 
   3.7551202845934935`*^9}, {3.75512032978981*^9, 3.7551204543169312`*^9}, {
   3.755120518319457*^9, 3.7551205738819246`*^9}, {3.756386476950342*^9, 
   3.7563864779032145`*^9}, {3.7563912369946976`*^9, 
   3.7563912382378764`*^9}, {3.756403596612093*^9, 3.756403627698996*^9}, {
   3.7564037188801713`*^9, 3.7564037324739213`*^9}, {3.756403825625576*^9, 
   3.756403834937793*^9}, {3.756403876268505*^9, 3.756403877172021*^9}, {
   3.7567310645741835`*^9, 3.756731072848161*^9}, 3.7567457169290257`*^9, {
   3.7567458242582664`*^9, 3.756745824759415*^9}, {3.75674601545231*^9, 
   3.7567460568299193`*^9}, {3.7567461925353575`*^9, 
   3.7567462723898273`*^9}, {3.75674632034587*^9, 3.756746324547168*^9}, 
   3.756898806679554*^9, {3.756909668640376*^9, 3.7569096696602125`*^9}}],

Cell[BoxData[
 TemplateBox[{PanelBox[
    GraphicsBox[{{
       InsetBox[
        GraphicsBox[{{{}, 
           GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGBQA2IQbQwGj/d/04jpP/T1xv5qkXXuD6umwPnLekMXuO+8
uX/Dw5dTN/Fc3w9TD+PD1MP4QTvkWl8HPtgfEm53+vODG/sZwODB/gf7+OYY
L7qxH2SqRsz9/avXr+O6knRjP1j5jnv7YyIXbT6jdGM/2DiRe/sPX9ZOlXx0
fX+hLdf1xQV397f7nd+9ccH1/WfPgMCd/ctP9myfGnd9vybYwDv7T5a8+LJH
GuEekC6g1v3o/oOZb5Hukpn/4Qbc/JK6rscHVt+Am8897RVTXNoNuPlL775I
tlO4sR/kWrnW2/sFc49fib15fT/QMKCJt/af6vY5sH7i9f1g42xv7V8QuOuL
vidh98Dseznjc0/tSYR9mg4iZ2Y0Iexr65MNeWR1A27fldmBn0M/IezbPt3E
7fWK6/tnzQSBm/Dwgdmz1DDKPVQY0z1Z3pOiI3MfwNVV/VP52vPvNly+d4MZ
N7PiPbh8wc1V3C8334TL735hf9ra5C5cfv7Optlmj27A5QGL0mDL
            "], {{{}, {}, {
               EdgeForm[], 
               RGBColor[1, 0.85, 0.85], 
               GraphicsGroupBox[{
                 PolygonBox[{{3, 4, 15, 35, 16, 17, 18, 19, 20, 21, 22}}]}]}, {
               EdgeForm[], 
               RGBColor[1, 0.85, 0.85], 
               GraphicsGroupBox[{
                 PolygonBox[{{3, 5, 23, 36}}]}]}, {}, {
               EdgeForm[], 
               RGBColor[0.87, 0.94, 1], 
               GraphicsGroupBox[{
                 
                 PolygonBox[{{37, 2, 32, 38, 31, 30, 29, 28, 27, 26, 
                  25}}]}]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {
               EdgeForm[], 
               RGBColor[1, 1, 0], 
               GraphicsGroupBox[{
                 
                 PolygonBox[{{24, 37, 25, 26, 27, 28, 29, 30, 31, 38, 32, 23, 
                  36, 3, 22, 21, 20, 19, 18, 17, 16, 35, 
                  15}}]}]}, {}, {}}, {{}, {}, {}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.01388888888888889], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                Dashing[{Small, Small}], 
                GrayLevel[0], 
                Thickness[0.005]], 
               LineBox[{33, 6, 7, 8, 9, 10, 11, 12, 13, 34}]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.01388888888888889], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 1, 0], 
                Thickness[0.005]], 
               LineBox[{35, 16, 17, 18, 19, 20, 21, 22, 3, 36}]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.01388888888888889], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                Dashing[{Small, Small}], 
                RGBColor[1, 0, 0], 
                Thickness[0.005]], 
               
               LineBox[{37, 25, 26, 27, 28, 29, 30, 31, 
                38}]}}}], {}, {}, {{}, {}}}, {
           TagBox[
            InsetBox[
            "m=0\n\!\(\*OverscriptBox[\(\[Kappa]\), \(_\)]\)= 0", {-0.441, \
-0.365}], "InsetString"]}}, {
         ImagePadding -> {{40, 0}, {40, 40}}, AspectRatio -> Full, 
          BaseStyle -> {Large, FontFamily -> "Times", Italic}, LabelStyle -> 
          Directive[
            GrayLevel[0], FontFamily -> "Times", FontSize -> 14], 
          DisplayFunction -> Identity, PlotRangePadding -> {{0, 0}, {0, 0}}, 
          AxesOrigin -> {-0.44005, -0.36014999999999997`}, 
          PlotRange -> {{-0.45, -0.44}, {-0.39, -0.36}}, PlotRangeClipping -> 
          True, ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
          NCache[GoldenRatio^(-1), 0.6180339887498948], 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {-0.44005, -0.36014999999999997`}, DisplayFunction :> 
          Identity, Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> Automatic,
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLines -> {{0}, {0}}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], LabelStyle -> {FontFamily -> "Times"}, 
          Method -> {"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
                 Part[#, 1]], 
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
                 Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
                 Part[#, 1]], 
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
                 Part[#, 2]]}& )}}, 
          PlotRange -> {{-0.45, -0.44}, {-0.39, -0.36}}, PlotRangeClipping -> 
          True, PlotRangePadding -> {{0, 0}, {0, 0}}, 
          Ticks -> {Automatic, Automatic}}], {0, 0}, {Left, Bottom}, 
        NCache[{
          Rational[1403, 3], 363}, {467.6666666666667, 363}]]}, {
       InsetBox[
        GraphicsBox[{{{}, 
           GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGAwBGIQbQwGj/d/04jpP/T1xv5qkXXuD6umwPmcXJsM7B7d
3L/h4cupm3iu74eph/Fh6mH8oB1yra8DH+wPCbc7/fnBjf0MYPBg/4N9fHOM
F93YDzJVI+b+/tXr13FdSbqxH6x8x739MZGLNp9RurEfbJzIvf2HL2unSj66
vr/Qluv64oK7+9v9zu/euOD6/rNnQODO/uUne7ZPjbu+XxNs4J39J0tefNkj
jXAPSBdQ6350/8HMd0p4ekHp9g24+bXl2t4l027AzRft784SDLwBN7+oY4fl
VJ4b+0GulWu9vf+++PRVW45e3w80DGjirf3TzWSmsdVd3w82zvbW/rw/nafa
TIl3j0W6S2b+B4R7Suq6Hh9YjXAP97RXTHFpCPcsvfsi2U4B4R7B3ONXYm8i
3HOq2+fA+okI9ywI3PVF35Owe2D2vZzxuaf2JMI+TQeRMzOaEPa19cmGPLK6
AbfvyuzAz6GfEPZtn27i9nrF9f2zZoLATXh8wexZahjlHiqM6Z4s70nRkbkP
4Oqq/ql87fl3Gy5v558SuCzkHly+dhXLiwN3bsLlezeYcTMrIuQLbq7ifrkZ
Ib/7hf1pa5O7cPn5O5tmmz26AZcHAB6DwbE=
            "], {{{}, {}, {
               EdgeForm[], 
               RGBColor[1, 0.85, 0.85], 
               GraphicsGroupBox[{
                 PolygonBox[{{3, 4, 15, 44, 16, 17, 18, 19, 20, 21, 22}}]}]}, {
               EdgeForm[], 
               RGBColor[1, 0.85, 0.85], 
               GraphicsGroupBox[{
                 PolygonBox[{{3, 5, 23, 45}}]}]}, {}, {
               EdgeForm[], 
               RGBColor[0.87, 0.94, 1], 
               GraphicsGroupBox[{
                 
                 PolygonBox[{{46, 2, 32, 47, 31, 30, 29, 28, 27, 26, 
                  25}}]}]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {
               EdgeForm[], 
               RGBColor[1, 1, 0], 
               GraphicsGroupBox[{
                 
                 PolygonBox[{{24, 46, 25, 26, 27, 28, 29, 30, 31, 47, 32, 23, 
                  45, 3, 22, 21, 20, 19, 18, 17, 16, 44, 
                  15}}]}]}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, {}, {}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.01388888888888889], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                Dashing[{Small, Small}], 
                GrayLevel[0], 
                Thickness[0.005]], 
               LineBox[{42, 6, 7, 8, 9, 10, 11, 12, 13, 43}]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.01388888888888889], 
                RGBColor[0.365248, 0.427802, 0.758297], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                Thickness[0.005]], 
               LineBox[{44, 16, 17, 18, 19, 20, 21, 22, 3, 45}]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.01388888888888889], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 1, 0], 
                Thickness[0.005]], 
               LineBox[{46, 25, 26, 27, 28, 29, 30, 31, 47}]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.01388888888888889], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                Dashing[{Small, Small}], 
                RGBColor[1, 0, 0], 
                Thickness[0.005]], 
               
               LineBox[{48, 34, 35, 36, 37, 38, 39, 40, 
                49}]}}}], {}, {}, {{}, {}}}, {
           TagBox[
            InsetBox[
            "m=0\n\!\(\*OverscriptBox[\(\[Kappa]\), \(_\)]\)= 0.5", {-0.441, \
-0.365}], "InsetString"]}}, {
         ImagePadding -> {{0, 0}, {40, 40}}, AspectRatio -> Full, 
          BaseStyle -> {Large, FontFamily -> "Times", Italic}, LabelStyle -> 
          Directive[
            GrayLevel[0], FontFamily -> "Times", FontSize -> 14], 
          DisplayFunction -> Identity, PlotRangePadding -> {{0, 0}, {0, 0}}, 
          AxesOrigin -> {-0.44005, -0.36014999999999997`}, 
          PlotRange -> {{-0.45, -0.44}, {-0.39, -0.36}}, PlotRangeClipping -> 
          True, ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
          NCache[GoldenRatio^(-1), 0.6180339887498948], 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {-0.44005, -0.36014999999999997`}, DisplayFunction :> 
          Identity, Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> Automatic,
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLines -> {{0}, {0}}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], LabelStyle -> {FontFamily -> "Times"}, 
          Method -> {"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
                 Part[#, 1]], 
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
                 Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
                 Part[#, 1]], 
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
                 Part[#, 2]]}& )}}, 
          PlotRange -> {{-0.45, -0.44}, {-0.39, -0.36}}, PlotRangeClipping -> 
          True, PlotRangePadding -> {{0, 0}, {0, 0}}, 
          Ticks -> {Automatic, Automatic}}], 
        NCache[{
          Rational[1403, 3], 0}, {467.6666666666667, 0}], {Left, Bottom}, 
        NCache[{
          Rational[1283, 3], 363}, {427.6666666666667, 363}]]}, {
       InsetBox[
        GraphicsBox[{{{}, 
           GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQbQwGj/d/04jpP/T1xv5qkXXuD6umwPkFbLJlGny3
9m94+HLqJp7r+z0eVoFUwPkw9ejyMP1BO+RaXwc+2B8Sbnf684Mb+xnA4MH+
B/v45hgvurEfpEoj5v7+1evXcV1JurEfrHzHvf0xkYs2n1G6sR9svMi9/Ycv
a6dKPrq+v9CW6/rigrv72/3O79644Pr+s2dA4M7+5Sd7tk+Nu75fE2zgnf0n
S1582SONcB9IF1Arhvtg5rcvDz9ldOQG3Py2gjOb1BtvwM2X69C5dMT6Btz8
msbIhR7fr+8HuVau9fb+lwIWQhkbru+HGH9rf+rD19mxWdf3g42zvbXfennk
gruKmO5BD3+YeyzSXTLzPyDcU1LX9fjAaoR7uKe9YopLQ7hn6d0XyXYKN+Du
Ecw9fiX2JsI9p7p9DqyfiHDPgsBdX/Q9CbsHZt/LGZ97ak8i7NN0EDkzowlh
X1ufbMgjqxtw+67MDvwc+glh3/bpJm6vV1zfP2smCNyExxfMnqWGUe6hwpju
yfKeFB2Z+wCuruqfyteef7fh8j8eMhm8774Hl3+yLF93NcctuHzvBjNuZkWE
fMHNVdwvN9+Ey+9+YX/a2uQuXH7+zqbZZo9uwOUBw77POg==
            "], {{{}, {}, {
               EdgeForm[], 
               RGBColor[1, 0.85, 0.85], 
               GraphicsGroupBox[{
                 PolygonBox[{{3, 4, 16, 45, 17, 18, 19, 20, 21, 22, 23}}]}]}, {
               EdgeForm[], 
               RGBColor[1, 0.85, 0.85], 
               GraphicsGroupBox[{
                 PolygonBox[{{3, 5, 24, 46}}]}]}, {}, {
               EdgeForm[], 
               RGBColor[0.87, 0.94, 1], 
               GraphicsGroupBox[{
                 
                 PolygonBox[{{47, 2, 33, 48, 32, 31, 30, 29, 28, 27, 
                  26}}]}]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {
               EdgeForm[], 
               RGBColor[1, 1, 0], 
               GraphicsGroupBox[{
                 
                 PolygonBox[{{6, 47, 26, 27, 28, 29, 30, 31, 32, 48, 33, 24, 
                  46, 3, 23, 22, 21, 20, 19, 18, 17, 45, 
                  16}}]}]}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, {}, {}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.01388888888888889], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                Dashing[{Small, Small}], 
                GrayLevel[0], 
                Thickness[0.005]], 
               LineBox[{43, 7, 8, 9, 10, 11, 12, 13, 14, 44}]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.01388888888888889], 
                RGBColor[0.365248, 0.427802, 0.758297], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                Thickness[0.005]], 
               LineBox[{45, 17, 18, 19, 20, 21, 22, 23, 3, 46}]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.01388888888888889], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 1, 0], 
                Thickness[0.005]], 
               LineBox[{47, 26, 27, 28, 29, 30, 31, 32, 48}]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.01388888888888889], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                Dashing[{Small, Small}], 
                RGBColor[1, 0, 0], 
                Thickness[0.005]], 
               
               LineBox[{49, 35, 36, 37, 38, 39, 40, 41, 
                50}]}}}], {}, {}, {{}, {}}}, {
           TagBox[
            InsetBox[
            "m=0\n\!\(\*OverscriptBox[\(\[Kappa]\), \(_\)]\)= 1", {-0.441, \
-0.365}], "InsetString"]}}, {
         ImagePadding -> {{0, 40}, {40, 40}}, AspectRatio -> Full, 
          BaseStyle -> {Large, FontFamily -> "Times", Italic}, LabelStyle -> 
          Directive[
            GrayLevel[0], FontFamily -> "Times", FontSize -> 14], 
          DisplayFunction -> Identity, PlotRangePadding -> {{0, 0}, {0, 0}}, 
          AxesOrigin -> {-0.44005, -0.36014999999999997`}, 
          PlotRange -> {{-0.45, -0.44}, {-0.39, -0.36}}, PlotRangeClipping -> 
          True, ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
          NCache[GoldenRatio^(-1), 0.6180339887498948], 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {-0.44005, -0.36014999999999997`}, DisplayFunction :> 
          Identity, Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> Automatic,
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLines -> {{0}, {0}}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], LabelStyle -> {FontFamily -> "Times"}, 
          Method -> {"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
                 Part[#, 1]], 
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
                 Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
                 Part[#, 1]], 
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
                 Part[#, 2]]}& )}}, 
          PlotRange -> {{-0.45, -0.44}, {-0.39, -0.36}}, PlotRangeClipping -> 
          True, PlotRangePadding -> {{0, 0}, {0, 0}}, 
          Ticks -> {Automatic, Automatic}}], 
        NCache[{
          Rational[2686, 3], 0}, {895.3333333333334, 0}], {Left, Bottom}, 
        NCache[{
          Rational[1403, 3], 363}, {467.6666666666667, 363}]]}}, 
     PlotRange -> {{0, 1363}, {0, 363}}, ImageSize -> {1363, 363}], 
    Background -> GrayLevel[1]],
   "\"\\!\\(\\*\\nStyleBox[\\\"\[CapitalLambda]\\\",\\nFontFamily->\\\"Times \
New Roman\\\",\\nFontSize->24,\\nFontWeight->\\\"Plain\\\"]\\)\"",RotationBox[
   "\"\\!\\(\\*\\nStyleBox[\\\"b\\\",\\nFontFamily->\\\"Times New \
Roman\\\",\\nFontSize->24,\\nFontWeight->\\\"Plain\\\"]\\)\"", BoxRotation -> 
    1.5707963267948966`]},
  "Labeled",
  DisplayFunction->(GridBox[{{
      ItemBox[#3, DefaultBaseStyle -> "PanelLabel"], 
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}, {"", 
      ItemBox[#2, DefaultBaseStyle -> "PanelLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, 
    GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
    BaselinePosition -> {1, 2}]& ),
  InterpretationFunction->(RowBox[{"Labeled", "[", 
     RowBox[{#, ",", 
       RowBox[{"{", 
         RowBox[{#2, ",", #3}], "}"}], ",", 
       RowBox[{"{", 
         RowBox[{"Bottom", ",", "Left"}], "}"}], ",", 
       RowBox[{"DefaultLabelStyle", "\[Rule]", "\"PanelLabel\""}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
         RowBox[{"{", "}"}]}], ",", 
       RowBox[{"RotateLabel", "\[Rule]", "False"}], ",", 
       RowBox[{"Spacings", "\[Rule]", "Automatic"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.75638630800834*^9, 3.7563864113095913`*^9, 3.756386634756816*^9, 
   3.756387033252141*^9, 3.7563871488060513`*^9, {3.756403636594595*^9, 
   3.756403651124302*^9}, {3.7564036844576874`*^9, 3.7564037158535843`*^9}, 
   3.756403849566763*^9, 3.756403885714408*^9, 3.756731090337716*^9, 
   3.756745717593614*^9, 3.7567458253990736`*^9, 3.756745932449931*^9, 
   3.7567459650164256`*^9, {3.7567460363294506`*^9, 3.7567460574466314`*^9}, {
   3.75674619934101*^9, 3.7567462395897975`*^9}, 3.7567462730072165`*^9, 
   3.7567483081554823`*^9, {3.7568987760421257`*^9, 3.7568988179936075`*^9}, {
   3.756898865282226*^9, 3.7568988936679497`*^9}, 3.7568989675344043`*^9, 
   3.756899490979308*^9}],

Cell[BoxData["\<\"D:\\\\Downloads\"\>"], "Output",
 CellChangeTimes->{
  3.75638630800834*^9, 3.7563864113095913`*^9, 3.756386634756816*^9, 
   3.756387033252141*^9, 3.7563871488060513`*^9, {3.756403636594595*^9, 
   3.756403651124302*^9}, {3.7564036844576874`*^9, 3.7564037158535843`*^9}, 
   3.756403849566763*^9, 3.756403885714408*^9, 3.756731090337716*^9, 
   3.756745717593614*^9, 3.7567458253990736`*^9, 3.756745932449931*^9, 
   3.7567459650164256`*^9, {3.7567460363294506`*^9, 3.7567460574466314`*^9}, {
   3.75674619934101*^9, 3.7567462395897975`*^9}, 3.7567462730072165`*^9, 
   3.7567483081554823`*^9, {3.7568987760421257`*^9, 3.7568988179936075`*^9}, {
   3.756898865282226*^9, 3.7568988936679497`*^9}, 3.7568989675344043`*^9, 
   3.7568994910833025`*^9}],

Cell[BoxData["\<\"fig4.pdf\"\>"], "Output",
 CellChangeTimes->{
  3.75638630800834*^9, 3.7563864113095913`*^9, 3.756386634756816*^9, 
   3.756387033252141*^9, 3.7563871488060513`*^9, {3.756403636594595*^9, 
   3.756403651124302*^9}, {3.7564036844576874`*^9, 3.7564037158535843`*^9}, 
   3.756403849566763*^9, 3.756403885714408*^9, 3.756731090337716*^9, 
   3.756745717593614*^9, 3.7567458253990736`*^9, 3.756745932449931*^9, 
   3.7567459650164256`*^9, {3.7567460363294506`*^9, 3.7567460574466314`*^9}, {
   3.75674619934101*^9, 3.7567462395897975`*^9}, 3.7567462730072165`*^9, 
   3.7567483081554823`*^9, {3.7568987760421257`*^9, 3.7568988179936075`*^9}, {
   3.756898865282226*^9, 3.7568988936679497`*^9}, 3.7568989675344043`*^9, 
   3.7568994914025736`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Figure 5",
 FontSize->18]], "Section",
 CellChangeTimes->{{3.7569094355456886`*^9, 3.7569094389570155`*^9}},
 Background->RGBColor[0., 1., 1.]],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"Stability", " ", "range", " ", "with", " ", "m"}], "=", "0.1"}], 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7563892965397*^9, 3.7563892970707874`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  StyleBox[
   RowBox[{
    RowBox[{"alistllrangemin", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0218665"}], ",", 
         RowBox[{"-", "0.08"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0277182"}], ",", 
         RowBox[{"-", "0.09"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0342741"}], ",", 
         RowBox[{"-", "0.1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0415376"}], ",", 
         RowBox[{"-", "0.11"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0495123"}], ",", 
         RowBox[{"-", "0.12"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0582016"}], ",", 
         RowBox[{"-", "0.13"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0676093"}], ",", 
         RowBox[{"-", "0.14"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0777389"}], ",", 
         RowBox[{"-", "0.15"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0885944"}], ",", 
         RowBox[{"-", "0.16"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.100179"}], ",", 
         RowBox[{"-", "0.17"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.112498"}], ",", 
         RowBox[{"-", "0.18"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.125554"}], ",", 
         RowBox[{"-", "0.19"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.139351"}], ",", 
         RowBox[{"-", "0.2"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.153894"}], ",", 
         RowBox[{"-", "0.21"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.169186"}], ",", 
         RowBox[{"-", "0.22"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.185232"}], ",", 
         RowBox[{"-", "0.23"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.202035"}], ",", 
         RowBox[{"-", "0.24"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.219602"}], ",", 
         RowBox[{"-", "0.25"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.237935"}], ",", 
         RowBox[{"-", "0.26"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.257039"}], ",", 
         RowBox[{"-", "0.27"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.276919"}], ",", 
         RowBox[{"-", "0.28"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.29758"}], ",", 
         RowBox[{"-", "0.29"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.319025"}], ",", 
         RowBox[{"-", "0.3"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.341261"}], ",", 
         RowBox[{"-", "0.31"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.364292"}], ",", 
         RowBox[{"-", "0.32"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.388122"}], ",", 
         RowBox[{"-", "0.33"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.412758"}], ",", 
         RowBox[{"-", "0.34"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.438204"}], ",", 
         RowBox[{"-", "0.35"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.464466"}], ",", 
         RowBox[{"-", "0.36"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.491548"}], ",", 
         RowBox[{"-", "0.37"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.519457"}], ",", 
         RowBox[{"-", "0.38"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.548199"}], ",", 
         RowBox[{"-", "0.39"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.577778"}], ",", 
         RowBox[{"-", "0.4"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.608201"}], ",", 
         RowBox[{"-", "0.41"}]}], "}"}]}], "}"}]}], ";"}],
   FontSize->9], 
  StyleBox[
   RowBox[{"(*", 
    RowBox[{
    "List", " ", "of", " ", "parameters", " ", "corresponding", " ", "to", 
     " ", "the", " ", "upper", " ", "theoretical", " ", "limit"}], "*)"}],
   FontSize->12]}], "\[IndentingNewLine]", 
 RowBox[{
  StyleBox[
   RowBox[{
    RowBox[{"listllrangemax", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0195188"}], ",", 
         RowBox[{"-", "0.08"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0247561"}], ",", 
         RowBox[{"-", "0.09"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0306287"}], ",", 
         RowBox[{"-", "0.1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.037141"}], ",", 
         RowBox[{"-", "0.11"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0442972"}], ",", 
         RowBox[{"-", "0.12"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0521019"}], ",", 
         RowBox[{"-", "0.13"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0605598"}], ",", 
         RowBox[{"-", "0.14"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0696755"}], ",", 
         RowBox[{"-", "0.15"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0794537"}], ",", 
         RowBox[{"-", "0.16"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0898995"}], ",", 
         RowBox[{"-", "0.17"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.101018"}], ",", 
         RowBox[{"-", "0.18"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.112814"}], ",", 
         RowBox[{"-", "0.19"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.125292"}], ",", 
         RowBox[{"-", "0.2"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.138459"}], ",", 
         RowBox[{"-", "0.21"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15232"}], ",", 
         RowBox[{"-", "0.22"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.166881"}], ",", 
         RowBox[{"-", "0.23"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.182146"}], ",", 
         RowBox[{"-", "0.24"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.198122"}], ",", 
         RowBox[{"-", "0.25"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.214816"}], ",", 
         RowBox[{"-", "0.26"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.232233"}], ",", 
         RowBox[{"-", "0.27"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.25038"}], ",", 
         RowBox[{"-", "0.28"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.269263"}], ",", 
         RowBox[{"-", "0.29"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.288889"}], ",", 
         RowBox[{"-", "0.3"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.309265"}], ",", 
         RowBox[{"-", "0.31"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.330398"}], ",", 
         RowBox[{"-", "0.32"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.352296"}], ",", 
         RowBox[{"-", "0.33"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.374966"}], ",", 
         RowBox[{"-", "0.34"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.398416"}], ",", 
         RowBox[{"-", "0.35"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.422653"}], ",", 
         RowBox[{"-", "0.36"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.447687"}], ",", 
         RowBox[{"-", "0.37"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.473525"}], ",", 
         RowBox[{"-", "0.38"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.500177"}], ",", 
         RowBox[{"-", "0.39"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.527652"}], ",", 
         RowBox[{"-", "0.4"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.555958"}], ",", 
         RowBox[{"-", "0.41"}]}], "}"}]}], "}"}]}], ";"}],
   FontSize->9], 
  StyleBox[
   RowBox[{"(*", 
    RowBox[{
    "List", " ", "of", " ", "parameters", " ", "corresponding", " ", "to", 
     " ", "the", " ", "lower", " ", "limit", " ", "of", " ", "metastable", 
     " ", "solutions"}], "*)"}],
   FontSize->12]}], "\[IndentingNewLine]", 
 RowBox[{
  StyleBox[
   RowBox[{
    RowBox[{"mlista0", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0202665"}], ",", 
         RowBox[{"-", "0.08"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0257182"}], ",", 
         RowBox[{"-", "0.09"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0317741"}], ",", 
         RowBox[{"-", "0.1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0385376"}], ",", 
         RowBox[{"-", "0.11"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0460123"}], ",", 
         RowBox[{"-", "0.12"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0541016"}], ",", 
         RowBox[{"-", "0.13"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0628093"}], ",", 
         RowBox[{"-", "0.14"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0722389"}], ",", 
         RowBox[{"-", "0.15"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0823944"}], ",", 
         RowBox[{"-", "0.16"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0931794"}], ",", 
         RowBox[{"-", "0.17"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.104698"}], ",", 
         RowBox[{"-", "0.18"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.116854"}], ",", 
         RowBox[{"-", "0.19"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.129751"}], ",", 
         RowBox[{"-", "0.2"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.143394"}], ",", 
         RowBox[{"-", "0.21"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.157586"}], ",", 
         RowBox[{"-", "0.22"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.172632"}], ",", 
         RowBox[{"-", "0.23"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.188335"}], ",", 
         RowBox[{"-", "0.24"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.204802"}], ",", 
         RowBox[{"-", "0.25"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.221935"}], ",", 
         RowBox[{"-", "0.26"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.239839"}], ",", 
         RowBox[{"-", "0.27"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.258419"}], ",", 
         RowBox[{"-", "0.28"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.27778"}], ",", 
         RowBox[{"-", "0.29"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.297925"}], ",", 
         RowBox[{"-", "0.3"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.318761"}], ",", 
         RowBox[{"-", "0.31"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.340392"}], ",", 
         RowBox[{"-", "0.32"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.362822"}], ",", 
         RowBox[{"-", "0.33"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.385958"}], ",", 
         RowBox[{"-", "0.34"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.409904"}], ",", 
         RowBox[{"-", "0.35"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.434666"}], ",", 
         RowBox[{"-", "0.36"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.460148"}], ",", 
         RowBox[{"-", "0.37"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.486457"}], ",", 
         RowBox[{"-", "0.38"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.513599"}], ",", 
         RowBox[{"-", "0.39"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.541478"}], ",", 
         RowBox[{"-", "0.4"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.570301"}], ",", 
         RowBox[{"-", "0.41"}]}], "}"}]}], "}"}]}], ";"}],
   FontSize->9], 
  StyleBox[
   RowBox[{"(*", 
    RowBox[{
    "List", " ", "of", " ", "parameters", " ", "corresponding", " ", "to", 
     " ", "the", " ", "upper", " ", "limit", " ", "of", " ", "metastalble", 
     " ", "solutions", " ", "for", " ", "zero", " ", "Backreaction"}], "*)"}],
   FontSize->12]}], "\[IndentingNewLine]", 
 RowBox[{
  StyleBox[
   RowBox[{
    RowBox[{"mlista05", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0203665"}], ",", 
         RowBox[{"-", "0.08"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0258182"}], ",", 
         RowBox[{"-", "0.09"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0319741"}], ",", 
         RowBox[{"-", "0.1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0388376"}], ",", 
         RowBox[{"-", "0.11"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0463123"}], ",", 
         RowBox[{"-", "0.12"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0545016"}], ",", 
         RowBox[{"-", "0.13"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0634093"}], ",", 
         RowBox[{"-", "0.14"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0730389"}], ",", 
         RowBox[{"-", "0.15"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0832944"}], ",", 
         RowBox[{"-", "0.16"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0942794"}], ",", 
         RowBox[{"-", "0.17"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.105998"}], ",", 
         RowBox[{"-", "0.18"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.118354"}], ",", 
         RowBox[{"-", "0.19"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.131551"}], ",", 
         RowBox[{"-", "0.2"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.145394"}], ",", 
         RowBox[{"-", "0.21"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.159986"}], ",", 
         RowBox[{"-", "0.22"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.175332"}], ",", 
         RowBox[{"-", "0.23"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.191435"}], ",", 
         RowBox[{"-", "0.24"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.208302"}], ",", 
         RowBox[{"-", "0.25"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.225935"}], ",", 
         RowBox[{"-", "0.26"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.244339"}], ",", 
         RowBox[{"-", "0.27"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.263519"}], ",", 
         RowBox[{"-", "0.28"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.28348"}], ",", 
         RowBox[{"-", "0.29"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.304125"}], ",", 
         RowBox[{"-", "0.3"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.325661"}], ",", 
         RowBox[{"-", "0.31"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.348092"}], ",", 
         RowBox[{"-", "0.32"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.371222"}], ",", 
         RowBox[{"-", "0.33"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.395258"}], ",", 
         RowBox[{"-", "0.34"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.420004"}], ",", 
         RowBox[{"-", "0.35"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.445666"}], ",", 
         RowBox[{"-", "0.36"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.472248"}], ",", 
         RowBox[{"-", "0.37"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.499557"}], ",", 
         RowBox[{"-", "0.38"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.527899"}], ",", 
         RowBox[{"-", "0.39"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.556978"}], ",", 
         RowBox[{"-", "0.4"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.587001"}], ",", 
         RowBox[{"-", "0.41"}]}], "}"}]}], "}"}]}], ";"}],
   FontSize->9], 
  StyleBox[
   RowBox[{"(*", 
    RowBox[{
    "List", " ", "of", " ", "parameters", " ", "corresponding", " ", "to", 
     " ", "the", " ", "upper", " ", "limit", " ", "of", " ", "metastalble", 
     " ", "solutions", " ", "for", " ", "Backreaction", " ", "parameter", " ",
      "equal", " ", "to", " ", "0.5"}], "*)"}],
   FontSize->12]}], "\[IndentingNewLine]", 
 RowBox[{
  StyleBox[
   RowBox[{
    RowBox[{"mlista1", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0204665"}], ",", 
         RowBox[{"-", "0.08"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0260182"}], ",", 
         RowBox[{"-", "0.09"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0321741"}], ",", 
         RowBox[{"-", "0.1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0391376"}], ",", 
         RowBox[{"-", "0.11"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0467123"}], ",", 
         RowBox[{"-", "0.12"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0550016"}], ",", 
         RowBox[{"-", "0.13"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0640093"}], ",", 
         RowBox[{"-", "0.14"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0737389"}], ",", 
         RowBox[{"-", "0.15"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0841944"}], ",", 
         RowBox[{"-", "0.16"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0953794"}], ",", 
         RowBox[{"-", "0.17"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.107298"}], ",", 
         RowBox[{"-", "0.18"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.119954"}], ",", 
         RowBox[{"-", "0.19"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.133451"}], ",", 
         RowBox[{"-", "0.2"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.147594"}], ",", 
         RowBox[{"-", "0.21"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.162586"}], ",", 
         RowBox[{"-", "0.22"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.178332"}], ",", 
         RowBox[{"-", "0.23"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.194835"}], ",", 
         RowBox[{"-", "0.24"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.212202"}], ",", 
         RowBox[{"-", "0.25"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.230335"}], ",", 
         RowBox[{"-", "0.26"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.249239"}], ",", 
         RowBox[{"-", "0.27"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.269019"}], ",", 
         RowBox[{"-", "0.28"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.28968"}], ",", 
         RowBox[{"-", "0.29"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.311125"}], ",", 
         RowBox[{"-", "0.3"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.333461"}], ",", 
         RowBox[{"-", "0.31"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.356692"}], ",", 
         RowBox[{"-", "0.32"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.380722"}], ",", 
         RowBox[{"-", "0.33"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.405758"}], ",", 
         RowBox[{"-", "0.34"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.431604"}], ",", 
         RowBox[{"-", "0.35"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.458466"}], ",", 
         RowBox[{"-", "0.36"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.486148"}], ",", 
         RowBox[{"-", "0.37"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.514857"}], ",", 
         RowBox[{"-", "0.38"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.544599"}], ",", 
         RowBox[{"-", "0.39"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.575278"}], ",", 
         RowBox[{"-", "0.4"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.606901"}], ",", 
         RowBox[{"-", "0.41"}]}], "}"}]}], "}"}]}], ";"}],
   FontSize->9], 
  StyleBox[
   RowBox[{"(*", 
    RowBox[{
    "List", " ", "of", " ", "parameters", " ", "corresponding", " ", "to", 
     " ", "the", " ", "upper", " ", "limit", " ", "of", " ", "metastalble", 
     " ", "solutions", " ", "for", " ", "Backreaction", " ", "parameter", " ",
      "equal", " ", "to", " ", "1"}], "*)"}],
   FontSize->12]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"p", "[", "1", "]"}], "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"ListLinePlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sort", "[", "alistllrangemin", "]"}], ",", 
         RowBox[{"Sort", "[", "mlista0", "]"}], ",", 
         RowBox[{"Sort", "[", "listllrangemax", "]"}]}], "}"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Dashed", ",", "Black", ",", 
            RowBox[{"Thickness", "[", "0.005", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Green", ",", 
            RowBox[{"Thickness", "[", "0.005", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Dashed", ",", "Red", ",", 
            RowBox[{"Thickness", "[", "0.005", "]"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", ".33"}], ",", 
            RowBox[{"-", ".30"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", ".32"}], ",", 
            RowBox[{"-", ".29"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
       RowBox[{"Filling", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", "3", "}"}], ",", "Yellow"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"Axis", ",", "LightGray"}], "}"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"1", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", "2", "}"}], ",", "LightRed"}], "}"}]}], "}"}], 
            ",", 
            RowBox[{"3", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"Bottom", ",", "LightBlue"}], "}"}]}]}], "}"}]}], 
         "}"}]}]}], "]"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Inset", "[", 
        RowBox[{
        "\"\<m=0.1\\n\!\(\*OverscriptBox[\(\[Kappa]\), \(_\)]\)= 0\>\"", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", ".327"}], ",", 
           RowBox[{"-", ".295"}]}], "}"}]}], "]"}], "}"}], "]"}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Large", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Italic"}], 
       "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "14"}]}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"p", "[", "2", "]"}], "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"ListLinePlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sort", "[", "alistllrangemin", "]"}], ",", 
         RowBox[{"Sort", "[", "mlista05", "]"}], ",", 
         RowBox[{"Sort", "[", "listllrangemin", "]"}], ",", 
         RowBox[{"Sort", "[", "listllrangemax", "]"}]}], "}"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Dashed", ",", "Black", ",", 
            RowBox[{"Thickness", "[", "0.005", "]"}]}], "}"}], ",", 
          RowBox[{"Thickness", "[", "0.005", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Green", ",", 
            RowBox[{"Thickness", "[", "0.005", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Dashed", ",", "Red", ",", 
            RowBox[{"Thickness", "[", "0.005", "]"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", ".33"}], ",", 
            RowBox[{"-", ".30"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", ".32"}], ",", 
            RowBox[{"-", ".29"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
       RowBox[{"Filling", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", "3", "}"}], ",", "Yellow"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"3", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", "4", "}"}], ",", "LightRed"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"Axis", ",", "LightGray"}], "}"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"1", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", "2", "}"}], ",", "LightRed"}], "}"}]}], "}"}], 
            ",", 
            RowBox[{"3", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"Bottom", ",", "LightBlue"}], "}"}]}]}], "}"}]}], 
         "}"}]}]}], "]"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Inset", "[", 
        RowBox[{
        "\"\<m=0.1\\n\!\(\*OverscriptBox[\(\[Kappa]\), \(_\)]\)= 0.5\>\"", 
         ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", ".327"}], ",", 
           RowBox[{"-", ".295"}]}], "}"}]}], "]"}], "}"}], "]"}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Large", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Italic"}], 
       "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "14"}]}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"p", "[", "3", "]"}], "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"ListLinePlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sort", "[", "alistllrangemin", "]"}], ",", 
         RowBox[{"Sort", "[", "mlista1", "]"}], ",", 
         RowBox[{"Sort", "[", "listllrangemin", "]"}], ",", 
         RowBox[{"Sort", "[", "listllrangemax", "]"}]}], "}"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Dashed", ",", "Black", ",", 
            RowBox[{"Thickness", "[", "0.005", "]"}]}], "}"}], ",", 
          RowBox[{"Thickness", "[", "0.005", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Green", ",", 
            RowBox[{"Thickness", "[", "0.005", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Dashed", ",", "Red", ",", 
            RowBox[{"Thickness", "[", "0.005", "]"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", ".33"}], ",", 
            RowBox[{"-", ".30"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", ".32"}], ",", 
            RowBox[{"-", ".29"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
       RowBox[{"Filling", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", "3", "}"}], ",", "Yellow"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"3", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", "4", "}"}], ",", "LightRed"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"Axis", ",", "LightGray"}], "}"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"1", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", "2", "}"}], ",", "LightRed"}], "}"}]}], "}"}], 
            ",", 
            RowBox[{"3", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"Bottom", ",", "LightBlue"}], "}"}]}]}], "}"}]}], 
         "}"}]}]}], "]"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Inset", "[", 
        RowBox[{
        "\"\<m=0.1\\n\!\(\*OverscriptBox[\(\[Kappa]\), \(_\)]\)= 1\>\"", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", ".327"}], ",", 
           RowBox[{"-", ".295"}]}], "}"}]}], "]"}], "}"}], "]"}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Large", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Italic"}], 
       "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "14"}]}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"grid", "=", 
   RowBox[{"Panel", "[", 
    RowBox[{
     RowBox[{"GraphicsGrid", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], ",", 
          RowBox[{"p", "[", "2", "]"}], ",", 
          RowBox[{"p", "[", "3", "]"}]}], "}"}], "}"}], ",", 
       RowBox[{"Spacings", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "Full"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<\[CapitalLambda]\>\"", ",", 
       RowBox[{"Rotate", "[", 
        RowBox[{"\"\<b\>\"", ",", 
         RowBox[{"Pi", "/", "2"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Bottom", ",", "Left"}], "}"}], ",", 
     RowBox[{"Background", "\[Rule]", "White"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gridl", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"p", "[", "i", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "3"}], "}"}]}], "]"}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{"k2", "=", 
  RowBox[{"Panel", "[", 
   RowBox[{
    RowBox[{"plotGrid", "[", 
     RowBox[{"gridl", ",", "1363", ",", "363"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<\!\(\*
StyleBox[\"\[CapitalLambda]\",
FontFamily->\"Times New Roman\",
FontSize->24,
FontWeight->\"Plain\"]\)\>\"", ",", 
      RowBox[{"Rotate", "[", 
       RowBox[{"\"\<\!\(\*
StyleBox[\"b\",
FontFamily->\"Times New Roman\",
FontSize->24,
FontWeight->\"Plain\"]\)\>\"", ",", 
        RowBox[{"Pi", "/", "2"}]}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"Bottom", ",", "Left"}], "}"}], ",", 
    RowBox[{"Background", "\[Rule]", "White"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{"\"\<fig5.pdf\>\"", ",", "k2", ",", 
   RowBox[{"ImageResolution", "\[Rule]", "1000"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"Scaled", "[", "4", "]"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7555164166560946`*^9, 3.755516449766582*^9}, {
   3.7555249884108763`*^9, 3.7555250139762363`*^9}, 3.7555251555661592`*^9, {
   3.755527298632121*^9, 3.755527317853877*^9}, {3.75552852407489*^9, 
   3.7555285310693903`*^9}, {3.7555286877615633`*^9, 
   3.7555287115813227`*^9}, {3.755528856571269*^9, 3.755528971731166*^9}, {
   3.7555290853948555`*^9, 3.7555291185318203`*^9}, {3.7555291861012964`*^9, 
   3.7555291897515717`*^9}, {3.755529252701316*^9, 3.7555292553012276`*^9}, {
   3.75552928938461*^9, 3.755529295364374*^9}, {3.7555294459315267`*^9, 
   3.755529482451914*^9}, {3.755529540742057*^9, 3.755529568642087*^9}, {
   3.755529743890092*^9, 3.7555297642965717`*^9}, {3.755530359722475*^9, 
   3.7555303688042207`*^9}, {3.7555304330643053`*^9, 3.75553047819493*^9}, {
   3.755530509331643*^9, 3.7555305428633347`*^9}, {3.7555306254371414`*^9, 
   3.755530632006349*^9}, 3.7555307071537123`*^9, {3.7555307667295094`*^9, 
   3.7555308205189424`*^9}, {3.7563862159831905`*^9, 
   3.7563862248717527`*^9}, {3.7563862726730475`*^9, 3.756386281249031*^9}, {
   3.7563863999372816`*^9, 3.7563864056078777`*^9}, {3.7563864521438155`*^9, 
   3.7563864530340853`*^9}, {3.756391251121169*^9, 3.756391252049396*^9}, {
   3.7564037539024143`*^9, 3.7564038081737394`*^9}, {3.756730918149069*^9, 
   3.756730931009856*^9}, {3.7567309766667185`*^9, 3.7567310019508944`*^9}, {
   3.7567396225191765`*^9, 3.75673964132872*^9}, {3.7567463440367956`*^9, 
   3.7567463565393534`*^9}, {3.7568995418896565`*^9, 
   3.7568995427302694`*^9}, {3.756899607739458*^9, 3.7568996418445063`*^9}, {
   3.756899694296851*^9, 3.7568997193656335`*^9}, 3.756899810293809*^9, {
   3.756899843615274*^9, 3.7568998623849287`*^9}, {3.7569096569847*^9, 
   3.7569096579571314`*^9}}],

Cell[BoxData[
 TemplateBox[{PanelBox[
    GraphicsBox[{{
       InsetBox[
        GraphicsBox[{{{}, 
           GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQvW1+z8fEssf7q0XWuT+surL//PsFdXv+TIbz7yTV
5WWcegjnc3hdPLX3wJT9/Ye+asT0X9r/i+PPw+f2j+DyDnzNP7VTpsHlZ8k8
1r8kcHm/6Vlrv4sTL+2H2Qfj20LVw/iTC3tS+gOuw807PXdmgsX1q/uvLy6w
5bp+eb/T+bSrz7Ou7DcGg8v7HVP//O7hvgy3zxbNfnT3pVd/aft94iqcH53Q
3zkl7Qrc/B6vVywmgpfh5jc9v3dY9fhFuHlcaP5HD5+r1VrLbVUR5jtxGuf+
P3UZbr6u6mlPjdpLcPPDyw4+mGWNMB8W/jA+AFkf8HM=
            "], {{{
               EdgeForm[], 
               GrayLevel[0.85], 
               GraphicsGroupBox[{
                 PolygonBox[{{7, 8, 1, 5, 10, 11, 12}}]}]}, {
               EdgeForm[], 
               GrayLevel[0.85], 
               GraphicsGroupBox[{
                 PolygonBox[{{7, 9, 14, 13}}]}]}, {}, {}, {}, {
               EdgeForm[], 
               RGBColor[0.87, 0.94, 1], 
               GraphicsGroupBox[{
                 PolygonBox[{{22, 2, 26, 25, 24, 23}}]}]}, {}, {}, {}, {
               EdgeForm[], 
               RGBColor[1, 0.85, 0.85], 
               GraphicsGroupBox[{
                 
                 PolygonBox[{{15, 3, 16, 17, 18, 19, 6, 14, 13, 12, 11, 10, 
                  5}}]}]}, {}, {}, {}, {}, {}, {
               EdgeForm[], 
               RGBColor[1, 1, 0], 
               GraphicsGroupBox[{
                 
                 PolygonBox[{{21, 22, 23, 24, 25, 4, 20, 19, 18, 17, 16, 
                  3}}]}]}, {}, {}}, {{}, {}, {}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.01388888888888889], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                Dashing[{Small, Small}], 
                GrayLevel[0], 
                Thickness[0.005]], 
               LineBox[{10, 11, 12, 7, 13}]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.01388888888888889], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 1, 0], 
                Thickness[0.005]], 
               LineBox[{16, 17, 18, 19}]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.01388888888888889], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                Dashing[{Small, Small}], 
                RGBColor[1, 0, 0], 
                Thickness[0.005]], 
               LineBox[{22, 23, 24, 25}]}}}], {}, {}, {{}, {}}}, {
           TagBox[
            InsetBox[
            "m=0.1\n\!\(\*OverscriptBox[\(\[Kappa]\), \(_\)]\)= 0", {-0.327, \
-0.295}], "InsetString"]}}, {
         ImagePadding -> {{40, 0}, {40, 40}}, AspectRatio -> Full, 
          BaseStyle -> {Large, FontFamily -> "Times", Italic}, LabelStyle -> 
          Directive[
            GrayLevel[0], FontFamily -> "Times", FontSize -> 14], 
          DisplayFunction -> Identity, PlotRangePadding -> {{0, 0}, {0, 0}}, 
          AxesOrigin -> {-0.30015, -0.29014999999999996`}, 
          PlotRange -> {{-0.33, -0.3}, {-0.32, -0.29}}, PlotRangeClipping -> 
          True, ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
          NCache[GoldenRatio^(-1), 0.6180339887498948], 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {-0.30015, -0.29014999999999996`}, DisplayFunction :> 
          Identity, Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> Automatic,
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLines -> {{0}, {0}}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], LabelStyle -> {FontFamily -> "Times"}, 
          Method -> {"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
                 Part[#, 1]], 
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
                 Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
                 Part[#, 1]], 
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
                 Part[#, 2]]}& )}}, 
          PlotRange -> {{-0.33, -0.3}, {-0.32, -0.29}}, PlotRangeClipping -> 
          True, PlotRangePadding -> {{0, 0}, {0, 0}}, 
          Ticks -> {Automatic, Automatic}}], {0, 0}, {Left, Bottom}, 
        NCache[{
          Rational[1403, 3], 363}, {467.6666666666667, 363}]]}, {
       InsetBox[
        GraphicsBox[{{{}, 
           GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGBQAmIQvW1+z8fEssf7q0XWuT+surKfy+viqb0HpsD5d5Lq
8jJOPYTzOaDy/Ye+asT0X9r/i+PPw+f2j+DyAWl71n65hZCvZDEP2nYCIe/A
1/xTO2UaXH6WzGP9SwKX95uetfa7OPHS/smFPSn9Adfh6k/PnZlgcf3q/uuL
C2y5rl/e73Q+7erzrCv7jcHg8n7H1D+/e7gvw82D+Qdmni3UPnQ+Lvdlf/6/
Stn9Gpxv46Vqs/D6Fbj9AhGWW06UXYbbb1jj4tOpcgluni+a/9HDJ736S9vv
E1fh/OiE/s4paQjze7xesZgIIsxven7vsOrxi3DzuNDCHz1+rlZrLbdVRZjv
xGmc+//UZbj5uqqnPTVqL8HNDy87+GCWNcL88+8X1O35MxnOBwAuiDY0
            "], {{{
               EdgeForm[], 
               GrayLevel[0.85], 
               GraphicsGroupBox[{
                 PolygonBox[{{9, 14, 1, 7, 10, 11, 12}}]}]}, {
               EdgeForm[], 
               GrayLevel[0.85], 
               GraphicsGroupBox[{
                 PolygonBox[{{9, 15, 16, 13}}]}]}, {}, {}, {}, {
               EdgeForm[], 
               RGBColor[0.87, 0.94, 1], 
               GraphicsGroupBox[{
                 
                 PolygonBox[{{24, 2, 28, 27, 26, 
                  25}}]}]}, {}, {}, {}, {}, {}, {
               EdgeForm[], 
               RGBColor[1, 0.85, 0.85], 
               GraphicsGroupBox[{
                 
                 PolygonBox[{{17, 5, 18, 19, 20, 21, 8, 16, 13, 12, 11, 10, 
                  7}}]}]}, {}, {}, {}, {}, {}, {}, {}, {
               EdgeForm[], 
               RGBColor[1, 1, 0], 
               GraphicsGroupBox[{
                 
                 PolygonBox[{{23, 3, 24, 25, 26, 27, 6, 22, 21, 20, 19, 18, 
                  5}}]}]}, {}, {}, {}, {}, {}, {
               EdgeForm[], 
               RGBColor[1, 0.85, 0.85], 
               GraphicsGroupBox[{
                 
                 PolygonBox[{{29, 30, 31, 32, 33, 4, 28, 27, 26, 25, 24, 
                  3}}]}]}, {}, {}}, {{}, {}, {}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.01388888888888889], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                Dashing[{Small, Small}], 
                GrayLevel[0], 
                Thickness[0.005]], 
               LineBox[{10, 11, 12, 9, 13}]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.01388888888888889], 
                RGBColor[0.365248, 0.427802, 0.758297], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                Thickness[0.005]], 
               LineBox[{18, 19, 20, 21}]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.01388888888888889], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 1, 0], 
                Thickness[0.005]], 
               LineBox[{24, 25, 26, 27}]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.01388888888888889], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                Dashing[{Small, Small}], 
                RGBColor[1, 0, 0], 
                Thickness[0.005]], 
               LineBox[{30, 31, 32, 33}]}}}], {}, {}, {{}, {}}}, {
           TagBox[
            InsetBox[
            "m=0.1\n\!\(\*OverscriptBox[\(\[Kappa]\), \(_\)]\)= 0.5", \
{-0.327, -0.295}], "InsetString"]}}, {
         ImagePadding -> {{0, 0}, {40, 40}}, AspectRatio -> Full, 
          BaseStyle -> {Large, FontFamily -> "Times", Italic}, LabelStyle -> 
          Directive[
            GrayLevel[0], FontFamily -> "Times", FontSize -> 14], 
          DisplayFunction -> Identity, PlotRangePadding -> {{0, 0}, {0, 0}}, 
          AxesOrigin -> {-0.30015, -0.29014999999999996`}, 
          PlotRange -> {{-0.33, -0.3}, {-0.32, -0.29}}, PlotRangeClipping -> 
          True, ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
          NCache[GoldenRatio^(-1), 0.6180339887498948], 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {-0.30015, -0.29014999999999996`}, DisplayFunction :> 
          Identity, Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> Automatic,
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLines -> {{0}, {0}}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], LabelStyle -> {FontFamily -> "Times"}, 
          Method -> {"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
                 Part[#, 1]], 
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
                 Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
                 Part[#, 1]], 
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
                 Part[#, 2]]}& )}}, 
          PlotRange -> {{-0.33, -0.3}, {-0.32, -0.29}}, PlotRangeClipping -> 
          True, PlotRangePadding -> {{0, 0}, {0, 0}}, 
          Ticks -> {Automatic, Automatic}}], 
        NCache[{
          Rational[1403, 3], 0}, {467.6666666666667, 0}], {Left, Bottom}, 
        NCache[{
          Rational[1283, 3], 363}, {427.6666666666667, 363}]]}, {
       InsetBox[
        GraphicsBox[{{{}, 
           GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGBQAmIQvW1+z8fEssf7q0XWuT+surKfy+viqb0HpsD5d5Lq
8jJOPYTzOaDy/Ye+asT0X9r/i+PPw+f2j+DyE5qWT9D+ipC3loldujsbYb4D
X/NP7ZRpcPlZMo/1Lwlc3m961trv4sRL+ycX9qT0B1yHqz89d2aCxfWr+68v
LrDlun55v9P5tKvPs67sNwaDy/sdU//87uG+DDcP5h+YebZQ+9D5uNwXsnr9
Oq4r1+B8lpL4cznhCPu3ff57peLlZbj9Wzsn/5btugQ3D93/6OGTXv2l7feJ
q3B+dEJ/55S0K3Dze7xesZgIIsxven7vsOrxi3DzuNDCHz1+rlZrLbdVRZjv
xGmc+//UZbj5uqqnPTVqL8HNDy87+GCWNcL88+8X1O35MxnOBwAVrzjL
            "], {{{
               EdgeForm[], 
               GrayLevel[0.85], 
               GraphicsGroupBox[{
                 PolygonBox[{{9, 14, 1, 7, 10, 11, 12}}]}]}, {
               EdgeForm[], 
               GrayLevel[0.85], 
               GraphicsGroupBox[{
                 PolygonBox[{{9, 15, 16, 13}}]}]}, {}, {}, {}, {
               EdgeForm[], 
               RGBColor[0.87, 0.94, 1], 
               GraphicsGroupBox[{
                 
                 PolygonBox[{{24, 2, 28, 27, 26, 
                  25}}]}]}, {}, {}, {}, {}, {}, {
               EdgeForm[], 
               RGBColor[1, 0.85, 0.85], 
               GraphicsGroupBox[{
                 
                 PolygonBox[{{17, 5, 18, 19, 20, 21, 8, 16, 13, 12, 11, 10, 
                  7}}]}]}, {}, {}, {}, {}, {}, {}, {}, {
               EdgeForm[], 
               RGBColor[1, 1, 0], 
               GraphicsGroupBox[{
                 
                 PolygonBox[{{23, 3, 24, 25, 26, 27, 6, 22, 21, 20, 19, 18, 
                  5}}]}]}, {}, {}, {}, {}, {}, {
               EdgeForm[], 
               RGBColor[1, 0.85, 0.85], 
               GraphicsGroupBox[{
                 
                 PolygonBox[{{29, 30, 31, 32, 33, 4, 28, 27, 26, 25, 24, 
                  3}}]}]}, {}, {}}, {{}, {}, {}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.01388888888888889], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                Dashing[{Small, Small}], 
                GrayLevel[0], 
                Thickness[0.005]], 
               LineBox[{10, 11, 12, 9, 13}]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.01388888888888889], 
                RGBColor[0.365248, 0.427802, 0.758297], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                Thickness[0.005]], 
               LineBox[{18, 19, 20, 21}]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.01388888888888889], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 1, 0], 
                Thickness[0.005]], 
               LineBox[{24, 25, 26, 27}]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.01388888888888889], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                Dashing[{Small, Small}], 
                RGBColor[1, 0, 0], 
                Thickness[0.005]], 
               LineBox[{30, 31, 32, 33}]}}}], {}, {}, {{}, {}}}, {
           TagBox[
            InsetBox[
            "m=0.1\n\!\(\*OverscriptBox[\(\[Kappa]\), \(_\)]\)= 1", {-0.327, \
-0.295}], "InsetString"]}}, {
         ImagePadding -> {{0, 40}, {40, 40}}, AspectRatio -> Full, 
          BaseStyle -> {Large, FontFamily -> "Times", Italic}, LabelStyle -> 
          Directive[
            GrayLevel[0], FontFamily -> "Times", FontSize -> 14], 
          DisplayFunction -> Identity, PlotRangePadding -> {{0, 0}, {0, 0}}, 
          AxesOrigin -> {-0.30015, -0.29014999999999996`}, 
          PlotRange -> {{-0.33, -0.3}, {-0.32, -0.29}}, PlotRangeClipping -> 
          True, ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
          NCache[GoldenRatio^(-1), 0.6180339887498948], 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {-0.30015, -0.29014999999999996`}, DisplayFunction :> 
          Identity, Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> Automatic,
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLines -> {{0}, {0}}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], LabelStyle -> {FontFamily -> "Times"}, 
          Method -> {"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
                 Part[#, 1]], 
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
                 Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
                 Part[#, 1]], 
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
                 Part[#, 2]]}& )}}, 
          PlotRange -> {{-0.33, -0.3}, {-0.32, -0.29}}, PlotRangeClipping -> 
          True, PlotRangePadding -> {{0, 0}, {0, 0}}, 
          Ticks -> {Automatic, Automatic}}], 
        NCache[{
          Rational[2686, 3], 0}, {895.3333333333334, 0}], {Left, Bottom}, 
        NCache[{
          Rational[1403, 3], 363}, {467.6666666666667, 363}]]}}, 
     PlotRange -> {{0, 1363}, {0, 363}}, ImageSize -> {1363, 363}], 
    Background -> GrayLevel[1]],
   "\"\\!\\(\\*\\nStyleBox[\\\"\[CapitalLambda]\\\",\\nFontFamily->\\\"Times \
New Roman\\\",\\nFontSize->24,\\nFontWeight->\\\"Plain\\\"]\\)\"",RotationBox[
   "\"\\!\\(\\*\\nStyleBox[\\\"b\\\",\\nFontFamily->\\\"Times New \
Roman\\\",\\nFontSize->24,\\nFontWeight->\\\"Plain\\\"]\\)\"", BoxRotation -> 
    1.5707963267948966`]},
  "Labeled",
  DisplayFunction->(GridBox[{{
      ItemBox[#3, DefaultBaseStyle -> "PanelLabel"], 
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}, {"", 
      ItemBox[#2, DefaultBaseStyle -> "PanelLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, 
    GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
    BaselinePosition -> {1, 2}]& ),
  InterpretationFunction->(RowBox[{"Labeled", "[", 
     RowBox[{#, ",", 
       RowBox[{"{", 
         RowBox[{#2, ",", #3}], "}"}], ",", 
       RowBox[{"{", 
         RowBox[{"Bottom", ",", "Left"}], "}"}], ",", 
       RowBox[{"DefaultLabelStyle", "\[Rule]", "\"PanelLabel\""}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
         RowBox[{"{", "}"}]}], ",", 
       RowBox[{"RotateLabel", "\[Rule]", "False"}], ",", 
       RowBox[{"Spacings", "\[Rule]", "Automatic"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.7567310155222354`*^9, 3.75673102929202*^9}, 
   3.7567396428182297`*^9, 3.7567463596271353`*^9, 3.7567483110873036`*^9, {
   3.7568995893973026`*^9, 3.7568996113497972`*^9}, 3.756899729866374*^9, 
   3.756899872523224*^9}],

Cell[BoxData["\<\"D:\\\\Downloads\"\>"], "Output",
 CellChangeTimes->{{3.7567310155222354`*^9, 3.75673102929202*^9}, 
   3.7567396428182297`*^9, 3.7567463596271353`*^9, 3.7567483110873036`*^9, {
   3.7568995893973026`*^9, 3.7568996113497972`*^9}, 3.756899729866374*^9, 
   3.756899872586643*^9}],

Cell[BoxData["\<\"fig5.pdf\"\>"], "Output",
 CellChangeTimes->{{3.7567310155222354`*^9, 3.75673102929202*^9}, 
   3.7567396428182297`*^9, 3.7567463596271353`*^9, 3.7567483110873036`*^9, {
   3.7568995893973026`*^9, 3.7568996113497972`*^9}, 3.756899729866374*^9, 
   3.7568998729214196`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Figure 6",
 FontSize->18]], "Section",
 CellChangeTimes->{{3.7569094678846245`*^9, 3.756909470525697*^9}},
 Background->RGBColor[0., 1., 1.]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Plots", " ", "corresponding", " ", "to", " ", "the", " ", "simulation", 
    " ", "of", " ", "the", " ", "field", " ", "evolution", " ", "at", " ", 
    "different", " ", "initial", " ", "wall", " ", "radii"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"b", ",", "ll"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"b", "=", 
     RowBox[{"-", "0.255"}]}], ";", " ", 
    RowBox[{"ll", "=", 
     RowBox[{"-", "0.202"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr", "=", 
     RowBox[{
      RowBox[{"r", "^", "2"}], "+", 
      RowBox[{"2", " ", "b", " ", 
       RowBox[{"r", "^", "3"}]}], " ", "-", " ", 
      RowBox[{"ll", " ", 
       RowBox[{
        RowBox[{"r", "^", "4"}], " ", "/", "3"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"v", ",", "f", ",", "h", ",", "h1"}], "]"}], ";", " ", 
    RowBox[{"(*", " ", 
     RowBox[{
     "this", " ", "is", " ", "a", " ", "good", " ", "choice", " ", "of", " ", 
      "parameters", " ", "starting", " ", "exactly", " ", "on", " ", "the", 
      " ", "static", " ", "solution", " ", "and", " ", "staying", " ", 
      "there"}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Vphi", "[", 
      RowBox[{"t_", ",", "x_"}], "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"f", "[", 
           RowBox[{"t", ",", "x"}], "]"}], "^", "2"}], "-", "1"}], ")"}], "^",
        "2"}], "/", "4"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"V", "[", 
      RowBox[{"t_", ",", "x_"}], "]"}], "=", 
     RowBox[{"Vphi", "[", 
      RowBox[{"t", ",", "x"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"dV", "[", 
      RowBox[{"t_", ",", "x_"}], "]"}], "=", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"Vphi", "[", 
        RowBox[{"t", ",", "x"}], "]"}], ",", 
       RowBox[{"f", "[", 
        RowBox[{"t", ",", "x"}], "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dd", "=", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", "b", " ", "r"}], " ", "-", 
      RowBox[{"ll", " ", 
       RowBox[{
        RowBox[{"r", "^", "2"}], "/", "3"}]}]}]}], " ", ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pde", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"f", "[", 
           RowBox[{"t", ",", "r"}], "]"}], ",", "t"}], "]"}], " ", "==", 
        RowBox[{"g", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"r", "^", "2"}], " ", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"g", "[", 
             RowBox[{"t", ",", "r"}], "]"}], ",", "t"}], "]"}], "/", "dd"}]}],
         "\[Equal]", " ", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"r", "^", "2"}], " ", "dd", " ", 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"f", "[", 
               RowBox[{"t", ",", "r"}], "]"}], ",", "r"}], "]"}]}], ",", 
           "r"}], "]"}], "-", 
         RowBox[{
          RowBox[{"dV", "[", 
           RowBox[{"t", ",", "r"}], "]"}], " ", 
          RowBox[{"r", "^", "2"}]}]}]}]}], "}"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"rmin", "=", "0.1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rmax", "=", "15"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r0", "=", "3.3"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tmax", "=", "800"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], "=", 
     RowBox[{"Tanh", "[", 
      RowBox[{"3", 
       RowBox[{"(", 
        RowBox[{"r", "-", "r0"}], ")"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"h1", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], "=", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"h", "[", 
        RowBox[{"t", ",", "r"}], "]"}], ",", "t"}], "]"}]}], ";", " ", 
    RowBox[{"(*", " ", 
     RowBox[{"time", " ", "derivative", " ", "of", " ", 
      RowBox[{"h", "[", 
       RowBox[{"t", ",", "x"}], "]"}]}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"bc", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"0", ",", "r"}], "]"}], "\[Equal]", 
        RowBox[{"h", "[", 
         RowBox[{"0", ",", "r"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"g", "[", 
         RowBox[{"0", ",", "r"}], "]"}], "\[Equal]", 
        RowBox[{"h1", "[", 
         RowBox[{"0", ",", "r"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"t", ",", "rmin"}], "]"}], "\[Equal]", 
        RowBox[{"-", "1"}]}], ",", 
       RowBox[{
        RowBox[{"g", "[", 
         RowBox[{"t", ",", "rmin"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"t", ",", "rmax"}], "]"}], "\[Equal]", "1"}], ",", 
       RowBox[{
        RowBox[{"g", "[", 
         RowBox[{"t", ",", "rmax"}], "]"}], "\[Equal]", "0"}]}], "}"}]}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{"solution", "=", 
     RowBox[{"NDSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"pde", ",", "bc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"f", ",", "g"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "rmin", ",", "rmax"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
       RowBox[{"StartingStepSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", 
          RowBox[{"rmax", "/", "30"}]}], "}"}]}], ",", 
       RowBox[{"PrecisionGoal", "\[Rule]", "2"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"fsol0", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{"t", ",", "r"}], "]"}], " ", "/.", " ", "solution"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"plm0t0", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"fsol0", "[", 
        RowBox[{"0", ",", "r"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "rmin", ",", "rmax"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2"}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Thick", ",", "Dashed"}], "}"}]}]}], "]"}]}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{"plm0tt", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"fsol0", "[", 
        RowBox[{"170", ",", "r"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "rmin", ",", "rmax"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2"}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Thick", ",", "Dashed"}], "}"}]}]}], "]"}]}], 
    ";"}], "\n", 
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"sol", "[", "tt", "]"}], "=", 
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{"fsol0", "[", 
         RowBox[{"tt", ",", "r"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", "rmin", ",", "rmax"}], "}"}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "2"}], ",", "2"}], "}"}]}], ",", 
        RowBox[{"Frame", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Blue", ",", "Thick", ",", "Dashed"}], "}"}]}]}], "]"}]}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"tt", ",", "0", ",", "tmax"}], "}"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Animate", "[", 
     RowBox[{
      RowBox[{"sol", "[", "tt", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"tt", ",", "0", ",", "tmax", ",", "1"}], "}"}], ",", 
      RowBox[{"AnimationRunning", "\[Rule]", "False"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sol0", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"fsol0", "[", 
        RowBox[{"0", ",", "r"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "rmin", ",", "rmax"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "8"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Thick"}], "}"}]}], ",", 
       RowBox[{"PlotTheme", "->", "\"\<Scientific\>\""}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sol400", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"fsol0", "[", 
        RowBox[{"400", ",", "r"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "rmin", ",", "rmax"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "8"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Dashed"}], "}"}]}], 
       ",", 
       RowBox[{"PlotTheme", "->", "\"\<Scientific\>\""}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sol800", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"fsol0", "[", 
        RowBox[{"800", ",", "r"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "rmin", ",", "rmax"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "8"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Green", ",", "Thick", ",", "Dashed"}], "}"}]}], ",", 
       RowBox[{"PlotTheme", "->", "\"\<Scientific\>\""}]}], "]"}]}], ";"}], 
   "\n", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"v", ",", "f", ",", "h", ",", "h1"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Vphi", "[", 
      RowBox[{"t_", ",", "x_"}], "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"f", "[", 
           RowBox[{"t", ",", "x"}], "]"}], "^", "2"}], "-", "1"}], ")"}], "^",
        "2"}], "/", "4"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"V", "[", 
      RowBox[{"t_", ",", "x_"}], "]"}], "=", 
     RowBox[{"Vphi", "[", 
      RowBox[{"t", ",", "x"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"dV", "[", 
      RowBox[{"t_", ",", "x_"}], "]"}], "=", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"Vphi", "[", 
        RowBox[{"t", ",", "x"}], "]"}], ",", 
       RowBox[{"f", "[", 
        RowBox[{"t", ",", "x"}], "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dd", "=", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", "b", " ", "r"}], " ", "-", 
      RowBox[{"ll", " ", 
       RowBox[{
        RowBox[{"r", "^", "2"}], "/", "3"}]}]}]}], " ", ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pde", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"f", "[", 
           RowBox[{"t", ",", "r"}], "]"}], ",", "t"}], "]"}], " ", "==", 
        RowBox[{"g", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"r", "^", "2"}], " ", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"g", "[", 
             RowBox[{"t", ",", "r"}], "]"}], ",", "t"}], "]"}], "/", "dd"}]}],
         "\[Equal]", " ", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"r", "^", "2"}], " ", "dd", " ", 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"f", "[", 
               RowBox[{"t", ",", "r"}], "]"}], ",", "r"}], "]"}]}], ",", 
           "r"}], "]"}], "-", 
         RowBox[{
          RowBox[{"dV", "[", 
           RowBox[{"t", ",", "r"}], "]"}], " ", 
          RowBox[{"r", "^", "2"}]}]}]}]}], "}"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"rmin", "=", "0.1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rmax", "=", "15"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r0", "=", "3.5"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tmax", "=", "200"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], "=", 
     RowBox[{"Tanh", "[", 
      RowBox[{"3.1", 
       RowBox[{"(", 
        RowBox[{"r", "-", "r0"}], ")"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"h1", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], "=", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"h", "[", 
        RowBox[{"t", ",", "r"}], "]"}], ",", "t"}], "]"}]}], ";", " ", 
    RowBox[{"(*", " ", 
     RowBox[{"time", " ", "derivative", " ", "of", " ", 
      RowBox[{"h", "[", 
       RowBox[{"t", ",", "x"}], "]"}]}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"bc", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"0", ",", "r"}], "]"}], "\[Equal]", 
        RowBox[{"h", "[", 
         RowBox[{"0", ",", "r"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"g", "[", 
         RowBox[{"0", ",", "r"}], "]"}], "\[Equal]", 
        RowBox[{"h1", "[", 
         RowBox[{"0", ",", "r"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"t", ",", "rmin"}], "]"}], "\[Equal]", 
        RowBox[{"-", "1"}]}], ",", 
       RowBox[{
        RowBox[{"g", "[", 
         RowBox[{"t", ",", "rmin"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"t", ",", "rmax"}], "]"}], "\[Equal]", "1"}], ",", 
       RowBox[{
        RowBox[{"g", "[", 
         RowBox[{"t", ",", "rmax"}], "]"}], "\[Equal]", "0"}]}], "}"}]}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{"solution", "=", 
     RowBox[{"NDSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"pde", ",", "bc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"f", ",", "g"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "rmin", ",", "rmax"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
       RowBox[{"StartingStepSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", 
          RowBox[{"rmax", "/", "30"}]}], "}"}]}], ",", 
       RowBox[{"PrecisionGoal", "\[Rule]", "2"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"fsol0", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{"t", ",", "r"}], "]"}], " ", "/.", " ", "solution"}]}], ";"}], 
   "\n", 
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"out", "[", "tt", "]"}], "=", 
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{"fsol0", "[", 
         RowBox[{"tt", ",", "r"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", "rmin", ",", "rmax"}], "}"}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "2"}], ",", "2"}], "}"}]}], ",", 
        RowBox[{"Frame", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Red", ",", "Thick", ",", "Dashed"}], "}"}]}]}], "]"}]}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"tt", ",", "0", ",", "tmax"}], "}"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Animate", "[", 
     RowBox[{
      RowBox[{"out", "[", "tt", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"tt", ",", "0", ",", "tmax", ",", "1"}], "}"}], ",", 
      RowBox[{"AnimationRunning", "\[Rule]", "False"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"out0", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"fsol0", "[", 
        RowBox[{"0", ",", "r"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "rmin", ",", "rmax"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "8"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Thick"}], "}"}]}], ",", 
       RowBox[{"PlotTheme", "->", "\"\<Scientific\>\""}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"out100", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"fsol0", "[", 
        RowBox[{"100", ",", "r"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "rmin", ",", "rmax"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "8"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Dashed"}], "}"}]}], 
       ",", 
       RowBox[{"PlotTheme", "->", "\"\<Scientific\>\""}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"out200", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"fsol0", "[", 
        RowBox[{"200", ",", "r"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "rmin", ",", "rmax"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "8"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Green", ",", "Thick", ",", "Dashed"}], "}"}]}], ",", 
       RowBox[{"PlotTheme", "->", "\"\<Scientific\>\""}]}], "]"}]}], ";"}], 
   "\n", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"v", ",", "f", ",", "h", ",", "h1"}], "]"}], ";", "  ", 
    RowBox[{"(*", " ", 
     RowBox[{
     "this", " ", "is", " ", "a", " ", "good", " ", "choice", " ", "of", " ", 
      "parameters", " ", "starting", " ", "close", " ", "but", " ", "not", 
      " ", "exactly", " ", "on", " ", "the", " ", "static", " ", "solution", 
      " ", "and", " ", "showing", " ", "the", " ", "oscillations", " ", 
      "around", " ", "the", " ", "minimum"}], " ", "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Vphi", "[", 
      RowBox[{"t_", ",", "x_"}], "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"f", "[", 
           RowBox[{"t", ",", "x"}], "]"}], "^", "2"}], "-", "1"}], ")"}], "^",
        "2"}], "/", "4"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"V", "[", 
      RowBox[{"t_", ",", "x_"}], "]"}], "=", 
     RowBox[{"Vphi", "[", 
      RowBox[{"t", ",", "x"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"dV", "[", 
      RowBox[{"t_", ",", "x_"}], "]"}], "=", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"Vphi", "[", 
        RowBox[{"t", ",", "x"}], "]"}], ",", 
       RowBox[{"f", "[", 
        RowBox[{"t", ",", "x"}], "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dd", "=", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", "b", " ", "r"}], " ", "-", 
      RowBox[{"ll", " ", 
       RowBox[{
        RowBox[{"r", "^", "2"}], "/", "3"}]}]}]}], " ", ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pde", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"f", "[", 
           RowBox[{"t", ",", "r"}], "]"}], ",", "t"}], "]"}], " ", "==", 
        RowBox[{"g", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"r", "^", "2"}], " ", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"g", "[", 
             RowBox[{"t", ",", "r"}], "]"}], ",", "t"}], "]"}], "/", "dd"}]}],
         "\[Equal]", " ", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"r", "^", "2"}], " ", "dd", " ", 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"f", "[", 
               RowBox[{"t", ",", "r"}], "]"}], ",", "r"}], "]"}]}], ",", 
           "r"}], "]"}], "-", 
         RowBox[{
          RowBox[{"dV", "[", 
           RowBox[{"t", ",", "r"}], "]"}], " ", 
          RowBox[{"r", "^", "2"}]}]}]}]}], "}"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"rmin", "=", "0.1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rmax", "=", "15"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r0", "=", "3.1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tmax", "=", "800"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], "=", 
     RowBox[{"Tanh", "[", 
      RowBox[{"3.1", 
       RowBox[{"(", 
        RowBox[{"r", "-", "r0"}], ")"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"h1", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], "=", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"h", "[", 
        RowBox[{"t", ",", "r"}], "]"}], ",", "t"}], "]"}]}], ";", " ", 
    RowBox[{"(*", " ", 
     RowBox[{"time", " ", "derivative", " ", "of", " ", 
      RowBox[{"h", "[", 
       RowBox[{"t", ",", "x"}], "]"}]}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"bc", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"0", ",", "r"}], "]"}], "\[Equal]", 
        RowBox[{"h", "[", 
         RowBox[{"0", ",", "r"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"g", "[", 
         RowBox[{"0", ",", "r"}], "]"}], "\[Equal]", 
        RowBox[{"h1", "[", 
         RowBox[{"0", ",", "r"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"t", ",", "rmin"}], "]"}], "\[Equal]", 
        RowBox[{"-", "1"}]}], ",", 
       RowBox[{
        RowBox[{"g", "[", 
         RowBox[{"t", ",", "rmin"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"t", ",", "rmax"}], "]"}], "\[Equal]", "1"}], ",", 
       RowBox[{
        RowBox[{"g", "[", 
         RowBox[{"t", ",", "rmax"}], "]"}], "\[Equal]", "0"}]}], "}"}]}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{"solution", "=", 
     RowBox[{"NDSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"pde", ",", "bc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"f", ",", "g"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "rmin", ",", "rmax"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
       RowBox[{"StartingStepSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", 
          RowBox[{"rmax", "/", "30"}]}], "}"}]}], ",", 
       RowBox[{"PrecisionGoal", "\[Rule]", "2"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"fsol0", "[", 
      RowBox[{"t_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{"t", ",", "r"}], "]"}], " ", "/.", " ", "solution"}]}], ";"}], 
   "\n", 
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"in", "[", "tt", "]"}], "=", 
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{"fsol0", "[", 
         RowBox[{"tt", ",", "r"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", "rmin", ",", "rmax"}], "}"}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "2"}], ",", "2"}], "}"}]}], ",", 
        RowBox[{"Frame", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Green", ",", "Thick", ",", "Dashed"}], "}"}]}]}], "]"}]}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"tt", ",", "0", ",", "tmax"}], "}"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Animate", "[", 
     RowBox[{
      RowBox[{"in", "[", "tt", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"tt", ",", "0", ",", "tmax", ",", "1"}], "}"}], ",", 
      RowBox[{"AnimationRunning", "\[Rule]", "False"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"in0", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"fsol0", "[", 
        RowBox[{"0", ",", "r"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "rmin", ",", "rmax"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "8"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Thick"}], "}"}]}], ",", 
       RowBox[{"PlotTheme", "->", "\"\<Scientific\>\""}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"in400", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"fsol0", "[", 
        RowBox[{"400", ",", "r"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "rmin", ",", "rmax"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "8"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Dashed"}], "}"}]}], 
       ",", 
       RowBox[{"PlotTheme", "->", "\"\<Scientific\>\""}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"in800", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"fsol0", "[", 
        RowBox[{"800", ",", "r"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "rmin", ",", "rmax"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "8"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Green", ",", "Thick", ",", "Dashed"}], "}"}]}], ",", 
       RowBox[{"PlotTheme", "->", "\"\<Scientific\>\""}]}], "]"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7321190605959387`*^9, 3.73211917398787*^9}, {
   3.7321192710863523`*^9, 3.732119272923603*^9}, {3.732119379027589*^9, 
   3.7321194261558075`*^9}, {3.7321194752842836`*^9, 
   3.7321194777096195`*^9}, {3.7321195472193575`*^9, 
   3.7321195966537094`*^9}, {3.7321196338187575`*^9, 3.732119829188079*^9}, {
   3.7321198644332314`*^9, 3.732119899305007*^9}, {3.732120310567562*^9, 
   3.7321203522646646`*^9}, {3.732120405599489*^9, 3.7321204119790573`*^9}, {
   3.732120494455752*^9, 3.7321204955584073`*^9}, {3.732120526608444*^9, 
   3.732120655222393*^9}, {3.7321213326730175`*^9, 3.7321213971031303`*^9}, {
   3.73212145026457*^9, 3.732121481296589*^9}, {3.7321215372315087`*^9, 
   3.7321215778362913`*^9}, 3.732121610594673*^9, 3.732121662387097*^9, {
   3.7321217435703945`*^9, 3.732121774505725*^9}, 3.7321218191692953`*^9, {
   3.732121872481229*^9, 3.7321218960622454`*^9}, {3.7321219771262493`*^9, 
   3.7321219792429843`*^9}, {3.7321220114917774`*^9, 3.732122018732851*^9}, {
   3.7325150717721014`*^9, 3.732515110148345*^9}, {3.7529321174358206`*^9, 
   3.7529321180688424`*^9}, {3.7529322148735733`*^9, 3.752932215325709*^9}, {
   3.7529323629521823`*^9, 3.752932409741891*^9}, {3.75293249280488*^9, 
   3.7529325043264337`*^9}, {3.7529327154355917`*^9, 3.7529327359442863`*^9}, 
   3.752934396498439*^9, {3.7529344547875085`*^9, 3.75293448339758*^9}, {
   3.752934854232464*^9, 3.7529348550774183`*^9}, {3.752987272843272*^9, 
   3.7529872978218465`*^9}, {3.7529873334693556`*^9, 3.752987334102709*^9}, {
   3.7543387128494797`*^9, 3.754338837597498*^9}, {3.75433899335111*^9, 
   3.7543389964941607`*^9}, {3.7543391023047943`*^9, 
   3.7543391028598194`*^9}, {3.754339164211977*^9, 3.7543391661019526`*^9}, 
   3.75433928240688*^9, 3.7543786461732044`*^9, 3.754379278341504*^9, 
   3.7544136704012365`*^9, {3.7544144568246455`*^9, 3.754414485890335*^9}, {
   3.7544145937169743`*^9, 3.7544145959663706`*^9}, {3.7544149868823767`*^9, 
   3.7544149872104406`*^9}, 3.7544249078487372`*^9, {3.7544249379197683`*^9, 
   3.7544249603988714`*^9}, {3.754431097549021*^9, 3.7544311039692907`*^9}, {
   3.754436342893217*^9, 3.7544363521879025`*^9}, 3.7550293370695577`*^9, 
   3.7550298192072926`*^9, {3.755124159559496*^9, 3.7551241612240896`*^9}, 
   3.756386591657612*^9, {3.7568999020861907`*^9, 3.75690004329353*^9}, {
   3.7569095529984226`*^9, 3.756909555021593*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"g", "[", "1", "]"}], "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"sol0", ",", "sol400", ",", "sol800"}], "}"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"4.8", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Thickness", "[", "0.005", "]"}], ",", "Dashed", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"4.8", ",", 
             RowBox[{"-", ".5"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", 
             RowBox[{"-", ".5"}]}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"Thickness", "[", "0.001", "]"}], ",", "Dashed", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"4.8", ",", 
             RowBox[{"-", "1"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", 
             RowBox[{"-", "1"}]}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Inset", "[", 
        RowBox[{"\"\<\!\(\*
StyleBox[\"t\",
FontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\"=\",
FontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\"0\",
FontColor->RGBColor[0, 0, 1]]\)\\n\!\(\*
StyleBox[\"t\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"=\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"400\",
FontColor->RGBColor[1, 0, 0]]\)\\n\!\(\*
StyleBox[\"t\",
FontColor->RGBColor[0, 1, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[0, 1, 0]]\)\!\(\*
StyleBox[\"=\",
FontColor->RGBColor[0, 1, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[0, 1, 0]]\)\!\(\*
StyleBox[\"800\",
FontColor->RGBColor[0, 1, 0]]\)\>\"", ",", 
         RowBox[{"{", 
          RowBox[{"6", ",", 
           RowBox[{"-", ".5"}]}], "}"}]}], "]"}], "}"}], "]"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Inset", "[", 
        RowBox[{"\"\<\!\(\*SubscriptBox[\(r\), \(0\)]\) = 3.3\>\"", ",", 
         RowBox[{"{", 
          RowBox[{"6", ",", "1.5"}], "}"}]}], "]"}], "}"}], "]"}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Large", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Italic"}], 
       "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Large"}], 
       "]"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g", "[", "2", "]"}], "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"in0", ",", "in400", ",", "in800"}], "}"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"4.8", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Thickness", "[", "0.005", "]"}], ",", "Dashed", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"4.8", ",", 
             RowBox[{"-", ".5"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", 
             RowBox[{"-", ".5"}]}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"Thickness", "[", "0.001", "]"}], ",", "Dashed", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"4.8", ",", 
             RowBox[{"-", "1"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", 
             RowBox[{"-", "1"}]}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Inset", "[", 
        RowBox[{"\"\<\!\(\*
StyleBox[\"t\",
FontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\"=\",
FontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\"0\",
FontColor->RGBColor[0, 0, 1]]\)\\n\!\(\*
StyleBox[\"t\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"=\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"400\",
FontColor->RGBColor[1, 0, 0]]\)\\n\!\(\*
StyleBox[\"t\",
FontColor->RGBColor[0, 1, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[0, 1, 0]]\)\!\(\*
StyleBox[\"=\",
FontColor->RGBColor[0, 1, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[0, 1, 0]]\)\!\(\*
StyleBox[\"800\",
FontColor->RGBColor[0, 1, 0]]\)\>\"", ",", 
         RowBox[{"{", 
          RowBox[{"6", ",", 
           RowBox[{"-", ".5"}]}], "}"}]}], "]"}], "}"}], "]"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Inset", "[", 
        RowBox[{"\"\<\!\(\*SubscriptBox[\(r\), \(0\)]\) = 3.1\>\"", ",", 
         RowBox[{"{", 
          RowBox[{"6", ",", "1.5"}], "}"}]}], "]"}], "}"}], "]"}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Large", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Italic"}], 
       "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Large"}], 
       "]"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g", "[", "3", "]"}], "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"out0", ",", "out100", ",", "out200"}], "}"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"4.8", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Thickness", "[", "0.005", "]"}], ",", "Dashed", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"4.8", ",", 
             RowBox[{"-", ".5"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", 
             RowBox[{"-", ".5"}]}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"Thickness", "[", "0.001", "]"}], ",", "Dashed", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"4.8", ",", 
             RowBox[{"-", "1"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", 
             RowBox[{"-", "1"}]}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Inset", "[", 
        RowBox[{"\"\<\!\(\*
StyleBox[\"t\",
FontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\"=\",
FontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\"0\",
FontColor->RGBColor[0, 0, 1]]\)\\n\!\(\*
StyleBox[\"t\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"=\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"100\",
FontColor->RGBColor[1, 0, 0]]\)\\n\!\(\*
StyleBox[\"t\",
FontColor->RGBColor[0, 1, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[0, 1, 0]]\)\!\(\*
StyleBox[\"=\",
FontColor->RGBColor[0, 1, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[0, 1, 0]]\)\!\(\*
StyleBox[\"200\",
FontColor->RGBColor[0, 1, 0]]\)\>\"", ",", 
         RowBox[{"{", 
          RowBox[{"6", ",", 
           RowBox[{"-", ".5"}]}], "}"}]}], "]"}], "}"}], "]"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Inset", "[", 
        RowBox[{"\"\<\!\(\*SubscriptBox[\(r\), \(0\)]\) = 3.5\>\"", ",", 
         RowBox[{"{", 
          RowBox[{"6", ",", "1.5"}], "}"}]}], "]"}], "}"}], "]"}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Large", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Italic"}], 
       "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Large"}], 
       "]"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pt1", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"g", "[", "i", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "3"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{"d1", "=", 
  RowBox[{"Panel", "[", 
   RowBox[{
    RowBox[{"plotGrid", "[", 
     RowBox[{"pt1", ",", "1363", ",", "363"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<\!\(\*
StyleBox[\"r\",
FontSize->24]\)\>\"", ",", 
      RowBox[{"Rotate", "[", 
       RowBox[{"\"\<\!\(\*
StyleBox[\"\[CapitalPhi]\",
FontSize->24]\)\!\(\*
StyleBox[\"(\",
FontSize->24]\)\!\(\*
StyleBox[\"r\",
FontSize->24]\)\!\(\*
StyleBox[\")\",
FontSize->24]\)\>\"", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->20,
         FontWeight->"Plain"], 
        RowBox[{"Pi", "/", "2"}]}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"Bottom", ",", "Left"}], "}"}], ",", 
    RowBox[{"Background", "\[Rule]", "White"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{"\"\<fig6.pdf\>\"", ",", "d1", ",", 
   RowBox[{"ImageResolution", "\[Rule]", "1000"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "Full"}]}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.7544147367358117`*^9, 3.7544147956932707`*^9}, {
   3.7544148319686007`*^9, 3.7544149064545107`*^9}, {3.7544150252796235`*^9, 
   3.7544150863250093`*^9}, {3.754415573516797*^9, 3.7544155776795483`*^9}, {
   3.754415607743471*^9, 3.7544156651914396`*^9}, {3.7544157698848925`*^9, 
   3.754415776664547*^9}, {3.754415873307823*^9, 3.754415888698*^9}, {
   3.7544159714287395`*^9, 3.754415976318122*^9}, {3.754416146590703*^9, 
   3.754416154401469*^9}, {3.754416238506747*^9, 3.7544162465361123`*^9}, {
   3.7544163896413484`*^9, 3.754416390938058*^9}, 3.7544166131687374`*^9, {
   3.754425096001748*^9, 3.754425104546672*^9}, {3.754429847329777*^9, 
   3.7544298573584805`*^9}, {3.754437037275526*^9, 3.7544370495773644`*^9}, {
   3.754437270990673*^9, 3.754437298337166*^9}, {3.754437333722128*^9, 
   3.7544373791585093`*^9}, {3.754438399432101*^9, 3.754438436944772*^9}, {
   3.754438616981239*^9, 3.754438623187613*^9}, {3.7544386935754194`*^9, 
   3.7544387339722075`*^9}, {3.754438802594267*^9, 3.754438828229021*^9}, {
   3.754520352120162*^9, 3.7545203922020063`*^9}, {3.754520424957428*^9, 
   3.754520471759264*^9}, {3.7548422927529497`*^9, 3.754842319456156*^9}, {
   3.7548425792748375`*^9, 3.7548426882338247`*^9}, {3.754842755600211*^9, 
   3.754842763212597*^9}, {3.754842812554013*^9, 3.754842829229435*^9}, {
   3.7563866259777417`*^9, 3.756386626993211*^9}, {3.7563867452463665`*^9, 
   3.7563867464493093`*^9}, {3.7563893151445847`*^9, 
   3.7563893516987195`*^9}, {3.7563912657299767`*^9, 
   3.7563912667017775`*^9}, {3.75673187277626*^9, 3.7567318797354116`*^9}, {
   3.756732035215311*^9, 3.756732163727008*^9}, {3.756732201328046*^9, 
   3.7567322340679693`*^9}, {3.7567336290577*^9, 3.756733630732792*^9}, {
   3.7567350541970468`*^9, 3.756735056548629*^9}, {3.756735174153046*^9, 
   3.7567351833871536`*^9}, {3.7567352301087437`*^9, 3.75673525664616*^9}, 
   3.7567353852348967`*^9, {3.7567368123748474`*^9, 3.7567368149940605`*^9}, {
   3.756737010069747*^9, 3.7567370788915854`*^9}, {3.756737446430437*^9, 
   3.756737470574807*^9}, {3.7567375666960144`*^9, 3.7567376195573177`*^9}, {
   3.7567376755598707`*^9, 3.7567377484384484`*^9}, {3.7567378809897327`*^9, 
   3.75673791616831*^9}, {3.7567379599316244`*^9, 3.756738055407282*^9}, {
   3.756738099801086*^9, 3.756738103459242*^9}, {3.756738165592331*^9, 
   3.756738186508396*^9}, {3.7567382599645257`*^9, 3.7567382622237635`*^9}, {
   3.7567383949610476`*^9, 3.7567383952770863`*^9}, {3.7567384869858456`*^9, 
   3.7567384946795177`*^9}, {3.7567385304788637`*^9, 
   3.7567385388106337`*^9}, {3.7567387425464272`*^9, 3.756738751839383*^9}, {
   3.7569096428773065`*^9, 3.756909643481325*^9}}],

Cell[BoxData[
 TemplateBox[{PanelBox[
    GraphicsBox[{{
       InsetBox[
        GraphicsBox[{{{{{}, {}, 
             TagBox[{
               Directive[
                Opacity[1.], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Thickness[Large]], 
               LineBox[CompressedData["
1:eJxF2nk0Vd8XAHAzmb33PCpJkpQylCjF2SIKKVNFhpLQXIoyFKEokiiJBkOl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                "]]}, 
              Annotation[#, 
               "Charting`Private`Tag$278617#1"]& ]}}, {}, {}}, {{{{}, {}, 
             TagBox[{
               Directive[
                Opacity[1.], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Thickness[0.01], 
                Dashing[{Small, Small}]], 
               LineBox[CompressedData["
1:eJwt13c8Ve8fAHB7j3uv66IkoySF9iA9H6WUVERlF2kXGkQDGfG1Eg1FaSCp
kFSyDjJCRqRkZmS7x97j9xz97h/3vt6vc+4zPp/P8zznKNg6HDjOxcHBsQt/
Ub+Mtifvnzz8jPodvNZacvQTHfJVCxbmp6ESrVptbewMK37PB/3p6GJ+D+di
7OO/HAxD9LKQ3aSsYdEcSVgefzqafTUHRe2KF+yfJYkCL01Vd1ouund/f3cG
9urnP6y0Y3NR/9UdPAHYfE0C+Z+/f0E+T/q/qmInmV4IS1YpQG9vQ/2VGZJY
cEW40DGrANFOfSrdi+1zL2ZS3aQQaSwLzVuCbV752+a1+1d0vUgnvnqaJLgN
tq2K/lmMLM5rvduGbX+m/pjtuRJ0i92gIo9d4+f8QJ7rGzop+OPK7BRJvMmP
n41UK0W/z1jeysQ+hCRK73mXo67f3NW62H8SDnGoilYg2epSJxVsVpbSAkHT
CpT2xiJfBNujPnNvYV8FmjYRtP41SRImMoMp22Uq0VZj3rFL2P+pEGWKdpXo
8IcPwZbYWRsDOzkTK5H5UNa7HdjLDynLZutWIcLz4X8y2LOh5l5bHH+gSMXP
jMIJklj7fNnjhek/0BfLofvvsU+9G/44yVuNtlm2+T7FrioP7k6NqEZrrAae
XcOOE/litL7wJ9rz/J3pBmyjWyvk1eV+I1OvGKn0cZJgSN11MnP4jTrOGae+
xq58OV3snf0bQVNKVCT2gaJSpzrbWmQlOrTeHdtExLHE72UdGntltVIP+1Bo
inPrqkZUERrQ1DRGEurlT058e9aMJt13ty/BDpYyptsWN6O2HSrhMtjsI/wZ
Y4PN6GCn2F4x7MR+B7qSbguKHzVMHxsliVUMnQzX9hbk9jYxoBh79cFW+rIV
bcgsz1ndAXtd3bLMmyntSLRuqClxhCQ2Vp1tP1HbjmidV7SjsTVLEsUNODqQ
b4t4YDg2St9oyzLoQM81Pkx5YOtH6PG/bu1A6VubFhth21icNPrB6EJd4d6e
/cMkYWf8+urnTV3IpOmdZhv2iT3kiyfWXWjV8z1Nv7DPaV0ZPRXfhV4s7+/J
wnZZ6Bsxo9ON7rF0+QKxg+ti/ypf6EHxTRq1Cth3qrrFRB70oE+3GxSZ2HdL
1DcNZPQgDb1cQz7sh+kf/dMFetH6dDvz7iGSiI4o0DB82ouarp+TfoedbtHu
6lreh042Hfy9CXu4j8HfzupHc4UWEuqDJDEm4+vkurwfdfsvuSyLPbljqlVk
Sz/at8X0jRA255PW7LU2/Uj969DT9gGSENuXcvXm635kyT4YGImtknCQLQsD
6GF24sBcP0msqC2yTDowgPybnvn1YKvzbS3ZfnwAZbEXsn9ir7dWjjvjP4Bq
69covsXeJjZmk/pjAJVp6C86jG1pH15tfHoQbTJTL3lKksSRRyK6HdcGkU3x
02k/bNsCj+SrwYPIlvV9wBH7tNzp28/eD6KdV04uAWznss27yZlBFBSQfbeO
TRIh6nUZ/qFDaNylcT0v9hf2ouic9GGkFjC9Sr6XJFSnXBQ6y4fRqYixQ9M9
+H7+H0/E2oYRXwVI1mBbyvs/tBAZQSe+Kh4Mxh42Gg0esRxBzS32n0e6SWLJ
hzLX5bMj6EqgyKeELpLwz1k+tp8xioLvqr/2wu4v9b7srDyKFF6zF5liZ7Rr
OnzZN4oCpoquzHXi9SD90s4qahTlEUEFetje19z334ExJNcseSmtnSS6fWu/
fTIZQ5He+xi3sA3vrtdvPDWGso2raUbYsm97dFfcGUPyYXJKf/+SRErjYc38
5jHk7CFnxYvdprNq6YTnOGph9MwqteL63RfwfPGDcdTrs+9SWwveH83bF+98
PY6K7eTlorGvX4pcEFY1jkQ7CoQUsJkxAjS1JRPITuRkO62ZJHYINE8ezZ9A
QXfknuQ34vt7vTZq1EwgNxMu2RvYKRXKl2e6J5Da54jUtdiKD8/1PaRNotgt
i+BJA0lwqI43VVpMIsu1LLfj9SSRtkc8X3dwEkn9Op6Y+5skBjWSOSV4p5B9
9udnp7GXMw9ubZaaQjKdFtfFscPrH326oT2FlrIaaw/XkITTeeX4j35TqPBX
flHtT7z+b2vfVlk8jbyeeHjEVOH97dKfktHV0+itOK13E3bUYS+BfN1pJCyy
ZqS4EtezfNFNmzPTSFfvSlH3d5LoSTK5/OjDNEpaW1glXUESsZVnzUQMZtCR
uppilW8k0fhR7H6t9QwSF02Ve1FCEpIR7yrjLsyggt3GMQuxvY+N7dnxYAZt
QOWq/MV4fxj23OrWMoM81ogbZhXifLEeKfW7zCIxd/VTBbkk8bFWycEoaBaJ
979zFMc2jHqblvxsFrEtFpQezMHtqeQYORXPIpbNQZNagiT6NDvdJxfOIeeD
CXtyMkjCb+5CicWqOXT3cmP0UDqOd94UK1N3Dq2ybO9TxD60VzzB/fwcGr8n
yHL5jM+LIxvqeYg5dDPVjjn1gSRMl2QvO1E1h5JbunQlsIc6d18q7JhDRHVv
+7IUnP/P6rw7BDgg58ypjTuTSWLXtm2R/Ks5oE+tfcQkAdePyeniQE8OyLxk
cisuhiRmNqg7ZgZyAHutvp5bNK43mSFJ9n0OeP8laoHBC1yPDddt9r/mgH0v
pmy/PSUJ6ZMh4/QfHDDun783OIIkju8++GRbIwd0NkbqrH5EEskrFuhe6uSA
m089osrCScKg/8XtH9McMLl/yebxeyRx0/WT8oOlnBA55yDOE0ISZRbXvxVq
cMK5thHvK8E43lt1Lo5v5oRo048BbYE43lwlmWb7OGEo3rQ0/j+8vgIaTWSv
cEIvGB1v88Tn1RNer2dfOUHePEis+xJJPA1/f+95JSfofWEmsi/g8yfUJu5F
PSdIOLa/7HbA6903szSmnxM428/VFp4liVxHJ+l4aS6QM7/lSj9GErSzSite
K3KBaqO/bMlRkrA+/l37zUouSOjabHPVGu+3ZmrHEoALqhvTfqaakcSa7X/f
Jp/igqXX7nC77cfPA9ph2e8vcsFNlRsyBQZ4fht1qlKuc0HvWf5xTn2SOLPy
8fjHEC5wuCa1yUSXJJ5LHtyensoFVl5N9pabSILemVfzRYAbgvqlL+Yswv23
XOzJY3CDft/EWpUF+HmlXn42X5YbtgvNGbqxcH6/X1f6uoobYKWWwpgY7j9t
nf03U25YvdmPnzbHJspSWjxKbXF7Ji+j2yfZhGxiSFjZOW5ImokwfDXKJlJf
9KZWeHCD00ff3v4+NtEfGM1dHccNmQMcvNfq2MRW3wOsn8ncsKvvJFf0TzYR
eJNj+a8M/H8Bxd8p39mEirPlvt8V3JDglBUfUMgmjh5hPmwY5wbdcCPm9Ds2
UbHaW719Fw+szCvRa/RgE3zSP+W1DvDA+PSWG3evsgnt2WUSIRY8UGN1f2TF
ZTYRX1wyttmeB9h8LpzTJ9iEzzGJnKAwHjDm6/ousodNZOw+/r4lkgc46+/4
ft7OxvvPp5iNsTzQe6QqSWcL7n/a3L85lQe6//Nd1LySTWjee268vpEHWpcv
8dIVYROO14Z3+HfwwJzV6QUfuNnES5udm5r6eYDHKXjx5GQfwVTvlv2Pmxe2
juQGzHT2EWTB6vZ6FV4QkD5pXprbR0SPZ7t4X+KFH/5Bo+Hn+ojaRsbZ39d5
Qflj+fryo30EPd/OSv0Wvu5TF1Zo0ke43RHYVhPOC3qRmpoTWn2Emaqh8Mos
XvD88fv2Jv4+IoT2fMajkBdy6RnGphO9RMHoEFldwQs2yj8j1Xt6iXVfHvxw
b+WFhGO1Z3aV9xJilk2PqwT44MtIrFTs3V5ix7bVISoMPvC4kJC3xKeXuK7i
5XljIR988/4vT8+pl+gaVj65TJ0PXnz88MDRpJfIC7Jfdc2YD35Wm1jxivUS
k5eyFSss+eDqIbnH1lM9xGpzhuTSE3zgO7DRVq+zh3ii/HGizIUP7HyO5GZk
9xCuxEyu4hM+cPT5K9hztodokfyyRScOW+bx7f+Mewj9c34fjyTzwQ6fzNH/
NHuIBTIS8ZEFfLDOR3j/c74eIu2iyh0WyQfuiiBedr+bUCzqE1o/wQecm9Ii
pF27Cf/F772NuflBzM/6fZx5N2H+TdslRIofVKZvGQcs7CYmlxofEQJ+2Ljl
qf5YWBdhe136t4o+P6jyvVUUduwiiisbDuiZ8MM2sc1Gu/Z0EY/cT+30PsUP
0q6GJavmOgnN3zfUZkP44cv9uJ9mlp3Ec43tL2Uj+MFY3IfvzJpOQuiWgIJW
DD/YPKhTrxXoJGrXhDFdPvPDgAVRU5zcQVwNjJsaaOaHi6wb1UaT7URLy3kn
Wi8/FNsZdXsUtRP6m9eS6qP8cGqRDO3Og3ZiQXtmy1khAfAZcqtEq9qJNFRV
9HeNAEiecZbZY/yXULwfvp1HWwAqJWtkR6X/Ev69VpmKegJgsdgMLBraCPOH
nUlHLARgkVvqw222bcTk4MyD314CEF+yazfTspWw3f2FPh4kALUcVcvkpFqJ
4ii/AFa4AIg32ll9qWghHhlIuBu/EYBfd9p8qlALoRmrcqL0hwCUZoo6EyLN
xDUz43U5SwXBQ8/46obseuJbREbQWg1BmIhqZQgw6wnZxqUdMZsEYbXZGw+d
43VElu34Q/89gvDszOtv5NxvguPc4znjC4JwfcdQ1J+en8Qtt47i9gxB6BHK
WpaoXkGEvrhmI2IiBA2XhG5Zq4QTrX/b0tyshMCj6kDzKW5PYp3KPubACSHY
afZiR/trF1T9Rr6w2lUI1nlMrzq46zmS/pi/MipKCGRL3x8+YJaKHn8VH1/d
IwQRf9ZXemwtQXF9L4IPewqDoX61tbJrHZrUGzV5FCAMHwSzu5W21eP3oF0L
G+4KQ5itDrlNsAGxD/W9tH0pDBf2JMpn3mlE67M35Jz/Jgwh0Q/m9PP/oFsL
/vNNqhaGtbtuEF8VmlHN5bq9Q43CkOf0ccWaG83o+nKPWpcBYRh+p9byaVUL
yg0tGvJiiUB5bz17iX8rYvYtTCtYLAJ2DeWH7jW0ouN69h6Cy0UgJEjT7YdG
GxKYZoje1hIBy8oO6fcVbWj/cUvlR0dF4GtQ+dUY7nb0lEjorT8tApF2Eb1b
97ajQRnO94svicDu725Foffa0f2yGBTjIwIpehI6toodqH4jaZoULwI8zuTd
Sys7kXqozuKh9yJwJ0L4e/LZTuTeG/Z3faYIHHNKW/3sVSdSfLbpYnq5CHiu
WOTrp9CFTgt5BhQMi8DHwfpDFaNdKM3uh5HgrAi4LE+a5FTpRiKEsrQBvyis
12570Hu4GyVdKon+LiMKRlqs5ZPvu9FoPTOrfqsofLfRSrOw6kG7Np70XrxL
FBLaS3U+e/egh3c+69saicJZVcFvffE9aMtO618dx0TBSvmceN9QDwp+mvRY
9bwo1OqkPspm4fegSS67886ikB3YWnx9Uy/yTHzZP+gnCsnb3dNzXHrRD8HJ
j+tDRcGJIcFp8qAXLbUzuOESIQpCHmlDzSm96Kv0gODsW1HgPX4ojaevF4l7
aioJVonC8MI1BsNGfSjUgOOCZIMoyN3bJll/pg+xpAqyFDrweOSzXXI9+5Ds
GyNzzSlR2PpS9U5sYh+KcpaK28krBtwFjUrJeX1IUadh5IC4GJgVOArW1PQh
lZ+n7pxVEoP9M9Z/g2f70Oun6k1X1MSAZ/XQsBqNjdTPDq/03igGGUWfbnEr
sNE6Do+vkXvEYK+W5TV7YKNPxTtYrw6KgYG7KCdjPxtp3hO2+3BEDOp8L+8R
sGIjUH0wV3pJDDyiwvUEr7DRl2HLvbU3xKBlYdeQghcb7SQUI9p9xSAhe/zQ
q2A2MjBJ2DAXIQaDPGN72NFsVC532Vs4Vgw+1FRl7klmowNdmyulksRAwitf
VoNgI1O3/POr8sTghuKRDfd+sVHdroD0LWVi8LNq4T25VjayljAS3F0jBjGL
jJZrsdnILq4+2qZXDJLG2u5qcpPIsXKoLpQpDn82PEt+qUKiocjPy6PkxMEz
M+qo/GoSOZ90v/JaRRxcUZWo7mYSXZ8WksjbIg7H7nFrPdhFormCiqMVO8Uh
J6OG69t+EnneuZ9QbygO3uWlZh8PkchPWVF/xE4cprYfT/hwjETCAx0POB3E
4dUM07f8NImC09/+FXUVh86IzTFxDiS6a7j5pnKQOGicjPj57CqJnl41TD38
QRySbv+n1RdEIqUdLD47QhyqjjgXbw0lUax4vbFjkTiYZbdFHL1PojfRJ0m/
BnFIX5PyQPYJiTQc1LTvdYjDd/nH59KekSh585D/swFxGHlq9FsjhkSWJ5FE
AxcNXBWrDOJek+iJgaJmKz8N3hqTUQkJJGpazWvTJUKDSiJRKewdiWynixNG
WDSw5bOrmf5Ioujmt9VTC2nAMc6Y8v5Mor8FIdOcCjRQi2StGUgn0ak7h/TF
VtDgYdWWXdeycfvnhG2yNGiw8ebKKr9cEv3Qy75iv44GoV16JiF5JILZ5TFl
2jTo/Rm5+ORXHP/fjelu22jQ5azE3FSM55cSVqmuR4PnMbeujJeQSOrszFyw
IQ1+h3oH6ZeTyGBnMgsdpEGk68XEhgqcD4WTaqQZDd7ZKy0+Vkki9q8K8/3H
aLAwiOOqXjWJCnSjP4g706BAZn/8rVoSTS82+0ZcpYFB6shYRh2J1kyJtjq4
4/lrnhLvrifR43dXaBV+NMj+yzyu2kSiy3J7zoZE0ECfkT64r5VE8RNzN+Ep
bi+pZW5nG4n+/EgJ74/G9/Mfqtv0F48vQK7AMIEG3oali4Q7cD7HB+TpOTQY
nT783rGbRKZVsRtz8mmw1X/ppq09uD4SLPZdKKYB/Z2dKX8viSbt8q99r8LW
2skd1Eeiyu/hP++00yCTln30dD+JBN7u7dPpoYFNiJqW1ACJtvpx8QySNBiI
5vfNwX619dzqAxM0+HXT77nwEIkaZRR2cc3SIAy0vV5jM0eqrZO56LAgKW1M
b5hE+hX+Trb8dDj1zparGdvjNQpkiNAh/bXFC+cREn28Nfw8l0YH7i+Ztxqw
e21efb4oSYf9gt/k1EZJpKhtXaG4gA41ekWPXLFNpSU6KuXoYHeDX+ULdvBQ
4YynEh0yRmYGBMdIlFd2nblWhQ4+L40U92Fr+LTrhK2mw6GF6cbl2HZHI0y3
b6DD7fP6USLjJHqkZegwpEmHfdWa7XrYfIOfI4116VA58rkzFbvROmhM4jAd
dnNZjvtOkGjl4NR3FUs6RO1tOZ6Bfc3nzBttGzoobY90JbGl3+jZnDxLh1e6
d6eMJkl0YIKzJM2dDoVRcbVCU3g9BjrGlHvj/p4kjW/AJhc3ubf9R4dJn0/W
ttiBOzPWid2lw/v73us+YReEOT+xiaND74CQhPk0ju+yvy7Ob+kg/FrE7yb2
sTRj44BkOuxK+OQdh83RvErgQwYdvIpUF41g77sc1VKUQ4dYB5O0BTO4/vjF
MhsL6IB34xaEranec0HgOx20bw9/9cP2yzEzWPQTt9/L6/kG+5fJV+U1dXSY
emTyuRxbuXMDp94fOpAVZacHsS9fi6mz+EuHVOnEIOYsib6IMT86dtPhaI2f
3AZsxnPPEB+SDj+Hx3mMsI+uHzjzaJgO1tfm+KyxE78e2ZE4QYdbt/e5nMGe
tShbnDdLh9Llh485YxuQWyZruBlQECJUeRO7W3JBIpcYA/KvFB55gL3k2A/p
Q4oMyHsctywL++LotqEzyxhQZn9XrhA75793pe4rGSAb2/erHNs6Kdjz1QYG
uHdIvvqDHT6zq3danwG8px8accyRqD3kUwHdkAG+Jto9/Njrlyg/Uz7IAI7A
krPi2JX63IcMjzDA2l5DTQ5bJDyTeHGJAYE+B/o1sT3WrAnTj2RAaWyXz0Xs
ciPJaL1nDDge/FjDFVvuwniKbiwDeIz+lrljZyRm/dyaxICJVRu7A7GFy591
aH1gwJqQtmNh2OZs7/FNaQxob3Ese4g9vnLPgrV5DFh7ZMwhFlvPQH3FqiIG
nCsJefEG+/5Z+ha1Mtz+DoOcZOy//sMGqlUMmMs/xk7BXhf/y2pZDQOO8cv1
fMT2KkqzX9LAgNGlJlWp1Pw6H7srtDCgKjw8Lg3bcZnds4W9DHCKWiufhU3s
1EuWHmDA0vt78wlssROqXyRHGZDiMGOZM0edH/1t4hwS0MZXeyoPu1PhhgoP
UwLWSVSJF2Mflb2f2KslAVsUB/f/wE7Ucs3uAgl43r7cvxp71tzye/sOCTAR
isv9iR35UHHoz34JsBm9ofEbu4aVuKH6mAQkCO2ZacBetiFUr/KUBISIF6o3
YTsfdDItPy8B+5Xdj/zBZt7Vulp0RQJsdU9ktWAb0r9mZgZIgC/HU/sO7KhV
r8vSQiQgbuLb/U5s9v7gpk/3JKD3zUhGF7a2w4X+lEcSsGjbjz/d2IHBJpzJ
URKwKmQRVy923duNjMRoCXh186Z8H7Zq6QKlN68kYNzltRYb27V3Zu2rBAmo
SdlmTGJ/FW7WjX2Px087nEpZakXewRepEmB3mFOmH/uE/ssTTzMlINx9hzNl
nv/O+z0qxPG6HL5sABv4JkuC6yTg5qrYs4NU/hYmflv/RwLQuRPJlAtW2ZXW
t0lANNeLMcp7LcrKVNkSoHVRwm2Iqqek598LOJiQIzV4YxjbyXzPr9mlTKh6
+9JyFDvVgaMmRpUJ9hfv3Kc87f2hxkCDCbXV6hWUPRMX1z7axIRcq4htY9gh
PMP1G/YwwbXw7pJx7PiEyBZ7RyZcXKlUP0HF84tRq6QTE+6m3KZPYq/+zdeW
4cqEgs2BOylfZqe3HXNjwqyi+DXKqdwX/gp5MeGgtlgi5Slp5fZ3vkywLnRr
obxVva7dNJAJQdcPSk5R49ke0jEXwgTee15bKOeb7uiMvccEjqpYY8oC9pOd
ex8xYd0r1TOUDbwSu4afMKGIlPKgXPlWpmdbHBNidxnGU/7Dxe5rTGPC737R
CcpK0i/YPgQTuIo+CE9T+VEzJVfmMcEhgUOOct/h3P6rpUwwG7mnQ3nyzf0h
1h8mNGzf7UNZ8jCa2McrCX9C1nPNYF9ckpBpLiQJn8/sZ1AuG5D1PCEuCcWL
tipSvhU4KeQmIwm8iU91KI/mfJB9qyYJ+kYP3SgfuL2kOXWNJDT1Xw2inGAZ
FpO3URJ8cjZGUj4x5qheryMJ8Y91PlP+uXIlCB+ShCD2zQHKayYf8UhZSIK9
qeoc5eBCwSLFo/j6zViRWezuuy5B6scloa9gWIbyTtsOI80zkrDhhMQyys81
DrF2OkiChQfHOsqz03m1RpclgUfJaQtl8+K1UVaukvDfmru6lD8+eH7stJsk
ZE14GVBmHKerOHlJwlqvnSaU7dd49Hr4ScKJLw0WlJVLrZzCQyVhYdmdM5Tv
c8n4FsZKwil9dIvyYLnvnqrXkjBs8yuQ8r7Ho+JNSZKg02sYRplv04/w0TRJ
+K3fF0XZ+fzt+KXlkqAx0/WJ8qEa3jKvMUkwHEtppZwcczn09rQkGMf97KQs
dqn1UAQnC7TPtfdRLhDNaUoWZsGva9/HKG/Yfn2geTELjt6pF5rDDqX1fOhb
wgJuHmdxyuwGs6sTy1ngIT8nQTnWZSM3fR0LGq78kaXMShhkwi4W5A80qlE+
cWFt0YgBC5LFk1ZT/rTu8o3XRizo3LZ6PWWB8ZTVNodY8CEVbaJsmj7yl2XB
goVSoEX54dfxj33nWRBxLmMn5e6AzWdfXGRBsNj13ZQ1919dbHaFBd3fNAwo
11ZP+eZ5sKCo87IRZdnWWdOIMBb4cLpZUD4Xi0SNwllwiqPDinLmaY8cvscs
sDux8yhl635O1YuxLNht3mVHOWqGZ2rXZ3x9Kv88ZUVp4cejjSwIvMbtRvnL
k0Be204WqFQX36Rst1TMvnSABXdMrvhQjllDR9E8UmBW4xlIeefn0JfiYlKw
aEXrbcrtiEm7JiUFQ9tXhFFW2SvVbKQqBR+8Lz+k/LUqfHfmWilgythEUj5t
viBZRVsKsjiZUZTjTy7ymtsvBVximtGU1TyVlr51kgJt7qi3lDlcpSVb3KUg
6NxkIuVKB1FeKX8pEJjalkzZ2WqszeOJFBiGPflIecGe5rzuZCn4evxTGuWs
TSXRJoU4GftDsyjbKn/wzqqTgqSba3Mp8zGj7FT6pcD//pN8yvvIi0umpaXh
JfePEsqD9ZY8J9Sk4free2WU7xfvbCvXkYbtriu/U26KWRD94ow0nIjrrJ6f
/032sSth0uAqL1dL2dEyV2lPhjTctGhsoJzxQPPB0TZpuBCl0jxfP1XJQs4i
MpAQTW+jbCK2wi1gnQyEuse1U366+8XAU0sZeFUz2Ul5U3ZYTckbGYh6PtBL
uWKDNzE6LQMLRpf0Uw5oeeHrH7oAHjg8Gp7PV/CX/XIqCyF1SeIYZSntBbf1
ixfCox0ck5Q7exzLnM/Jgt+3iCnKumZ8As3ciyDK+e30fP8FETp7IhZBeoLT
DGWhlNzdGRpy4GfIP0vZ6VmXkVqeHAwWX5736B297xuOL4ZiWtm8tXIOqMhz
y4M+P32Ocra0wt/t++TBNh/mvdORfHbyoTwk9B6f96HdZo9+dcvDzBqfeZ9U
/BKqt0UBNp5/PG/3dKdBzUAFmBVMmvcDE5UD6vUK8Ckra97DBpMJ2cqKsD6j
aN5GO74JG19QBONXlfPWJDZHr85VhFiP2nkrbn65hSahBFer/8zbkLGuMsha
CcTi/877Rk/2SeF4JWiP65p3svd9O5FhJbDv6Z13x6JzNqJbl4BCLDnvl5sa
HpoHL4EeucF/4zfeV/mycQkcVBue97nSRv67y5cCX/HIvC/qOWh7XF4KG1XG
5s21PSIhNX8pHDs9Pu+wrYWLB1jKsN1lYt6nHzKCv9oqg+/+yXmjYavpqARl
OCUwNW9Z8cHvk+PKUBj9zxPLb708uH0ZGKycnrdtwYfU6bBlYPr6n4tt/xa9
aFsGv6Vn5u1iva6mS0MFXl3456XmXu0a11TAhfhn61/nV+V+UwENwdn/x9/0
qonccvDa/c+/7gSsOGO/HFo9/lmqPKvePWs5JL3758iz9IB1gqqgUPvPigJ2
m7uMVcF09p/XKB9Q6o5WhWsKc/PerguiPSOq0An//DBn77C/zgqwtvhncqtF
nWrQCrC/9M8G198t3/drBXD898+vPvO7XFBYCZWR/3x1Y0+AYe5KaM795+pL
oo/Om6rBs+Z/fprSW7jhjRrsGPjnsyMlOFFqwDH/6Uf/A9EpLSE=
                "]]}, 
              Annotation[#, 
               "Charting`Private`Tag$278655#1"]& ]}}, {}, {}}, {{{{}, {}, 
             TagBox[{
               Directive[
                Opacity[1.], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 1, 0], 
                Thickness[Large], 
                Dashing[{Small, Small}]], 
               LineBox[CompressedData["
1:eJwt13c8ld8fAHCbzHuve6/RICIjpEH01fm0qEhCJZFIGiQqozTRQlKEkFFE
S1Iakke2RELDjuxxH3tl/M6jnz+u1/v1nPuccz6fzxl3scMJ80M8XFxcW/EH
9Z/RGvsq9t57NLGIy1uPu5/okK+SnV+QiQYmUr7TsbNsBX0j+j+gX5tTlvZw
9ROHfp4wCzHKRtpn08LisW0OxY/mnP2EXm+rEGZjF/rpq12k5aIFi3T5e2ZJ
QvtBta3Bo1w0i/hvP8UWaBIqeP8tD+X1XtmrjZ1m5R6arlKI/DRrMk1nSELW
S6TILbsQ8Xzgj5TBvnI3aVLTsgiVDSuVtU2ThHVljf3Ti8UoRuG0nC82r8mG
5Yk/PqMrZuZBJVMk4Xqs/qCDSykK2LTdLBb713XPCHmeL+iOy0ut09jPCp7M
xGiUoUK1hCWK2LuRZNld/68oTL9C5eZfkviduptLTawCddVOCB3DZmcrys6z
qkA22Ru/GmFfqv+4vaivAh00Thjhx7aUGXy9UaYSXQpfwxs0SRI3VIhyBcdK
tOft3uMnsLN1gzq5X1SiiOL5tyywVXcrL8jZVIUecZa1LsSeuWPt959bNQrr
idiUOUESKx8svT//QzX6HatQ9wD7yMvhN5P831HtQ3nuIOyqr8Hd76K/owcs
5S477BTRvJ2ri34ga/rSVDHshvkhzkzGT6S6y2vT5DhJMNRtrwzZ/EQvWR1G
Hdjnto69ezn4E4mX3r+ai73zqrq85qIa5PLAzOc81V4qzGPviRr0Olf/tTN2
ZfLUZ/+cGrT3kpixNbZ5SZlHnUMtCs4YvLwG21LUrfR6ch1qr1uWPD6G43nn
teef5Y2oOK87wx+brbjwi7hvI0qImZH0wv7x6spi/apG9LTpxL2j2Hu+7/4S
4tGEVgoPS+zAXhY0RZOz/Y085Sqd5mNrfo11+pLQjB63j/94O0oSwVIWdIfP
zUjXzzTqKTbHTjBrbLAZabpNHIzDftF/gq64qQVpzJzmu4a9nLE+60x7C7pr
v99yN7b2rj/0peqtSNRIQHt4hCRW1S39ePl1O2oSbtu9FFu3yrndqbYdGelv
aJfF1i99IWHC1YGuWK93EsdGH3Qd2CYdyL74tO7IMElsizYSfPqnA0kKXJfN
xbbfd3hnNaMLyTYcTtiH7Wjx9Oz7NV0o06U5yRTbyZh8GLu/CxnYmoWvx3ZZ
6zV65EkXKtQS01uK7T3/WvT0+m70cZ2K98AQnm/dozZl9x5E27fO7TL27apu
cdGIHmTx1XbiJHZYqeaagawe1LL2rZMj9r0PbwI+CPUiZTGdXkPsxOhCLbP4
XvS4WPeuMPaHfe1nznztQ0/a/UYCB0liuI8h2M7uR8fOqN4+NUASYzLXPM6o
9iNNv98Me+zJzX//iP7Xj3Ztf3jMFJs79k/OSvt+dGRWM0oFW9z09dnLT/vR
5d8bu2v7SUIldRdnAQygwjTPCh1s9doSmzTzAXRthY3bYmxNgXWlGw8NoGG2
QoMI9ur9yinHAgbQ6dF82d8kSWwQH7N/Vz2AjnHUmFexbVwjv1scHUT7+gyc
ijgkYRcluqnDZxBFOx7zS8V2KLyUfjZ4EDHmb3G4i3100dFbCa8G0YH5w/YO
2J7lelvJ6UHEGfIxn+gjiRDNuqyAO0NIcdWimzLYeZyFiZ8+DKPR9ONP5XpI
Qu2v9+LOr8NofszqrZPduL1gdax46zCK1Ofzqca2kQ+4t090BIllZoddwx7e
ORo8YjOCXEwsPTq7SGJJRvkZ1ZkR9HfXXq/QTpII+KQ6toMxijxfCYU6YfeX
+Z/2VB5FL1IPLdXDzmrXP5FnOoq2Cmqk13fg9SSd7GgbN4oS34qwF2L7+1zc
cRvGUH2F6sELbSTRfa32y1vLMZTPG/vaCNssbPW2xiNjaJPAWVsa9oLnPZvU
b4+h4Q8rnsW1ksTrxj36Bc1jaOXiDZMZf0iidf1ypQnfccRzb0acaMb1axr4
QC5iHDkGBSadw06zbpczfDqOFmXPP6KHfe5UjGxo1Tg6XavnmPabJJhJQjSN
JRNoJbmwJrSJJDYLNU8eKJhAzBjpcxoNuH2vn67WrwlEF9gb1VyP+69QPj3d
PYFY1otKw7AV7rn03aNNIkflq7vG60iCS228qXLfJArK0q5KqyWJTGOJgk2D
k0iP6Cju+0kSg1rp3JL8f1FScJVbCLYqc9e6Zqm/qDTJcUAbO7I+6u15g79o
g1ixs/sPkvA4rvzkzfW/qOmSTGlzNV7/twxuqchNoYocNz7/b3g/PfW7dFR7
CvVJWM5jYMft8RMq2DSFviubRcRW4HqWL7lsf2wK+SQ66rz6ShI9aZanozKm
0HJTroqSMpJ4VOm8V9RkGu1f0uP6qIQkGt+Ih9fun0ZHWJV/ZLBZ0S8rU9yn
kXEc3S2wGOfv4Jjx5ohpdHRz1LMjRXh/GPZdd6FlGhW8zK3jLsD5Ykcp9nvP
oOunHvAVEyTxplbxxM6bMyj52PNTgthmcc8z0xNm0N7VK0Q2ZeP3qXza6fF5
BokLVvm+ziKJPv3Oi5PzZ9EClKbq/p4krs+6l+5bPovWsFacjnyH453/l/1x
0yy65uvvk/UW78/bJVIvHp9Fa5umfScz8Plkp1PPR8yiSOPyZybpJGG1JGep
UxVub2cubfWSJIY6t54q6phFbwo83tul4fy/1+TfLMQFhueLdhxMJYktGzbE
CGpzgcfo4bt6T3D9WB79HOTLBYJa7uPiCSQxraPp9jGIC6yNbkdVxeF6kxli
ccK5YMPjuppbsbgeG87Z73jKBdIy1a490SQhfThknF7NBVfWLuiwCyeJQ1t3
xW5o5IIFHSvjOGEkka4uu+lUJxcYzPM45BVKEib9D29VT3FBsf2DN54hJHH5
zFvlCCVuGGSFuqoGkET5vnNfirS4QXbwa/yV6zje69afHNfjhp/LD03VXsXx
5in9uNeUG3T2mT5288PrK7DRcoEXN4RLvOvdeA6fd7H8fgnF3FBZFh3k5EIS
8ZGv7j6o5AZz3WiZ7cfw+XPHPuVhPTcs1gz0UTuC1/u1j2VJ/dww3VPVW3yQ
JHLdPKSfSPOASuphz2BrkqA5K6o/VeABiXzLR0pWJLH/0DeDZ8t4QE9y7e+X
u/B+u1fjYCrwgMiBouMpZiSxYmPb8/QjPOC0J6GuejO+fxiE5rw6yQPTBaUl
wxvw/HTXV70+xwNmDI9KQSCJY8vuj78J4YGuxEM7BfRJ4gFr18YP73jgNW2J
3X4NkqB35v/KE+KF8U09DwzouP+Wkz35DF4osJ1pPSGG70f18jMFC3jhWA0t
NmQezu+3c4rFy3mhUlGgK5ob95+5yvWLFS9IiK41L+/nEOWvWy6VOeDndYsr
j/RyiAUvQkLLXXgh8W7ZHk4Hh3j3sPddxSVeeBig4fWukUP0ByXyfk/hhcHs
agP9Ug6x7po5+0c6LzDqAgwWFXKIoMtcqj+zeIFf3ft3Zw6HUPG0Ma2p4IUp
vYlgrTcc4oAd817DOC/cbEgXcYvjEBXa/prtW/gg1NtEKd+ZQwhI/5Bfa84H
g11elSqHOITBzFLJkH188F7RRff4fg7x5HPpmJ4rH4wuX7zzjhmHuHJQ8tPN
UD5QfnC/dc1KDpG19dCrlhg++JD7OPiqOgfvP2+TdB/xATry9/NzRdz/lHVA
8zs++Nljd/OKJIfQv/vAYnUjHxgXOyisH+gj3HyGNwd08IGYT+rRDZ19RLK9
4Zqmfj7g0rD6w2rqI5ia3Qtu8PKD4IyhldaXPoIs1G6vV+GHmG8xHuKJfUTi
eI63/yl+0LqyKcxnax9R28hwrjnHD+rxpUdlDPoIeoGjreZVfogsNXL2XN5H
XLgttOFXJD+oOk6YH2H3EXvVzESWZfPDiVzvep6mXiKE9mD6UhE/OA+qHnav
6CUKR4fI7xX8ELE2Uj30Uy+xKi+i+uIffpgxdltskdhLiNs03a8SEoDwM3YV
rU69xOYN2iEqDAHgWaXJl7y7lzin4ud7fr4A3IzVCJln2Et0DSsfXqopAKt7
lDWSFHuJ/Juuy30sBOCJHm9JT00PMXkqR6HCRgD2rbRa7VTYQ2hbM1hKTgLA
eybD2zm9h4hVfjNR7i0AjdWqZ0Ru9BBniOlchVgBKIgz87RY3kO0sPL+W58i
ACsPyet9Z/cQ21yuv7FLF4C1u7Oep091E7Iykk9iCvF4vpltPlnYTWSeVLnN
JgVg+aVsvbid3YRCSZ/w6gkB0GkYe3hvRTcRIPfK34JXELrnW3AqGd2E9RcD
7xApQfA67l02VNFFTCpZ2AmDILxcf2AkYGMX4XBOukZlmyAc99YIl17URXyu
bDA3shSEbPklRPFYJxF18Yih/xFBuB7sUuGb0kno15zXmAkRhJJvmbtnZjqI
s0EpfweaBcF2+zPh4aB2oqXluAetVxDsIgN3CVm3E9v0VpKao4Jw2s0jekKp
nZBt/9jiLCwEsgqcZLvMNiITVZW0rRCCbRbqom+rWwmF8MiNfAZCUE2r6dWK
bCUCem0/KhgJQYjVxzv21q2E9b3ONLt9QpA+1m/ZVPuHmBycjqjxE4LNdT3l
DaUthMPWPPr4TSFYeKpHMsO/hfgcdz2QHSkExy+67Fb9r4WIMpG8aPFMCDLP
Wc1vfNRM6D9ScSqrFgJlkVO71jj/Jnz2Wqz6pDQP1iz09c+yqSO+RGfdXKk1
D2ILpQynn9USCxqVOpLWzIObNq2lryZriGyH8XsBxvNAcSDh6fXgXwSXy/1Z
C/d5ILyMmSV1/Dtx9ULH5/aseVDfLbuieXkZceehj72opTBw+dXdv+V0GP1p
a828YCsM8Zl259MX3kGrVEyZA074Ob+s7crH8ej7M/mi72eEIWXbQoEPv18g
6TcFy+LihIEmvrZ8jyKB7hdLjGv3CAPnhp69QGg5Sul7GLzHVwTSr/dccuiq
R5NGo5ZRgSLwS9yj7NjzBmT8YMv8hjARSBb+HOBzohFxdvclOySLgKljUcud
via0Okfn0/EvIlA89CNiz5FmdFX2xrW07yLwX6/rS8HcZvTrdN32oUYRsNzq
2B4t24LOqV6q9R4QgZXGdsIHi1tQ7p2SIT+2KARNzXdmslsRs29+ZqGcKChk
SSYHObWiQ0aul+apisIxVXf9bxmtSGiKIXZrrSioZV0TfmPWhnYcslGOOiAK
F2I2bXvt1Y7iidTe+qOicDuEsd0yux0NynC/kjslCoP0guMveTtQeHkSSroi
CtN/O2bvB3Sgel3SKu0Jft+pwp9LbnQizTvr5YZeiUJjzFnD2wWd6GJvaNvq
j6KQk+O66zVXF1JIWHPyw1dRiM0l3i481YWOCvsGFg6LQrrVpZiTqBtlOlbv
nDcjCmcdT7snuHYjUUJZ2kRQDK4fnLcyNKYbpZ0qTfwmIwaR0zP0suFuNFrP
zK5fJwaL8CV8NrwHbdE97C+3RQzkWIzJJ/h3zL3b77c57BSDUrMSUd3mHvSf
4f6fHQfFoHl1rw3v0l4UHJ92X+24GARIZO822dKLmiZ5HI97ikHo0diqa0d6
ke+L5P7B62JwenHcm86kXlQ9b/LN6jtiwDxhe04qrxcpOZqc944Wg/pAN1/j
pl5ULD0wb+a5GJjmzXz+wexDEr76ivOqxOC95XQtv0cfumPC5c5qwOOVszPO
CupDbKnC7MUdYmC70euGz8M+tODZTmv9v2KQMBSmr1Xeh+I8pVIM+cVhyI53
mXZLH1JY3zBiLiEOAq8E23aP9CGVH0duOyuKA/flF6MqMhz0NF6zyUtDHHyc
AqZbVDlI03l4mb+uOKhWeynV63HQKq5LxTHG4mBrtwqS93DQ28+b2Y93iUOz
Tnvz1UMcpH9XxDHDThy6f5yfzTnJQaAWMVt2ShzeZQT/sAvkoLxhm+2158WB
kXeSVhnOQYaEQnT7NXE4ziOf/z6Bg0wsU3Vmo8WhxPHxUMkbDvq66LS/yCNx
yNETFPfM4yDzLr1KqTRxeD1WLZT6lYOsLhQcX54vDhtdFPLK2zmobkvgh//K
xWHCiOj7OMBB+yV3ztv6Sxy+fjb6unmKgxxT6hPte8Vhx2PrdnUaidwqh+ru
MCVA7pyQ28OVJBqKea8at0gCDnjIFD9ZSyLPwxe9nqpIgG3E+bf2G0l0bkpY
Mv8/Cdg/k/uhcyeJZgsrDlQYSoBsV3LDRysS+d4OT603k4CBDyovTexIdF1Z
YduIowQ4tXT1xzuTSGSgI4L7hAToaT2ePuZOouAPz9vEzkiA3+eN02OeJAoz
07usfFMCfM1vXjl4mUTxZ83e7cmQAK2KXZ8yQ0mkuJkt4EhIgEmwdPGPCBI9
kqi3cCuRgL2WVTUF0SR6lniYvN4gARaSLrDkIYm0TmgY3O2QgC9nCoUiHpEo
XW8oIGFAAgx0LfL+PCaRzWEk2cBDA9+uA570NBLFmijo/xGkwdZonasj6SRq
0ua37xKlQc1t1bfvM0jkMPU5dYRNgzUslnZnJomO3N69TVydBrIaCfN58/H3
XUTss7VoYLjYQXasgETVRjlerqto8DZxXmRzEYlgRjWp3IAGHs3sPZdLcXxr
Gj9c2EADuWsntNaU4fG/Dq3UNKLBAa+b+5rKSSTlPD0bbEaDlc93BHNXksjE
MJ2NdtFg2HHb0PkqHO/FhzXIvTRwlhw50ldNIs7PCusdB2lwmit5IvkniQo3
JWZIeNIg+VbNqeh6Ek3J7f1CnMXve5pmltNAohV/xf6cuEiDTbKGfvWNJLr/
0otWcZ0G/CM7YqZ+k+j0ImPnkGga6Ommmre3kujJxOxliKeBVpd/ZkUbiX5X
v47sT6QBl1y/ZUY7Hl/gokKzVBpM7zi4wrUT52t8QJ7+iQZ56WvEk3pIZFX1
SPdTAQ1ujzx9crgX5z91n6n7Zxo4+cksU+4j0aRjgc+3KhrYVDU7R3BIVPkt
8sftdhqEPQuc3T5AIqHn2/vW99BA0LZ/ZhB73XUevkES5+eM6OOwQRI9Xuei
bT5BgyZDl6XlQyRqlFm8hWcGx2vQSNhpmETMke/703no0Pd5S8Yk9raKAA8H
QWyFBtWgERJdeoqCGKJ0GF9nflh2lERvrg4/yKXRYQvT8K4Pdq/94/cnWXSo
1DywpxBbwWB/hYIsHVIU+tXEx/D8pCU7KhfRoeL6lL4FdvBQ0bSvIh0+NhSl
3cXOLz/HXKlCh1yfX6++Y2tdaV8fqk2H8OVOY6bjJHI8EG21UYcOyXKBF65j
R601OzGkT4cN05byOdgCg+9jLDbR4f2rEC21CTy//TfHJPfQ4bBz8Y1e7GWD
f7+p2NBBoS81d+EkiXyuHHtmYE8H87wv77ZjSz8zsj/sTIfvO8bWPcE2n+Au
zbxIh/iJRG6rv3i9BbklffWnQ6e48KXL2KRc08XWG3QwXH7E8gl2kGHWKvEw
OrzqL9OYxC4M9Yy1T6GDe8rY/dApHN+lbd6ez+kgGn/42zvsg5kWFoHpdEh/
tzy8AZureblQRhYdmMmDtUrTJDI9HddS8okO0q79+7Zi3xcU/9hYSIcimaNu
Ltj6mj3uQt9w++cxxi+xr3/aa7LwBx0srqiJVmH/tCxWXlFHhwi+AYthbOVO
HW6j33TYfm1iIWsG169PUt2+NjpcqH/guBo7T5z5xq2bDtY6zxfvwmY88A25
QtLBVnrazxX7wOqBY1HDdHjoPJF4FvtFsd3mFxN0WBa9Zt1V7Jl95XL5M3TI
2HFv721sE/K/yV+8DPirfpkrBrubJfuCR5wBB5mazDTsJQerpXcrMMA3ZZ52
NfbJ0Q1Dx5Yy4Hvx7I167E83XpZdXMaAxDV5j1ux96cF+z7WYUDnoVsWw9iR
01t6p7YxoGQgqJo+S6L2kLeFdDMG3N8s2CONvXqJcoLyLgZID73olsOu3Ma7
28yOAfEW9mka2KKRH4mHpxhwK8c/ZAv2pRUrQrfFMKBrjWHsOeyvO1mJRgkM
mKmnNfpiL3Iff73pEfbKAOYN7KwX2T/WpTFATCvN/i62yNeEjrUZDHh5luUZ
jW3N8R9fk8mAAvm4cwnY48uMZVfmMyDlppb1c2wjE0315SUMOLFkQuMVdrgz
/T+NcgYMibn3vcNuCxg2UatigPyOfDITe9WTn7ZLfzFgydXw/Cxsv5JM1yUN
DBBdZ3k1m5pf5/2Li1sYEEH31snBdlvqmDC/lwEeWy8ezsMmDI3SpQdwPCv/
dudjizup5bFGGfDjAt2hcJY6H/pbJbgkQdv9rFYJdufi8yp8TEngrSx0KMc+
sCD8Re9aSTCbWfX9J/aLtWdyukASrC3sx35hz1jbfGvfLAmM2/Ola7Fj7ikM
/d4hCbo/l+2ux/7FfqHz/aAkjKVIl/zGXqpzx6jyiCQU0Wxam7E9d3lYfT0u
CSp00dkWbGbY2rMlXpIgEX1qRRu2Gb3448dASfj4mDe4Cztu+dPyzBBJuBIf
mNCNzdkR3PT2riRIbdv6qgfb4IR7/+soSTjwdiK3Fzso2JI7PU4STo5bVvRh
1z3XZbxIlAQrH/E6DrZamazis8eS0HbsewuJfaZ3euXjVEm4Lbarox+7WKR5
06NXkhAuKrdxAFtKPX/Xw3eSMBRaHUXZaVuyU/xHSYj7eIykzHfj+PWoIklw
dlIKGcQGgcnS4DpJ2NmXnDFE5W/+iy+rf0uCa827EcqFyx3L6lsloVbLedUw
9vZ95eVqHDwed41UytZpD74VcjFhex49fATbw9r454wSE2jqs1vGsN+d4PqV
pMaEMJeP5ylP+Wf8MtFiwoJ8g3TKvi/kaqPWMOH9rnuy49ghfMP1OsZM6GqZ
10X5SWpMi6sbE34Lf/aZpOKZt/MPy4MJbkXVzyhr1wi0Zp1hwtmacw2UT3M+
tB68wARDsfdif6n+ed3bhP2Y8F/cRQPKf6WV219eY8INw0IXyus069qtgpjw
HflGU/bdGNIxG8KEvs3bCMoFVps7H91lguKD6SrKQq6TndujmPA4Tr6Tsonf
i67hWCasdP3wl3Llc5meDSlMaPXyWjyF/ZuH09eYyYRTLeWHKStKP+RcIZig
ctfbm7KThhW5LJ8JD3Z9vU65b09u/9kyJpwIi0yhPPksfIj9mwmXv8i0UWbt
QROm/CwQERq0nMY+uST1o7UwC4YkDh6kXD6wwNdJggWy8i/cKV8NmhS+IMMC
z/8ab1Ie/ZSx4LkGC4KXvsqnbH5rSfO7FSxYrCNTSTnVJjQpX5cF9sl2TZSd
xtw069ezoEo9aILyj2XLQGQ3C3JJ02Uz2Csmo/ik9rFgOZG4hnJw0bwShQMs
qDtbtYlyd5j3Tc1DLDAMqjGjbOjQsVP/GAs4KMOG8gOt3WzDEyz4VOR4hPLM
VH7tztMs2C7QcYKy9eeVcbZnWNBqMN+L8puIBwePXmCB+FqlC5QZh+gqHn4s
eFIrcIWy64pLvZeus0Cv7VMgZeUyW4/IOyzInvgcSTmcR+Za0SMW3FO0fEl5
8Os146qnLIh/tuwtZdP7oxJNaSwI0+nOoiywpjpyNJMFe4uliyl7Hr/1ROkr
C2Ky7Roo7/7FX+43xoI/xhv5ZrHTk07fuTXFgnBmlRBl8VN/dkdzs4G5ykKM
cqHYp6Z0ETYE3lNiU9bZeG6gWY4NMqXSSynfofVk9C1hg8lBbXXKnIa9ZydU
2ZCZuFaL8iNvXV76Kjb81lLSpcxOHWTCFjYc2m5sSNnJfWXJiAkb+iLTt1J+
u+r0+ac72bDCtMKEstD4a2373WxIYvnvoGz1YaSNvY8Nkbbq5pTvFY+/6TvO
hriL5jaUuwP1nB+eZEOUa85+yvo7zsrt9WLDs1+K9pRrv/+9ln+JDTObvxyi
vODPjFV0KBsuCD91pezyCIntjGTD/WNf3Ch/PHrpk8B9Niy3aDtJeX8/t9rJ
R2zYFT7jSTlumu/vlvdsiLCsvkBZQVrk/mgjG/pdtG9SzosN4nfoZIOV6Y0Q
yo5K4q5lA2z4FVQSSjlpBR0l8klB5lf+KMqG7+8kS4hLwesRnvuU2xGT5iMl
BfJEdxxlle1SzTvVpMAwwyeJcnFV5NaPK6WgdpCeQvmotWy6ioEUfBM8/YTy
k8ML/WZ3SMHq6tlUyhq+ikrPPaTgOjJ+S7nyhBi/VIAUcKs6fqDsaTvWeilW
CqJ0DAjKssbN+d3pUqBjW5dLOXtNaaJlkRTEd24opOygnOGfXScFTYFeJZQF
mHGOKv1ScM393BfKpuTJJVPS0pCsNP6N8mC9DZ+ThjTsuO9UTTn8s2Hr1/XS
sKztxQ/KTUmyiQ+P4ecvGmrn5nuZc9ArVBqOhoU1UnazyVU0zpIGLz583GFn
RehHHGiVBlvr0ta5eqlKF/YUlQGhfJsOypbi6hcCV8mA5/2kLsrxWx8OxNvI
wAHu9B7Ka3JCf5U+k4HX5tok5Qodf2J0SgYIRb5ByoEtD68F3JGFHxJDI3P5
Cc7bsUhlPtR/eDJOWcpA9ta2z/PBujZjknJnj1u5p8sC4C+Sn6K8aa+AUDPv
QuiTZUzP9V8Yvd44eiEIp+TOWfh17tYsrUUgR984Q9kjoWunRv4i0Il8OOfR
20bfdA7JQen2wTmv/WSuIs8rDxv2aMxSzpFe3LbRVB72uO6Zs6EbmXD4njxY
annPeffWvVE/u+XB9lPonA8r5N0x+m8x1Cx4POeLHzwG9YMWg+SV93OOsFQx
16xfDE98Cuc8bDKZmqOsAK/UK+a8c/MXEQt3BRia92vO+oReonauApgNNc5Z
QS/5P5qkIoxfa52zGWNV5c39itBb0jnn8z05h0WeKILPjt45p/uHO4oOK+L7
HznnjoUu9mLrlkBz+MCck9c03LMOXgL384f+jd/CtDK5cQncDRuZs0tZo2CY
qhKYco3N+aTRCYNLp5VgcNX4nHk2Rqe+K1ACbrOJOYeuK5IbYCvDu3WTcz56
jxFc7KAMrlP/jIZtp+JSlWFv3N85L5AY/DY5rgxLVKfmPKF6NXnXxqVwK/6f
HQoz3k2FLgU/2vScPzu0lTxsXQo87v/svX/Vry4tFdhM/LOStV+7lo8K/OCd
mfP+n8eX535RgS+bZv4ff6uzlotU4dz5f/55O1D9mKsqbEv9Z6mv2fUXs1XB
tOafY5zpgavmqcHQ1D8rCDnqdVmoQcOC2TmvUDZX7E5Ug8q1/7xxE4j1jKiB
/55/vvdp+3DAenX44frP5Lp9dWo31UHU/59Nzr1UNf2pDuIR//z4vaC3++Jl
cC3ln8/q9gSa5S4D2c///P2UWNRxKw34r+2f41/3Fuk80wD+oX92HinFidMA
rrm/fvQ/xBwq6g==
                "]]}, 
              Annotation[#, "Charting`Private`Tag$278693#1"]& ]}}, {}, {}}, {
           Thickness[Large], 
           RGBColor[0, 0, 1], 
           LineBox[{{4.8, 0}, {5, 0}}]}, {
           RGBColor[1, 0, 0], 
           Thickness[0.005], 
           Dashing[{Small, Small}], 
           LineBox[{{4.8, -0.5}, {5, -0.5}}]}, {
           RGBColor[0, 1, 0], 
           Thickness[0.001], 
           Dashing[{Small, Small}], 
           LineBox[{{4.8, -1}, {5, -1}}]}, {
           TagBox[
            InsetBox[
            "\!\(\*\nStyleBox[\"t\",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*\n\
StyleBox[\" \",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*\nStyleBox[\"=\",\n\
FontColor->RGBColor[0, 0, 1]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0, 0, 1]]\)\!\(\*\nStyleBox[\"0\",\n\
FontColor->RGBColor[0, 0, 1]]\)\n\!\(\*\nStyleBox[\"t\",\n\
FontColor->RGBColor[1, 0, 0]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[1, 0, 0]]\)\!\(\*\nStyleBox[\"=\",\n\
FontColor->RGBColor[1, 0, 0]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[1, 0, 0]]\)\!\(\*\nStyleBox[\"400\",\n\
FontColor->RGBColor[1, 0, 0]]\)\n\!\(\*\nStyleBox[\"t\",\n\
FontColor->RGBColor[0, 1, 0]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0, 1, 0]]\)\!\(\*\nStyleBox[\"=\",\n\
FontColor->RGBColor[0, 1, 0]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0, 1, 0]]\)\!\(\*\nStyleBox[\"800\",\n\
FontColor->RGBColor[0, 1, 0]]\)", {6, -0.5}], "InsetString"]}, {
           TagBox[
            InsetBox["\!\(\*SubscriptBox[\(r\), \(0\)]\) = 3.3", {6, 1.5}], 
            "InsetString"]}}, {
         ImagePadding -> {{40, 0}, {40, 40}}, AspectRatio -> Full, 
          BaseStyle -> {Large, FontFamily -> "Times", Italic}, LabelStyle -> 
          Directive[
            GrayLevel[0], FontFamily -> "Times", Large], DisplayFunction -> 
          Identity, Ticks -> {Automatic, Automatic}, AxesOrigin -> {0, 0}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLines -> {{0}, {0}}, DisplayFunction -> Identity, 
          PlotRangePadding -> {{0, 0}, {0, 0}}, PlotRangeClipping -> True, 
          ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
          NCache[GoldenRatio^(-1), 0.6180339887498948], 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> Automatic,
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLines -> {{0}, {0}}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], LabelStyle -> {FontFamily -> "Times"}, 
          Method -> {
           "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
            AbsolutePointSize[6], "ScalingFunctions" -> None, 
            "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
                 Part[#, 1]], 
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
                 Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
                 Part[#, 1]], 
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
                 Part[#, 2]]}& )}}, PlotRange -> {{0, 8}, {-2, 2}}, 
          PlotRangeClipping -> True, 
          PlotRangePadding -> {{Automatic, Automatic}, {
            Automatic, Automatic}}, Ticks -> {Automatic, Automatic}}], {0, 
        0}, {Left, Bottom}, 
        NCache[{
          Rational[1403, 3], 363}, {467.6666666666667, 363}]]}, {
       InsetBox[
        GraphicsBox[{{{{{}, {}, 
             TagBox[{
               Directive[
                Opacity[1.], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Thickness[Large]], 
               LineBox[CompressedData["
1:eJxF2nc4le8bAHB7j+NwDkUISSUhLY3n1lJIdhkNpaisEGVEKIoWJaNppiFJ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                "]]}, 
              Annotation[#, 
               "Charting`Private`Tag$317056#1"]& ]}}, {}, {}}, {{{{}, {}, 
             TagBox[{
               Directive[
                Opacity[1.], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Thickness[0.01], 
                Dashing[{Small, Small}]], 
               LineBox[CompressedData["
1:eJwd1Xc8VW8YAHDK3te49h4hlBSldB4kDYpSFA3SUJlFSBRaSKisouymJBTi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                "]]}, 
              Annotation[#, 
               "Charting`Private`Tag$317094#1"]& ]}}, {}, {}}, {{{{}, {}, 
             TagBox[{
               Directive[
                Opacity[1.], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 1, 0], 
                Thickness[Large], 
                Dashing[{Small, Small}]], 
               LineBox[CompressedData["
1:eJwd13c8ld8fAHAjXPta1+basorKKDofIxqyZTasVGZEkUr4NpCMIhlZqSQk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                "]]}, 
              Annotation[#, "Charting`Private`Tag$317132#1"]& ]}}, {}, {}}, {
           Thickness[Large], 
           RGBColor[0, 0, 1], 
           LineBox[{{4.8, 0}, {5, 0}}]}, {
           RGBColor[1, 0, 0], 
           Thickness[0.005], 
           Dashing[{Small, Small}], 
           LineBox[{{4.8, -0.5}, {5, -0.5}}]}, {
           RGBColor[0, 1, 0], 
           Thickness[0.001], 
           Dashing[{Small, Small}], 
           LineBox[{{4.8, -1}, {5, -1}}]}, {
           TagBox[
            InsetBox[
            "\!\(\*\nStyleBox[\"t\",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*\n\
StyleBox[\" \",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*\nStyleBox[\"=\",\n\
FontColor->RGBColor[0, 0, 1]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0, 0, 1]]\)\!\(\*\nStyleBox[\"0\",\n\
FontColor->RGBColor[0, 0, 1]]\)\n\!\(\*\nStyleBox[\"t\",\n\
FontColor->RGBColor[1, 0, 0]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[1, 0, 0]]\)\!\(\*\nStyleBox[\"=\",\n\
FontColor->RGBColor[1, 0, 0]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[1, 0, 0]]\)\!\(\*\nStyleBox[\"400\",\n\
FontColor->RGBColor[1, 0, 0]]\)\n\!\(\*\nStyleBox[\"t\",\n\
FontColor->RGBColor[0, 1, 0]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0, 1, 0]]\)\!\(\*\nStyleBox[\"=\",\n\
FontColor->RGBColor[0, 1, 0]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0, 1, 0]]\)\!\(\*\nStyleBox[\"800\",\n\
FontColor->RGBColor[0, 1, 0]]\)", {6, -0.5}], "InsetString"]}, {
           TagBox[
            InsetBox["\!\(\*SubscriptBox[\(r\), \(0\)]\) = 3.1", {6, 1.5}], 
            "InsetString"]}}, {
         ImagePadding -> {{0, 0}, {40, 40}}, AspectRatio -> Full, 
          BaseStyle -> {Large, FontFamily -> "Times", Italic}, LabelStyle -> 
          Directive[
            GrayLevel[0], FontFamily -> "Times", Large], DisplayFunction -> 
          Identity, Ticks -> {Automatic, Automatic}, AxesOrigin -> {0, 0}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLines -> {{0}, {0}}, DisplayFunction -> Identity, 
          PlotRangePadding -> {{0, 0}, {0, 0}}, PlotRangeClipping -> True, 
          ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
          NCache[GoldenRatio^(-1), 0.6180339887498948], 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> Automatic,
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLines -> {{0}, {0}}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], LabelStyle -> {FontFamily -> "Times"}, 
          Method -> {
           "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
            AbsolutePointSize[6], "ScalingFunctions" -> None, 
            "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
                 Part[#, 1]], 
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
                 Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
                 Part[#, 1]], 
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
                 Part[#, 2]]}& )}}, PlotRange -> {{0, 8}, {-2, 2}}, 
          PlotRangeClipping -> True, 
          PlotRangePadding -> {{Automatic, Automatic}, {
            Automatic, Automatic}}, Ticks -> {Automatic, Automatic}}], 
        NCache[{
          Rational[1403, 3], 0}, {467.6666666666667, 0}], {Left, Bottom}, 
        NCache[{
          Rational[1283, 3], 363}, {427.6666666666667, 363}]]}, {
       InsetBox[
        GraphicsBox[{{{{{}, {}, 
             TagBox[{
               Directive[
                Opacity[1.], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Thickness[Large]], 
               LineBox[CompressedData["
1:eJxF2nk4Vd33AHDzPHMvSkiSJqFBUe0lKqEiKoRCoYRUCCWhSSJUQiSkkpCk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                "]]}, 
              Annotation[#, 
               "Charting`Private`Tag$286431#1"]& ]}}, {}, {}}, {{{{}, {}, 
             TagBox[{
               Directive[
                Opacity[1.], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Thickness[0.01], 
                Dashing[{Small, Small}]], 
               LineBox[CompressedData["
1:eJwl13c8Ve8fAHB7r3sv1yyyQmYJKT0fJRo2LdE3RVpCWqhQKkmyGkaoqFAU
JRoOmZGdkZm970H2/J3jd/+49/V+nXGfz3g+5951x92snVmYmJi8iDfyk9oT
lxkXlYNOuj/7KLqMY/0ydRKSRV+Q6jJzh/kSjn1z4Lz5ZOwr4mu/fz9oEcec
G90sQ01yEfsLIUHBBRyzd06YzvPORyo3/U33zuJY8S19FV+hH2jP60fUlzM4
pvXit4PBqx8oYfxKyso0jnF0cBXl1BSg+pDZxYIpHHt/yCMiQ6kYrdvfMnf5
H45JXOEtcc8tRqY3LcVHJnDs9qOkeXXbEuQi5XnOibBd7R/HVN9S9OJGx4mj
4zjGarpDM7GhDFW0LyVcwnHs/JnWE8fPlSM2/xfOLISbAi8/kWH5hTbXsdaE
MXDsbVHKcqxaBbLzc7bLHsWxA4hW8SigCr3OOO8tO4Jjf9MOMKnwV6Nfp+Y/
/RjGMXqunAT3oWo0GeEj6UzYr/W7WcloNZISDVF5P4RjtuITH3eK16IHaSY1
DoM4dk8Jq5R1qkUjN9bX8RPO1Q0eYE6vRTzhh8KwARxTPqAolWdUhxL61gkp
EV4Ot7u1zf03Unv9NJ+3H8c2vVj/TPLrbyS4+at5aR+OnfowmTXPXo/Kj7/W
u0O4ripkKDumHr36T2iGnfAbvgKrzSUN6JLwz2laL45Z3dkgo772D1r5Pnfa
sRvHqKKRlw67/UEYnlmvQrj29WJZQN4fNNUzoTjVhWPWPysutRxvRg9sQ62C
CdvyuZcHvm5B/QYop6CTyE/4x8vdmu2INbxXyuIvjqlXxZ389bwTBXXnbk1q
w7EQURvK8bJO5PanrtiHMOM/zm8zE53og3neQWvC6WNuFDmjLvTXJtt7pRXH
NKmG37z6utCFDMbhw4S19ndT1m/oQXtHxx5wteCYdsv67/4f+1D0b9G5HU04
plt3tu9kcx+6kTzwRJSwfnm6oClTPzqjnTgz3Ihj6KvucbppP0q9wDcdQXhv
jAlnanc/cvLJrP/bgGOOR1ysflMHEcfYNi63ehxzskn1ztEbRBpa2TeA8Ml9
+Mu4o4Non6bxawrhc1uvTJ9KGURWu4W4Mn/j2FXJuzFLhkNoa9av5vE6It6W
V72KHsNIbY2W3dFaHAurGxLgezKMFuWZNVQIR5ar641/G0bqiuMxUzU4FvU1
K+gr1wjacyNV9z7hxJhiDcuEEZTZkLD7QzWOfT3S5+VVNYoGbbns+ytxbHKU
ytlHH0OmXrZ0vAzHZsTvXvJSHkP8zyM7UgnP71ro5ts2hmyyogVOEWaO687b
5DiGkuJfP27/iWMC5h+9/VPHkLvVOYnCUhxTStvPkIJx1KV0YKtbMY5taP5p
/956HN3oYPZeR1idY3v5TudxpPk9crm2CMc2H1V8cyZoHCnZhFdvIrxDYMYx
+zdx/vLGQyMFxH4//7Te5vQE6ln3rE0nH8f+i+Yz6veZQKyndI615uHY8WK/
DO+QCXTCMJDZn/DptacfPs+cQD6zZo9KMBy7XLllD740gZ7MTX/Yk4tjoeot
34LC/yHpnznrpL/iWAFjTWL+10lU7ifyeSwTx1QWrq4bqJpEGn0LvacIh3L+
jhPomUROYT9COzKI9cgERR3hm0IXLt/ZVfqByJ/VdMiU/RTyYdx7cicdx+Q/
VXopL0+hzzlB3R9ScCwoX3nGgjqNtDo7NgsSHqsIuHhZcRrpPdz16kwyMe/6
9N0KzKfRI6myIsk3xH4Qe+3kED+NOLh2651MwrEAH1+LMJhBBzvt0aN4HBu6
2/zrs+0Mmho996sqDscsIzfvbT81g4wrMsM5CUu9GzbaEDaDWj5b9LrF4tjH
9oP6RZ0zKLViyw/ZKBzrMdRUmLs5i2qskjHucKJ/ze+/kH4yi17KTrJLhBHz
0a5P2jh1Fg3VJDmsD8Wxa56xEhF1s+g177jIlhAcE07iElKTn0P6BpmuukE4
tourc/5Y0Rw6ofaG+ZE/cf7ILV2Npjm0hm+Nc4Af8f3ViheXhuZQO+90kLsv
jslGnRuNEppHcSNfR7ZfxzEmldmO2iPzKFIt62XGVRz7sk+wyGhiHolfyUzr
O49jExoZzDT2BaR359qap67EPBPev71TdAEtJYt77jqHY09boz9fN1hALxtP
Pos4jWOXXBVTsgIX0AcFHZfFE8T+f2jwUEl6EVEXvG5MHCTmm+ff8mmtRbRL
4dGZIwdwLP7gLa4io0WkGBUImC3RzzI//R3PLKIr30wdrljh2PB724vRnxaR
WRau9Hovjr2qPXuYz3QJeac+nBrfimPtWQKPm48uob/1UyErW3BMJOZD7RuP
JST3D3vDoUfU78TMvl1PllAEh8A4kzYxHyZvbr/RtYTOah78/mIDUS96tNzY
1WVkzV0c7ieOY1nNcm5WD5bRKbfX1m10or7x775kPF9GNtf3casJE/dTyre6
VLaMqmseUNIEcGxUf8B3XnIF+QQXKm9kxbHAFY/yI5oryEHj6bwuE5HvwgX6
d6MVdKJ/fejGJQZ2wEwwzdd1BaV4BJuxzzCw3P90WtmwFUTNefNKcoiBHZLP
W3+ybgXlt7fp/+hjYP8G9niW9K+gpcbJuSPdDEw4R519FxcT9ARfpJxqZWC7
d+yI5dRiAk/960stFQzsve3psuCbTLC0gbp19h0DW9JRd/8ezAQ7TrPRM5MZ
2F7xfyKMx0zwLfxfnn0SA+tpu+ZokcoE99yltXxiGZiYS+gs5TcT2I7HZzTf
Y2DOe/bH7Whngl+jv61ZbjOwjA0SRp4DTODi+LhLxI+BmY69fPh7kQk+35bX
W7nEwPy9Pis+UWCGzbb2ae+OMbDKI9d+lWgwgy0e+E/iCAOT2m54YXYLM7CZ
Swy472dgWSzl3w+bM0OkLKdW/R4GNnS/3VbqCjO864savKDFwKzj2G89L2WG
gy+mxh8vjGIJTzMfvahlhv/o9Wu9JkcxRrjjm5etzLBLdlbCYHQUC7r7vSJp
jBl+Om3ZdKp9FPvhfkksRYwF8pzjePSxUUzorNyGVFkWELC5zRD/PIodda4x
eKvKAiXPB9Ma0kax+cNqJ9KABdi2eXD3PBvFNu7sfZdxigXEKus36XuPYn4G
EXmZF1iA07xNdtR9FKvUNaz7eI0FjrkyiVxxGcXOqD6bzQplgW12H8r5bEex
FyL7d37NZgGrG5GSShtGMcpAYVMBFyt8bngVz1czgh3tujBcSGWFtPZj9xmF
I9jbVpnlIilWeHu2tP1J9gi2u+aaXKkmK9w7k9SwNX4E8/uiff7XIVaQ2FJd
mnR6BKv82OVXcZwVpHtDq+KPjGBS6aERledYYb7n2soBsxEs++VIdrUfK2xO
rD01ozGCjQUnsta/YQXhuS82f8aHse13rekNGazwycXz46POYSzYn0m58Rsr
DCU+G2atGcaULtub/6lmhYf+c9142jB27D/hqLZZVrB49J9Ry8lhrForQL1v
Nxv4nC5JjC0awjjEGmS2WrPBnRG+azofhjCD5fW00CNsIGD7luNy7BCWUlY+
s+U8G4gZaIT89RjCbp+g5T+IYIOgX1S1rWJD2Lc9zpldsWwgvCHMu5lpiJg/
n5N0X7GB0/WMv7TBQezYol1QZzYb9LspWM/mDGL6j17YbG5ng+uT3aWpBwcx
d5/JXUH9bBCYIWY/ZzCIvXY01usYY4M9a27qVMkNYsLqQ1L3WNlhQFdDhocx
gOHFWn2tSuwQ+i7note1ASxxNu9qgCc7aD/+Gark2481t1PP/rnGDt3Zc1at
9v0YpcjJQf0OO/z6PvNiYks/diOMa0fTU3bY7SDIvX2iDzusYsmrmssOh4PT
f1OP9GGhQi+W/ErYgV5p3vFsUx9WPP0Pr69mB809xZbevH2YdsGT377d7FD9
9q6zdE4vJmDf8ayOi4PI14pxD28vtmuHVqgSlQOOFR6CwvYe7JrSrZvXJTkg
RCr2Ud/7HmxwUtFlvToHyJ/Z/3TYugcrfHBe08eGA764j94pe9CNeWFLP2Tj
OOCrX6CEemsn1iVSsM3wDQdkndpzRf9ZJ7b3XGDWfxkcsHyziMfKoROTEKel
xBZzwJEwsdPRzX+xLxeUwug4B3zkfRkoH9GBzSvY/McDnNDlvOuryEQzdvya
2B+lvZzgLuH8YO/+Zqysts3axJYTPOtT7J9k/cGifU8ZB5ziBFwq1cLfswnT
/3NdbTmUEzI0nsq3N9Rj3sFvFsY7OSHCZ9P+QuNqrKvL9ZLQCCfwjvak9IlX
YXu3bMLVpzmBNtmxZ+xFBSbR973rLA8X2Kvc8NdNLcO+oLqfvRu5IPp1Ogf/
40JsfmLpyZ9bXNB2eV44+sc7zOewjXa+AjeIh81s0rQuRL9ivj3YpMENPhJj
/n8nipBUu0J/kh43PEv1HJwML0G5x2ejgvZxg31941RBdRliOvdsxcaDGzj3
sAekxFejOzf6y/q+cUOfec90UW8DasyzlD9czA0XeC1Z7yQ3IiXWL9fLq7jB
2Hed0NTZJvTzbrDm+y5u+HwohjNx5A/iC9N67MXFA2aJstmpLa0o/KWPI58t
D/xKFaOco3Wi7t6eLzcceODQEUap8IlOpK1kLjx+kgc+XaNsLPnQierfypTU
e/HA2pwRzh2mXUgsq0g1Pp4H+r74cDpf6kanZtXvUJJ54AhF9IPG926Uo/+0
41YGD2y3fLAyy9qD7LAz4aeKeKBSx3pTQEgPelYqOKs1zAPP/CLTzj7pRQwe
L6vESR5gqTh2TryxF20360qhL/PAvQ+hI/kifehvzUeHBSFe+CVsY8Aa2odk
Ww4XFOrwwoV/7b2mV/vRm9GXIQdv8sKBnR3vvcQG0bzJtG30fV7wVdaQkjAh
fne/2C3ZFskLaV4pyz8vDiLGgdHXx1/zwsGYzY8cKgbR5jydfNdfvFCSW7Jw
3XMI3ZG4d/d9PS8IJRo9KIgeQk0XW8z+tfOCpngEUsgfQteU/ZqvjvMC7WqN
0mWeYfQj/Oe/W3Q+aJvUP68WPoyERyW/FEvzAePH3XG2jGHkbHLej1uZD+ae
H6fz1QwjrkUq/8OtfHDaw9bxI98IsnC2V4w+xgcvn10+/N17BCVgaSOtp/mA
1h4/6Bg5gibEmTOlPfkgLHf4qtm7EfS4Mgkl3eYDHsuHTBxtI6hVFz/0PoUP
xHoqju3XHkXq4YbS/zL5wPnexv1Bu0eR70hE7+bvfDASsKVD2n4UyT7Xu/C1
ig/ePLWY8PIfRRcXgvSWm/iA64eewq6IUVS8v20Zuvhgg74v3EgcRad5bt4v
nuQDc0b5G5OiUfTF6bcV9zIf6P2kZLf/HkV8mKKYKSc/9HNs3TTePYree5Yn
1ojzQwa7IfNjJgaabhXObd3OD7NL8YLbtRlot65LgPRufqDpOt8RBAaKCsvZ
e9yKHxac+m5f2cdA24yPNvaf4AdpG69gMUcGupn+emwikB8ctiV3LdxloN/c
81mbw/nBr2Jzc3soAyk4mV6/GsMPWtGFhReiGKhUbJx7+R1xnIfN4EsyAwne
1JfjruOH8Wb/jy4VDBRuyuQh0sYPH2VtmJ43MBBdtDh3XT8/3FVK0I7oYCCp
t1Z2+gv8sF/O1yJljIHiL4u+MWYXgNkf6qJ1swwka9g2ZS0oALtkft/7xoQj
pYZTYWflBCAyvPRbkyCOUhPUO66oCUAwzxluQVEcqZ+dVA3QFQDH9z3i/Gtx
pM3kVxq7TwAMROfVXTbgCFSerFR4CoCOqPEzbCeOCibtzZqvC4Dhq/GCY3tw
ZIzJxvTdFYCpnEqWBnMcmdqm6azECMBGljLYcRhHVWsvBvC+EgCeuEO9W4/i
yHpwS63oewHw1NUbFTiBo0M3ilw1CwVgfU8Xxfgcjlp23/+6rVIA7JOXQt66
4+gozYp7T5MAbPc20Ry/iCOnN62JjiMCkDPjv0v8Oo7ca/+1hAsLQrqefxlz
MI7+xeYox68VBPn60YzLD3F02cX3SqqSIGRfb8ivCcfRtUUeWuE2QXCZnik2
iMLRSnH1sWpjQXi/Kc7ZMhZHN8Mep7VaCgLG3OxjGo+jQEXZvVNOgmB88qEI
WxKOeMf7nzC7CUKjMRNf/mschXx918vvJQgvpzcdO5OCo0jLLf6KDwThTN02
10vpOErwtsw++EkQDoh1OyVn40huF53DCROEfQ/7aiq/4OiVYKuN+09BMJyS
f9D7DUdvE13wwDZBeOtRwTGYhyN7F0RrYxGCrne84ftLcRRnKqvfzSkEAdy7
ZWllOOrQYncc5BOCh5dm04rKcXR8sSxtii4E0S4e+rxVODoVdmCvwAYhEPvM
H7qunrj+HK9jroYQZJ54YHG1AUe/TfKunNcWgin/v6kljUS9l5WTKg2EIO6v
GpdVM45Ezy6thFgKgdmzRVtaB1Ff4ww62i8EZ0pZRbT/Evla56KGHxaC9Wyu
peadOGI0VttZnBCCR0uldy5046jYKPGT4GUhsPfNO3S5H0eL0od/Yd5CcO/5
rq+nB3C0cYG/281XCCoX2BsPDuLo2YcrQtWBQrDh7xpv+WEc1Qarrvd7IATu
PG5rWEdwxHWq00AzXAhCjWgZrYQvrt13NjRGCBzwg41+DBylzK34Q4IQzH/8
fHUfjqO/vz8+HUsUgtxyfjXKGI7o70+nJyQT14c+35JL2PT+2mLLNCEozY86
aDZOxHOyrpUpUwh2iOeXNhLONgz89/6zEExaD2Q4TBD1mx2XoeQLwR3luAD7
f0T/1r3SzS8SgkaNpYx6wiFpR8w9yoQgMI11YO8kjuadinxq6oRA7d75QeUp
HGmCd7h/kxCkzhtNRRA+KamRrNUmBD217+7ME66tedoQ1icEXvsup3+fJuJ9
ZzZqOEzks3O/r8QMjrYHsrBN4ER+HlTuukg4efs5Les5Yv3gs1Z6Fkd+qSiY
ykeBo7LyKbZzOMq6M/nihxAFbhovdMQQHnFMzrkgQoFkTK30L+FDYrT+2rUU
yBTxXTkxT6z/X8nSTTkKhOZXX3xBuLDymvAmJQokyA0NtBPWuN1nGKFFgS8a
gVTrBWI/Hos5tFOHAnaHlwcCCUdvtXT7p0+BJwsKTLmEOSZyYm2MKKA8m75B
bhFH7UcfzNAOUqBoxHGqmbDqxEKNkj0FuuXMarmWcORz+8xbA0cKDNBuS20m
LPbWxNHlLAWEDArV7hE+ibK2XnOnAL9dNP8Hwp9q5elhlyhwke4c3EjYeo65
/IsvBV4oJ4bJLBP7L9g9qSqAAmpmvKo7CePSHb499yhwo/TAAyfC2zPN7OZC
KBATVOIeQDjY+Ju2QCQF9FVZ8FjCzX9UBOWiKGAzX2X9kbCya9SgbhwRb6VT
chnh4ojLcY5vKOAhedBxkrDw+t6rl99RYHdCcTPnCo5OfLGxuZ9B5PM/hSsS
hJk6Nbk+fSPqUTG804Cw+cX4rp/5FJDC2wLNCD/jFPjeXkyBKbMmcQfC+urD
Hlw1FIgzP2fkTTgw/7DpmgYKpEftxe8SbrQtVdzYQgH3sFyuR4Qv+iS1HOkl
6rPwLekd4fTS/3alz1Ggz0V79x/Cy0cqpQuXiXwlhat0EzbFt803sVKhUo0/
fYTwkIhEOosAFSIM6z8sE9ZLDrwnSqOCqHdoLCvTGLq7beaEqhgVLqUZfeEk
LH/it9gBWSpMShrdFyR8YXrHvzPrqbBBFjekEc6/96HCV5UKdNUzf+iEj74P
uZmsQwX2MZX3awg/Xdo9sriXCrpm1ZIqhPtCPxdTLKmQs695VpXwZnnF54r7
qVCrfStXg3DtXtYDlv9RgbotnX0zYZl2D01nJyqY5M/d1SXs5vGXx/s0FV7x
X5zcQjiXzaI35DwV0tZZ7NtGmO/pd+ylJxVoocnB2wnbbVCNzr5KhdtpH2oQ
4eTc6IsV16ngebTVGAjPWnFbdN2kguPpxjekjXuvKM/cpYKLNtsc6cirfax8
D4h4xz/qGRLu5t3fLhNOBY1e1dOkN8YXZG9+QgXZDwn3Sftt3BixN5Y4/lTn
OekqK5FEk+dUiNo7kUJ6rcfsR6NXRD7eWK3aNbSlyDCVClOGRgmkv6XnNmx/
T4VzB989IM1b9bx/6ycqjIg6eZK2YwTM6n2hgn/3JmvSyfynuHUwKkzfb1Uh
Pau6T2JTIRX+PqIuk+s3MVXfoPmTCrFevr9IPz5L2aZWSQWHnvzHpLVTGh3W
N1FhMIx/HWn39U7PJUeokHzEW4LMF2ZskiE2ToW9wlH1ZD4FTqoUiExT4VGS
VCjpt4ljPYJMNHAZdmUjPbDuuhKbMA1wXf0xsh66hse2MIvTYHB77lvSd47t
3Lu8hgbbxkXOkJaP5z43u54GC6YX+rcSPib1OH1kKw1CHBkj+oTTt3rlDQIN
8v8zf0962c6+pm8XDbRPWV8kbeaNurr30uBda5se6dgo2X9/LWhwmFG1RPbH
cDY7W7stDcraWQtI6zcNCLccpgGroVUg6Xsz5QpNR2mwKypejnQTPV2n/gQN
Wsx8PPQIr9cJN6k9RQPj154Y2X+X9186VOVKgxjLXH7SwpFbvX9eoYHpAPUt
2a+WlNLv3+/TIMHr6eRGwvGaqZVfQmnwRkV0L2mGRUjH50c0ELm98bkW4eAQ
W+aMeBpM1mXaahIu5e00epVJgwt4SJ0aYeCYLw9pocFtCV6kTPiWZPqvzX9p
wDwUkKdEuFjTqaK1hwaqKopGpM2OVFaqMGigU9tktZ7sl/cvaoqZhIFT+vEd
BcKX7PY1LisIw0+PeXNZwtluTE1JKsJA6Vk7to7wYsCnJlMNYSiV6gknfTNd
ujlaTxjabETaZAiHsk226uwThnvn845IE05Ji+067y4Mr5520aXI+AqsukUu
CUPqNauPkoS1/nD0fPMShvxNEjaks1k9enluCcOfw9mREoSLDu0aePVIGNTG
aErihLnOzw+YRQuDZwGqFiNseit9cDJOGLZf+u5Fuvad+PCON8JQKfaqWpTw
XxbGaPsXYci53PeAnD9yYi8ZtzFh+NVjD6RPqh3CVQuFQe6Y4KQI4dGDP8a8
K4RhXkPiP9Lzbx//o/8VhqEgu53ChEUOojlzdhEwDM0AKjnv5NO+2/GIQPr7
8RUK4cpxqZsnBUVgxMkij/Sd4HmeG+IiwH5inxHp6fxPUu/URKCoxPSAEGHr
h/Kd2RtFwEg7T4x0mn1EUqEucX+pda3kPD05467eaigCPHrPnUk3qKoC7wER
8I+0viVAzpf5aDbRIyKwe2bQlHRICfdP2WMiUCdhJ0ra+Hi/lf4ZEXjI+iWN
n3DWkxcnTt8QgdAzav185H5nEb9b8koEjE/cvsZLeKLq7r66VBGQ5DtpTdr8
2bRgx3sRGDWYVCLNoff76fQXEdh1UqCJh+x314cpClXE9YhhQPpAE3vlrRkR
mF7DqchNOCPpYvjDRRHIvObLTlrAs/tADDMd2GR9ernI/uTP78jgpcOmjROv
SOvsvDbeKU0Hy9FuNdL0tAlh2E2HqHvIgnzenPTY9HPKlA5SP1d0SH/Wvng9
1YoODgWi0qQPfZ3qpR+hA71uzxgH4ajS2axRVzroZ0Q8Ji3VvXwoJoIOVPWs
cXbC514hfqundJBYdGwn/f20Xz7HMzqErFiXkz46xqxy4RUdNt5nekU6folt
YXcOHTpzXY+SlhXjfTbdTodll2/NbGQ/tOyzettNh6GXJuWkC+KC2Y8P0IFn
G/c30k4KAucrxunQt101jnTSRgpKZBMF6tsWJ9JKZqKdViqiwHNMb4F83l4V
OvSIU0MUYpkrGaRL657u+b5JFPysQrpIn7aTyFAyEIVAz+Ay0ikua26tWIiC
yGPX1ee12k05hXeXRKEV7TAh/XhpzbMSb1E4RHXZRprJS0yky1cUgo5napGu
deNnFw0SBRauPCnSlx1mevziiONtTydZyOepXnmibYkoHPCoSCG9/mORlNsv
UfA3U3xBOlQjL/JejShE0uKiSB9X/BSQ2yIKux8OBJLmEI53UhoTBVMR5tOk
zfEL8otiYmAX5KxO+vMZ11j6WjHIdApYT1qmz0VYS04Msmy/ypCeaLVnO6km
Bs9n3GikH5cZ91QZioGc7tAcM+GOJInEl2fEwNmrsYz07nUiUrluYvDY3ryI
dEasYGTTRTHolGjCSAdEsAXw+4pBh4DcJ9JK/owTVyLEwP7MwwTS7vY/5PZ9
E4PGgiBv0s0ntGrN8sUg4YPCZdI7zyb4WRaLwax4lQdpuveNtv3VYuAwdfA0
6W9P9J8c6xGDb/G0w6S56jJ4LvOJQ+atCX3SF5rX5VyliMMOPydd0i2doS4+
dHE4M9a5iXTa2PlCPxlxiL61rEraVmDDjfva4iDM+UWadMKel+MJ9uLQf1Cc
kzSPFTXhpaM4mB7QZCPtecjf/NVJcci+aslM2tjlv9RUd3GYTE1dYCI8EiDp
nBUgDg0+ZWOk9fIimsrfikPvUmgr6RclLHcrP4iDq6F6M2neKo/NNVni8OPR
70bS7W0W4Q154vBEQLeOdMACr2nnb3H4e8GyjHS1TgA2vSgOCd1YDml17SKH
l8wSsN9k+DPpYC2ORQsOCdBqkMwivVs1UC9ZUAIENgVnkMbWBX84IisBfuvf
pJJO44t8mWciAce/YHGk+XjqDV1NJcAzROcZ6TOc9L/iVhLwLOFDDGkFlqdS
nnYS0LDv41PSsTMxjxRcJcDbcSic9P2ul3eDwiVgrYlgIOmBjh4F3ScSEBhZ
eIe0cZtCYXeMBMg/unGbNEvTayaDJAmQXFq8Sdq7ItUL/ywBH/Rlb5A+lZ15
1rZNAqqus19avT6kwGKtkiSU9jKcSG+ay6YZbpQEsPx3nLSMU1rjiW2S0NDF
4kh6fkvUf8mWkjDmusNhNd7e827aXpLgTt12gHSMpdOmg7ck4c6pCFvSgV8P
z3g9kASLh5PWpI+HGflizyUhP7LGgrSogcTDvWWSYOUztoc02xtBG9ffkuDN
Hbyb9ASVXTS0XRJuyGuYkP41gMfVT0jCxO77RqT9IovSjklKwbkHj9Fqfobd
Ky+fkwLuh406pCOjXoo4+UrBpyvMm0kjkwZ7q3ApuC1nsIn04xdbhzdkS8Ey
1qdBeofl+Y3i5VLE/1EbddKjSwleHO1SwPe1UpW00WEOrk7WNaCzgCuTHuPY
YlFJXwMOzyOVVuP/ePbxV+U18GNw1/rV9QvWyD+2WAPn/X/Jk04ojjHcF7MG
UkKPyqzm0z/plkveGuD8dXYt6f0G6UW3etdAYXa0FOn3s9mcCTxrIaxqQII0
z8cfe75prAXWIhtx0s5uv+432a4FE9ZmUdJ5Kg0Vk15rgUPci0760vNBK7XC
tTB5cZ62Gu+a/A9uI2thtCOfSjor6iklQ1gaFgviKKQbRNw9JrdJQ07pQyHS
02EmNTrO0nBVM0KQtE7QdOjXT9IgHFrOT3prvrWSDKsMOK7Zzkd6eSSHI0NJ
BvwKZ3lW1yO2rnenuQzEoj/cpG8ZBRbUe8rA5vRmrtX+c8efu0TJwDP6HCfp
A3sORzcOyYC203EO0i6yBeEm29ZBqb8CO2nfr5cm9IPXAXeeJhvpJ7ZK1uqt
60DF8zwr6UnT+bQ8RVlgfdXKQtpq1y9eGw9ZMC92XrU+tiVR64csUBcXmUnL
bnm9TYgmByP0N6u2pGrXPjgqB7FrXVZ9fTjPhTdFDhK2aq06I+CxE9+kHCgr
s6+6f805R/7t8oCr/mUi/VqvLcouRB6yonNX7WJjXvu6XR42xL1Y9bmKds5I
ZQVwexG86gsmbgZ+FxXg3ITXqll2xqRlFymAf8mpVUdsL5EepytCjrHdqk9H
UUNKjytC6FfzVaNJh8X4NEXYWWm0ainBiZr5WUVgPrlt1XPKd17v37kevCQ2
r/p48afsxYj1EGWovuqy470/X/ash45DSqu+elS7aVBDCWKC5VatYHerT8NH
CW4clF710UZXzR+/lIDPTpLp//k/5G27Vhn620RX3Rh2f8OZ88og1ya8atGq
3FbfXGVg16WuOvYs5b42twq8ZRNatSyX05ZBGxVo4RNY9UZFa7mhRBX4Jse3
6p1GwD88pQJtrjyrjso3mwwy3AAji1yrxrcfaVF5sAGM33Gu2vTaB2Xzxg2w
z49j1ck5nFc91qnClbPsq/bWHb5v+UMVbA6yrrrekz/a9ZAaSCQzrzrh40iJ
zls1cKhkWvXZqfKplRU1qF4hXzj6H1hUerk=
                "]]}, 
              Annotation[#, 
               "Charting`Private`Tag$286469#1"]& ]}}, {}, {}}, {{{{}, {}, 
             TagBox[{
               Directive[
                Opacity[1.], 
                CapForm["Butt"], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 1, 0], 
                Thickness[Large], 
                Dashing[{Small, Small}]], 
               LineBox[CompressedData["
1:eJwl2nc81d8fB3B7j8vl2iNkVVZGlM7bCEmiVGhLqZDwpdIwK5UkSUpGUSmy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                "]]}, 
              Annotation[#, "Charting`Private`Tag$286507#1"]& ]}}, {}, {}}, {
           Thickness[Large], 
           RGBColor[0, 0, 1], 
           LineBox[{{4.8, 0}, {5, 0}}]}, {
           RGBColor[1, 0, 0], 
           Thickness[0.005], 
           Dashing[{Small, Small}], 
           LineBox[{{4.8, -0.5}, {5, -0.5}}]}, {
           RGBColor[0, 1, 0], 
           Thickness[0.001], 
           Dashing[{Small, Small}], 
           LineBox[{{4.8, -1}, {5, -1}}]}, {
           TagBox[
            InsetBox[
            "\!\(\*\nStyleBox[\"t\",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*\n\
StyleBox[\" \",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*\nStyleBox[\"=\",\n\
FontColor->RGBColor[0, 0, 1]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0, 0, 1]]\)\!\(\*\nStyleBox[\"0\",\n\
FontColor->RGBColor[0, 0, 1]]\)\n\!\(\*\nStyleBox[\"t\",\n\
FontColor->RGBColor[1, 0, 0]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[1, 0, 0]]\)\!\(\*\nStyleBox[\"=\",\n\
FontColor->RGBColor[1, 0, 0]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[1, 0, 0]]\)\!\(\*\nStyleBox[\"100\",\n\
FontColor->RGBColor[1, 0, 0]]\)\n\!\(\*\nStyleBox[\"t\",\n\
FontColor->RGBColor[0, 1, 0]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0, 1, 0]]\)\!\(\*\nStyleBox[\"=\",\n\
FontColor->RGBColor[0, 1, 0]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0, 1, 0]]\)\!\(\*\nStyleBox[\"200\",\n\
FontColor->RGBColor[0, 1, 0]]\)", {6, -0.5}], "InsetString"]}, {
           TagBox[
            InsetBox["\!\(\*SubscriptBox[\(r\), \(0\)]\) = 3.5", {6, 1.5}], 
            "InsetString"]}}, {
         ImagePadding -> {{0, 40}, {40, 40}}, AspectRatio -> Full, 
          BaseStyle -> {Large, FontFamily -> "Times", Italic}, LabelStyle -> 
          Directive[
            GrayLevel[0], FontFamily -> "Times", Large], DisplayFunction -> 
          Identity, Ticks -> {Automatic, Automatic}, AxesOrigin -> {0, 0}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLines -> {{0}, {0}}, DisplayFunction -> Identity, 
          PlotRangePadding -> {{0, 0}, {0, 0}}, PlotRangeClipping -> True, 
          ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
          NCache[GoldenRatio^(-1), 0.6180339887498948], 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> Automatic,
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLines -> {{0}, {0}}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], LabelStyle -> {FontFamily -> "Times"}, 
          Method -> {
           "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
            AbsolutePointSize[6], "ScalingFunctions" -> None, 
            "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
                 Part[#, 1]], 
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
                 Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
                 Part[#, 1]], 
                (
                Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
                 Part[#, 2]]}& )}}, PlotRange -> {{0, 8}, {-2, 2}}, 
          PlotRangeClipping -> True, 
          PlotRangePadding -> {{Automatic, Automatic}, {
            Automatic, Automatic}}, Ticks -> {Automatic, Automatic}}], 
        NCache[{
          Rational[2686, 3], 0}, {895.3333333333334, 0}], {Left, Bottom}, 
        NCache[{
          Rational[1403, 3], 363}, {467.6666666666667, 363}]]}}, 
     PlotRange -> {{0, 1363}, {0, 363}}, ImageSize -> {1363, 363}], 
    Background -> GrayLevel[1]],
   "\"\\!\\(\\*\\nStyleBox[\\\"r\\\",\\nFontSize->24]\\)\"",RotationBox[
   "\"\\!\\(\\*\\nStyleBox[\\\"\[CapitalPhi]\\\",\\nFontSize->24]\\)\\!\\(\\*\
\\nStyleBox[\\\"(\\\",\\nFontSize->24]\\)\\!\\(\\*\\nStyleBox[\\\"r\\\",\\\
nFontSize->24]\\)\\!\\(\\*\\nStyleBox[\\\")\\\",\\nFontSize->24]\\)\"", 
    BoxRotation -> 1.5707963267948966`]},
  "Labeled",
  DisplayFunction->(GridBox[{{
      ItemBox[#3, DefaultBaseStyle -> "PanelLabel"], 
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}, {"", 
      ItemBox[#2, DefaultBaseStyle -> "PanelLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, 
    GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
    BaselinePosition -> {1, 2}]& ),
  InterpretationFunction->(RowBox[{"Labeled", "[", 
     RowBox[{#, ",", 
       RowBox[{"{", 
         RowBox[{#2, ",", #3}], "}"}], ",", 
       RowBox[{"{", 
         RowBox[{"Bottom", ",", "Left"}], "}"}], ",", 
       RowBox[{"DefaultLabelStyle", "\[Rule]", "\"PanelLabel\""}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
         RowBox[{"{", "}"}]}], ",", 
       RowBox[{"RotateLabel", "\[Rule]", "False"}], ",", 
       RowBox[{"Spacings", "\[Rule]", "Automatic"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.7567370797761993`*^9, 3.756737471832923*^9, {3.756737567251175*^9, 
   3.7567376201271152`*^9}, {3.7567376780672684`*^9, 3.756737749001684*^9}, {
   3.756737895097311*^9, 3.756737917316779*^9}, {3.7567380158253083`*^9, 
   3.756738031412562*^9}, 3.756738104764644*^9, {3.7567381699793777`*^9, 
   3.7567381872638636`*^9}, {3.7567382637262497`*^9, 
   3.7567382741113386`*^9}, {3.756738399536504*^9, 3.7567384152133026`*^9}, {
   3.7567384953806486`*^9, 3.7567385091076207`*^9}, {3.7567385421171813`*^9, 
   3.7567385528341084`*^9}, {3.756738753815297*^9, 3.7567387651480684`*^9}, 
   3.7567484787143974`*^9}],

Cell[BoxData["\<\"C:\\\\Users\\\\Leandros\\\\Dropbox\\\\diplomatikes-phd\\\\\
george-alestas\\\\project\\\\tex-lp1\"\>"], "Output",
 CellChangeTimes->{
  3.7567370797761993`*^9, 3.756737471832923*^9, {3.756737567251175*^9, 
   3.7567376201271152`*^9}, {3.7567376780672684`*^9, 3.756737749001684*^9}, {
   3.756737895097311*^9, 3.756737917316779*^9}, {3.7567380158253083`*^9, 
   3.756738031412562*^9}, 3.756738104764644*^9, {3.7567381699793777`*^9, 
   3.7567381872638636`*^9}, {3.7567382637262497`*^9, 
   3.7567382741113386`*^9}, {3.756738399536504*^9, 3.7567384152133026`*^9}, {
   3.7567384953806486`*^9, 3.7567385091076207`*^9}, {3.7567385421171813`*^9, 
   3.7567385528341084`*^9}, {3.756738753815297*^9, 3.7567387651480684`*^9}, 
   3.7567484790703835`*^9}],

Cell[BoxData["\<\"fig6.pdf\"\>"], "Output",
 CellChangeTimes->{
  3.7567370797761993`*^9, 3.756737471832923*^9, {3.756737567251175*^9, 
   3.7567376201271152`*^9}, {3.7567376780672684`*^9, 3.756737749001684*^9}, {
   3.756737895097311*^9, 3.756737917316779*^9}, {3.7567380158253083`*^9, 
   3.756738031412562*^9}, 3.756738104764644*^9, {3.7567381699793777`*^9, 
   3.7567381872638636`*^9}, {3.7567382637262497`*^9, 
   3.7567382741113386`*^9}, {3.756738399536504*^9, 3.7567384152133026`*^9}, {
   3.7567384953806486`*^9, 3.7567385091076207`*^9}, {3.7567385421171813`*^9, 
   3.7567385528341084`*^9}, {3.756738753815297*^9, 3.7567387651480684`*^9}, 
   3.7567484799281273`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Figures 7 & 8",
 FontSize->18]], "Section",
 CellChangeTimes->{{3.756909579524736*^9, 3.7569095861004148`*^9}, {
  3.7569101134420743`*^9, 3.756910117502713*^9}},
 Background->RGBColor[0., 1., 1.]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.7569000873085938`*^9, 3.7569000909094896`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Plot", " ", "of", " ", "the", " ", "comparison", " ", "of", " ", "static",
     " ", "wall", " ", "field", " ", "solution", " ", "in", " ", "the", " ", 
    "presence", " ", "and", " ", "absence", " ", "of", " ", "backreaction"}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"b", ",", "ll"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"b", "=", 
     RowBox[{"-", "0.255"}]}], ";", " ", 
    RowBox[{"ll", "=", 
     RowBox[{"-", "0.202"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr", "=", 
     RowBox[{
      RowBox[{"r", "^", "2"}], "+", 
      RowBox[{"2", " ", "b", " ", 
       RowBox[{"r", "^", "3"}]}], " ", "-", " ", 
      RowBox[{"ll", " ", 
       RowBox[{
        RowBox[{"r", "^", "4"}], " ", "/", "3"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Plot", "[", 
     RowBox[{"gr", ",", 
      RowBox[{"{", 
       RowBox[{"r", ",", "0", ",", "6"}], "}"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"imax", "=", "200"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rmin", "=", "0.0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rmax", "=", "16"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dx", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"rmax", "-", "rmin"}], ")"}], "/", "imax"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"r", "[", "i_", "]"}], ":=", 
     RowBox[{
      RowBox[{"i", " ", "dx"}], "+", "rmin"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"fp", "[", "i_", "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"f", "[", "i", "]"}], "-", 
        RowBox[{"f", "[", 
         RowBox[{"i", "-", "1"}], "]"}]}], ")"}], "/", "dx"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"e", "[", "i_", "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"r", "[", "i", "]"}], "^", "2"}], " ", "+", " ", 
         RowBox[{"2", " ", "b", " ", 
          RowBox[{
           RowBox[{"r", "[", "i", "]"}], "^", "3"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"ll", "/", "3"}], ")"}], " ", 
          RowBox[{
           RowBox[{"r", "[", "i", "]"}], "^", "4"}]}]}], ")"}], 
       RowBox[{
        RowBox[{
         RowBox[{"fp", "[", "i", "]"}], "^", "2"}], "/", "2"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"r", "[", "i", "]"}], "^", "2"}], 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"f", "[", "i", "]"}], "^", "2"}], "-", "1"}], ")"}], "^", 
         "2"}], " ", "/", "4"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "0", "]"}], "=", 
     RowBox[{"-", "1"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "imax", "]"}], "=", "1"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"etot", "=", 
     RowBox[{"dx", "  ", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{"e", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "imax"}], "}"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r0", "=", "10"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ft", "[", "x_", "]"}], ":=", 
     RowBox[{"Tanh", "[", 
      RowBox[{"5", 
       RowBox[{"(", 
        RowBox[{"x", "-", "r0"}], ")"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ftab", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"f", "[", "i", "]"}], ",", 
         RowBox[{"ft", "[", 
          RowBox[{"r", "[", "i", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"imax", "-", "1"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sol1", "=", 
     RowBox[{"FindMinimum", "[", 
      RowBox[{"etot", ",", "ftab", ",", 
       RowBox[{"MaxIterations", "\[Rule]", "1000000"}], ",", 
       RowBox[{"AccuracyGoal", "\[Rule]", "6"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"etot", " ", "/.", " ", 
     RowBox[{"sol1", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tfsol", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"i", " ", "dx"}], "+", "rmin"}], ",", 
         RowBox[{
          RowBox[{"f", "[", "i", "]"}], "/.", " ", 
          RowBox[{"sol1", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "imax"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"plsol1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"tfsol", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"r", ",", "\[CapitalPhi]"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"ftfsol", "=", 
     RowBox[{"Interpolation", "[", "tfsol", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"fmet", "[", "r_", "]"}], ":=", 
     RowBox[{"(", 
      RowBox[{"1", " ", "+", " ", 
       RowBox[{"2", " ", "b", " ", "r"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"ll", "/", "3"}], ")"}], " ", 
        RowBox[{"r", "^", "2"}]}]}], ")"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"aa", "=", "0.02"}], ";"}], 
   RowBox[{"(*", 
    RowBox[{
    "We", " ", "set", " ", "the", " ", "Backreaction", " ", "parameter", " ", 
     "value"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rho1", "=", 
     RowBox[{
      RowBox[{"0.5", " ", 
       RowBox[{"fmet", "[", "r", "]"}], " ", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"ftfsol", "[", "r", "]"}], ",", "r"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"ftfsol", "[", "r", "]"}], "^", "2"}], "-", "1"}], ")"}], 
        "^", "2"}], " ", "/", "4"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rho2", "=", 
     RowBox[{"aa", " ", "rho1"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Plot", "[", 
     RowBox[{"rho2", ",", 
      RowBox[{"{", 
       RowBox[{"r", ",", "0", ",", "8"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"eq1", "=", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"g3", "[", "r", "]"}], 
        SuperscriptBox["r", "2"]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["g3", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}], "r"]}], "\[Equal]", 
      RowBox[{"rho2", "-", 
       RowBox[{"4", " ", 
        RowBox[{"b", "/", "r"}]}], " ", "+", "ll"}]}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{
    "Einstein", " ", "equation", " ", "for", " ", "energy", " ", "density"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rmin", "=", "0.0001"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"grmin", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rmax", "=", "16"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ggsol", "=", 
     RowBox[{"NDSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"eq1", ",", 
         RowBox[{
          RowBox[{"g3", "[", "rmin", "]"}], "\[Equal]", "0.0"}]}], "}"}], ",", 
       RowBox[{"g3", "[", "r", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "rmin", ",", "rmax"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pl2", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"r", "^", "2"}], 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"Evaluate", "[", 
           RowBox[{
            RowBox[{"g3", "[", "r", "]"}], "/.", "ggsol"}], "]"}]}], ")"}]}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "rmin", ",", "rmax"}], "}"}]}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"gbr", "=", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"g3", "[", "r", "]"}], "/.", "ggsol"}], "]"}]}], ")"}]}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{"gbrc", "[", "x_", "]"}], ":=", 
    RowBox[{
     RowBox[{"gbr", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "/.", " ", 
     RowBox[{"r", "\[Rule]", "x"}]}]}], "\n", 
   RowBox[{
    RowBox[{"dx", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"rmax", "-", "rmin"}], ")"}], "/", "imax"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"r", "[", "i_", "]"}], ":=", 
     RowBox[{
      RowBox[{"i", " ", "dx"}], "+", "rmin"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"fp", "[", "i_", "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"f", "[", "i", "]"}], "-", 
        RowBox[{"f", "[", 
         RowBox[{"i", "-", "1"}], "]"}]}], ")"}], "/", "dx"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"e", "[", "i_", "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"r", "[", "i", "]"}], "^", "2"}], " ", 
         RowBox[{"gbrc", "[", 
          RowBox[{"r", "[", "i", "]"}], "]"}]}], ")"}], 
       RowBox[{
        RowBox[{
         RowBox[{"fp", "[", "i", "]"}], "^", "2"}], "/", "2"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"r", "[", "i", "]"}], "^", "2"}], 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"f", "[", "i", "]"}], "^", "2"}], "-", "1"}], ")"}], "^", 
         "2"}], " ", "/", "4"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"etot", "=", 
     RowBox[{"dx", "  ", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{"e", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "imax"}], "}"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ft", "[", "x_", "]"}], ":=", 
     RowBox[{"Tanh", "[", 
      RowBox[{"5", 
       RowBox[{"(", 
        RowBox[{"x", "-", "r0"}], ")"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ftab", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"f", "[", "i", "]"}], ",", 
         RowBox[{"ft", "[", 
          RowBox[{"r", "[", "i", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"imax", "-", "1"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sol1", "=", 
     RowBox[{"FindMinimum", "[", 
      RowBox[{"etot", ",", "ftab", ",", 
       RowBox[{"MaxIterations", "\[Rule]", "1000000"}], ",", 
       RowBox[{"AccuracyGoal", "\[Rule]", "6"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"etot", " ", "/.", " ", 
     RowBox[{"sol1", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tfsol", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"i", " ", "dx"}], "+", "rmin"}], ",", 
         RowBox[{
          RowBox[{"f", "[", "i", "]"}], "/.", " ", 
          RowBox[{"sol1", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "imax"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"plsol2", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"tfsol", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "Dashed"}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"r", ",", "\[CapitalPhi]"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
   RowBox[{"solbnb", "=", 
    RowBox[{"Show", "[", 
     RowBox[{"plsol1", ",", "plsol2", ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Inset", "[", 
         RowBox[{"\"\<\!\(\*
StyleBox[OverscriptBox[\"\[Kappa]\", \"_\"],
FontSize->10]\)\!\(\*
StyleBox[\"=\",
FontSize->10]\)\!\(\*
StyleBox[\"0\",
FontSize->10]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"2.5", ",", "1"}], "}"}]}], "]"}], "}"}], "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"2.69", ",", "0.81"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"3.28", ",", "0.21"}], "}"}]}], "}"}], "]"}], "}"}], 
       "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Inset", "[", 
         RowBox[{"\"\<\!\(\*
StyleBox[OverscriptBox[\"\[Kappa]\", \"_\"],
FontSize->10]\)\!\(\*
StyleBox[\"=\",
FontSize->10]\)\!\(\*
StyleBox[\"0.02\",
FontSize->10]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"4.2", ",", 
            RowBox[{"-", "1"}]}], "}"}]}], "]"}], "}"}], "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"3.93", ",", 
             RowBox[{"-", "0.81"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"3.52", ",", 
             RowBox[{"-", "0.270"}]}], "}"}]}], "}"}], "]"}], "}"}], "]"}], 
      ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Red", ",", "Blue"}], "}"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "6"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"PlotTheme", "->", "\"\<Scientific\>\""}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Medium", ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Italic"}], 
        "}"}]}], ",", 
      RowBox[{"LabelStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Black", ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Medium"}], 
        "]"}]}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", " ", 
       RowBox[{"{", 
        RowBox[{"\"\<\!\(\*
StyleBox[\"r\",
FontSize->12]\)\>\"", ",", "\"\<\[CapitalPhi](r)\>\""}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"SetDirectory", "[", 
    RowBox[{"NotebookDirectory", "[", "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{"\"\<fig7.pdf\>\"", ",", "solbnb", ",", 
     RowBox[{"ImageResolution", "\[Rule]", "1000"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Clear", "[", 
    RowBox[{"h", ",", "h1", ",", "fmet"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"fmet", "[", "r_", "]"}], ":=", 
     RowBox[{"(", 
      RowBox[{"1", " ", "+", " ", 
       RowBox[{"2", " ", "b", " ", "r"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"ll", "/", "3"}], ")"}], " ", 
        RowBox[{"r", "^", "2"}]}]}], ")"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{"r_", ",", "r0_"}], "]"}], ":=", 
     RowBox[{"Tanh", "[", 
      RowBox[{"3.1", 
       RowBox[{"(", 
        RowBox[{"r", "-", "r0"}], ")"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"rhod", "[", "r0_", "]"}], ":=", 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"r", "^", "2"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"0.5", " ", 
           RowBox[{"fmet", "[", "r", "]"}], " ", 
           RowBox[{
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"h", "[", 
               RowBox[{"r", ",", "r0"}], "]"}], ",", "r"}], "]"}], "^", 
            "2"}]}], "+", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"h", "[", 
                RowBox[{"r", ",", "r0"}], "]"}], "^", "2"}], "-", "1"}], 
             ")"}], "^", "2"}], " ", "/", "4"}]}], " ", ")"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "rmin", ",", "rmax"}], "}"}]}], "]"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7526388054795094`*^9, 3.7526388085819044`*^9}, {
   3.752638903814629*^9, 3.752638950361088*^9}, {3.7526389880026255`*^9, 
   3.7526389988849473`*^9}, {3.752659448808524*^9, 3.7526594798028154`*^9}, {
   3.7526595575305443`*^9, 3.7526595584942646`*^9}, {3.752735485583605*^9, 
   3.752735486059798*^9}, {3.7529014347044687`*^9, 3.752901436192116*^9}, {
   3.752910713484153*^9, 3.75291071378502*^9}, 3.7529294233793464`*^9, {
   3.7529376833865013`*^9, 3.752937855081313*^9}, {3.752937909139614*^9, 
   3.7529380122243414`*^9}, {3.7529883024858084`*^9, 
   3.7529885705937376`*^9}, {3.7529886131814914`*^9, 3.752988622013634*^9}, {
   3.752988722788665*^9, 3.752988795930296*^9}, {3.752996377196164*^9, 
   3.752996417072567*^9}, {3.756387572785722*^9, 3.7563875753943734`*^9}, {
   3.756387735030757*^9, 3.7563877420602417`*^9}, {3.75638777852771*^9, 
   3.7563877983282304`*^9}, {3.7563878357486153`*^9, 
   3.7563878905500007`*^9}, {3.756387921128769*^9, 3.756387973694552*^9}, {
   3.7563880253478575`*^9, 3.7563880537506*^9}, {3.756391341579517*^9, 
   3.7563913868423986`*^9}, {3.756731801583148*^9, 3.756731808597704*^9}, {
   3.756739005683852*^9, 3.756739010201908*^9}, {3.7567394980184298`*^9, 
   3.756739502050481*^9}, {3.7567395530383525`*^9, 3.756739559393359*^9}, {
   3.7567409087885847`*^9, 3.756740915533928*^9}, {3.7567409559924927`*^9, 
   3.7567409561399565`*^9}, {3.756740988396229*^9, 3.756740994817458*^9}, {
   3.7569000979705267`*^9, 3.7569002609376173`*^9}, {3.7569002999791546`*^9, 
   3.7569003014798465`*^9}, {3.7569003918436146`*^9, 3.756900415788612*^9}, {
   3.7569021187184734`*^9, 3.75690214018351*^9}, {3.756902213598543*^9, 
   3.756902214423468*^9}, {3.7569022585164614`*^9, 3.7569024040279665`*^9}, {
   3.7569096003336554`*^9, 3.756909601600638*^9}, 3.7569116799286137`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxV1wlUVNcdBnAEiQGJIDvIvg7MMHAao2KU+xkikB4b96AWEu1RSWLjEkvC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       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[1, 0, 0], PointSize[0.009166666666666668], AbsoluteThickness[
      1.6], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwt13k0lWsXAPBDpI6U4Zg55uEYKxF96d2aTqmIaPpOGYoG0dHtK1RCoYHU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       "]]}}, {}, {}, {{}, {}}}, 
   TagBox[InsetBox[
     StyleBox[
      RowBox[{
       OverscriptBox["\[Kappa]", "_"], "=", "0"}],
      FontSize->10], {2.5, 1}],
    "InsetString"], ArrowBox[{{2.69, 0.81}, {3.28, 0.21}}], 
   TagBox[InsetBox[
     StyleBox[
      RowBox[{
       OverscriptBox["\[Kappa]", "_"], "=", "0.02"}],
      FontSize->10], {4.2, -1}],
    "InsetString"], ArrowBox[{{3.93, -0.81}, {3.52, -0.27}}]},
  PlotStyle -> {
    RGBColor[1, 0, 0], 
    RGBColor[0, 0, 1]},
  PlotTheme -> "Scientific",
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{Medium, FontFamily -> "Times", Italic},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox[
    "\"\\!\\(\\*\\nStyleBox[\\\"r\\\",\\nFontSize->12]\\)\"", 
     TraditionalForm], 
    FormBox["\"\[CapitalPhi](r)\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    GrayLevel[0], FontFamily -> "Times", Medium],
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1, 6}, {-2, 2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.756387975615999*^9, {3.7563880410973372`*^9, 3.75638805493782*^9}, 
   3.7567313571959276`*^9, 3.756731810777043*^9, {3.7567390119302053`*^9, 
   3.75673903037499*^9}, 3.756739503696023*^9, {3.7567395607800603`*^9, 
   3.7567395678547897`*^9}, 3.7567397233712273`*^9, {3.7567399357943277`*^9, 
   3.7567399463636236`*^9}, 3.756740220030528*^9, 3.756740747948182*^9, {
   3.7567409958361635`*^9, 3.7567410029777126`*^9}, 3.756748481804081*^9, {
   3.7569021257353134`*^9, 3.7569021417880974`*^9}, 3.7569022164133263`*^9, {
   3.756902261364813*^9, 3.756902286584502*^9}, 3.75690231771673*^9, 
   3.756902414272025*^9}],

Cell[BoxData["\<\"fig7.pdf\"\>"], "Output",
 CellChangeTimes->{
  3.756387975615999*^9, {3.7563880410973372`*^9, 3.75638805493782*^9}, 
   3.7567313571959276`*^9, 3.756731810777043*^9, {3.7567390119302053`*^9, 
   3.75673903037499*^9}, 3.756739503696023*^9, {3.7567395607800603`*^9, 
   3.7567395678547897`*^9}, 3.7567397233712273`*^9, {3.7567399357943277`*^9, 
   3.7567399463636236`*^9}, 3.756740220030528*^9, 3.756740747948182*^9, {
   3.7567409958361635`*^9, 3.7567410029777126`*^9}, 3.756748481804081*^9, {
   3.7569021257353134`*^9, 3.7569021417880974`*^9}, 3.7569022164133263`*^9, {
   3.756902261364813*^9, 3.756902286584502*^9}, 3.75690231771673*^9, 
   3.756902414477222*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
  "Plot", " ", "of", " ", "the", " ", "effect", " ", "of", " ", 
   "backreaction", " ", "on", " ", "the", " ", "energy", " ", "functional"}], 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7569003148900175`*^9, 3.756900359424135*^9}, 
   3.756912641787306*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"pl1", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"rhod", "[", "r0", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"r0", ",", "rmin", ",", "4.5"}], "}"}], ",", 
     RowBox[{"PlotTheme", "->", "\"\<Scientific\>\""}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Blue"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"Clear", "[", 
  RowBox[{"h", ",", "h1", ",", "fmet"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fmet", "[", "r_", "]"}], ":=", 
   RowBox[{"gbrc", "[", "r", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"h", "[", 
    RowBox[{"r_", ",", "r0_"}], "]"}], ":=", 
   RowBox[{"Tanh", "[", 
    RowBox[{"3.1", 
     RowBox[{"(", 
      RowBox[{"r", "-", "r0"}], ")"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rhodbc", "[", "r0_", "]"}], ":=", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"r", "^", "2"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"0.5", " ", 
         RowBox[{"gbrc", "[", "r", "]"}], " ", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"h", "[", 
             RowBox[{"r", ",", "r0"}], "]"}], ",", "r"}], "]"}], "^", "2"}]}],
         "+", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"h", "[", 
              RowBox[{"r", ",", "r0"}], "]"}], "^", "2"}], "-", "1"}], ")"}], 
          "^", "2"}], " ", "/", "4"}]}], " ", ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "rmin", ",", "rmax"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"imax", "=", "100"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rmin1", "=", "0.1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rmax1", "=", "4.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dx", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"rmax1", "-", "rmin1"}], ")"}], "/", "imax"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trhodbc", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"i", " ", "dx"}], "+", "rmin1"}], ",", 
       RowBox[{"rhodbc", "[", 
        RowBox[{
         RowBox[{"i", " ", "dx"}], "+", "rmin1"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "imax"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"pl2", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"trhodbc", ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotTheme", "->", "\"\<Scientific\>\""}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Dashed"}], "}"}]}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7526388054795094`*^9, 3.7526388085819044`*^9}, {
   3.752638903814629*^9, 3.752638950361088*^9}, {3.7526389880026255`*^9, 
   3.7526389988849473`*^9}, {3.752659448808524*^9, 3.7526594798028154`*^9}, {
   3.7526595575305443`*^9, 3.7526595584942646`*^9}, {3.752735485583605*^9, 
   3.752735486059798*^9}, {3.7529014347044687`*^9, 3.752901436192116*^9}, {
   3.752910713484153*^9, 3.75291071378502*^9}, 3.7529294233793464`*^9, {
   3.7529376833865013`*^9, 3.752937855081313*^9}, {3.752937909139614*^9, 
   3.7529380122243414`*^9}, {3.7529883024858084`*^9, 
   3.7529885705937376`*^9}, {3.7529886131814914`*^9, 3.752988622013634*^9}, {
   3.752988722788665*^9, 3.752988795930296*^9}, {3.752996377196164*^9, 
   3.7529964638491993`*^9}, {3.752997725827078*^9, 3.752997726932114*^9}, 
   3.754947037950157*^9, {3.7549471388656673`*^9, 3.7549471482310715`*^9}, 
   3.756900055403187*^9, {3.7569003748569727`*^9, 3.756900382016507*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"energ", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"pl1", ",", "pl2", ",", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{"Inset", "[", 
       RowBox[{"\"\<\!\(\*
StyleBox[OverscriptBox[\"b\", \"_\"],
FontSize->14]\)\!\(\*
StyleBox[\" \",
FontSize->14]\)\!\(\*
StyleBox[\"=\",
FontSize->14]\)\!\(\*
StyleBox[\" \",
FontSize->14]\)\!\(\*
StyleBox[\"-\",
FontSize->14]\)\!\(\*
StyleBox[\"0.255\",
FontSize->14]\)\\n\!\(\*
StyleBox[OverscriptBox[\"\[CapitalLambda]\", \"_\"],
FontSize->14]\)\!\(\*
StyleBox[\" \",
FontSize->14]\)\!\(\*
StyleBox[\"=\",
FontSize->14]\)\!\(\*
StyleBox[\" \",
FontSize->14]\)\!\(\*
StyleBox[\"-\",
FontSize->14]\)\!\(\*
StyleBox[\"0.202\",
FontSize->14]\)\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"0.5", ",", "4.5"}], "}"}]}], "]"}], "}"}], "]"}], ",", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{"Inset", "[", 
       RowBox[{"\"\<\!\(\*
StyleBox[\"no\",
FontSize->16]\)\!\(\*
StyleBox[\" \",
FontSize->16]\)\!\(\*
StyleBox[\"back\",
FontSize->16]\)\!\(\*
StyleBox[\"-\",
FontSize->16]\)\!\(\*
StyleBox[\"reaction\",
FontSize->16]\)\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"2.5", ",", "3.5"}], "}"}]}], "]"}], "}"}], "]"}], ",", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2.89", ",", "3.32"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"3.57", ",", "2.49"}], "}"}]}], "}"}], "]"}], "}"}], "]"}], 
    ",", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{"Inset", "[", 
       RowBox[{"\"\<\!\(\*
StyleBox[\"with\",
FontSize->16,
FontWeight->\"Plain\"]\)\!\(\*
StyleBox[\" \",
FontSize->16,
FontWeight->\"Plain\"]\)\!\(\*
StyleBox[\"back\",
FontSize->16,
FontWeight->\"Plain\"]\)\!\(\*
StyleBox[\"-\",
FontSize->16,
FontWeight->\"Plain\"]\)\!\(\*
StyleBox[\"reaction\",
FontSize->16,
FontWeight->\"Plain\"]\)\\n\!\(\*
StyleBox[\"(\",
FontSize->14]\)\!\(\*
StyleBox[OverscriptBox[\"\[Kappa]\", \"_\"],
FontSize->14]\)\!\(\*
StyleBox[\" \",
FontSize->14]\)\!\(\*
StyleBox[\"=\",
FontSize->14]\)\!\(\*
StyleBox[\" \",
FontSize->14]\)\!\(\*
StyleBox[\"0.02\",
FontSize->14]\)\!\(\*
StyleBox[\")\",
FontSize->14]\)\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "1"}], "}"}]}], "]"}], "}"}], "]"}], ",", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2.56", ",", "1.36"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"3.37", ",", "2.08"}], "}"}]}], "}"}], "]"}], "}"}], "]"}], 
    ",", 
    RowBox[{"PlotTheme", "->", "\"\<Scientific\>\""}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Medium", ",", 
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Italic"}], 
      "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", 
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "Medium"}], 
      "]"}]}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"r\",
FontSize->12]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"E\",
FontSize->12]\)\!\(\*
StyleBox[\"/\",
FontSize->12]\)\!\(\*
StyleBox[\"4\",
FontSize->12]\)\!\(\*
StyleBox[\"\[Pi]\",
FontSize->12]\)\>\""}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7529977442145576`*^9, 3.7529977482697864`*^9}, 
   3.75494700349061*^9, {3.754947189169622*^9, 3.754947190935401*^9}, {
   3.7549474553525515`*^9, 3.7549475217932277`*^9}, {3.7549485385242186`*^9, 
   3.754948539457569*^9}, {3.7551229769790287`*^9, 3.7551229776234813`*^9}, 
   3.7551232458366623`*^9, {3.755123284474085*^9, 3.755123326719835*^9}, {
   3.755123360590502*^9, 3.7551234171934958`*^9}, {3.7551236489000187`*^9, 
   3.7551236738003073`*^9}, {3.7551237062557645`*^9, 3.755123801411987*^9}, {
   3.7563881148422813`*^9, 3.7563882345951786`*^9}, {3.756388361362238*^9, 
   3.7563884284869184`*^9}, {3.756388510186389*^9, 3.7563885345556355`*^9}, {
   3.7563885652205424`*^9, 3.7563885751555176`*^9}, {3.7567313203227425`*^9, 
   3.7567313384890833`*^9}, 3.7567314787762117`*^9, {3.7567315223893695`*^9, 
   3.7567315592956595`*^9}, {3.756739686386895*^9, 3.75673970785324*^9}, {
   3.7567398294809437`*^9, 3.7567398316568637`*^9}, 3.7567400634620028`*^9, 
   3.756740165467351*^9, 3.7567410679740615`*^9, {3.7567412058158197`*^9, 
   3.7567412059633136`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], CapForm[
       "Butt"], LineBox[CompressedData["
1:eJwV2Hk4VV8XB/B7z7nkDsZEhpBQyVShDLVXlIhCpJIQGSukKJQpJCpkKEXJ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        "]]},
      Annotation[#, 
       "Charting`Private`Tag$318845#1"]& ]}, {}, {}}, {{}, {{}, {}, 
     {RGBColor[1, 0, 0], PointSize[0.009166666666666668], AbsoluteThickness[
      1.6], Dashing[{Small, Small}], CapForm["Butt"], LineBox[CompressedData["
1:eJwllHs0VXkUx++559zrkcdFb1KaS2amploUJbM3QiUJkzAUV4yRJNNDRkSP
yZREGQmJmIkmUUqphNQypiwk8mhQFCGu9+sy53fvXuuss84/++zv/n4/W0e0
38Gby+FwvNmHvK8kknoII46S0tDVebChxS46IaAUvoy6e7uqFkC2uMZWJCiH
K5lnF+XrF8ECxkllxZ1X8LlzXkaH+TPYeNb/02RWNSiWjmXfVC+H0Nk51m0h
taDx0vyP2eGv4E5K318vbOrBy/xOkFVxNXzWWy3/t1YjuJ0+GVLAfwNLc4N8
Y3ubwbmi0EMU/Rac1+WXHy5qgTnuYvt925phU1sI6QjCwKSmLp1WaM9MKluS
+x60tCbyygzeQ7jf44MX57dDrkV4cblLO2iufCfkR3TAXWHrGX7sRygYlNQG
d32EGp/2ibS6TnB4oH2q274TmNoOgzfLuuFLKKzZVdgFJf41egMRvfC7mUdH
1dJuSLa2TvR63we6/Ih4i7M9EPZrcbPTV2IoqUizvD/YC5v7t5kYOQ2Ae0zp
sL5bH4hApzHnzCBMZZGF9cPlItv8Px8OwRYl7re/zRUD7VlVN7tzGC4HqJ8o
rhDDSXqv95T6KHysWto0HjYAsYa2KfvWjYGhAalBqKB96065jkMk+3f/T4Pg
kyI+sf/QBFSNOn7ITBqC+V5ehqKoSdB23WPSYjcMNms1Y9Pjp2AvWQczArfq
77pHJkrgIZH7YASCNTWPeFyaBjkix38UEj321Nw4NQM7PpCFjsFtvRumfms5
eJ1VJ6kdg3NC+Cc/g4Ni1j2jqHGI/yEp85gyhaBYfz3QdALKrrgOXQqk8Byx
XzwBJZY/u1e/orCxkgw4Cd6TfUoCXS7qE7tdp+Bt3ZNcw8NcPMxO56QiAYPj
8oe+LuFiGbu9mFIJLEM7TguPRnVpAKbh/HOtgK0badxduJnd4AxoDmzdtD+U
xltaRPAMtJjuDrPJofEYsW8zB/WDjFy7G2jMCDRlJ+RgXOGRA7tnaPyX2CXh
YKXIIa5Im8EBEmdnCv1HtmTrGjMoyzOFvNLGjAIbBpG0U+KizZAVpLgw+JMP
KS7mNS2rZEQMnk8gBnJRIVevX8ebwXtsWlMX0jjp76m/wovB5vEwNpE0uia3
uXi5MUiz7jdU0njh86QWz57Bb9xIYBjcteblpx1mDNpHk4bs900tXtIKBoPZ
bivfMZiWPu6ycC6DVwk+RjyM3vkLvWCSxudLCDA8DLbHjoZmGnvsSaB56NUU
6Jz8iEYNNl1plnxcfsPKOimBxvUEp1Q+/regQ1f5AI2eHSRwfGxtLNypu4nG
M+x0o45yGFSskT5vEY23rQlwcjhT7bNeu5+LdcFdLLHymPqBcz+S9Usizbc8
PjOIjcuK5aKwiQiWR2HEcrPFnuzepHlXwMQn4vyMVVwMInYEKmCUzevHxhQX
ZflXQO8XxhaatRQ+JXKFilibxNtQnk2hjAdF7AgTpXadplCZtGtQxLKJ+eNm
fhTK+JiFkSYxuhedKPyRxD96Fk5fECqetqVQxsssLDkw2ZOwncIsEl8zJZx2
iIsWeFIo40cJjxlyX1PHKRwl8RtWwvW396bb5VAo40kZs7ocvjzuodBSet+U
8bX9otQJEy76S/lSQauAg4fuJXMxrpccEBUM0nFXS1OlUcabCho45viGx9PY
Ss6puir6XxI1ClcyKONPFZ9eU71wlPX5O+mBVMVes7WKR9N4KLu3Agy435y+
KpSP30t5E+BW8/r0JwFyWE3W4ydAvkPTdpsQeZTKTxCgMR1joHZNAceIvDIB
avkcuWrfpojS8cUC9J1qOucMSriYjKethny58tKQR8oou89qmHeVrz9npypa
EfyD1dAy30L/RZQAG6Q8q+GtqZMaekfVcB9pV6OGde/C33qFqCNHWuqYnmcX
tOG8Bv4PiYfTJg==
       "]]}}, {}, {}, {{}, {}}}, 
   TagBox[InsetBox[
     RowBox[{
      StyleBox[
       RowBox[{
        OverscriptBox["b", "_"], " ", "=", " ", 
        RowBox[{"-", "0.255"}]}],
       FontSize->14], "\n", 
      StyleBox[
       RowBox[{
        OverscriptBox["\[CapitalLambda]", "_"], " ", "=", " ", 
        RowBox[{"-", "0.202"}]}],
       FontSize->14]}], {0.5, 4.5}],
    "InsetString"], 
   TagBox[InsetBox[
     StyleBox[
      RowBox[{
       RowBox[{"no", " ", "back"}], "-", "reaction"}],
      FontSize->16], {2.5, 3.5}],
    "InsetString"], ArrowBox[{{2.89, 3.32}, {3.57, 2.49}}], 
   TagBox[InsetBox[
     RowBox[{
      StyleBox[
       RowBox[{
        RowBox[{"with", " ", "back"}], "-", "reaction"}],
       FontSize->16,
       FontWeight->"Plain"], "\n", 
      StyleBox[
       RowBox[{"(", 
        RowBox[{
         OverscriptBox["\[Kappa]", "_"], " ", "=", " ", "0.02"}], ")"}],
       FontSize->14]}], {2, 1}],
    "InsetString"], ArrowBox[{{2.56, 1.36}, {3.37, 2.08}}]},
  PlotTheme -> "Scientific",
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{Medium, FontFamily -> "Times", Italic},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox[
    "\"\\!\\(\\*\\nStyleBox[\\\"r\\\",\\nFontSize->12]\\)\"", 
     TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*\\nStyleBox[\\\"E\\\",\\nFontSize->12]\\)\\!\\(\\*\\nStyleBox[\
\\\"/\\\",\\nFontSize->12]\\)\\!\\(\\*\\nStyleBox[\\\"4\\\",\\nFontSize->12]\\\
)\\!\\(\\*\\nStyleBox[\\\"\[Pi]\\\",\\nFontSize->12]\\)\"", TraditionalForm]},
  FrameStyle->Automatic,
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{{0}, {0}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{864., Automatic},
  LabelStyle->Directive[
    GrayLevel[0], FontFamily -> "Times", Medium],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.7563876893526726`*^9, 3.7563882358449163`*^9, 3.756388576389561*^9, 
   3.756731340734888*^9, 3.75673145025978*^9, 3.7567314805842705`*^9, {
   3.756731611993763*^9, 3.7567316409610834`*^9}, 3.756731674735468*^9, 
   3.7567317254939976`*^9, {3.7567398215394254`*^9, 3.7567398322597666`*^9}, 
   3.756740194997674*^9, 3.756740346076479*^9, {3.7567412003762884`*^9, 
   3.756741220714069*^9}, 3.756748726341649*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Export", "[", 
   RowBox[{"\"\<fig8.pdf\>\"", ",", "energ", ",", 
    RowBox[{"ImageResolution", "\[Rule]", "1000"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "Full"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.754947207114312*^9, 3.7549472088176737`*^9}, {
   3.754947528605138*^9, 3.7549476609724255`*^9}, {3.7549478603250203`*^9, 
   3.7549478616947117`*^9}, {3.7563914155770497`*^9, 3.7563914175636816`*^9}, 
   3.7569096295353513`*^9}],

Cell[BoxData["\<\"fig8.pdf\"\>"], "Output",
 CellChangeTimes->{
  3.7563876893838873`*^9, 3.7567317415296717`*^9, 3.756739852587616*^9, 
   3.7567403535004272`*^9, {3.756741278490107*^9, 3.7567412864438066`*^9}, 
   3.756748726987218*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["General Comments",
 FontSize->18]], "Section",
 CellChangeTimes->{{3.756910351224037*^9, 3.756910373270178*^9}},
 Background->RGBColor[1., 0.5019607843137255, 0.25098039215686274`]],

Cell[TextData[StyleBox["All the lists in Figures 4 & 5 have been created \
using slight appropriate variations of the numerical analysis code in the \
support file.",
 FontSize->14]], "Text",
 CellChangeTimes->{{3.7569103818310204`*^9, 3.756910532485437*^9}, {
  3.7569107326931205`*^9, 3.7569107535946665`*^9}, {3.7569110639644485`*^9, 
  3.7569110639644485`*^9}}],

Cell[TextData[StyleBox["The grid plot module must be run first in order to \
correctly produce figures 4, 5 and 6, and to set the directory for figure \
export.  ",
 FontSize->14]], "Text",
 CellChangeTimes->{{3.7569111889732165`*^9, 3.756911193606467*^9}, {
  3.7569117697738867`*^9, 3.7569118186566777`*^9}}]
}, Closed]]
}, Open  ]]
},
WindowSize->{1536, 781},
WindowMargins->{{-8, Automatic}, {Automatic, -8}},
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (September 21, 2016)",
StyleDefinitions->FrontEnd`FileName[{"Book"}, "Textbook.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 468, 13, 115, "Title"],
Cell[CellGroupData[{
Cell[1073, 39, 225, 4, 59, "Section"],
Cell[1301, 45, 6997, 180, 300, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[8335, 230, 311, 6, 39, "Section"],
Cell[CellGroupData[{
Cell[8671, 240, 28209, 781, 1587, "Input"],
Cell[36883, 1023, 50277, 869, 489, "Output"],
Cell[87163, 1894, 113, 1, 29, "Output"]
}, Open  ]],
Cell[87291, 1898, 1671, 22, 29, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[88999, 1925, 165, 3, 39, "Section"],
Cell[CellGroupData[{
Cell[89189, 1932, 10300, 309, 498, "Input"],
Cell[99492, 2243, 14765, 239, 50, "Output"],
Cell[114260, 2484, 24069, 421, 259, "Output"],
Cell[138332, 2907, 712, 10, 29, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[139093, 2923, 162, 3, 39, "Section"],
Cell[139258, 2928, 10482, 308, 498, "Input"],
Cell[CellGroupData[{
Cell[149765, 3240, 466, 13, 29, "Input"],
Cell[150234, 3255, 593662, 10357, 754, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[743933, 13617, 393, 7, 48, "Input"],
Cell[744329, 13626, 109, 1, 29, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[744487, 13633, 162, 3, 39, "Section"],
Cell[744652, 13638, 204, 5, 29, "Input"],
Cell[744859, 13645, 45739, 1321, 552, "Input"],
Cell[CellGroupData[{
Cell[790623, 14970, 13656, 331, 314, "Input"],
Cell[804282, 15303, 18020, 371, 424, "Output"],
Cell[822305, 15676, 767, 11, 29, "Output"],
Cell[823075, 15689, 760, 11, 29, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[823884, 15706, 167, 3, 39, "Section"],
Cell[824054, 15711, 204, 5, 29, "Input"],
Cell[CellGroupData[{
Cell[824283, 15720, 37186, 1094, 692, "Input"],
Cell[861472, 16816, 17304, 370, 424, "Output"],
Cell[878779, 17188, 295, 4, 29, "Output"],
Cell[879077, 17194, 290, 4, 29, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[879416, 17204, 165, 3, 39, "Section"],
Cell[879584, 17209, 30783, 866, 1290, "Input"],
Cell[CellGroupData[{
Cell[910392, 18079, 13667, 375, 277, "Input"],
Cell[924062, 18456, 134292, 2285, 420, "Output"],
Cell[1058357, 20743, 764, 11, 29, "Output"],
Cell[1059124, 20756, 676, 10, 29, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1059849, 20772, 221, 4, 39, "Section"],
Cell[1060073, 20778, 96, 1, 29, "Input"],
Cell[CellGroupData[{
Cell[1060194, 20783, 18909, 545, 1043, "Input"],
Cell[1079106, 21330, 9044, 172, 252, "Output"],
Cell[1088153, 21504, 685, 10, 29, "Output"]
}, Open  ]],
Cell[1088853, 21517, 298, 7, 29, "Input"],
Cell[1089154, 21526, 3761, 99, 210, "Input"],
Cell[CellGroupData[{
Cell[1092940, 21629, 4634, 145, 94, "Input"],
Cell[1097577, 21776, 15449, 290, 569, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1113063, 22071, 500, 9, 48, "Input"],
Cell[1113566, 22082, 238, 4, 29, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1113853, 22092, 205, 3, 39, "Section"],
Cell[1114061, 22097, 365, 6, 24, "Text"],
Cell[1114429, 22105, 310, 5, 24, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)

